<?php
ob_start(); // Start output buffering
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set(timezoneId: 'Asia/Kuala_Lumpur');

$success = false; // Variable to track if the operation was successful
$error = ''; // Variable to hold any error messages

// Fetch user groups from the database
try {
    $groups = $pdo->query('SELECT * FROM user_groups')->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    $error = "Failed to retrieve user groups: " . $e->getMessage(); // Capture any error message
}

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $username = $_POST['username'];
    $password = $_POST['password']; // Password in plaintext
    $role = $_POST['role'];
    $group = $_POST['group'];
    $phone = $_POST['phone'];
    $email = $_POST['email'];
    $active = 1;
    $admin_id = $_POST['admin_id'] ?? null;

    try {
        if ($admin_id) {
            // Fetch the old data before updating
            $stmt = $pdo->prepare('SELECT * FROM admins WHERE id = ?');
            $stmt->execute([$admin_id]);
            $oldData = $stmt->fetch(PDO::FETCH_ASSOC);

            // Update existing admin
            $stmt = $pdo->prepare('UPDATE admins SET username = ?, password = ?, role = ?, user_group = ?, phone = ?, email = ?, active = ? WHERE id = ?');
            $stmt->execute([$username, $password, $role, $group, $phone, $email, $active, $admin_id]);

            // Compare old and new data to find changes
            $changes = [];
            if ($oldData['username'] !== $username) {
                $changes['username'] = "Username: {$oldData['username']} → $username";
            }
            if ($oldData['password'] !== $password) {
                $changes['password'] = "Password: {$oldData['password']} → $password"; // Log plaintext password
            }
            if ($oldData['role'] !== $role) {
                $changes['role'] = "Role: {$oldData['role']} → $role";
            }
            if ($oldData['user_group'] !== $group) {
                $changes['user_group'] = "Group: {$oldData['user_group']} → $group";
            }
            if ($oldData['phone'] !== $phone) {
                $changes['phone'] = "Phone: {$oldData['phone']} → $phone";
            }
            if ($oldData['email'] !== $email) {
                $changes['email'] = "Email: {$oldData['email']} → $email";
            }

            // Prepare the log message with only the changes
            $logMessage = "Updated admin with ID: $admin_id\n";
            if (!empty($changes)) {
                $logMessage .= "Changes:\n" . implode("\n", $changes);
            } else {
                $logMessage .= "No changes detected.";
            }
        } else {
            // Insert new admin
            $stmt = $pdo->prepare('INSERT INTO admins (username, password, role, user_group, phone, email, active) VALUES (?, ?, ?, ?, ?, ?, ?)');
            $stmt->execute([$username, $password, $role, $group, $phone, $email, $active]);

            // Prepare the log message for new data
            $logMessage = "Added new admin: $username\n";
            $logMessage .= "New Data: " . json_encode([
                'username' => $username,
                'password' => $password, // Include plaintext password
                'role' => $role,
                'user_group' => $group,
                'phone' => $phone,
                'email' => $email,
                'active' => $active
            ]);
        }
        $success = true; // Mark success if operation was successful

        // Log the activity
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);
    } catch (PDOException $e) {
        $error = "Failed to add/update admin: " . $e->getMessage(); // Capture any error message
    }
}

// Handle actions like edit and deactivate
if (isset($_GET['action'])) {
    $action = $_GET['action'];
    $admin_id = $_GET['id'];

    if ($action === 'deactivate') {
        // Fetch the current active status of the user
        $stmt = $pdo->prepare('SELECT username, active FROM admins WHERE id = ?');
        $stmt->execute([$admin_id]);
        $user = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($user) {
            // Check if the user being deactivated is the currently logged-in user
            if ($admin_id == $_SESSION['admin_id']) { // Ensure this comparison is correct
                $_SESSION['deactivation_message'] = "You cannot deactivate your own account.";
            } else {
                // Toggle the active status
                $newActiveStatus = $user['active'] ? 0 : 1;
                $stmt = $pdo->prepare('UPDATE admins SET active = ? WHERE id = ?');
                $stmt->execute([$newActiveStatus, $admin_id]);

                // Prepare the log message with old and new status
                $logMessage = "Toggled active status for user '{$user['username']}'\n";
                $logMessage .= "Old Status: " . ($user['active'] ? 'Active' : 'Inactive') . "\n";
                $logMessage .= "New Status: " . ($newActiveStatus ? 'Active' : 'Inactive');

                // Log the activity
                $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                           VALUES (:username, :timestamp, :role, :activity)";
                $stmtLog = $pdo->prepare($sqlLog);
                $stmtLog->execute([
                    ':username' => $_SESSION['username'],
                    ':timestamp' => date('Y-m-d H:i:s'),
                    ':role' => $_SESSION['role'],
                    ':activity' => $logMessage
                ]);

                // Set the appropriate message based on the new status
                if ($newActiveStatus) {
                    $_SESSION['deactivation_message'] = "User '{$user['username']}' has been activated.";
                } else {
                    $_SESSION['deactivation_message'] = "User '{$user['username']}' has been deactivated.";
                }
            }
        }

        header('Location: manage_admins.php');
        exit();
    }

    if ($action === 'edit') {
        $stmt = $pdo->prepare('SELECT * FROM admins WHERE id = ?');
        $stmt->execute([$admin_id]);
        $editUser = $stmt->fetch(PDO::FETCH_ASSOC);
    }
}

// Fetch all admins from the database
$admins = $pdo->query('SELECT * FROM admins')->fetchAll(PDO::FETCH_ASSOC);
ob_end_flush(); // Flush the output buffer and send output
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Admins</title>
    <!-- Bootstrap 5.x CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-4">
        <h1 class="mb-4">Manage Admins</h1>
        <!-- Card for Form Fields -->
        <div class="card mb-3">
            <div class="card-header">
                <h5 class="card-title">Admin Details</h5>
            </div>
            <div class="card-body">
                <form method="POST" action="">
                    <input type="hidden" name="admin_id" value="<?php echo htmlspecialchars($editUser['id'] ?? ''); ?>">
                    
                    <div class="row">
                        <div class="col-md-6">
                            <!-- Username Field -->
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="username" name="username" placeholder="Username" required value="<?php echo htmlspecialchars($editUser['username'] ?? ''); ?>">
                                <label for="username">Username</label>
                            </div>

                            <!-- Password Field -->
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="password" name="password" placeholder="Password" value="<?php echo htmlspecialchars($editUser['password'] ?? ''); ?>">
                                <label for="password">Password</label>
                            </div>

                            <!-- Role Field -->
                            <div class="form-floating mb-3">
                                <select class="form-select" id="role" name="role" required>
                                    <option value="">Select a role</option>
                                    <option value="super_admin" <?php if (!empty($editUser['role']) && $editUser['role'] == 'super_admin') echo 'selected'; ?>>Super Admin</option>
                                    <option value="admin" <?php if (!empty($editUser['role']) && $editUser['role'] == 'admin') echo 'selected'; ?>>Admin</option>
                                    <option value="user" <?php if (!empty($editUser['role']) && $editUser['role'] == 'user') echo 'selected'; ?>>User</option>
                                </select>
                                <label for="role">Role</label>
                            </div>
                        </div>

                        <div class="col-md-6">
                            <!-- Group Field -->
                            <div class="form-floating mb-3">
                                <select class="form-select" id="group" name="group" required>
                                    <option value="">Select a group</option>
                                    <?php foreach ($groups as $group): ?>
                                        <option value="<?php echo htmlspecialchars($group['user_group']); ?>" <?php if (!empty($editUser['user_group']) && $editUser['user_group'] == $group['user_group']) echo 'selected'; ?>><?php echo htmlspecialchars($group['user_group']); ?></option>
                                    <?php endforeach; ?>
                                </select>
                                <label for="group">Group</label>
                            </div>

                            <!-- Phone Field -->
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="phone" name="phone" placeholder="Phone" required value="<?php echo htmlspecialchars($editUser['phone'] ?? ''); ?>">
                                <label for="phone">Phone</label>
                            </div>

                            <!-- Email Field -->
                            <div class="form-floating mb-3">
                                <input type="email" class="form-control" id="email" name="email" placeholder="Email" required value="<?php echo htmlspecialchars($editUser['email'] ?? ''); ?>">
                                <label for="email">Email</label>
                            </div>
                        </div>
                    </div>

                    <!-- Submit Button -->
                    <button type="submit" class="btn btn-primary"><?php echo isset($editUser) ? 'Update Admin' : 'Add Admin'; ?></button>
                </form>
            </div>
        </div>

        <!-- Admin List Table -->
        <h2 class="mt-5 mb-3">Admin List</h2>
        <table class="table table-striped">
            <thead>
                <tr>
                    <th>Username</th>
                    <th>Role</th>
                    <th>Group</th>
                    <th>Phone</th>
                    <th>Email</th>
                    <th>Active</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php if (!empty($admins)): ?>
                    <?php foreach ($admins as $admin): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($admin['username']); ?></td>
                            <td><?php echo htmlspecialchars($admin['role']); ?></td>
                            <td><?php echo htmlspecialchars($admin['user_group']); ?></td>
                            <td><?php echo htmlspecialchars($admin['phone']); ?></td>
                            <td><?php echo htmlspecialchars($admin['email']); ?></td>
                            <td><?php echo $admin['active'] ? 'Yes' : 'No'; ?></td>
                            <td>
                                <a href="?action=edit&id=<?php echo htmlspecialchars($admin['id']); ?>" class="btn btn-warning btn-sm">Edit</a> 
                                <a href="?action=deactivate&id=<?php echo htmlspecialchars($admin['id']); ?>" class="btn btn-info btn-sm"><?php echo $admin['active'] ? 'Deactivate' : 'Activate'; ?></a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="8" class="text-center">No admins found</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <!-- Bootstrap 5.x JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <!-- JavaScript to handle success or failure -->
    <?php if ($success): ?>
        <script>
            alert('Admin added/updated successfully!');
            window.location.href = 'manage_admins.php'; // Redirect to manage admins page
        </script>
    <?php endif; ?>

    <!-- JavaScript to display activation/deactivation alert -->
    <?php if (isset($_SESSION['deactivation_message'])): ?>
        <script>
            alert("<?php echo $_SESSION['deactivation_message']; ?>");
        </script>
        <?php unset($_SESSION['deactivation_message']); // Clear the message after displaying ?>
    <?php endif; ?>
</body>
</html>
