<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Function to fetch all groups
function fetchGroups($pdo) {
    $stmt = $pdo->query("SELECT * FROM user_groups");
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Function to log activity
function logActivity($pdo, $activity) {
    $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
               VALUES (:username, :timestamp, :role, :activity)";
    $stmtLog = $pdo->prepare($sqlLog);
    $stmtLog->execute([
        ':username' => $_SESSION['username'],
        ':timestamp' => date('Y-m-d H:i:s'),
        ':role' => $_SESSION['role'],
        ':activity' => $activity
    ]);
}

// Insert Group
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['insert_group'])) {
    $group_name = $_POST['group_name'];
    $sql = "INSERT INTO user_groups (user_group) VALUES (:group_name)";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':group_name', $group_name);
    if ($stmt->execute()) {
        // Log the activity
        $logMessage = "Group '$group_name' added";
        logActivity($pdo, $logMessage);

        echo "<script>alert('Group inserted successfully!');</script>";
    } else {
        echo "<script>alert('Error: " . $stmt->errorInfo()[2] . "');</script>";
    }
}

// Delete Group
if ($_SERVER["REQUEST_METHOD"] == "POST" && isset($_POST['delete_group'])) {
    $group_id = $_POST['group_id'];
    
    // Fetch the group name before deleting
    $sqlFetch = "SELECT user_group FROM user_groups WHERE id = :group_id";
    $stmtFetch = $pdo->prepare($sqlFetch);
    $stmtFetch->bindParam(':group_id', $group_id);
    $stmtFetch->execute();
    $group = $stmtFetch->fetch(PDO::FETCH_ASSOC);
    $group_name = $group['user_group'];

    // Delete the group
    $sql = "DELETE FROM user_groups WHERE id=:group_id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':group_id', $group_id);
    if ($stmt->execute()) {
        // Log the activity
        $logMessage = "Group '$group_name' deleted";
        logActivity($pdo, $logMessage);

        echo "<script>alert('Group deleted successfully!');</script>";
    } else {
        echo "<script>alert('Error: " . $stmt->errorInfo()[2] . "');</script>";
    }
}

// Fetch all groups
$groups = fetchGroups($pdo);

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Groups</title>
    <!-- Bootstrap 5.3 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-5">
        <!-- Insert Group Card -->
        <div class="card mb-3">
            <div class="card-header">
                <h5 class="card-title">Insert Group</h5>
            </div>
            <div class="card-body">
                <form method="post" action="">
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="text" name="group_name" class="form-control" id="groupName" placeholder="Group Name" required>
                                <label for="groupName">Group Name</label>
                            </div>
                        </div>
                    </div>
                    <button type="submit" name="insert_group" class="btn btn-primary">Insert Group</button>
                </form>
            </div>
        </div>

        <!-- All Groups Card -->
        <div class="card mb-3">
            <div class="card-header">
                <h5 class="card-title">All Groups</h5>
            </div>
            <div class="card-body">
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>Group Name</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($groups as $group): ?>
                            <tr>
                                <td><?= $group['id'] ?></td>
                                <td><?= $group['user_group'] ?></td>
                                <td>
                                    <form method="post" action="" class="d-inline" onsubmit="return confirmDelete();">
                                        <input type="hidden" name="group_id" value="<?= $group['id'] ?>">
                                        <button type="submit" name="delete_group" class="btn btn-danger">Delete</button>
                                    </form>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS (with Popper included) -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <!-- Confirmation Dialog Script -->
    <script>
        function confirmDelete() {
            return confirm("Are you sure you want to delete this group?");
        }
    </script>
</body>
</html>