<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // Include the encryption function
date_default_timezone_set('Asia/Kuala_Lumpur');

// Initialize variables
$ac_dl_url = $ac_dl_id = $ac_dl_pwd = $ac_rs_pwd_acc = $ac_rs_pwd_pos = $ac_script_update = $ac_supp_number = '';

// Handle form submission for insert
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve form data
    $ac_dl_url = filter_input(INPUT_POST, 'ac_dl_url', FILTER_SANITIZE_STRING);
    $ac_dl_id = filter_input(INPUT_POST, 'ac_dl_id', FILTER_SANITIZE_STRING);
    $ac_dl_pwd = filter_input(INPUT_POST, 'ac_dl_pwd', FILTER_SANITIZE_STRING);
    $ac_rs_pwd_acc = filter_input(INPUT_POST, 'ac_rs_pwd_acc', FILTER_SANITIZE_STRING);
    $ac_rs_pwd_pos = filter_input(INPUT_POST, 'ac_rs_pwd_pos', FILTER_SANITIZE_STRING);
    $ac_script_update = filter_input(INPUT_POST, 'ac_script_update', FILTER_SANITIZE_STRING);
    $ac_supp_number = filter_input(INPUT_POST, 'ac_supp_number', FILTER_SANITIZE_STRING);
    $active = 1;
    $updated_at = date('Y-m-d H:i:s');

    // Encrypt passwords
    $encryptionKey = 'your_secret_key'; // This should be a secure key
    $ac_dl_pwd = encryptPassword($ac_dl_pwd, $encryptionKey);
    $ac_rs_pwd_acc = encryptPassword($ac_rs_pwd_acc, $encryptionKey);
    $ac_rs_pwd_pos = encryptPassword($ac_rs_pwd_pos, $encryptionKey);
    $ac_script_update = encryptPassword($ac_script_update, $encryptionKey);

    // Insert new entry
    $created_at = date('Y-m-d H:i:s');
    $sql = "INSERT INTO citssb_info_account_support (ac_dl_url, ac_dl_id, ac_dl_pwd, ac_rs_pwd_acc, ac_rs_pwd_pos, ac_script_update, ac_supp_number, active, created_at, updated_at) 
            VALUES (:ac_dl_url, :ac_dl_id, :ac_dl_pwd, :ac_rs_pwd_acc, :ac_rs_pwd_pos, :ac_script_update, :ac_supp_number, :active, :created_at, :updated_at)";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':ac_dl_url', $ac_dl_url);
    $stmt->bindParam(':ac_dl_id', $ac_dl_id);
    $stmt->bindParam(':ac_dl_pwd', $ac_dl_pwd);
    $stmt->bindParam(':ac_rs_pwd_acc', $ac_rs_pwd_acc);
    $stmt->bindParam(':ac_rs_pwd_pos', $ac_rs_pwd_pos);
    $stmt->bindParam(':ac_script_update', $ac_script_update);
    $stmt->bindParam(':ac_supp_number', $ac_supp_number);
    $stmt->bindParam(':active', $active);
    $stmt->bindParam(':created_at', $created_at);
    $stmt->bindParam(':updated_at', $updated_at);

    // Execute and check for success
    if ($stmt->execute()) {
        // Log the activity
        $logMessage = "Accounting Support information inserted into CITSSB Info";
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        echo "<script>alert('Data saved successfully!'); window.location.href='account_support_info.php';</script>";
    } else {
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}

// Handle toggle active/inactive action
if (isset($_GET['toggle_active']) && isset($_GET['id'])) {
    $id = filter_input(INPUT_GET, 'id', FILTER_SANITIZE_NUMBER_INT);

    // Fetch the current status
    $sql = "SELECT active FROM citssb_info_account_support WHERE id = :id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':id', $id);
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);

    // Toggle the active status
    if ($row) {
        $newStatus = $row['active'] == 1 ? 0 : 1;

        // Update the database with the new status
        $sql = "UPDATE citssb_info_account_support SET active = :active WHERE id = :id";
        $stmt = $pdo->prepare($sql);
        $stmt->bindParam(':active', $newStatus);
        $stmt->bindParam(':id', $id);

        if ($stmt->execute()) {
            // Log the activity
            $logMessage = "Accounting Support status toggled to " . ($newStatus == 1 ? "active" : "inactive") . " for ID: $id";
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            echo "<script>alert('Status updated successfully!'); window.location.href='account_support_info.php';</script>";
        } else {
            echo "<script>alert('Failed to update status. Please try again.');</script>";
        }
    }
}

// Fetch data from the database
$sql = "SELECT * FROM citssb_info_account_support";
$stmt = $pdo->query($sql);
$data = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add Accounting Support Information</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 5px;
        }
        .password-container span {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 150px;
            overflow: hidden;
        }
        .password-container button {
            background: none;
            border: none;
            padding: 0;
        }
    </style>
</head>
<body>
<div class="container mt-5">
    <!-- Tab Navigation -->
    <ul class="nav nav-tabs" id="myTab" role="tablist">
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="office365-tab" href="/crm/public/citssb_info/o365_info.php" role="tab">Office 365</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="email-tab" href="/crm/public/citssb_info/support_email_info.php" role="tab">Email</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="wifi-tab" href="/crm/public/citssb_info/wifi_info.php" role="tab">WiFi</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="nas-tab" href="/crm/public/citssb_info/nas_info.php" role="tab">NAS</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="hamachi-tab" href="/crm/public/citssb_info/hamachi_info.php" role="tab">Hamachi</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="printer-tab" href="/crm/public/citssb_info/printer_info.php" role="tab">Printer</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="it-support-tab" href="/crm/public/citssb_info/it_support_info.php" role="tab">IT Support</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link active" id="accounting-tab" href="/crm/public/citssb_info/account_support_info.php" role="tab">Accounting</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="user-profile-tab" href="/crm/public/citssb_info/user_profile_info.php" role="tab">User Profile</a>
        </li>
    </ul>
</div>

<!-- Add Accounting Support Information Form -->
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h4 class="mb-0">Add Accounting Support Information</h4>
        </div>
        <div class="card-body">
            <form method="POST" action="">
                <!-- Autocount Dealer Space Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Autocount Dealer Space</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <!-- URL -->
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="ac_dl_url" name="ac_dl_url" placeholder="URL" value="<?= htmlspecialchars($ac_dl_url) ?>" required>
                                    <label for="ac_dl_url">URL</label>
                                </div>
                            </div>

                            <!-- Login ID -->
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="ac_dl_id" name="ac_dl_id" placeholder="Login ID" value="<?= htmlspecialchars($ac_dl_id) ?>" required>
                                    <label for="ac_dl_id">Login ID</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <!-- Password -->
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="ac_dl_pwd" name="ac_dl_pwd" placeholder="Password" value="<?= htmlspecialchars($ac_dl_pwd) ?>" required>
                                    <label for="ac_dl_pwd">Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Support Phone Number Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Support Phone Number</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <!-- Support Phone Number -->
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="ac_supp_number" name="ac_supp_number" placeholder="Support Phone Number" value="<?= htmlspecialchars($ac_supp_number) ?>" required>
                                    <label for="ac_supp_number">Support Phone Number</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Autocount Reset Password Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Autocount Reset Password</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <!-- Account Reset Password -->
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="ac_rs_pwd_acc" name="ac_rs_pwd_acc" placeholder="Account Reset Password" value="<?= htmlspecialchars($ac_rs_pwd_acc) ?>" required>
                                    <label for="ac_rs_pwd_acc">Account Reset Password</label>
                                </div>
                            </div>

                            <!-- POS Reset Password -->
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="ac_rs_pwd_pos" name="ac_rs_pwd_pos" placeholder="POS Reset Password" value="<?= htmlspecialchars($ac_rs_pwd_pos) ?>" required>
                                    <label for="ac_rs_pwd_pos">POS Reset Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Autocount Script Update Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Autocount Script Update</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <!-- Password -->
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="ac_script_update" name="ac_script_update" placeholder="Password" value="<?= htmlspecialchars($ac_script_update) ?>" required>
                                    <label for="ac_script_update">Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Buttons -->
                <div class="d-flex justify-content-center mt-3">
                    <button type="submit" class="btn btn-primary mr-2">Save</button>
                    <a href="account_support_info.php" class="btn btn-secondary">Cancel</a>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Autocount Support Information Table -->
<div class="container mt-5">
    <h2 class="mb-4">Autocount Support Information Table</h2>
    <table class="table table-bordered">
        <thead>
            <tr>
                <th>URL</th>
                <th>Login ID</th>
                <th>Password</th>
                <th>Account Reset Password</th>
                <th>POS Reset Password</th>
                <th>Script Update Password</th>
                <th>Support Phone Number</th>
                <th>Updated At</th>
                <th>Action</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($data as $row): ?>
                <tr>
                    <td><?= htmlspecialchars($row['ac_dl_url']) ?></td>
                    <td><?= htmlspecialchars($row['ac_dl_id']) ?></td>
                    <td>
                        <div class="password-container">
                            <span id="pwd_<?= $row['id'] ?>">*******</span>
                            <button class="btn btn-sm btn-link p-0" onclick="togglePassword('pwd_<?= $row['id'] ?>', '<?= $row['ac_dl_pwd'] ?>', 'your_secret_key')">
                                <i class="bi bi-eye"></i>
                            </button>
                        </div>
                    </td>
                    <td>
                        <div class="password-container">
                            <span id="rs_pwd_acc_<?= $row['id'] ?>">*******</span>
                            <button class="btn btn-sm btn-link p-0" onclick="togglePassword('rs_pwd_acc_<?= $row['id'] ?>', '<?= $row['ac_rs_pwd_acc'] ?>', 'your_secret_key')">
                                <i class="bi bi-eye"></i>
                            </button>
                        </div>
                    </td>
                    <td>
                        <div class="password-container">
                            <span id="rs_pwd_pos_<?= $row['id'] ?>">*******</span>
                            <button class="btn btn-sm btn-link p-0" onclick="togglePassword('rs_pwd_pos_<?= $row['id'] ?>', '<?= $row['ac_rs_pwd_pos'] ?>', 'your_secret_key')">
                                <i class="bi bi-eye"></i>
                            </button>
                        </div>
                    </td>
                    <td>
                        <div class="password-container">
                            <span id="script_update_<?= $row['id'] ?>">*******</span>
                            <button class="btn btn-sm btn-link p-0" onclick="togglePassword('script_update_<?= $row['id'] ?>', '<?= $row['ac_script_update'] ?>', 'your_secret_key')">
                                <i class="bi bi-eye"></i>
                            </button>
                        </div>
                    </td>
                    <td><?= htmlspecialchars($row['ac_supp_number']) ?></td>
                    <td><?= htmlspecialchars($row['updated_at']) ?></td>
                    <td>
                        <a href="?toggle_active=1&id=<?= $row['id'] ?>" class="btn btn-<?= $row['active'] ? 'danger' : 'success' ?>">
                            <?= $row['active'] ? 'Inactive' : 'Active' ?>
                        </a>
                    </td>
                </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
</div>

<!-- Bootstrap 5.x JS -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script>
    function togglePassword(spanId, encryptedPassword, key) {
        var passwordSpan = document.getElementById(spanId);
        var eyeIcon = passwordSpan.nextElementSibling.querySelector('i');

        if (passwordSpan.innerText === '*******') {
            var xhr = new XMLHttpRequest();
            xhr.onreadystatechange = function() {
                if (xhr.readyState == 4 && xhr.status == 200) {
                    passwordSpan.innerText = xhr.responseText;
                    eyeIcon.classList.remove('bi-eye');
                    eyeIcon.classList.add('bi-eye-slash');
                }
            };
            xhr.open("POST", "../functions/decrypt.php", true);
            xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
            xhr.send("encryptedPassword=" + encodeURIComponent(encryptedPassword) + "&key=" + encodeURIComponent(key));
        } else {
            passwordSpan.innerText = '*******';
            eyeIcon.classList.remove('bi-eye-slash');
            eyeIcon.classList.add('bi-eye');
        }
    }
</script>

