<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // Include the encryption function
date_default_timezone_set('Asia/Kuala_Lumpur');

// Initialize variables
$active = 1; // Set active to 1 by default

// Handle form submission for insert
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate required fields
    $requiredFields = ['company', 'acc_url', 'acc_title', 'acc_id', 'acc_pwd', 'toll_free'];
    $missingFields = [];

    foreach ($requiredFields as $field) {
        if (empty($_POST[$field])) {
            $missingFields[] = $field;
        }
    }

    if (!empty($missingFields)) {
        echo "<script>alert('Please fill out the following required fields: " . implode(', ', $missingFields) . "');</script>";
    } else {
        $updated_at = date('Y-m-d H:i:s');
        $created_at = date('Y-m-d H:i:s');

        // Get the selected company
        $company = $_POST['company'];

        // Encrypt the password
        $encryption_key = 'your_secret_key'; // Replace with your actual secret key
        $encrypted_password = encryptPassword($_POST['acc_pwd'], $encryption_key);

        // Dynamically set the parameters based on the selected company
        $sql = "INSERT INTO citssb_info_it_support (company, acc_url, acc_title, acc_id, acc_pwd, toll_free, active, created_at, updated_at) 
                VALUES (:company, :acc_url, :acc_title, :acc_id, :acc_pwd, :toll_free, :active, :created_at, :updated_at)";

        $stmt = $pdo->prepare($sql);
        $stmt->bindParam(':company', $company);
        $stmt->bindParam(':acc_url', $_POST['acc_url']);
        $stmt->bindParam(':acc_title', $_POST['acc_title']);
        $stmt->bindParam(':acc_id', $_POST['acc_id']);
        $stmt->bindParam(':acc_pwd', $encrypted_password); // Use the encrypted password
        $stmt->bindParam(':toll_free', $_POST['toll_free']);
        $stmt->bindParam(':active', $active);
        $stmt->bindParam(':created_at', $created_at);
        $stmt->bindParam(':updated_at', $updated_at);

        if ($stmt->execute()) {
            // Log the activity
            $logMessage = "IT Support information inserted into CITSSB Info";
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            echo "<script>alert('Data saved successfully!'); window.location.href='it_support_info.php';</script>";
        } else {
            echo "<script>alert('Failed to save data. Please try again.');</script>";
        }
    }
}

// Handle toggle active/inactive action
if (isset($_GET['toggle_active']) && isset($_GET['id'])) {
    $id = filter_input(INPUT_GET, 'id', FILTER_SANITIZE_NUMBER_INT);

    // Fetch the current status
    $sql = "SELECT active FROM citssb_info_it_support WHERE id = :id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':id', $id);
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);

    // Toggle the active status
    if ($row) {
        $newStatus = $row['active'] == 1 ? 0 : 1;

        // Update the database with the new status
        $sql = "UPDATE citssb_info_it_support SET active = :active WHERE id = :id";
        $stmt = $pdo->prepare($sql);
        $stmt->bindParam(':active', $newStatus);
        $stmt->bindParam(':id', $id);

        if ($stmt->execute()) {
            // Log the activity
            $logMessage = "IT Support status toggled to " . ($newStatus == 1 ? "active" : "inactive") . " for ID: $id";
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            echo "<script>alert('Status updated successfully!'); window.location.href='it_support_info.php';</script>";
        } else {
            echo "<script>alert('Failed to update status. Please try again.');</script>";
        }
    }
}

// Fetch data from the database
$sql = "SELECT * FROM citssb_info_it_support";
$stmt = $pdo->query($sql);
$data = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add IT Support Information</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
    </style>
</head>
<body>
<div class="container mt-5">
    <!-- Tab Navigation -->
    <ul class="nav nav-tabs" id="myTab" role="tablist">
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="office365-tab" href="/crm/public/citssb_info/o365_info.php" role="tab">Office 365</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="email-tab" href="/crm/public/citssb_info/support_email_info.php" role="tab">Email</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="wifi-tab" href="/crm/public/citssb_info/wifi_info.php" role="tab">WiFi</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="nas-tab" href="/crm/public/citssb_info/nas_info.php" role="tab">NAS</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="hamachi-tab" href="/crm/public/citssb_info/hamachi_info.php" role="tab">Hamachi</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="printer-tab" href="/crm/public/citssb_info/printer_info.php" role="tab">Printer</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link active" id="it-support-tab" href="/crm/public/citssb_info/it_support_info.php" role="tab">IT Support</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="accounting-tab" href="/crm/public/citssb_info/account_support_info.php" role="tab">Accounting</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="user-profile-tab" href="/crm/public/citssb_info/user_profile_info.php" role="tab">User Profile</a>
        </li>
    </ul>
</div>

<!-- Add IT Support Information Form -->
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h4 class="mb-0">Add IT Support Information</h4>
        </div>
        <div class="card-body">
            <form method="POST" action="">
                <!-- Select Company -->
                <div class="form-floating mb-3">
                    <select class="form-control" id="company" name="company" required>
                        <option value="cisco">Cisco</option>
                        <option value="hp">HP</option>
                        <option value="dell">Dell</option>
                        <option value="lenovo">Lenovo</option>
                        <option value="asus">Asus</option>
                        <option value="acer">Acer</option>
                        <option value="huawei">Huawei</option>
                        <option value="fortinet">Fortinet</option>
                    </select>
                    <label for="company">Select Company</label>
                </div>

                <!-- Account Information Card -->
                <div class="row">
                    <div class="col-md-12 mb-4">
                        <div class="card">
                            <div class="card-header">
                                <h3 class="mb-0" id="account-info-header">Cisco Account Information</h3>
                            </div>
                            <div class="card-body">
                                <!-- Form Row for Two Columns -->
                                <div class="row">
                                    <!-- Account URL -->
                                    <div class="col-md-6">
                                        <div class="form-floating mb-3">
                                            <input type="text" class="form-control" id="acc_url" name="acc_url" placeholder="Account URL" required>
                                            <label for="acc_url">Account URL</label>
                                        </div>
                                    </div>

                                    <!-- Account Title -->
                                    <div class="col-md-6">
                                        <div class="form-floating mb-3">
                                            <input type="text" class="form-control" id="acc_title" name="acc_title" placeholder="Account Title" required>
                                            <label for="acc_title">Account Title</label>
                                        </div>
                                    </div>
                                </div>

                                <!-- Form Row for Two Columns -->
                                <div class="row">
                                    <!-- Account ID -->
                                    <div class="col-md-6">
                                        <div class="form-floating mb-3">
                                            <input type="text" class="form-control" id="acc_id" name="acc_id" placeholder="Account ID" required>
                                            <label for="acc_id">Account ID</label>
                                        </div>
                                    </div>

                                    <!-- Account Password -->
                                    <div class="col-md-6">
                                        <div class="form-floating mb-3">
                                            <input type="password" class="form-control" id="acc_pwd" name="acc_pwd" placeholder="Account Password" required>
                                            <label for="acc_pwd">Account Password</label>
                                        </div>
                                    </div>
                                </div>

                                <!-- Toll Free Number -->
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-floating mb-3">
                                            <input type="text" class="form-control" id="toll_free" name="toll_free" placeholder="Toll Free Number" required>
                                            <label for="toll_free">Toll Free Number</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Buttons -->
                <div class="d-flex justify-content-center mt-4">
                    <button type="submit" class="btn btn-primary mr-2">Save</button>
                    <a href="it_support_info.php" class="btn btn-secondary">Cancel</a>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- IT Support Information Table -->
<div class="container mt-5">
    <h2 class="mb-4">IT Support Information Table</h2>
    <table class="table table-bordered">
        <thead>
            <tr>
                <th>ID</th>
                <th>Company</th>
                <th>Account URL</th>
                <th>Account Title</th>
                <th>Account ID</th>
                <th>Account Password</th>
                <th>Toll Free Number</th>
                <th>Active</th>
                <th>Created At</th>
                <th>Updated At</th>
                <th>Action</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($data as $row): ?>
                <tr>
                    <td><?= htmlspecialchars($row['id'] ?? '') ?></td>
                    <td><?= htmlspecialchars($row['company'] ?? '') ?></td>
                    <td><?= htmlspecialchars($row['acc_url'] ?? '') ?></td>
                    <td><?= htmlspecialchars($row['acc_title'] ?? '') ?></td>
                    <td><?= htmlspecialchars($row['acc_id'] ?? '') ?></td>
                    <td>
                        <div class="password-container">
                            <div class="password-field" data-encrypted-password="<?= htmlspecialchars($row['acc_pwd'] ?? '') ?>">******</div>
                            <button class="btn btn-link p-0 toggle-password-btn" onclick="togglePasswordField(this)">
                                <i class="bi bi-eye"></i>
                            </button>
                        </div>
                    </td>
                    <td><?= htmlspecialchars($row['toll_free'] ?? '') ?></td>
                    <td><?= isset($row['active']) && $row['active'] ? 'Active' : 'Inactive' ?></td>
                    <td><?= htmlspecialchars($row['created_at'] ?? '') ?></td>
                    <td><?= htmlspecialchars($row['updated_at'] ?? '') ?></td>
                    <td>
                        <a href="?toggle_active=1&id=<?= htmlspecialchars($row['id'] ?? '') ?>" class="btn btn-<?= isset($row['active']) && $row['active'] ? 'danger' : 'success' ?>">
                            <?= isset($row['active']) && $row['active'] ? 'Inactive' : 'Active' ?>
                        </a>
                    </td>
                </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
</div>

<!-- Bootstrap 5.x JS -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script>
    // Toggle password visibility in the form
    function togglePassword(fieldId) {
        const passwordField = document.getElementById(fieldId);
        const toggleButton = passwordField.nextElementSibling.querySelector('i');
        if (passwordField.type === 'password') {
            passwordField.type = 'text';
            toggleButton.classList.replace('bi-eye', 'bi-eye-slash');
        } else {
            passwordField.type = 'password';
            toggleButton.classList.replace('bi-eye-slash', 'bi-eye');
        }
    }

    // Toggle password visibility in the table
    function togglePasswordField(button) {
        const passwordField = button.previousElementSibling;
        const encryptedPassword = passwordField.getAttribute('data-encrypted-password');

        if (passwordField.innerText === '******') {
            // Send an AJAX request to decrypt the password
            fetch('../functions/decrypt.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded',
                },
                body: `encryptedPassword=${encodeURIComponent(encryptedPassword)}`,
            })
            .then(response => response.text())
            .then(decryptedPassword => {
                passwordField.innerText = decryptedPassword;
                button.innerHTML = '<i class="bi bi-eye-slash"></i>';
            })
            .catch(error => {
                console.error('Error:', error);
                alert('Failed to decrypt password.');
            });
        } else {
            passwordField.innerText = '******';
            button.innerHTML = '<i class="bi bi-eye"></i>';
        }
    }

    // Update account information header based on selected company
    document.getElementById('company').addEventListener('change', function() {
        var selectedCompany = this.value.charAt(0).toUpperCase() + this.value.slice(1);
        document.getElementById('account-info-header').innerText = selectedCompany + ' Account Information';
    });
</script>
</body>
</html>

