<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // Include the encryption function
date_default_timezone_set('Asia/Kuala_Lumpur');

// Initialize variables
$printer_color_pwd = '';
$active = 1; // Set active to 1 by default

// Handle form submission for insert
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve form data
    $printer_color_pwd = filter_input(INPUT_POST, 'printer_color_pwd', FILTER_SANITIZE_STRING);
    $updated_at = date('Y-m-d H:i:s');

    // Encrypt the password
    $encryption_key = 'your_secret_key'; // Replace with your actual secret key
    $encrypted_password = encryptPassword($printer_color_pwd, $encryption_key);

    // Insert new entry
    $created_at = date('Y-m-d H:i:s');
    $sql = "INSERT INTO citssb_info_printer (printer_color_pwd, active, created_at, updated_at) 
            VALUES (:printer_color_pwd, :active, :created_at, :updated_at)";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':printer_color_pwd', $encrypted_password); // Use the encrypted password
    $stmt->bindValue(':active', 1); // Always insert 1 for active
    $stmt->bindParam(':created_at', $created_at);
    $stmt->bindParam(':updated_at', $updated_at);

    // Execute and check for success
    if ($stmt->execute()) {
        // Log the activity
        $logMessage = "Printer information inserted into CITSSB Info";
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        echo "<script>alert('Data saved successfully!'); window.location.href='printer_info.php';</script>";
    } else {
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}

// Handle toggle active/inactive action
if (isset($_GET['toggle_active']) && isset($_GET['id'])) {
    $id = filter_input(INPUT_GET, 'id', FILTER_SANITIZE_NUMBER_INT);

    // Fetch the current status
    $sql = "SELECT active FROM citssb_info_printer WHERE id = :id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':id', $id);
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);

    // Toggle the active status
    if ($row) {
        $newStatus = $row['active'] == 1 ? 0 : 1;

        // Update the database with the new status
        $sql = "UPDATE citssb_info_printer SET active = :active WHERE id = :id";
        $stmt = $pdo->prepare($sql);
        $stmt->bindParam(':active', $newStatus);
        $stmt->bindParam(':id', $id);

        if ($stmt->execute()) {
            // Log the activity
            $logMessage = "Printer status toggled to " . ($newStatus == 1 ? "active" : "inactive") . " for ID: $id";
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            echo "<script>alert('Status updated successfully!'); window.location.href='printer_info.php';</script>";
        } else {
            echo "<script>alert('Failed to update status. Please try again.');</script>";
        }
    }
}

// Fetch data from the database
$sql = "SELECT * FROM citssb_info_printer";
$stmt = $pdo->query($sql);
$data = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add Printer Information</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
    </style>
</head>
<body>
<div class="container mt-5">
    <!-- Tab Navigation -->
    <ul class="nav nav-tabs" id="myTab" role="tablist">
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="office365-tab" href="/crm/public/citssb_info/o365_info.php" role="tab">Office 365</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="email-tab" href="/crm/public/citssb_info/support_email_info.php" role="tab">Email</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="wifi-tab" href="/crm/public/citssb_info/wifi_info.php" role="tab">WiFi</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="nas-tab" href="/crm/public/citssb_info/nas_info.php" role="tab">NAS</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="hamachi-tab" href="/crm/public/citssb_info/hamachi_info.php" role="tab">Hamachi</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link active" id="printer-tab" href="/crm/public/citssb_info/printer_info.php" role="tab">Printer</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="it-support-tab" href="/crm/public/citssb_info/it_support_info.php" role="tab">IT Support</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="accounting-tab" href="/crm/public/citssb_info/account_support_info.php" role="tab">Accounting</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="user-profile-tab" href="/crm/public/citssb_info/user_profile_info.php" role="tab">User Profile</a>
        </li>
    </ul>
</div>

<!-- Add Printer Information Form -->
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h4 class="mb-0">Add Printer Information</h4>
        </div>
        <div class="card-body">
            <form method="POST" action="">
                <!-- Form Row for Two Columns (if needed) -->
                <div class="row">
                    <!-- Printer Color Password -->
                    <div class="col-md-6">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="printer_color_pwd" name="printer_color_pwd" placeholder="Printer Color Password" value="<?= htmlspecialchars($printer_color_pwd) ?>" required>
                            <label for="printer_color_pwd">Printer Color Password</label>
                        </div>
                    </div>
                </div>

                <!-- Buttons -->
                <div class="d-flex justify-content-center mt-4">
                    <button type="submit" class="btn btn-primary mr-2">Save</button>
                    <a href="printer_info.php" class="btn btn-secondary">Cancel</a>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Printer Information Table -->
<div class="container mt-5">
    <h2 class="mb-4">Printer Information Table</h2>
    <table class="table table-bordered">
        <thead>
            <tr>
                <th>ID</th>
                <th>Printer Color Password</th>
                <th>Active</th>
                <th>Created At</th>
                <th>Updated At</th>
                <th>Action</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($data as $row): ?>
                <tr>
                    <td><?= htmlspecialchars($row['id']) ?></td>
                    <td>
                        <div class="password-container">
                            <div class="password-field" data-encrypted-password="<?= htmlspecialchars($row['printer_color_pwd']) ?>">******</div>
                            <button class="btn btn-link p-0 toggle-password-btn" onclick="togglePasswordField(this)">
                                <i class="bi bi-eye"></i>
                            </button>
                        </div>
                    </td>
                    <td><?= $row['active'] ? 'Active' : 'Inactive' ?></td>
                    <td><?= htmlspecialchars($row['created_at']) ?></td>
                    <td><?= htmlspecialchars($row['updated_at']) ?></td>
                    <td>
                        <a href="?toggle_active=1&id=<?= $row['id'] ?>" class="btn btn-<?= $row['active'] ? 'danger' : 'success' ?>">
                            <?= $row['active'] ? 'Inactive' : 'Active' ?>
                        </a>
                    </td>
                </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
</div>

<!-- Bootstrap 5.x JS -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script>
    // Toggle password visibility in the table
    function togglePasswordField(button) {
        const passwordField = button.previousElementSibling;
        const encryptedPassword = passwordField.getAttribute('data-encrypted-password');

        if (passwordField.innerText === '******') {
            // Send an AJAX request to decrypt the password
            fetch('../functions/decrypt.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded',
                },
                body: `encryptedPassword=${encodeURIComponent(encryptedPassword)}`,
            })
            .then(response => response.text())
            .then(decryptedPassword => {
                passwordField.innerText = decryptedPassword;
                button.innerHTML = '<i class="bi bi-eye-slash"></i>';
            })
            .catch(error => {
                console.error('Error:', error);
                alert('Failed to decrypt password.');
            });
        } else {
            passwordField.innerText = '******';
            button.innerHTML = '<i class="bi bi-eye"></i>';
        }
    }
</script>
</body>
</html>

