<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // Include the encryption function
require '../functions/decrypt.php'; // Include the decryption function
date_default_timezone_set('Asia/Kuala_Lumpur');

$encryption_key = 'your_secret_key'; // Define your encryption key

// Function to fetch all usernames
function fetchAllUsernames($pdo) {
    $sql = "SELECT ci.admin_id, a.username FROM citssb_info_user ci LEFT JOIN admins a ON ci.admin_id = a.id";
    $stmt = $pdo->query($sql);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Function to fetch user information by admin_id
function fetchUserInfo($pdo, $admin_id) {
    $sql = "SELECT ci.*, a.username FROM citssb_info_user ci LEFT JOIN admins a ON ci.admin_id = a.id WHERE ci.admin_id = :admin_id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':admin_id', $admin_id);
    $stmt->execute();
    return $stmt->fetch(PDO::FETCH_ASSOC);
}

// Function to fetch additional information
function fetchAdditionalInfo($pdo, $tables) {
    $additional_info = [];
    foreach ($tables as $table => $fields) {
        $sql = "SELECT " . implode(', ', $fields) . " FROM $table WHERE active = 1";
        $stmt = $pdo->query($sql);
        $data = $stmt->fetchAll(PDO::FETCH_ASSOC); // Fetch all rows
        if ($data) {
            $additional_info[$table] = $data;
        }
    }
    return $additional_info;
}

// Function to decrypt data
function decrypt($data, $key) {
    return decryptPassword($data, $key);
}

// Helper function to convert active values
function convertActiveValue($value) {
    return $value == 1 ? 'yes' : 'no';
}

// Function to map field names to display names
function mapFieldName($field) {
    $fieldMap = [
        'o365_login_id' => 'Office 365 Login ID',
        'o365_pwd' => 'Office 365 Password',
        'email_login_id' => 'Email Login ID',
        'email_pwd' => 'Email Password',
        'wifi_ssid' => 'WiFi SSID',
        'wifi_pwd' => 'WiFi Password',
        'function' => 'WiFi Function',
        'nas_login_id' => 'NAS Login ID',
        'nas_pwd' => 'NAS Password',
        'nas_tcpip' => 'NAS TCP/IP',
        'nas_url' => 'NAS URL',
        'nas_function' => 'NAS Function',
        'hamachi_login_id' => 'Hamachi Login ID',
        'hamachi_pwd' => 'Hamachi Password',
        'printer_color_pwd' => 'Printer Color Password',
        'computer_login' => 'Computer Login',
        'computer_login_pwd' => 'Computer Login Password',
        'autocount_id' => 'Autocount ID',
        'autocount_pwd' => 'Autocount Password',
        'email_id' => 'Email ID',
        'vtiger_crm_id' => 'Vtiger CRM ID',
        'vtiger_crm_pwd' => 'Vtiger CRM Password',
        'teamviewer_id' => 'Teamviewer ID',
        'teamviewer_pwd' => 'Teamviewer Password',
        'ac_licence_portal_id' => 'Autocount Licence Portal ID',
        'ac_licence_portal_pwd' => 'Autocount Licence Portal Password',
        'vpn_login_id' => 'VPN Login ID',
        'vpn_login_pwd' => 'VPN Login Password',
        'pulseway_login_id' => 'Pulseway Login ID',
        'pulseway_pwd' => 'Pulseway Password',
        'admin_id' => 'Admin ID',
        'active' => 'Active',
        'created_at' => 'Created At',
        'updated_at' => 'Updated At',
        'username' => 'Username',
        'id' => 'ID',
        'company' => 'Company',
        'acc_url' => 'URL',
        'acc_title' => 'Title',
        'acc_id' => 'ID',
        'acc_pwd' => 'Password',
        'toll_free' => 'Toll Free Number',
        'ac_dl_url' => 'Autocount Dealer Portal URL',
        'ac_supp_number' => 'Autocount Support Phone Number',
        'ac_dl_id' => 'Autocount Dealer Login ID',
        'ac_dl_pwd' => 'Autocount Dealer Password',
        'ac_rs_pwd_acc' => 'Autocount Reset Password',
        'ac_rs_pwd_pos' => 'Autocount Reset Password POS',
        'ac_script_update' => 'Autocount Script Update Password',
    ];
    return $fieldMap[$field] ?? ucfirst(str_replace('_', ' ', $field));
}

// Function to map table names to display names
function mapTableName($table) {
    $tableMap = [
        'citssb_info_o365' => 'Office 365 Information',
        'citssb_info_email' => 'Email Information',
        'citssb_info_wifi' => 'WiFi Information',
        'citssb_info_nas' => 'NAS Information',
        'citssb_info_hamachi' => 'Hamachi Information',
        'citssb_info_printer' => 'Printer Information',
        'citssb_info_it_support' => 'IT Support Information',
        'citssb_info_account_support' => 'Accounting/Payroll Support Information',
    ];
    return $tableMap[$table] ?? ucfirst(str_replace('_', ' ', $table));
}

// Initialize variables
$is_super_admin = $_SESSION['role'] == 'super_admin';
$usernames = $is_super_admin ? fetchAllUsernames($pdo) : [];
$selected_admin_id = isset($_POST['admin_id']) ? (int)$_POST['admin_id'] : ($_SESSION['id'] ?? null);

// Ensure the selected admin ID is valid
if (!$is_super_admin && $selected_admin_id != $_SESSION['id']) {
    $selected_admin_id = $_SESSION['id'];
}

$row = $selected_admin_id ? fetchUserInfo($pdo, $selected_admin_id) : null;

if (!$row && $selected_admin_id) {
    echo "<script>alert('User profile information not found.');</script>";
}

// Fetch additional information
$tables = [
    'citssb_info_o365' => ['o365_login_id', 'o365_pwd'],
    'citssb_info_email' => ['email_login_id', 'email_pwd'],
    'citssb_info_wifi' => ['wifi_ssid', 'wifi_pwd', 'function'],
    'citssb_info_nas' => ['nas_login_id', 'nas_pwd', 'nas_tcpip', 'nas_url', 'nas_function'],
    'citssb_info_hamachi' => ['hamachi_login_id', 'hamachi_pwd'],
    'citssb_info_printer' => ['printer_color_pwd']
];
$additional_info = fetchAdditionalInfo($pdo, $tables);

// Fetch IT Support information if user_group is IT Support or super_admin
$it_support_info = [];
if ($_SESSION['user_group'] == 'IT Support' || $_SESSION['role'] == 'super_admin') {
    $sql = "SELECT * FROM citssb_info_it_support WHERE active = 1";
    $stmt = $pdo->query($sql);
    $it_support_info = $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Fetch Accounting/Payroll Support information if user_group is Accounting/Payroll Support or super_admin
$account_support_info = [];
if ($_SESSION['user_group'] == 'Accounting/Payroll Support' || $_SESSION['role'] == 'super_admin') {
    $sql = "SELECT * FROM citssb_info_account_support WHERE active = 1";
    $stmt = $pdo->query($sql);
    $account_support_info = $stmt->fetchAll(PDO::FETCH_ASSOC);
}
?>

<?php
// ... [Previous PHP code remains the same until the HTML section]
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>User Profile</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Custom CSS for additional styling -->
    <style>
        .table thead th {
            background-color: #343a40;
            color: white;
        }
        .table-hover tbody tr:hover {
            background-color: #f8f9fa;
        }
        .btn-sm {
            padding: 0.25rem 0.5rem;
            font-size: 0.875rem;
        }
        .shadow {
            box-shadow: 0 0.5rem 1rem rgba(0, 0, 0, 0.15) !important;
        }
        .section-title {
            font-size: 1.5rem;
            font-weight: bold;
            margin-top: 2rem;
            margin-bottom: 1rem;
            color: #343a40;
        }
    </style>
</head>
<body>
<div class="container mt-5">
    <h2 class="mb-4">User Profile Information</h2>
    <?php if ($is_super_admin): ?>
        <form method="POST" class="mb-4" id="profileForm">
            <div class="form-group">
                <label for="admin_id">Select Username:</label>
                <select class="form-control" id="admin_id" name="admin_id" onchange="document.getElementById('profileForm').submit();">
                    <?php foreach ($usernames as $user): ?>
                        <option value="<?= $user['admin_id'] ?>" <?= $selected_admin_id == $user['admin_id'] ? 'selected' : '' ?>><?= htmlspecialchars($user['username']) ?></option>
                    <?php endforeach; ?>
                </select>
            </div>
        </form>
    <?php endif; ?>

    <?php if ($row): ?>
        <!-- Computer Login Section -->
        <div class="section-title">Computer Login</div>
        <div class="card shadow">
            <div class="card-body">
                <table class="table table-bordered table-striped table-hover">
                    <tbody>
                        <tr>
                            <td>Computer Login</td>
                            <td><?= htmlspecialchars($row['computer_login']) ?></td>
                        </tr>
                        <tr>
                            <td>Computer Login Password</td>
                            <td><?= htmlspecialchars(decrypt($row['computer_login_pwd'], $encryption_key)) ?></td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- Autocount Section -->
        <div class="section-title">Autocount</div>
        <div class="card shadow">
            <div class="card-body">
                <table class="table table-bordered table-striped table-hover">
                    <tbody>
                        <tr>
                            <td>Autocount ID</td>
                            <td><?= htmlspecialchars($row['autocount_id']) ?></td>
                        </tr>
                        <tr>
                            <td>Autocount Password</td>
                            <td><?= htmlspecialchars(decrypt($row['autocount_pwd'], $encryption_key)) ?></td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- Email Section -->
        <div class="section-title">Email</div>
        <div class="card shadow">
            <div class="card-body">
                <table class="table table-bordered table-striped table-hover">
                    <tbody>
                        <tr>
                            <td>Email ID</td>
                            <td><?= htmlspecialchars($row['email_id']) ?></td>
                        </tr>
                        <tr>
                            <td>Email Password</td>
                            <td><?= htmlspecialchars(decrypt($row['email_pwd'], $encryption_key)) ?></td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- Vtiger CRM Section -->
        <div class="section-title">Vtiger CRM</div>
        <div class="card shadow">
            <div class="card-body">
                <table class="table table-bordered table-striped table-hover">
                    <tbody>
                        <tr>
                            <td>Vtiger CRM ID</td>
                            <td><?= htmlspecialchars($row['vtiger_crm_id']) ?></td>
                        </tr>
                        <tr>
                            <td>Vtiger CRM Password</td>
                            <td><?= htmlspecialchars(decrypt($row['vtiger_crm_pwd'], $encryption_key)) ?></td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- Teamviewer Section -->
        <div class="section-title">Teamviewer</div>
        <div class="card shadow">
            <div class="card-body">
                <table class="table table-bordered table-striped table-hover">
                    <tbody>
                        <tr>
                            <td>Teamviewer ID</td>
                            <td><?= htmlspecialchars($row['teamviewer_id']) ?></td>
                        </tr>
                        <tr>
                            <td>Teamviewer Password</td>
                            <td><?= htmlspecialchars(decrypt($row['teamviewer_pwd'], $encryption_key)) ?></td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- Autocount Licence Portal Section -->
        <div class="section-title">Autocount Licence Portal</div>
        <div class="card shadow">
            <div class="card-body">
                <table class="table table-bordered table-striped table-hover">
                    <tbody>
                        <tr>
                            <td>Autocount Licence Portal ID</td>
                            <td><?= htmlspecialchars($row['ac_licence_portal_id']) ?></td>
                        </tr>
                        <tr>
                            <td>Autocount Licence Portal Password</td>
                            <td><?= htmlspecialchars(decrypt($row['ac_licence_portal_pwd'], $encryption_key)) ?></td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- VPN Section -->
        <div class="section-title">VPN</div>
        <div class="card shadow">
            <div class="card-body">
                <table class="table table-bordered table-striped table-hover">
                    <tbody>
                        <tr>
                            <td>VPN Login ID</td>
                            <td><?= htmlspecialchars($row['vpn_login_id']) ?></td>
                        </tr>
                        <tr>
                            <td>VPN Login Password</td>
                            <td><?= htmlspecialchars(decrypt($row['vpn_login_pwd'], $encryption_key)) ?></td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- Pulseway Section -->
        <div class="section-title">Pulseway</div>
        <div class="card shadow">
            <div class="card-body">
                <table class="table table-bordered table-striped table-hover">
                    <tbody>
                        <tr>
                            <td>Pulseway Login ID</td>
                            <td><?= htmlspecialchars($row['pulseway_login_id']) ?></td>
                        </tr>
                        <tr>
                            <td>Pulseway Password</td>
                            <td><?= htmlspecialchars(decrypt($row['pulseway_pwd'], $encryption_key)) ?></td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- Additional Information Section -->
        <div class="section-title">Additional Information</div>
        <div class="container mt-5">
            <?php foreach ($additional_info as $table => $data): ?>
                <div class="card shadow mt-4">
                    <div class="card-body">
                        <h5 class="card-title"><?= mapTableName($table) ?></h5>
                        <?php if (!empty($data)): ?>
                            <div class="row">
                                <?php foreach ($data as $item): ?>
                                    <div class="col-md-6">
                                        <table class="table table-bordered table-striped table-hover mt-4">
                                            <tbody>
                                                <?php foreach ($item as $field => $value): ?>
                                                    <tr>
                                                        <td><?= mapFieldName($field) ?></td>
                                                        <td>
                                                            <?php
                                                            if (filter_var($value, FILTER_VALIDATE_URL)) {
                                                                echo '<a href="' . htmlspecialchars($value) . '" target="_blank">' . htmlspecialchars($value) . '</a>';
                                                            } elseif (strpos($value, 'www.') === 0) {
                                                                $url = 'http://' . $value;
                                                                echo '<a href="' . htmlspecialchars($url) . '" target="_blank">' . htmlspecialchars($value) . '</a>';
                                                            } elseif (strpos($field, 'pwd') !== false || $field == 'ac_script_update') {
                                                                echo htmlspecialchars(decrypt($value, $encryption_key));
                                                            } else {
                                                                echo $field == 'active' ? convertActiveValue($value) : htmlspecialchars($value);
                                                            }
                                                            ?>
                                                        </td>
                                                    </tr>
                                                <?php endforeach; ?>
                                            </tbody>
                                        </table>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        <?php else: ?>
                            <p class="card-text">No data available.</p>
                        <?php endif; ?>
                    </div>
                </div>
            <?php endforeach; ?>

            <?php if (!empty($it_support_info)): ?>
                <div class="card shadow mt-4">
                    <div class="card-body">
                        <h5 class="card-title"><?= mapTableName('citssb_info_it_support') ?></h5>
                        <div class="row">
                            <?php foreach ($it_support_info as $info): ?>
                                <div class="col-md-6">
                                    <table class="table table-bordered table-striped table-hover mt-4">
                                        <tbody>
                                            <?php foreach ($info as $field => $value):
                                                if ($field != 'active' && $field != 'created_at' && $field != 'updated_at'): ?>
                                                    <tr>
                                                        <td><?= mapFieldName($field) ?></td>
                                                        <td>
                                                            <?php
                                                            if (filter_var($value, FILTER_VALIDATE_URL)) {
                                                                echo '<a href="' . htmlspecialchars($value) . '" target="_blank">' . htmlspecialchars($value) . '</a>';
                                                            } elseif (strpos($value, 'www.') === 0) {
                                                                $url = 'http://' . $value;
                                                                echo '<a href="' . htmlspecialchars($url) . '" target="_blank">' . htmlspecialchars($value) . '</a>';
                                                            } elseif (strpos($field, 'pwd') !== false || $field == 'ac_script_update') {
                                                                echo htmlspecialchars(decrypt($value, $encryption_key));
                                                            } else {
                                                                echo $field == 'active' ? convertActiveValue($value) : htmlspecialchars($value);
                                                            }
                                                            ?>
                                                        </td>
                                                    </tr>
                                                <?php endif;
                                            endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            <?php endif; ?>

            <?php if (!empty($account_support_info)): ?>
                <div class="card shadow mt-4">
                    <div class="card-body">
                        <h5 class="card-title"><?= mapTableName('citssb_info_account_support') ?></h5>
                        <div class="row">
                            <?php foreach ($account_support_info as $info): ?>
                                <div class="col-md-6">
                                    <table class="table table-bordered table-striped table-hover mt-4">
                                        <tbody>
                                            <?php foreach ($info as $field => $value):
                                                if ($field != 'active' && $field != 'created_at' && $field != 'updated_at'): ?>
                                                    <tr>
                                                        <td><?= mapFieldName($field) ?></td>
                                                        <td>
                                                            <?php
                                                            if (filter_var($value, FILTER_VALIDATE_URL)) {
                                                                echo '<a href="' . htmlspecialchars($value) . '" target="_blank">' . htmlspecialchars($value) . '</a>';
                                                            } elseif (strpos($value, 'www.') === 0) {
                                                                $url = 'http://' . $value;
                                                                echo '<a href="' . htmlspecialchars($url) . '" target="_blank">' . htmlspecialchars($value) . '</a>';
                                                            } elseif (strpos($field, 'pwd') !== false || $field == 'ac_script_update') {
                                                                echo htmlspecialchars(decrypt($value, $encryption_key));
                                                            } else {
                                                                echo $field == 'active' ? convertActiveValue($value) : htmlspecialchars($value);
                                                            }
                                                            ?>
                                                        </td>
                                                    </tr>
                                                <?php endif;
                                            endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            <?php endif; ?>
        </div>
    <?php endif; ?>
</div>

<!-- Bootstrap 5.3 JS CDN (with Popper.js included) -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>