<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // Include the encryption function
require '../functions/decrypt.php'; // Include the encryption function
date_default_timezone_set('Asia/Kuala_Lumpur');

$encryption_key = 'your_secret_key'; // Define your encryption key

// Initialize variables
$computer_login = $computer_login_pwd = $autocount_id = $autocount_pwd = $email_id = $email_pwd = $vtiger_crm_id = $vtiger_crm_pwd = $teamviewer_id = $teamviewer_pwd = '';
$ac_licence_portal_id = $ac_licence_portal_pwd = $vpn_login_id = $vpn_login_pwd = $pulseway_login_id = $pulseway_pwd = '';
$admin_id = null;
$active = 1;
$isEditMode = false; // Flag to indicate if editing
$isViewMode = false; // Flag to indicate if viewing
$idToEdit = null;    // ID of the row being edited

// Fetch users from the admins table
$sql = "SELECT id, username FROM admins";
$stmt = $pdo->query($sql);
$users = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Function to log changes
function logChanges($pdo, $oldData, $newData, $username, $role) {
    $changes = [];
    foreach ($oldData as $key => $value) {
        // Skip 'id', 'created_at', and 'updated_at' fields
        if ($key === 'id' || $key === 'created_at' || $key === 'updated_at') {
            continue;
        }

        // Check if the value has changed
        if ($oldData[$key] !== $newData[$key]) {
            $changes[$key] = [
                'old' => $oldData[$key],
                'new' => $newData[$key]
            ];
        }
    }

    if (!empty($changes)) {
        // Construct the custom log message
        $logMessage = "User updated in CITSSB Info\n";
        $logMessage .= "id '{$oldData['id']}'\n";
        $logMessage .= "username '{$username}'\n";

        // Append the changes to the log message
        foreach ($changes as $field => $change) {
            $logMessage .= "{$field}: '{$change['old']}' -> '{$change['new']}';\n";
        }

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $username,
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $role,
            ':activity' => $logMessage
        ]);
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve form data
    $computer_login = filter_input(INPUT_POST, 'computer_login', FILTER_SANITIZE_STRING);
    $computer_login_pwd = filter_input(INPUT_POST, 'computer_login_pwd', FILTER_SANITIZE_STRING); // Plaintext password
    $autocount_id = filter_input(INPUT_POST, 'autocount_id', FILTER_SANITIZE_STRING);
    $autocount_pwd = filter_input(INPUT_POST, 'autocount_pwd', FILTER_SANITIZE_STRING); // Plaintext password
    $email_id = filter_input(INPUT_POST, 'email_id', FILTER_SANITIZE_STRING);
    $email_pwd = filter_input(INPUT_POST, 'email_pwd', FILTER_SANITIZE_STRING); // Plaintext password
    $vtiger_crm_id = filter_input(INPUT_POST, 'vtiger_crm_id', FILTER_SANITIZE_STRING);
    $vtiger_crm_pwd = filter_input(INPUT_POST, 'vtiger_crm_pwd', FILTER_SANITIZE_STRING); // Plaintext password
    $teamviewer_id = filter_input(INPUT_POST, 'teamviewer_id', FILTER_SANITIZE_STRING);
    $teamviewer_pwd = filter_input(INPUT_POST, 'teamviewer_pwd', FILTER_SANITIZE_STRING); // Plaintext password
    $ac_licence_portal_id = filter_input(INPUT_POST, 'ac_licence_portal_id', FILTER_SANITIZE_STRING);
    $ac_licence_portal_pwd = filter_input(INPUT_POST, 'ac_licence_portal_pwd', FILTER_SANITIZE_STRING); // Plaintext password
    $vpn_login_id = filter_input(INPUT_POST, 'vpn_login_id', FILTER_SANITIZE_STRING);
    $vpn_login_pwd = filter_input(INPUT_POST, 'vpn_login_pwd', FILTER_SANITIZE_STRING); // Plaintext password
    $pulseway_login_id = filter_input(INPUT_POST, 'pulseway_login_id', FILTER_SANITIZE_STRING);
    $pulseway_pwd = filter_input(INPUT_POST, 'pulseway_pwd', FILTER_SANITIZE_STRING); // Plaintext password
    $admin_id = filter_input(INPUT_POST, 'admin_id', FILTER_SANITIZE_NUMBER_INT);
    $active = 1;
    $updated_at = date('Y-m-d H:i:s');

    // Check if the user already has data in the table
    $sqlCheck = "SELECT id FROM citssb_info_user WHERE admin_id = :admin_id";
    $stmtCheck = $pdo->prepare($sqlCheck);
    $stmtCheck->bindParam(':admin_id', $admin_id);
    $stmtCheck->execute();
    $existingUser = $stmtCheck->fetch(PDO::FETCH_ASSOC);

    if ($existingUser && !isset($_POST['id'])) {
        // If the user already has data and we're not in edit mode, show an alert
        echo "<script>alert('User information already exists for this user. Cannot add duplicate data.'); window.location.href='user_profile_info.php';</script>";
    } else {
        // Check if we are editing an existing record
        if (isset($_POST['id']) && !empty($_POST['id'])) {
            $idToEdit = $_POST['id'];
            // Fetch old data for comparison
            $sqlOldData = "SELECT * FROM citssb_info_user WHERE id = :id";
            $stmtOldData = $pdo->prepare($sqlOldData);
            $stmtOldData->bindParam(':id', $idToEdit);
            $stmtOldData->execute();
            $oldData = $stmtOldData->fetch(PDO::FETCH_ASSOC);

            // Decrypt old passwords for comparison
            $oldData['computer_login_pwd'] = decryptPassword($oldData['computer_login_pwd'], $encryption_key);
            $oldData['autocount_pwd'] = decryptPassword($oldData['autocount_pwd'], $encryption_key);
            $oldData['email_pwd'] = decryptPassword($oldData['email_pwd'], $encryption_key);
            $oldData['vtiger_crm_pwd'] = decryptPassword($oldData['vtiger_crm_pwd'], $encryption_key);
            $oldData['teamviewer_pwd'] = decryptPassword($oldData['teamviewer_pwd'], $encryption_key);
            $oldData['ac_licence_portal_pwd'] = decryptPassword($oldData['ac_licence_portal_pwd'], $encryption_key);
            $oldData['vpn_login_pwd'] = decryptPassword($oldData['vpn_login_pwd'], $encryption_key);
            $oldData['pulseway_pwd'] = decryptPassword($oldData['pulseway_pwd'], $encryption_key);

            // Prepare new data for comparison
            $newData = [
                'computer_login' => $computer_login,
                'computer_login_pwd' => $computer_login_pwd, // Plaintext password
                'autocount_id' => $autocount_id,
                'autocount_pwd' => $autocount_pwd, // Plaintext password
                'email_id' => $email_id,
                'email_pwd' => $email_pwd, // Plaintext password
                'vtiger_crm_id' => $vtiger_crm_id,
                'vtiger_crm_pwd' => $vtiger_crm_pwd, // Plaintext password
                'teamviewer_id' => $teamviewer_id,
                'teamviewer_pwd' => $teamviewer_pwd, // Plaintext password
                'ac_licence_portal_id' => $ac_licence_portal_id,
                'ac_licence_portal_pwd' => $ac_licence_portal_pwd, // Plaintext password
                'vpn_login_id' => $vpn_login_id,
                'vpn_login_pwd' => $vpn_login_pwd, // Plaintext password
                'pulseway_login_id' => $pulseway_login_id,
                'pulseway_pwd' => $pulseway_pwd, // Plaintext password
                'admin_id' => $admin_id,
                'active' => $active
            ];

            // Check if there are any changes
            $changesDetected = false;
            foreach ($oldData as $key => $value) {
                if ($key === 'id' || $key === 'created_at' || $key === 'updated_at') {
                    continue;
                }
                if ($oldData[$key] !== $newData[$key]) {
                    $changesDetected = true;
                    break;
                }
            }

            if ($changesDetected) {
                // Log changes
                logChanges($pdo, $oldData, $newData, $_SESSION['username'], $_SESSION['role']);

                // Encrypt passwords before saving to the database
                $computer_login_pwd = encryptPassword($computer_login_pwd, $encryption_key);
                $autocount_pwd = encryptPassword($autocount_pwd, $encryption_key);
                $email_pwd = encryptPassword($email_pwd, $encryption_key);
                $vtiger_crm_pwd = encryptPassword($vtiger_crm_pwd, $encryption_key);
                $teamviewer_pwd = encryptPassword($teamviewer_pwd, $encryption_key);
                $ac_licence_portal_pwd = encryptPassword($ac_licence_portal_pwd, $encryption_key);
                $vpn_login_pwd = encryptPassword($vpn_login_pwd, $encryption_key);
                $pulseway_pwd = encryptPassword($pulseway_pwd, $encryption_key);

                // Update query
                $sql = "UPDATE citssb_info_user 
                        SET computer_login = :computer_login, computer_login_pwd = :computer_login_pwd, autocount_id = :autocount_id, autocount_pwd = :autocount_pwd, 
                            email_id = :email_id, email_pwd = :email_pwd, vtiger_crm_id = :vtiger_crm_id, vtiger_crm_pwd = :vtiger_crm_pwd, 
                            teamviewer_id = :teamviewer_id, teamviewer_pwd = :teamviewer_pwd, ac_licence_portal_id = :ac_licence_portal_id, 
                            ac_licence_portal_pwd = :ac_licence_portal_pwd, vpn_login_id = :vpn_login_id, vpn_login_pwd = :vpn_login_pwd, 
                            pulseway_login_id = :pulseway_login_id, pulseway_pwd = :pulseway_pwd, active = :active, admin_id = :admin_id, updated_at = :updated_at 
                        WHERE id = :id";
                $stmt = $pdo->prepare($sql);
                $stmt->bindParam(':computer_login', $computer_login);
                $stmt->bindParam(':computer_login_pwd', $computer_login_pwd);
                $stmt->bindParam(':autocount_id', $autocount_id);
                $stmt->bindParam(':autocount_pwd', $autocount_pwd);
                $stmt->bindParam(':email_id', $email_id);
                $stmt->bindParam(':email_pwd', $email_pwd);
                $stmt->bindParam(':vtiger_crm_id', $vtiger_crm_id);
                $stmt->bindParam(':vtiger_crm_pwd', $vtiger_crm_pwd);
                $stmt->bindParam(':teamviewer_id', $teamviewer_id);
                $stmt->bindParam(':teamviewer_pwd', $teamviewer_pwd);
                $stmt->bindParam(':ac_licence_portal_id', $ac_licence_portal_id);
                $stmt->bindParam(':ac_licence_portal_pwd', $ac_licence_portal_pwd);
                $stmt->bindParam(':vpn_login_id', $vpn_login_id);
                $stmt->bindParam(':vpn_login_pwd', $vpn_login_pwd);
                $stmt->bindParam(':pulseway_login_id', $pulseway_login_id);
                $stmt->bindParam(':pulseway_pwd', $pulseway_pwd);
                $stmt->bindParam(':active', $active);
                $stmt->bindParam(':admin_id', $admin_id);
                $stmt->bindParam(':updated_at', $updated_at);
                $stmt->bindParam(':id', $idToEdit);

                // Execute the update query
                if ($stmt->execute()) {
                    echo "<script>alert('User updated successfully!'); window.location.href='user_profile_info.php';</script>";
                    exit();
                } else {
                    echo "<script>alert('Failed to update user. Please try again.');</script>";
                }
            } else {
                // No changes detected
                echo "<script>alert('No changes made.'); window.location.href='user_profile_info.php';</script>";
                exit();
            }
        } else {
            // Encrypt passwords before saving to the database
            $computer_login_pwd = encryptPassword($computer_login_pwd, $encryption_key);
            $autocount_pwd = encryptPassword($autocount_pwd, $encryption_key);
            $email_pwd = encryptPassword($email_pwd, $encryption_key);
            $vtiger_crm_pwd = encryptPassword($vtiger_crm_pwd, $encryption_key);
            $teamviewer_pwd = encryptPassword($teamviewer_pwd, $encryption_key);
            $ac_licence_portal_pwd = encryptPassword($ac_licence_portal_pwd, $encryption_key);
            $vpn_login_pwd = encryptPassword($vpn_login_pwd, $encryption_key);
            $pulseway_pwd = encryptPassword($pulseway_pwd, $encryption_key);

            // Insert query
            $created_at = date('Y-m-d H:i:s');
            $sql = "INSERT INTO citssb_info_user (computer_login, computer_login_pwd, autocount_id, autocount_pwd, email_id, email_pwd, vtiger_crm_id, vtiger_crm_pwd, 
                        teamviewer_id, teamviewer_pwd, ac_licence_portal_id, ac_licence_portal_pwd, vpn_login_id, vpn_login_pwd, pulseway_login_id, pulseway_pwd, 
                        active, admin_id, created_at, updated_at) 
                    VALUES (:computer_login, :computer_login_pwd, :autocount_id, :autocount_pwd, :email_id, :email_pwd, :vtiger_crm_id, :vtiger_crm_pwd, 
                        :teamviewer_id, :teamviewer_pwd, :ac_licence_portal_id, :ac_licence_portal_pwd, :vpn_login_id, :vpn_login_pwd, :pulseway_login_id, :pulseway_pwd, 
                        :active, :admin_id, :created_at, :updated_at)";
            $stmt = $pdo->prepare($sql);
            $stmt->bindParam(':computer_login', $computer_login);
            $stmt->bindParam(':computer_login_pwd', $computer_login_pwd);
            $stmt->bindParam(':autocount_id', $autocount_id);
            $stmt->bindParam(':autocount_pwd', $autocount_pwd);
            $stmt->bindParam(':email_id', $email_id);
            $stmt->bindParam(':email_pwd', $email_pwd);
            $stmt->bindParam(':vtiger_crm_id', $vtiger_crm_id);
            $stmt->bindParam(':vtiger_crm_pwd', $vtiger_crm_pwd);
            $stmt->bindParam(':teamviewer_id', $teamviewer_id);
            $stmt->bindParam(':teamviewer_pwd', $teamviewer_pwd);
            $stmt->bindParam(':ac_licence_portal_id', $ac_licence_portal_id);
            $stmt->bindParam(':ac_licence_portal_pwd', $ac_licence_portal_pwd);
            $stmt->bindParam(':vpn_login_id', $vpn_login_id);
            $stmt->bindParam(':vpn_login_pwd', $vpn_login_pwd);
            $stmt->bindParam(':pulseway_login_id', $pulseway_login_id);
            $stmt->bindParam(':pulseway_pwd', $pulseway_pwd);
            $stmt->bindParam(':active', $active);
            $stmt->bindParam(':admin_id', $admin_id);
            $stmt->bindParam(':created_at', $created_at);
            $stmt->bindParam(':updated_at', $updated_at);

            // Execute the insert query
            if ($stmt->execute()) {
                // Log the insertion
                $logMessage = "Item inserted into citssb_info_user for admin_id: $admin_id";
                $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                           VALUES (:username, :timestamp, :role, :activity)";
                $stmtLog = $pdo->prepare($sqlLog);
                $stmtLog->execute([
                    ':username' => $_SESSION['username'],
                    ':timestamp' => date('Y-m-d H:i:s'),
                    ':role' => $_SESSION['role'],
                    ':activity' => $logMessage
                ]);

                echo "<script>alert('Data saved successfully!'); window.location.href='user_profile_info.php';</script>";
                exit();
            } else {
                echo "<script>alert('Failed to save data. Please try again.');</script>";
            }
        }
    }
}

// Check if we are in edit mode
if (isset($_GET['edit']) && isset($_GET['id'])) {
    $idToEdit = filter_input(INPUT_GET, 'id', FILTER_SANITIZE_NUMBER_INT);
    $sql = "SELECT * FROM citssb_info_user WHERE id = :id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':id', $idToEdit);
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($row) {
        $computer_login = $row['computer_login'];
        $computer_login_pwd = decryptPassword($row['computer_login_pwd'], $encryption_key); // Decrypt password
        $autocount_id = $row['autocount_id'];
        $autocount_pwd = decryptPassword($row['autocount_pwd'], $encryption_key); // Decrypt password
        $email_id = $row['email_id'];
        $email_pwd = decryptPassword($row['email_pwd'], $encryption_key); // Decrypt password
        $vtiger_crm_id = $row['vtiger_crm_id'];
        $vtiger_crm_pwd = decryptPassword($row['vtiger_crm_pwd'], $encryption_key); // Decrypt password
        $teamviewer_id = $row['teamviewer_id'];
        $teamviewer_pwd = decryptPassword($row['teamviewer_pwd'], $encryption_key); // Decrypt password
        $ac_licence_portal_id = $row['ac_licence_portal_id'];
        $ac_licence_portal_pwd = decryptPassword($row['ac_licence_portal_pwd'], $encryption_key); // Decrypt password
        $vpn_login_id = $row['vpn_login_id'];
        $vpn_login_pwd = decryptPassword($row['vpn_login_pwd'], $encryption_key); // Decrypt password
        $pulseway_login_id = $row['pulseway_login_id'];
        $pulseway_pwd = decryptPassword($row['pulseway_pwd'], $encryption_key); // Decrypt password
        $admin_id = $row['admin_id'];
        $active = $row['active'];
        $isEditMode = true;
    }
}

// Check if we are in view mode
if (isset($_GET['view']) && isset($_GET['id'])) {
    $idToEdit = filter_input(INPUT_GET, 'id', FILTER_SANITIZE_NUMBER_INT);
    $sql = "SELECT * FROM citssb_info_user WHERE id = :id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':id', $idToEdit);
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($row) {
        $computer_login = $row['computer_login'];
        $computer_login_pwd = decryptPassword($row['computer_login_pwd'], $encryption_key); // Decrypt password
        $autocount_id = $row['autocount_id'];
        $autocount_pwd = decryptPassword($row['autocount_pwd'], $encryption_key); // Decrypt password
        $email_id = $row['email_id'];
        $email_pwd = decryptPassword($row['email_pwd'], $encryption_key); // Decrypt password
        $vtiger_crm_id = $row['vtiger_crm_id'];
        $vtiger_crm_pwd = decryptPassword($row['vtiger_crm_pwd'], $encryption_key); // Decrypt password
        $teamviewer_id = $row['teamviewer_id'];
        $teamviewer_pwd = decryptPassword($row['teamviewer_pwd'], $encryption_key); // Decrypt password
        $ac_licence_portal_id = $row['ac_licence_portal_id'];
        $ac_licence_portal_pwd = decryptPassword($row['ac_licence_portal_pwd'], $encryption_key); // Decrypt password
        $vpn_login_id = $row['vpn_login_id'];
        $vpn_login_pwd = decryptPassword($row['vpn_login_pwd'], $encryption_key); // Decrypt password
        $pulseway_login_id = $row['pulseway_login_id'];
        $pulseway_pwd = decryptPassword($row['pulseway_pwd'], $encryption_key); // Decrypt password
        $admin_id = $row['admin_id'];
        $active = $row['active'];
        $isViewMode = true;
    }
}

// Handle toggle active/inactive action
if (isset($_GET['toggle_active']) && isset($_GET['id'])) {
    $id = filter_input(INPUT_GET, 'id', FILTER_SANITIZE_NUMBER_INT);

    // Fetch the current status
    $sql = "SELECT active FROM citssb_info_user WHERE id = :id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':id', $id);
    $stmt->execute();
    $row = $stmt->fetch(PDO::FETCH_ASSOC);

    // Toggle the active status
    if ($row) {
        $newStatus = $row['active'] == 1 ? 0 : 1;

        // Update the database with the new status
        $sql = "UPDATE citssb_info_user SET active = :active WHERE id = :id";
        $stmt = $pdo->prepare($sql);
        $stmt->bindParam(':active', $newStatus);
        $stmt->bindParam(':id', $id);

        if ($stmt->execute()) {
            echo "<script>alert('Status updated successfully!'); window.location.href='user_profile_info.php';</script>";
            exit();
        } else {
            echo "<script>alert('Failed to update status. Please try again.');</script>";
        }
    }
}

// Fetch data from the database
$sql = "SELECT ci.*, a.username FROM citssb_info_user ci LEFT JOIN admins a ON ci.admin_id = a.id";
$stmt = $pdo->query($sql);
$data = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?= $isEditMode ? 'Edit User Information' : ($isViewMode ? 'View User Information' : 'Add User Information') ?></title>
    <!-- Bootstrap 5.3 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <!-- Tab Navigation -->
    <ul class="nav nav-tabs" id="myTab" role="tablist">
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="office365-tab" href="/crm/public/citssb_info/o365_info.php" role="tab">Office 365</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="email-tab" href="/crm/public/citssb_info/support_email_info.php" role="tab">Email</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="wifi-tab" href="/crm/public/citssb_info/wifi_info.php" role="tab">WiFi</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="nas-tab" href="/crm/public/citssb_info/nas_info.php" role="tab">NAS</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="hamachi-tab" href="/crm/public/citssb_info/hamachi_info.php" role="tab">Hamachi</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="printer-tab" href="/crm/public/citssb_info/printer_info.php" role="tab">Printer</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="it-support-tab" href="/crm/public/citssb_info/it_support_info.php" role="tab">IT Support</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link" id="accounting-tab" href="/crm/public/citssb_info/account_support_info.php" role="tab">Accounting</a>
        </li>
        <li class="nav-item" role="presentation">
            <a class="nav-link active" id="user-profile-tab" href="/crm/public/citssb_info/user_profile_info.php" role="tab">User Profile</a>
        </li>
    </ul>
</div>

<!-- Add User Information Form -->
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h4 class="mb-0"><?= $isEditMode ? 'Edit User Information' : ($isViewMode ? 'View User Information' : 'Add User Information') ?></h4>
        </div>
        <div class="card-body">
            <form method="POST" action="">
                <!-- Group 1: User Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">User Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-control" id="admin_id" name="admin_id" <?= $isViewMode ? 'disabled' : 'required' ?>>
                                        <option value="">Select User</option>
                                        <?php foreach ($users as $user): ?>
                                            <option value="<?= $user['id'] ?>" <?= $user['id'] == $admin_id ? 'selected' : '' ?>><?= htmlspecialchars($user['username']) ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="admin_id">Select User</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Group 2: Computer Login -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Computer Login</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="computer_login" name="computer_login" value="<?= htmlspecialchars($computer_login) ?>" <?= $isViewMode ? 'readonly' : 'required' ?> placeholder="Computer Login">
                                    <label for="computer_login">Computer Login</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="computer_login_pwd" name="computer_login_pwd" value="<?= htmlspecialchars($computer_login_pwd) ?>" <?= $isViewMode ? 'readonly' : 'required' ?> placeholder="Computer Login Password">
                                    <label for="computer_login_pwd">Computer Login Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Group 3: Autocount -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Autocount</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="autocount_id" name="autocount_id" value="<?= htmlspecialchars($autocount_id) ?>" <?= $isViewMode ? 'readonly' : '' ?> placeholder="Autocount ID">
                                    <label for="autocount_id">Autocount ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="autocount_pwd" name="autocount_pwd" value="<?= htmlspecialchars($autocount_pwd) ?>" <?= $isViewMode ? 'readonly' : '' ?> placeholder="Autocount Password">
                                    <label for="autocount_pwd">Autocount Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Group 4: Email -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Email</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="email_id" name="email_id" value="<?= htmlspecialchars($email_id) ?>" <?= $isViewMode ? 'readonly' : 'required' ?> placeholder="Email ID">
                                    <label for="email_id">Email ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="email_pwd" name="email_pwd" value="<?= htmlspecialchars($email_pwd) ?>" <?= $isViewMode ? 'readonly' : 'required' ?> placeholder="Email Password">
                                    <label for="email_pwd">Email Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Group 5: Vtiger CRM -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Vtiger CRM</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="vtiger_crm_id" name="vtiger_crm_id" value="<?= htmlspecialchars($vtiger_crm_id) ?>" <?= $isViewMode ? 'readonly' : 'required' ?> placeholder="Vtiger CRM ID">
                                    <label for="vtiger_crm_id">Vtiger CRM ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="vtiger_crm_pwd" name="vtiger_crm_pwd" value="<?= htmlspecialchars($vtiger_crm_pwd) ?>" <?= $isViewMode ? 'readonly' : 'required' ?> placeholder="Vtiger CRM Password">
                                    <label for="vtiger_crm_pwd">Vtiger CRM Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Group 6: Teamviewer -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Teamviewer</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="teamviewer_id" name="teamviewer_id" value="<?= htmlspecialchars($teamviewer_id) ?>" <?= $isViewMode ? 'readonly' : 'required' ?> placeholder="Teamviewer ID">
                                    <label for="teamviewer_id">Teamviewer ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="teamviewer_pwd" name="teamviewer_pwd" value="<?= htmlspecialchars($teamviewer_pwd) ?>" <?= $isViewMode ? 'readonly' : 'required' ?> placeholder="Teamviewer Password">
                                    <label for="teamviewer_pwd">Teamviewer Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Group 7: AutoCount Licence Portal -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">AutoCount Licence Portal</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="ac_licence_portal_id" name="ac_licence_portal_id" value="<?= htmlspecialchars($ac_licence_portal_id) ?>" <?= $isViewMode ? 'readonly' : '' ?> placeholder="AutoCount Licence Portal ID">
                                    <label for="ac_licence_portal_id">AutoCount Licence Portal ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="ac_licence_portal_pwd" name="ac_licence_portal_pwd" value="<?= htmlspecialchars($ac_licence_portal_pwd) ?>" <?= $isViewMode ? 'readonly' : '' ?> placeholder="AutoCount Licence Portal Password">
                                    <label for="ac_licence_portal_pwd">AutoCount Licence Portal Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Group 8: VPN Login -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">VPN Login</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="vpn_login_id" name="vpn_login_id" value="<?= htmlspecialchars($vpn_login_id) ?>" <?= $isViewMode ? 'readonly' : '' ?> placeholder="VPN Login ID">
                                    <label for="vpn_login_id">VPN Login ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="vpn_login_pwd" name="vpn_login_pwd" value="<?= htmlspecialchars($vpn_login_pwd) ?>" <?= $isViewMode ? 'readonly' : '' ?> placeholder="VPN Login Password">
                                    <label for="vpn_login_pwd">VPN Login Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Group 9: Pulseway -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Pulseway</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="pulseway_login_id" name="pulseway_login_id" value="<?= htmlspecialchars($pulseway_login_id) ?>" <?= $isViewMode ? 'readonly' : 'required' ?> placeholder="Pulseway Login ID">
                                    <label for="pulseway_login_id">Pulseway Login ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="pulseway_pwd" name="pulseway_pwd" value="<?= htmlspecialchars($pulseway_pwd) ?>" <?= $isViewMode ? 'readonly' : 'required' ?> placeholder="Pulseway Password">
                                    <label for="pulseway_pwd">Pulseway Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <?php if ($isEditMode): ?>
                    <input type="hidden" name="id" value="<?= htmlspecialchars($idToEdit) ?>">
                <?php endif; ?>

                <div class="d-flex justify-content-center mt-4">
                    <button type="submit" class="btn btn-primary mr-2" <?= $isViewMode ? 'disabled' : '' ?>><?= $isEditMode ? 'Update' : 'Save' ?></button>
                    <a href="user_profile_info.php" class="btn btn-secondary">Cancel</a>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- User Information Table -->
<div class="container mt-5">
    <h2 class="mb-4">User Information Table</h2>
    <table class="table table-bordered">
        <thead>
            <tr>
                <th>ID</th>
                <th>User</th>
                <th>Active</th>
                <th>Action</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($data as $row): ?>
                <tr>
                    <td><?= htmlspecialchars($row['id']) ?></td>
                    <td><?= htmlspecialchars($row['username']) ?></td>
                    <td>
                        <a href="?toggle_active=1&id=<?= $row['id'] ?>" class="btn btn-<?= $row['active'] ? 'danger' : 'success' ?> d-inline-block me-2">
                            <?= $row['active'] ? 'Inactive' : 'Active' ?>
                        </a>
                    </td>
                    <td>
                        <div class="d-flex">
                            <a href="?edit=1&id=<?= $row['id'] ?>" class="btn btn-primary me-2">Edit</a>
                            <a href="?view=1&id=<?= $row['id'] ?>" class="btn btn-info">View</a>
                        </div>
                    </td>
                </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
</div>

<!-- Bootstrap 5.3 JS -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

