<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the user_group from the session
$userGroup = $_SESSION['user_group'];

$currentUrl = basename($_SERVER['REQUEST_URI']);

// Access control check
if (!hasAccess($pdo, $currentUrl, $userGroup)) {
    echo "<script>alert('Access denied!'); window.location.href = '/crm/public/main/dashboard.php';</script>";
    exit();
}

$success = false; // Variable to track if the operation was successful
$error = ''; // Variable to hold any error messages

// Handle form submission for adding a company
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['debtor_code'])) {
    // Collect and sanitize input
    $debtor_code = $_POST['debtor_code'] ?? '';
    $company_name = $_POST['company_name'] ?? '';
    $email = $_POST['email'] ?? '';
    $address1 = $_POST['address1'] ?? '';
    $address2 = $_POST['address2'] ?? '';
    $address3 = $_POST['address3'] ?? '';
    $address4 = $_POST['address4'] ?? '';
    $postcode = $_POST['postcode'] ?? '';
    $phone1 = $_POST['phone1'] ?? '';
    $phone2 = $_POST['phone2'] ?? '';
    $fax = $_POST['fax'] ?? '';
    $mobile = $_POST['mobile'] ?? '';
    $attention = $_POST['attention'] ?? '';
    $introducer_person = $_POST['introducer_person'] ?? '';
    $business_registration_number = $_POST['business_registration_number'] ?? '';
    $tin_number = $_POST['tin_number'] ?? '';
    $service_tax_number = $_POST['service_tax_number'] ?? '';
    $sales_tax_number = $_POST['sales_tax_number'] ?? '';
    $gst_number = $_POST['gst_number'] ?? '';
    $is_dealer = isset($_POST['is_dealer']) ? 1 : 0;
    $related_companies = $_POST['related_companies'] ?? [];
    $billing_company = $_POST['billing_company'] ?? '';

    // Dynamically concatenate addresses with commas only if the next field has data
    $addressParts = [];
    if (!empty($address1)) $addressParts[] = $address1;
    if (!empty($address2)) $addressParts[] = $address2;
    if (!empty($address3)) $addressParts[] = $address3;
    if (!empty($address4)) $addressParts[] = $address4;
    $fullAddress = implode(', ', $addressParts); // Join with commas

    // Validate debtor_code uniqueness
    $stmt = $pdo->prepare('SELECT COUNT(*) FROM company_info WHERE debtor_code = :debtor_code');
    $stmt->bindParam(':debtor_code', $debtor_code);
    $stmt->execute();
    $count = $stmt->fetchColumn();

    if ($count > 0) {
        $error = 'Debtor code already exists. Please choose a different one.';
    } else {
        try {
            // Begin transaction
            $pdo->beginTransaction();

            // Insert into the company_info table
            $stmt = $pdo->prepare('INSERT INTO company_info (debtor_code, company_name, email, address1, address2, address3, address4, full_address, postcode, phone1, phone2, fax, mobile, 
            attention, introducer_person, business_registration_number, tin_number, service_tax_number, sales_tax_number, gst_number, is_dealer, billing_company) VALUES 
            (:debtor_code, :company_name, :email, :address1, :address2, :address3, :address4, :full_address, :postcode, :phone1, :phone2, :fax, :mobile, 
            :attention, :introducer_person, :business_registration_number, :tin_number ,:service_tax_number, :sales_tax_number, :gst_number, :is_dealer, :billing_company)');

            // Bind parameters
            $stmt->execute([
                ':debtor_code' => $debtor_code,
                ':company_name' => $company_name,
                ':email' => $email,
                ':address1' => $address1,
                ':address2' => $address2,
                ':address3' => $address3,
                ':address4' => $address4,
                ':full_address' => $fullAddress, // Use the concatenated address here
                ':postcode' => $postcode,
                ':phone1' => $phone1,
                ':phone2' => $phone2,
                ':fax' => $fax,
                ':mobile' => $mobile,
                ':attention' => $attention,
                ':introducer_person' => $introducer_person,
                ':business_registration_number' => $business_registration_number,
                ':tin_number' => $tin_number,
                ':service_tax_number' => $service_tax_number,
                ':sales_tax_number' => $sales_tax_number,
                ':gst_number' => $gst_number,
                ':is_dealer' => $is_dealer,
                ':billing_company' => $billing_company
            ]);

            // Insert related companies into the relation_company table
            $relationStmt = $pdo->prepare('INSERT INTO relation_company (debtor_code, related_company_debtor_code) VALUES (:debtor_code, :related_company_debtor_code)');
            foreach ($related_companies as $related_company_debtor_code) {
                $relationStmt->execute([
                    ':debtor_code' => $debtor_code,
                    ':related_company_debtor_code' => $related_company_debtor_code
                ]);
            }

            // Commit the transaction
            $pdo->commit();

            // Log the activity
            $logMessage = "Company added: Debtor Code - $debtor_code, Company Name - $company_name";
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            echo "<script>alert('Company added successfully!'); window.location.href='/crm/public/main/dashboard.php';</script>";
            exit();
        } catch (PDOException $e) {
            $pdo->rollBack();
            $error = 'Database error: ' . $e->getMessage();
            echo "<script>alert('Database error: " . $error . "');</script>";
        }
    }
}

// Handle CSV file upload
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_FILES['csv_file'])) {
    $file = $_FILES['csv_file'];

    // Check if the file is a CSV
    if ($file['type'] === 'text/csv' || $file['type'] === 'application/vnd.ms-excel') {
        $handle = fopen($file['tmp_name'], 'r');

        // Skip the header row
        fgetcsv($handle);

        // Process each row
        while (($data = fgetcsv($handle)) !== false) {
            // Skip the row if debtor_code or company_name is empty
            if (empty($data[0]) || empty($data[1])) {
                continue;
            }

            $debtor_code = $data[0];
            $company_name = $data[1];
            $email = isset($data[2]) ? $data[2] : '';
            $address1 = isset($data[3]) ? $data[3] : '';
            $address2 = isset($data[4]) ? $data[4] : '';
            $address3 = isset($data[5]) ? $data[5] : '';
            $address4 = isset($data[6]) ? $data[6] : '';
            $postcode = isset($data[7]) ? $data[7] : '';
            $phone1 = isset($data[8]) ? $data[8] : '';
            $phone2 = isset($data[9]) ? $data[9] : '';
            $fax = isset($data[10]) ? $data[10] : '';
            $mobile = isset($data[11]) ? $data[11] : '';
            $attention = isset($data[12]) ? $data[12] : '';
            $introducer_person = isset($data[13]) ? $data[13] : '';
            $business_registration_number = isset($data[14]) ? $data[14] : '';
            $tin_number = isset($data[15]) ? $data[15] : '';
            $service_tax_number = isset($data[16]) ? $data[16] : '';
            $sales_tax_number = isset($data[17]) ? $data[17] : '';
            $gst_number = isset($data[18]) ? $data[18] : '';

            // Dynamically concatenate addresses with commas only if the next field has data
            $addressParts = [];
            if (!empty($address1)) $addressParts[] = $address1;
            if (!empty($address2)) $addressParts[] = $address2;
            if (!empty($address3)) $addressParts[] = $address3;
            if (!empty($address4)) $addressParts[] = $address4;
            $fullAddress = implode(', ', $addressParts); // Join with commas

            // Validate debtor_code uniqueness
            $stmt = $pdo->prepare('SELECT COUNT(*) FROM company_info WHERE debtor_code = :debtor_code');
            $stmt->bindParam(':debtor_code', $debtor_code);
            $stmt->execute();
            $count = $stmt->fetchColumn();

            if ($count === 0) {
                try {
                    // Insert into the company_info table
                    $stmt = $pdo->prepare('INSERT INTO company_info (debtor_code, company_name, email, address1, address2, address3, address4, full_address, postcode, phone1, phone2, fax, mobile, 
                    attention, introducer_person, business_registration_number, tin_number, service_tax_number, sales_tax_number, gst_number) VALUES 
                    (:debtor_code, :company_name, :email, :address1, :address2, :address3, :address4, :full_address, :postcode, :phone1, :phone2, :fax, :mobile, 
                    :attention, :introducer_person, :business_registration_number, :tin_number ,:service_tax_number, :sales_tax_number, :gst_number)');

                    // Bind parameters
                    $stmt->execute([
                        ':debtor_code' => $debtor_code,
                        ':company_name' => $company_name,
                        ':email' => $email,
                        ':address1' => $address1,
                        ':address2' => $address2,
                        ':address3' => $address3,
                        ':address4' => $address4,
                        ':full_address' => $fullAddress, // Use the concatenated address here
                        ':postcode' => $postcode,
                        ':phone1' => $phone1,
                        ':phone2' => $phone2,
                        ':fax' => $fax,
                        ':mobile' => $mobile,
                        ':attention' => $attention,
                        ':introducer_person' => $introducer_person,
                        ':business_registration_number' => $business_registration_number,
                        ':tin_number' => $tin_number,
                        ':service_tax_number' => $service_tax_number,
                        ':sales_tax_number' => $sales_tax_number,
                        ':gst_number' => $gst_number
                    ]);

                    // Log the activity
                    $logMessage = "Company added via CSV: Debtor Code - $debtor_code, Company Name - $company_name";
                    $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                               VALUES (:username, :timestamp, :role, :activity)";
                    $stmtLog = $pdo->prepare($sqlLog);
                    $stmtLog->execute([
                        ':username' => $_SESSION['username'],
                        ':timestamp' => date('Y-m-d H:i:s'),
                        ':role' => $_SESSION['role'],
                        ':activity' => $logMessage
                    ]);

                    $success = true;
                } catch (PDOException $e) {
                    $error = 'Database error: ' . $e->getMessage();
                }
            }
        }

        fclose($handle);

        if ($success) {
            echo "<script>alert('CSV import completed successfully!'); window.location.href='/crm/public/main/dashboard.php';</script>";
            exit();
        } else {
            echo "<script>alert('CSV import completed with errors: $error');</script>";
        }
    } else {
        echo "<script>alert('Invalid file type. Please upload a CSV file.');</script>";
    }
}

// Fetch company information to display in multi-select dropdown
$companies = $pdo->query('SELECT debtor_code, company_name FROM company_info')->fetchAll(PDO::FETCH_ASSOC);

// Fetch dealer companies to display in the new dropdown
$dealerCompanies = $pdo->query('SELECT debtor_code, company_name FROM company_info WHERE is_dealer = 1')->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add Company Information</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Select CSS -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-select/1.14.0-beta2/css/bootstrap-select.min.css">
</head>
<body>
    <div class="container my-5">
        <div class="card">
            <div class="card-header">
                <h1 class="mb-0">Add Company Information</h1>
            </div>
            <div class="card-body">
                <!-- Tab Navigation -->
                <ul class="nav nav-tabs mb-4" id="myTab" role="tablist">
                    <li class="nav-item" role="presentation">
                        <button class="nav-link active" id="add-tab" data-bs-toggle="tab" data-bs-target="#add" type="button" role="tab" aria-controls="add" aria-selected="true">Add Company</button>
                    </li>
                    <li class="nav-item" role="presentation">
                        <button class="nav-link" id="csv-tab" data-bs-toggle="tab" data-bs-target="#csv" type="button" role="tab" aria-controls="csv" aria-selected="false">CSV Import</button>
                    </li>
                </ul>

                <!-- Tab Content -->
                <div class="tab-content" id="myTabContent">
                    <!-- Add Company Tab -->
                    <div class="tab-pane fade show active" id="add" role="tabpanel" aria-labelledby="add-tab">
                        <?php if ($success): ?>
                            <div class="alert alert-success">Company information added successfully!</div>
                        <?php elseif ($error): ?>
                            <div class="alert alert-danger"><?php echo $error; ?></div>
                        <?php endif; ?>

                        <form method="post" action="">
                            <div class="card mb-3">
                                <div class="card-header">
                                    <h5 class="mb-0">Company Information</h5>
                                </div>
                                <div class="card-body">
                                    <!-- Debtor Code and Related Companies -->
                                    <div class="row mb-3">
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="debtor_code" name="debtor_code" class="form-control" placeholder="Debtor Code" required>
                                                <label for="debtor_code">Debtor Code</label>
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <label for="related_companies" class="form-label">Related Companies:</label>
                                            <select id="related_companies" name="related_companies[]" class="selectpicker form-select" multiple data-live-search="true" style="width: 100%; height: 150px;">
                                                <?php foreach ($companies as $company): ?>
                                                    <option value="<?php echo $company['debtor_code']; ?>">
                                                        <?php echo $company['company_name'] . ' (Debtor Code: ' . $company['debtor_code'] . ')'; ?>
                                                    </option>
                                                <?php endforeach; ?>
                                            </select>
                                        </div>
                                    </div>

                                    <!-- Billing Company Checkbox and Dropdown -->
                                    <div class="row mb-3">
                                        <div class="col-md-6">
                                            <div class="form-check">
                                                <input type="checkbox" class="form-check-input" id="billing_company_checkbox" name="billing_company_checkbox">
                                                <label class="form-check-label" for="billing_company_checkbox">Billing Company</label>
                                            </div>
                                            <div class="form-floating" id="dealer_companies_container" style="display: none;">
                                                <select id="dealer_companies" name="billing_company" class="form-select">
                                                    <option value="">Select a Billing Company</option>
                                                    <?php foreach ($dealerCompanies as $dealerCompany): ?>
                                                        <option value="<?php echo $dealerCompany['debtor_code']; ?>">
                                                            <?php echo $dealerCompany['company_name'] . ' (Debtor Code: ' . $dealerCompany['debtor_code'] . ')'; ?>
                                                        </option>
                                                    <?php endforeach; ?>
                                                </select>
                                                <label for="dealer_companies">Billing Company</label>
                                            </div>
                                        </div>

                                        <!-- Is Dealer Checkbox -->
                                        <div class="col-md-6">
                                            <div class="form-check">
                                                <input type="checkbox" class="form-check-input" id="is_dealer" name="is_dealer">
                                                <label class="form-check-label" for="is_dealer">Is Dealer</label>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <div class="card mb-3">
                                <div class="card-header">
                                    <h5 class="mb-0">Company Details</h5>
                                </div>
                                <div class="card-body">
                                    <div class="row mb-3">
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="company_name" name="company_name" class="form-control" placeholder="Company Name">
                                                <label for="company_name">Company Name</label>
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="email" id="email" name="email" class="form-control" placeholder="Email">
                                                <label for="email">Email</label>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <div class="card mb-3">
                                <div class="card-header">
                                    <h5 class="mb-0">Address Information</h5>
                                </div>
                                <div class="card-body">
                                    <div class="row mb-3">
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="address1" name="address1" class="form-control" placeholder="Address 1">
                                                <label for="address1">Address 1</label>
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="address2" name="address2" class="form-control" placeholder="Address 2">
                                                <label for="address2">Address 2</label>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="row mb-3">
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="address3" name="address3" class="form-control" placeholder="Address 3">
                                                <label for="address3">Address 3</label>
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="address4" name="address4" class="form-control" placeholder="Address 4">
                                                <label for="address4">Address 4</label>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="row mb-3">
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="postcode" name="postcode" class="form-control" placeholder="Postcode">
                                                <label for="postcode">Postcode</label>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <div class="card mb-3">
                                <div class="card-header">
                                    <h5 class="mb-0">Contact Information</h5>
                                </div>
                                <div class="card-body">
                                    <div class="row mb-3">
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="phone1" name="phone1" class="form-control" placeholder="Phone 1">
                                                <label for="phone1">Phone 1</label>
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="phone2" name="phone2" class="form-control" placeholder="Phone 2">
                                                <label for="phone2">Phone 2</label>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="row mb-3">
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="fax" name="fax" class="form-control" placeholder="Fax">
                                                <label for="fax">Fax</label>
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="mobile" name="mobile" class="form-control" placeholder="Mobile">
                                                <label for="mobile">Mobile</label>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="row mb-3">
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="attention" name="attention" class="form-control" placeholder="Attention">
                                                <label for="attention">Attention</label>
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="introducer_person" name="introducer_person" class="form-control" placeholder="Introducer Person">
                                                <label for="introducer_person">Introducer Person</label>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <div class="card mb-3">
                                <div class="card-header">
                                    <h5 class="mb-0">Registration and Tax Information</h5>
                                </div>
                                <div class="card-body">
                                    <div class="row mb-3">
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="business_registration_number" name="business_registration_number" class="form-control" placeholder="Business Registration Number">
                                                <label for="business_registration_number">Business Registration Number</label>
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="tin_number" name="tin_number" class="form-control" placeholder="Tin Number">
                                                <label for="tin_number">Tin Number</label>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="row mb-3">
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="service_tax_number" name="service_tax_number" class="form-control" placeholder="Service Tax Number">
                                                <label for="service_tax_number">Service Tax Number</label>
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="sales_tax_number" name="sales_tax_number" class="form-control" placeholder="Sales Tax Number">
                                                <label for="sales_tax_number">Sales Tax Number</label>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="row mb-3">
                                        <div class="col-md-6">
                                            <div class="form-floating">
                                                <input type="text" id="gst_number" name="gst_number" class="form-control" placeholder="GST Number">
                                                <label for="gst_number">GST Number</label>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <button type="submit" class="btn btn-primary">Add Company</button>
                        </form>
                    </div>

                    <!-- CSV Import Tab -->
                    <div class="tab-pane fade" id="csv" role="tabpanel" aria-labelledby="csv-tab">
                        <form method="post" action="" enctype="multipart/form-data">
                            <div class="mb-3">
                                <label for="csv_file" class="form-label">Upload CSV File:</label>
                                <input type="file" class="form-control" id="csv_file" name="csv_file" accept=".csv" required>
                            </div>
                            <button type="submit" class="btn btn-primary">Upload CSV</button>
                        </form>
                        <div class="mt-4">
                            <p><strong>Note:</strong> Your CSV file should have the following columns in this order:</p>
                            <ul>
                                <li>Debtor Code</li>
                                <li>Company Name</li>
                                <li>Email</li>
                                <li>Address 1</li>
                                <li>Address 2</li>
                                <li>Address 3</li>
                                <li>Address 4</li>
                                <li>Postcode</li>
                                <li>Phone 1</li>
                                <li>Phone 2</li>
                                <li>Fax</li>
                                <li>Mobile</li>
                                <li>Attention</li>
                                <li>Introducer Person</li>
                                <li>Business Registration Number</li>
                                <li>Tin Number</li>
                                <li>Service Tax Number</li>
                                <li>Sales Tax Number</li>
                                <li>GST Number</li>
                            </ul>
                            <p>The first row should be a header row and will be skipped during import.</p>
                            <p><strong>Note:</strong> Rows with existing debtor codes or missing debtor code/company name will be skipped during the import process.</p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.x JS Bundle -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <!-- Bootstrap Select JS -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-select/1.14.0-beta2/js/bootstrap-select.min.js"></script>

    <!-- Initialize the Bootstrap Selectpicker -->
    <script>
        $(document).ready(function() {
            $('.selectpicker').selectpicker(); // Initialize selectpicker

            // Function to handle checkbox interactions
            function handleCheckboxInteractions() {
                const billingCompanyCheckbox = $('#billing_company_checkbox');
                const dealerCompaniesContainer = $('#dealer_companies_container');
                const isDealerCheckbox = $('#is_dealer');

                if (billingCompanyCheckbox.is(':checked')) {
                    dealerCompaniesContainer.show();
                    isDealerCheckbox.prop('disabled', true);
                } else {
                    dealerCompaniesContainer.hide();
                    isDealerCheckbox.prop('disabled', false);
                }

                if (isDealerCheckbox.is(':checked')) {
                    billingCompanyCheckbox.prop('disabled', true);
                } else {
                    billingCompanyCheckbox.prop('disabled', false);
                }
            }

            // Initial call to set the initial state
            handleCheckboxInteractions();

            // Event listeners for checkbox changes
            $('#billing_company_checkbox').change(function() {
                handleCheckboxInteractions();
            });

            $('#is_dealer').change(function() {
                handleCheckboxInteractions();
            });
        });
    </script>
</body>
</html>