<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database

if (isset($_GET['debtor_code'])) {
    $debtorCode = $_GET['debtor_code'];
    
    // Fetch the customer details from company_info table
    $stmt = $pdo->prepare('SELECT * FROM company_info WHERE debtor_code = :debtor_code');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->execute();
    $customer = $stmt->fetch(PDO::FETCH_ASSOC);
    
    // Check if customer exists
    if ($customer) {
        $debtorCode = $customer['debtor_code'];
        $companyName = $customer['company_name'];
        
        // Dynamically concatenate addresses with commas only if the next field has data
        $addressParts = [];
        if (!empty($customer['address1'])) $addressParts[] = $customer['address1'];
        if (!empty($customer['address2'])) $addressParts[] = $customer['address2'];
        if (!empty($customer['address3'])) $addressParts[] = $customer['address3'];
        if (!empty($customer['address4'])) $addressParts[] = $customer['address4'];
        $fullAddress = implode(', ', $addressParts); // Join with commas

        // Fetch associated data from item_type_ac table where company_name matches
        $itemTypeStmt = $pdo->prepare('SELECT * FROM item_type_ac WHERE debtor_code = :debtor_code');
        $itemTypeStmt->bindParam(':debtor_code', $debtorCode);
        $itemTypeStmt->execute();
        $itemTypeData = $itemTypeStmt->fetchAll(PDO::FETCH_ASSOC);

        // Fetch data from customer_info where company_name matches
        $customerStmt = $pdo->prepare('SELECT * FROM customer_info WHERE company_name = :company_name');
        $customerStmt->bindParam(':company_name', $companyName);
        $customerStmt->execute();
        $customerData = $customerStmt->fetchAll(PDO::FETCH_ASSOC);

        // Sort customerData to ensure main_customer = 1 is on top
        usort($customerData, function($a, $b) {
            return $b['main_customer'] - $a['main_customer'];
        });

        // Fetch related companies from relation_company table
        $relatedCompaniesStmt = $pdo->prepare('SELECT ci.company_name, ci.debtor_code 
                                               FROM relation_company rc 
                                               JOIN company_info ci ON rc.related_company_debtor_code = ci.debtor_code 
                                               WHERE rc.debtor_code = :debtor_code');
        $relatedCompaniesStmt->bindParam(':debtor_code', $debtorCode);
        $relatedCompaniesStmt->execute();
        $relatedCompanies = $relatedCompaniesStmt->fetchAll(PDO::FETCH_ASSOC);

        // Fetch subscription data where debtor_code matches, ordered by end_date DESC
        $subscriptionStmt = $pdo->prepare('
            SELECT s.*, 
                   r.invoice_number, 
                   r.invoice_date, 
                   r.quotation_number, 
                   r.quotation_date, 
                   r.pdf_file, 
                   r.or_number,
                   ic.item_name
            FROM subscriptions s
            LEFT JOIN (
                SELECT subscription_id, 
                       invoice_number, 
                       invoice_date, 
                       quotation_number, 
                       quotation_date, 
                       pdf_file, 
                       or_number,
                       ROW_NUMBER() OVER (PARTITION BY subscription_id ORDER BY created_at DESC) as rn
                FROM renewals
            ) r ON s.subscription_id = r.subscription_id AND r.rn = 1
            LEFT JOIN item_code ic ON s.item_code = ic.item_code
            WHERE s.debtor_code = :debtor_code
            ORDER BY s.end_date DESC, s.start_date DESC
        ');
        $subscriptionStmt->bindParam(':debtor_code', $debtorCode);
        $subscriptionStmt->execute();
        $subscriptionData = $subscriptionStmt->fetchAll(PDO::FETCH_ASSOC);

        // Fetch billing company details
        $billingCompanyStmt = $pdo->prepare('SELECT * FROM company_info WHERE debtor_code = :billing_company');
        $billingCompanyStmt->bindParam(':billing_company', $customer['billing_company']);
        $billingCompanyStmt->execute();
        $billingCompany = $billingCompanyStmt->fetch(PDO::FETCH_ASSOC);
    } else {
        echo "<p>Customer not found.</p>";
        exit();
    }
} else {
    echo "<p>No Debtor Code provided.</p>";
    exit();
}

if (isset($_POST['search_query'])) {
    $searchQuery = $_POST['search_query'];
    try {
        // Fetch customer data
        $companyStmt = $pdo->prepare("SELECT company_name FROM company_info WHERE company_name LIKE :search_query LIMIT 1");
        $companyStmt->execute(['search_query' => '%' . $searchQuery . '%']);
        $companyData = $companyStmt->fetch(PDO::FETCH_ASSOC);
        $companyName = $companyData['company_name'] ?? '';

        // Fetch data from item_type_ac based on the matching company name
        if ($companyName) {
            $itemTypeStmt = $pdo->prepare("
                SELECT *
                FROM item_type_ac
                WHERE company_name = :company_name
            ");
            $itemTypeStmt->execute(['company_name' => $companyName]);
            $itemTypeData = $itemTypeStmt->fetchAll(PDO::FETCH_ASSOC);
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
        echo "<script>alert('Error fetching data.');</script>";
    }
}

if (!$customer) {
    echo "<p>Customer not found.</p>";
    exit();
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title></title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        /* Smooth transition for tab content */
        .tab-content {
            overflow: hidden; /* Prevent content overflow during transition */
        }
        .tab-pane {
            transition: opacity 0.3s ease-in-out;
            opacity: 0;
        }
        .tab-pane.active {
            opacity: 1;
        }
    </style>
</head>
<body>
<div class="container-fluid mt-5">
    <div class="row justify-content-center">
        <div class="col-md-10">
            <!-- Navigation Tabs -->
            <ul class="nav nav-tabs mb-4">
                <li class="nav-item">
                    <a class="nav-link <?= $_SERVER['PHP_SELF'] === '/crm/public/company/company_details.php' ? 'active' : '' ?>" 
                    href="company_details.php?debtor_code=<?= urlencode($customer['debtor_code']); ?>&company_name=<?= urlencode($customer['company_name']); ?>">Company Details</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === '/crm/public/company/view_autocount_table.php' ? 'active' : '' ?>" 
                       href="view_autocount_table.php?debtor_code=<?= urlencode($customer['debtor_code']); ?>&company_name=<?= urlencode($customer['company_name']); ?>">Autocount</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_email_citssb_table.php' ? 'active' : '' ?>" 
                       href="view_email_citssb_table.php?debtor_code=<?= urlencode($customer['debtor_code']); ?>&company_name=<?= urlencode($customer['company_name']); ?>">Email</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_network_table.php' ? 'active' : '' ?>" 
                       href="view_network_table.php?debtor_code=<?= urlencode($customer['debtor_code']); ?>&company_name=<?= urlencode($customer['company_name']); ?>">Network</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_nas_table.php' ? 'active' : '' ?>" 
                       href="view_nas_table.php?debtor_code=<?= urlencode($customer['debtor_code']); ?>&company_name=<?= urlencode($customer['company_name']); ?>">NAS</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hardware_table.php' ? 'active' : '' ?>" 
                       href="view_hardware_table.php?debtor_code=<?= urlencode($customer['debtor_code']); ?>&company_name=<?= urlencode($customer['company_name']); ?>">Hardware</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pos_hardware_table.php' ? 'active' : '' ?>" 
                       href="view_pos_hardware_table.php?debtor_code=<?= urlencode($customer['debtor_code']); ?>&company_name=<?= urlencode($customer['company_name']); ?>">POS Hardware</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pc_table.php' ? 'active' : '' ?>" 
                       href="view_pc_table.php?debtor_code=<?= urlencode($customer['debtor_code']); ?>&company_name=<?= urlencode($customer['company_name']); ?>">Computer</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hosting_table.php' ? 'active' : '' ?>" 
                       href="view_hosting_table.php?debtor_code=<?= urlencode($customer['debtor_code']); ?>&company_name=<?= urlencode($customer['company_name']); ?>">Hosting</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_software_table.php' ? 'active' : '' ?>" 
                       href="view_software_table.php?debtor_code=<?= urlencode($customer['debtor_code']); ?>&company_name=<?= urlencode($customer['company_name']); ?>">Software</a>
                </li>
            </ul>

            <!-- Rest of the content remains unchanged -->
            <h2 class="text-center mb-4"><?= htmlspecialchars($customer['company_name']); ?>  
                <a href="edit_company.php?debtor_code=<?= urlencode($customer['debtor_code']); ?>" class="btn btn-sm btn-warning">Edit</a>
            </h2>
            <div class="row mb-4">
                <div class="col-md-6">
                    <div class="card">
                        <div class="card-body">
                            <ul class="list-group">
                                <li class="list-group-item"><strong>General Email:</strong> <?= htmlspecialchars($customer['email']); ?></li>
                                <li class="list-group-item"><strong>Address:</strong> <?= htmlspecialchars($fullAddress); ?></li>
                                <li class="list-group-item"><strong>Phone 1:</strong> <?= htmlspecialchars($customer['phone1']); ?></li>
                                <li class="list-group-item"><strong>Phone 2:</strong> <?= htmlspecialchars($customer['phone2']); ?></li>
                                <li class="list-group-item"><strong>Fax:</strong> <?= htmlspecialchars($customer['fax']); ?></li>
                                <li class="list-group-item"><strong>Mobile:</strong> <?= htmlspecialchars($customer['mobile']); ?></li>
                            </ul>
                        </div>
                    </div>
                </div>
                <div class="col-md-6">
                    <div class="card">
                        <div class="card-body">
                            <ul class="list-group">
                                <li class="list-group-item"><strong>Introducer Person:</strong> <?= htmlspecialchars($customer['introducer_person']); ?></li>
                                <li class="list-group-item"><strong>Business Registration Number:</strong> <?= htmlspecialchars($customer['business_registration_number']); ?></li>
                                <li class="list-group-item"><strong>Tin Number:</strong> <?= htmlspecialchars($customer['tin_number']); ?></li>
                                <li class="list-group-item"><strong>Service Tax Number:</strong> <?= htmlspecialchars($customer['service_tax_number']); ?></li>
                                <li class="list-group-item"><strong>Sales Tax Number:</strong> <?= htmlspecialchars($customer['sales_tax_number']); ?></li>
                                <li class="list-group-item"><strong>GST Number:</strong> <?= htmlspecialchars($customer['gst_number']); ?></li>
                                <li class="list-group-item"><strong>Billing Company:</strong> 
                                    <?php if (!empty($billingCompany)): ?>
                                        <a href="company_details.php?debtor_code=<?= urlencode($billingCompany['debtor_code']); ?>&company_name=<?= urlencode($billingCompany['company_name']); ?>">
                                            <?= htmlspecialchars($billingCompany['company_name']); ?>
                                        </a>
                                    <?php else: ?>
                                        N/A
                                    <?php endif; ?>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>

            <!-- Rest of the content remains unchanged -->
            <h2 class="mb-3">Customer Information</h2>
            <div class="table-responsive">
                <table class="table table-bordered">
                    <thead class="thead-light">
                        <tr>
                            <th>Customer Name</th>
                            <th>Mobile</th>
                            <th>Email</th>
                            <th>Title</th>
                            <th>Department</th>
                            <th>Action</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (!empty($customerData)): ?>
                            <?php foreach ($customerData as $customerItem): ?>
                                <tr>
                                    <td><?= htmlspecialchars($customerItem['customer_username']); ?>
                                        <?php if ($customerItem['main_customer'] == 1): ?>
                                            <svg xmlns="http://www.w3.org/2000/svg" width="30" height="30" fill="currentColor" class="bi bi-person-fill" viewBox="0 0 16 16">
                                                <path d="M3 14s-1 0-1-1 1-4 6-4 6 3 6 4-1 1-1 1zm5-6a3 3 0 1 0 0-6 3 3 0 0 0 0 6"/>
                                            </svg>                                
                                        <?php endif; ?>
                                    </td>
                                    <td><?= htmlspecialchars($customerItem['customer_mobile']); ?></td>
                                    <td><?= htmlspecialchars($customerItem['customer_email']); ?></td>
                                    <td><?= htmlspecialchars($customerItem['customer_title']); ?></td>
                                    <td><?= htmlspecialchars($customerItem['customer_dept']); ?></td>
                                    <td>
                                        <a href="/crm/public/customer/customer_details.php?debtor_code=<?= urlencode($customerItem['debtor_code']) ?>&company_name=<?= urlencode($customerItem['company_name']) ?>&customer_info_id=<?= urlencode($customerItem['customer_info_id']) ?>" class="btn btn-info btn-sm">View</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php else: ?>
                            <tr>
                                <td colspan="6" class="text-center">
                                    No customer data found for this company.
                                    <a href="/crm/public/customer/add_customer.php?debtor_code=<?= urlencode($customer['debtor_code']) ?>&company_name=<?= urlencode($customer['company_name']) ?>" class="btn btn-success btn-sm">Add Customer</a>
                                </td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <h2 class="mb-3">Related Companies</h2>
            <div class="table-responsive">
                <table class="table table-bordered">
                    <thead class="thead-light">
                        <tr>
                            <th>Company Name</th>
                            <th>Debtor Code</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (!empty($relatedCompanies)): ?>
                            <?php foreach ($relatedCompanies as $relatedCompany): ?>
                                <tr>
                                    <td>
                                        <a href="company_details.php?debtor_code=<?= urlencode($relatedCompany['debtor_code']); ?>&company_name=<?= urlencode($relatedCompany['company_name']); ?>">
                                            <?= htmlspecialchars($relatedCompany['company_name']); ?>
                                        </a>
                                    </td>
                                    <td>
                                        <a href="company_details.php?debtor_code=<?= urlencode($relatedCompany['debtor_code']); ?>&company_name=<?= urlencode($relatedCompany['company_name']); ?>">
                                            <?= htmlspecialchars($relatedCompany['debtor_code']); ?>
                                        </a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php else: ?>
                            <tr>
                                <td colspan="2" class="text-center">No related companies found for this company.</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <h2 class="mb-3">Subscription Information</h2>
            <div class="table-responsive">
                <table class="table table-bordered">
                    <thead class="thead-light">
                        <tr>
                            <th style="width: 60%;">Item Name</th>
                            <th style="width: 15%;">Date Range</th>
                            <th style="width: 15%;">Invoice Details</th>
                            <th style="width: 10%;">Action</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (!empty($subscriptionData)): ?>
                            <?php foreach ($subscriptionData as $subscriptionItem): 
                                // Existing PHP logic remains unchanged
                                $mainCustomerStmt = $pdo->prepare('SELECT customer_info_id, customer_username, customer_email FROM customer_info WHERE company_name = :company_name AND main_customer = 1');
                                $mainCustomerStmt->execute(['company_name' => $companyName]);
                                $mainCustomer = $mainCustomerStmt->fetch(PDO::FETCH_ASSOC);

                                // Row color logic remains unchanged
                                $rowColor = '';
                                if (!empty($subscriptionItem['invoice_number']) && empty($subscriptionItem['or_number'])) {
                                    $rowColor = 'table-danger';
                                } elseif (!empty($subscriptionItem['invoice_number']) && !empty($subscriptionItem['or_number'])) {
                                    $rowColor = 'table-success';
                                }

                                // Date handling logic remains unchanged
                                $endDate = new DateTime($subscriptionItem['end_date']);
                                $today = new DateTime();
                                $daysDiff = $endDate->diff($today)->days;
                                if ($today < $endDate && $daysDiff <= 30) {
                                    $rowColor = 'table-warning';
                                }

                                $startDate = new DateTime($subscriptionItem['start_date']);
                                $endDate = new DateTime($subscriptionItem['end_date']);
                                $formattedStartDate = $startDate->format('Y-m-d');
                                $formattedEndDate = $endDate->format('Y-m-d');
                            ?>
                                <tr class="<?= $rowColor ?>">
                                    <td>
                                        <div style="word-wrap: break-word;">
                                            <?= htmlspecialchars($subscriptionItem['item_name'] ?? 'N/A'); ?>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="d-flex flex-column">
                                            <div class="d-flex align-items-center mb-1">
                                                <span class="text-muted" style="width: 45px;">Start:</span>
                                                <span class="text-nowrap ms-1"><?= $formattedStartDate ?></span>
                                            </div>
                                            <div class="d-flex align-items-center">
                                                <span class="text-muted" style="width: 45px;">End:</span>
                                                <span class="text-nowrap ms-1"><?= $formattedEndDate ?></span>
                                                <?php if ($today < $endDate && $daysDiff <= 30): ?>
                                                    <span class="badge bg-warning text-dark ms-2">Expires in <?= $daysDiff ?> days</span>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="d-flex flex-column">
                                            <div class="d-flex align-items-center mb-1">
                                                <span class="text-muted" style="width: 60px;">Invoice:</span>
                                                <span class="text-nowrap ms-1"><?= htmlspecialchars($subscriptionItem['invoice_number'] ?? 'N/A'); ?></span>
                                            </div>
                                            <div class="d-flex align-items-center">
                                                <span class="text-muted" style="width: 60px;">Date:</span>
                                                <span class="text-nowrap ms-1"><?= htmlspecialchars($subscriptionItem['invoice_date'] ?? 'N/A'); ?></span>
                                            </div>
                                        </div>
                                    </td>
                                    <td>
                                        <div class="btn-group">
                                            <a href="view_subscription_details.php?debtor_code=<?= urlencode($subscriptionItem['debtor_code']) ?>&id=<?= urlencode($subscriptionItem['subscription_id']) ?>" 
                                            class="btn btn-outline-secondary btn-sm" title="View Details">
                                                <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-eye" viewBox="0 0 16 16">
                                                    <path d="M16 8s-3-5.5-8-5.5S0 8 0 8s3 5.5 8 5.5S16 8 16 8M1.173 8a13.133 13.133 0 0 1 1.66-2.043C4.12 4.668 5.88 3.5 8 3.5c2.12 0 3.879 1.168 5.168 2.457A13.133 13.133 0 0 1 14.828 8c-.058.087-.122.183-.195.288-.335.48-.83 1.12-1.465 1.755C11.879 11.332 10.119 12.5 8 12.5c-2.12 0-3.879-1.168-5.168-2.457A13.134 13.134 0 0 1 1.172 8z"/>
                                                    <path d="M8 5.5a2.5 2.5 0 1 0 0 5 2.5 2.5 0 0 0 0-5M4.5 8a3.5 3.5 0 1 1 7 0 3.5 3.5 0 0 1-7 0"/>
                                                </svg>
                                            </a>
                                            <?php if (!empty($subscriptionItem['quotation_number']) && 
                                                    !empty($subscriptionItem['quotation_date']) && 
                                                    !empty($subscriptionItem['pdf_file'])): ?>
                                                <?php
                                                $pdfPath = htmlspecialchars($subscriptionItem['pdf_file']);
                                                $fullPdfPath = 'http://' . $_SERVER['HTTP_HOST'] . '/admin/' . $pdfPath;
                                                $subject = urlencode("Quotation " . $subscriptionItem['quotation_number']);
                                                $body = urlencode("Please find attached the quotation " . $subscriptionItem['quotation_number'] . 
                                                                " dated " . $subscriptionItem['quotation_date'] . ".");
                                                $to = urlencode($mainCustomer['customer_email']);
                                                $cc = urlencode('sales@citssb.net');
                                                $mailtoLink = "mailto:{$to}?cc={$cc}&subject={$subject}&body={$body}&attachment={$fullPdfPath}";
                                                ?>
                                                <a href="<?= $mailtoLink ?>" class="btn btn-outline-primary btn-sm" title="Send Quotation">
                                                    <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-envelope" viewBox="0 0 16 16">
                                                        <path d="M0 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2zm2-1a1 1 0 0 0-1 1v.217l7 4.2 7-4.2V4a1 1 0 0 0-1-1zm13 2.383-4.708 2.825L15 11.105zm-.034 6.876-5.64-3.471L8 9.583l-1.326-.795-5.64 3.47A1 1 0 0 0 2 13h12a1 1 0 0 0 .966-.741M1 11.105l4.708-2.897L1 5.383z"/>
                                                    </svg>
                                                </a>
                                                <a href="<?= $fullPdfPath ?>" class="btn btn-outline-success btn-sm" download title="Download PDF">
                                                    <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-download" viewBox="0 0 16 16">
                                                        <path d="M.5 9.9a.5.5 0 0 1 .5.5v2.5a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2.5a.5.5 0 0 1 1 0v2.5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2v-2.5a.5.5 0 0 1 .5-.5"/>
                                                        <path d="M7.646 11.854a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 10.293V1.5a.5.5 0 0 0-1 0v8.793L5.354 8.146a.5.5 0 1 0-.708.708l3 3z"/>
                                                    </svg>
                                                </a>
                                            <?php endif; ?>
                                        </div>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php else: ?>
                            <tr>
                                <td colspan="4" class="text-center">No subscription data found for this company.</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            
        </div>
    </div>
</div>
<!-- Bootstrap 5.x JS Bundle (Optional, if you need Bootstrap JS components) -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>