<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Define the Offsite Backup group and its fields
$groups = [
    'Offsite Backup' => [
        'General' => ['active', 'url', 'login_id', 'password', 'monitor_service', 'others'],
    ]
];

// Check if debtor_code and item_type_ac_offsite_backup_id are passed via URL
if (isset($_GET['debtor_code']) && isset($_GET['item_type_ac_offsite_backup_id'])) {
    $debtorCode = $_GET['debtor_code'];
    $itemTypeId = $_GET['item_type_ac_offsite_backup_id'];
    $table = 'item_type_ac_offsite_backup';
    $idField = 'item_type_ac_offsite_backup_id';

    // Fetch the item details and company_name based on debtor_code and item ID
    $stmt = $pdo->prepare("SELECT * FROM $table WHERE debtor_code = :debtor_code AND $idField = :item_id LIMIT 1");
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$item) {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }

    // Extract company_name from the fetched item
    $companyName = $item['company_name'];

    // Determine the group name (Offsite Backup in this case)
    $groupName = 'Offsite Backup';
    $groupData = $groups[$groupName] ?? [];

    if (empty($groupData)) {
        echo "<p>Invalid group name.</p>";
        exit;
    }
} else {
    echo "<p>No debtor code or item ID provided.</p>";
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Offsite Backup Details</title>
    <!-- Bootstrap 5.x CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
        .table-fixed {
            table-layout: fixed;
            width: 100%;
        }
        .table-fixed td {
            overflow: hidden;
            text-overflow: ellipsis;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">Offsite Backup Details</h5>
                <p>Company: <?= htmlspecialchars($companyName) ?></p>
            </div>
            <div class="card-body">
                <!-- Nav tabs -->
                <ul class="nav nav-tabs" id="myTab" role="tablist">
                    <li class="nav-item">
                        <a class="nav-link active" id="general-tab" data-bs-toggle="tab" href="#general" role="tab">General</a>
                    </li>
                </ul>

                <!-- Tab content -->
                <div class="tab-content mt-3">
                    <!-- General Tab -->
                    <div class="tab-pane fade show active" id="general" role="tabpanel">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groupData['General'] as $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                        <td>
                                            <?php if ($field == 'active' || $field == 'monitor_service'): ?>
                                                <?= $item[$field] == 1 ? 'Yes' : 'No' ?>
                                            <?php elseif ($field == 'password'): ?>
                                                <div class="password-container">
                                                    <?php foreach (explode(',', $item[$field]) as $password): ?>
                                                        <div class="password-field" data-password="<?= htmlspecialchars($password) ?>">******</div>
                                                    <?php endforeach; ?>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? 'N/A') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
        <div style="display: flex; align-items: center; margin-top: 20px;">
            <a href="view_autocount_table.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>&company_name=<?= urlencode($companyName) ?>" class="btn btn-secondary">Back</a>
        </div>
    </div>

    <!-- Bootstrap 5.x JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
            button.addEventListener('click', function() {
                var passwordContainer = this.closest('.password-container');
                if (!passwordContainer) return;

                var passwordFields = passwordContainer.querySelectorAll('.password-field');
                passwordFields.forEach(function(field) {
                    if (field.innerText === '******') {
                        var encryptedPassword = field.getAttribute('data-password');
                        var xhr = new XMLHttpRequest();
                        xhr.onreadystatechange = function() {
                            if (xhr.readyState == 4 && xhr.status == 200) {
                                field.innerText = xhr.responseText;
                                button.innerHTML = '<i class="bi bi-eye-slash"></i>';
                            }
                        };
                        xhr.open("POST", "../functions/decrypt.php", true);
                        xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
                        xhr.send("encryptedPassword=" + encodeURIComponent(encryptedPassword) + "&key=your_secret_key");
                    } else {
                        field.innerText = '******';
                        button.innerHTML = '<i class="bi bi-eye"></i>';
                    }
                });
            });
        });
    </script>

    
</body>
</html>