<?php
require 'config/auth.php'; // Ensure user is authenticated
require '../layout/header.php';
require '../database/db.php'; // Connect to the database
require 'decrypt.php'; // Include the decryption function
require 'encrypt.php'; // Include the encryption function
date_default_timezone_set('Asia/Kuala_Lumpur');

// Define the groups and their fields
$groups = [
    'Autocount' => [
        'General' => ['active'],
        'Autocount Details' => ['autocount_edition', 'autocount_version', 'autocount_revision', 'number_of_account_book'],
        'Autocount Login' => ['admin_password', 'auto_email_address'],
        'SQL' => ['sql_name', 'sql_port', 'sql_server_version'],
        'Backup Details' => ['backup_time', 'offsite_backup'],
        'Tax' => ['tax'],
        'Autocount Main PC Details' => ['installed_pc', 'accounting_pid', 'main_pc_installer_computer_tcpip'],
        'E Invoice' => ['implement_and_training_e_invoice', 'einvoice_installed_company_name'],
        'Module and Plugins' => ['add_on_module', 'plug_in', 'add_on_pos_module'],
        'Others' => ['others'],
    ],
    'Cloud Accounting' => [
        'General' => ['active', 'login_account', 'login_password', 'onesales_pos', 'onesales_ecommerce', 'others'],
    ],
    'Cloud Payroll' => [
        'General' => ['active', 'login_account', 'login_password', 'payroll_user_login_id', 'payroll_user_login_password', 'others', 'hardware_id', 'linking_hardware', 'location'],
    ],
    'Million Accounting' => [
        'General' => ['active', 'sql_server_version', 'version', 'login_id', 'password', 'installed_pc', 'others'],
    ],
    'Million Payroll' => [
        'General' => ['active', 'sql_server_version', 'version', 'login_id', 'password', 'installed_pc', 'others'],
    ],
    'Offsite Backup' => [
        'General' => ['active', 'url', 'login_id', 'password', 'monitor_service', 'others'],
    ],
    'Autocount/Payroll Client' => [
        'General' => ['active', 'autocount_client_version', 'installed_pc', 'others'],
    ]
];

// Check if debtor_code and item ID are passed via URL
if (isset($_GET['debtor_code'])) {
    $debtorCode = $_GET['debtor_code'];

    // Determine the item ID and table based on the group
    if (isset($_GET['item_type_cloud_accounting_id'])) {
        $itemTypeId = $_GET['item_type_cloud_accounting_id'];
        $table = 'item_type_cloud_accounting';
        $idField = 'item_type_cloud_accounting_id';
    } elseif (isset($_GET['item_type_ac_offsite_backup_id'])) {
        $itemTypeId = $_GET['item_type_ac_offsite_backup_id'];
        $table = 'item_type_ac_offsite_backup';
        $idField = 'item_type_ac_offsite_backup_id';
    } elseif (isset($_GET['item_type_million_accounting_id'])) {
        $itemTypeId = $_GET['item_type_million_accounting_id'];
        $table = 'item_type_million_accounting';
        $idField = 'item_type_million_accounting_id';
    } elseif (isset($_GET['item_type_million_payroll_id'])) {
        $itemTypeId = $_GET['item_type_million_payroll_id'];
        $table = 'item_type_million_payroll';
        $idField = 'item_type_million_payroll_id';
    } elseif (isset($_GET['item_type_cloud_payroll_id'])) {
        $itemTypeId = $_GET['item_type_cloud_payroll_id'];
        $table = 'item_type_cloud_payroll';
        $idField = 'item_type_cloud_payroll_id';
    } elseif (isset($_GET['item_type_ac_id'])) {
        $itemTypeId = $_GET['item_type_ac_id'];
        $table = 'item_type_ac';
        $idField = 'item_type_ac_id';
    } elseif (isset($_GET['item_type_ac_client_id'])) {
        $itemTypeId = $_GET['item_type_ac_client_id'];
        $table = 'item_type_ac_client';
        $idField = 'item_type_ac_client_id';
    } elseif (isset($_GET['item_type_ac_main_id'])) {
        $itemTypeId = $_GET['item_type_ac_main_id'];
        $table = 'item_type_ac_main';
        $idField = 'item_type_ac_main_id';
    } else {
        echo "<p>No item ID provided.</p>";
        exit;
    }

    // Fetch the item details and company_name based on debtor_code and item ID
    $stmt = $pdo->prepare("SELECT * FROM $table WHERE debtor_code = :debtor_code AND $idField = :item_id LIMIT 1");
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$item) {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }

    // Extract company_name from the fetched item
    $companyName = $item['company_name'];

    // Determine the group name
    $groupName = $item['item_type_ac_group_name'];
    $groupData = $groups[$groupName] ?? [];

    if (empty($groupData)) {
        echo "<p>Invalid group name.</p>";
        exit;
    }

    // Fetch POS fields from ac_pos_fields table (only for Autocount group)
    $posFields = [];
    if ($groupName === 'Autocount') {
        $stmt = $pdo->prepare('SELECT * FROM ac_pos_fields WHERE item_type_ac_main_id = :item_type_ac_main_id');
        $stmt->bindParam(':item_type_ac_main_id', $itemTypeId);
        $stmt->execute();
        $posFields = $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    // Fetch item_type_pc_id for the installed PC
    $installedPc = $item['installed_pc'] ?? null;
    $itemTypePcId = null;
    if ($installedPc) {
        $stmt = $pdo->prepare('SELECT item_type_pc_id FROM item_type_pc WHERE debtor_code = :debtor_code AND computer_name = :computer_name LIMIT 1');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->bindParam(':computer_name', $installedPc);
        $stmt->execute();
        $pcDetails = $stmt->fetch(PDO::FETCH_ASSOC);
        $itemTypePcId = $pcDetails['item_type_pc_id'] ?? null;
    }
} else {
    echo "<p>No debtor code provided.</p>";
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Details</title>
    <!-- Bootstrap 5.x CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
        .table-fixed {
            table-layout: fixed;
            width: 100%;
        }
        .table-fixed td {
            overflow: hidden;
            text-overflow: ellipsis;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">Details for <?= htmlspecialchars($groupName) ?></h5>
                <p>Company: <?= htmlspecialchars($companyName) ?></p>
            </div>
            <div class="card-body">
                <!-- Nav tabs -->
                <ul class="nav nav-tabs" id="myTab" role="tablist">
                    <li class="nav-item">
                        <a class="nav-link active" id="general-tab" data-bs-toggle="tab" href="#general" role="tab">General</a>
                    </li>
                    <?php if ($groupName === 'Autocount'): ?>
                        <li class="nav-item">
                            <a class="nav-link" id="autocount-details-tab" data-bs-toggle="tab" href="#autocount-details" role="tab">Autocount Details</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="autocount-login-tab" data-bs-toggle="tab" href="#autocount-login" role="tab">Autocount Login</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="sql-tab" data-bs-toggle="tab" href="#sql" role="tab">SQL</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="backup-details-tab" data-bs-toggle="tab" href="#backup-details" role="tab">Backup Details</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="tax-tab" data-bs-toggle="tab" href="#tax" role="tab">Tax</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="autocount-main-pc-tab" data-bs-toggle="tab" href="#autocount-main-pc" role="tab">Autocount Main PC Details</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="e-invoice-tab" data-bs-toggle="tab" href="#e-invoice" role="tab">E Invoice</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="module-plugins-tab" data-bs-toggle="tab" href="#module-plugins" role="tab">Module and Plugins</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="others-tab" data-bs-toggle="tab" href="#others" role="tab">Others</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="pos-fields-tab" data-bs-toggle="tab" href="#pos-fields" role="tab">POS Fields</a>
                        </li>
                    <?php endif; ?>
                </ul>

                <!-- Tab content -->
                <div class="tab-content mt-3">
                    <!-- General Tab -->
                    <div class="tab-pane fade show active" id="general" role="tabpanel">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groupData['General'] as $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                        <td>
                                            <?php if ($field == 'active' || $field == 'tax' || $field == 'implement_and_training_e_invoice' || $field == 'onesales_pos' || $field == 'onesales_ecommerce' || $field == 'monitor_service'): ?>
                                                <?= $item[$field] == 1 ? 'Yes' : 'No' ?>
                                            <?php elseif ($field == 'installed_pc'): ?>
                                                <?php if (array_key_exists('installed_pc', $item) && $item['installed_pc']): ?>
                                                    <a href="view_pc_table_details.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>&item_type_pc_id=<?= htmlspecialchars($itemTypePcId) ?>"><?= htmlspecialchars($item['installed_pc']) ?></a>
                                                <?php else: ?>
                                                    N/A
                                                <?php endif; ?>
                                            <?php elseif ($field == 'login_password' || $field == 'password' || $field == 'payroll_user_login_password'): ?>
                                                <div class="password-container">
                                                    <?php foreach (explode(',', $item[$field]) as $password): ?>
                                                        <div class="password-field" data-password="<?= htmlspecialchars($password) ?>">******</div>
                                                    <?php endforeach; ?>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? 'N/A') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <?php if ($groupName === 'Autocount'): ?>
                        <!-- Autocount Details Tab -->
                        <div class="tab-pane fade" id="autocount-details" role="tabpanel">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['Autocount Details'] as $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                            <td><?= htmlspecialchars($item[$field] ?? 'N/A') ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>

                        <!-- Autocount Login Tab -->
                        <div class="tab-pane fade" id="autocount-login" role="tabpanel">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['Autocount Login'] as $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                            <td>
                                                <?php if ($field == 'admin_password'): ?>
                                                    <div class="password-container">
                                                        <?php foreach (explode(',', $item[$field]) as $password): ?>
                                                            <div class="password-field" data-password="<?= htmlspecialchars($password) ?>">******</div>
                                                        <?php endforeach; ?>
                                                        <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                            <i class="bi bi-eye"></i>
                                                        </button>
                                                    </div>
                                                <?php else: ?>
                                                    <?= htmlspecialchars($item[$field] ?? 'N/A') ?>
                                                <?php endif; ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>

                        <!-- SQL Tab -->
                        <div class="tab-pane fade" id="sql" role="tabpanel">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['SQL'] as $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                            <td><?= htmlspecialchars($item[$field] ?? 'N/A') ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>

                        <!-- Backup Details Tab -->
                        <div class="tab-pane fade" id="backup-details" role="tabpanel">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['Backup Details'] as $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                            <td>
                                                <?php if ($field == 'offsite_backup'): ?>
                                                    <?= $item[$field] == 1 ? 'Yes' : 'No' ?>
                                                <?php else: ?>
                                                    <?= htmlspecialchars($item[$field] ?? 'N/A') ?>
                                                <?php endif; ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>

                        <!-- Tax Tab -->
                        <div class="tab-pane fade" id="tax" role="tabpanel">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['Tax'] as $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                            <td><?= $item[$field] == 1 ? 'Yes' : 'No' ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>

                        <!-- Autocount Main PC Details Tab -->
                        <div class="tab-pane fade" id="autocount-main-pc" role="tabpanel">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['Autocount Main PC Details'] as $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                            <td>
                                                <?php if ($field == 'installed_pc'): ?>
                                                    <?php if (array_key_exists('installed_pc', $item) && $item['installed_pc']): ?>
                                                        <a href="view_pc_table_details.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>&item_type_pc_id=<?= htmlspecialchars($itemTypePcId) ?>"><?= htmlspecialchars($item['installed_pc']) ?></a>
                                                    <?php else: ?>
                                                        N/A
                                                    <?php endif; ?>
                                                <?php else: ?>
                                                    <?= htmlspecialchars($item[$field] ?? 'N/A') ?>
                                                <?php endif; ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>

                        <!-- E Invoice Tab -->
                        <div class="tab-pane fade" id="e-invoice" role="tabpanel">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['E Invoice'] as $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                            <td><?= $item[$field] == 1 ? 'Yes' : 'No' ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>

                        <!-- Module and Plugins Tab -->
                        <div class="tab-pane fade" id="module-plugins" role="tabpanel">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['Module and Plugins'] as $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                            <td><?= htmlspecialchars($item[$field] ?? 'N/A') ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>

                        <!-- Others Tab -->
                        <div class="tab-pane fade" id="others" role="tabpanel">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['Others'] as $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                            <td><?= htmlspecialchars($item[$field] ?? 'N/A') ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>

                        <!-- POS Fields Tab -->
                        <div class="tab-pane fade" id="pos-fields" role="tabpanel">
                            <table class="table table-bordered table-fixed">
                                <thead>
                                    <tr>
                                        <th>POS Edition</th>
                                        <th>POS Version</th>
                                        <th>POS Revision</th>
                                        <th>POS PID</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($posFields as $posField): ?>
                                        <tr>
                                            <td><?= htmlspecialchars($posField['pos_edition'] ?? 'N/A') ?></td>
                                            <td><?= htmlspecialchars($posField['pos_version'] ?? 'N/A') ?></td>
                                            <td><?= htmlspecialchars($posField['pos_revision'] ?? 'N/A') ?></td>
                                            <td><?= htmlspecialchars($posField['pos_pid'] ?? 'N/A') ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <div style="display: flex; align-items: center; margin-top: 20px;">
            <a href="view_autocount_table.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>&company_name=<?= urlencode($companyName) ?>" class="btn btn-secondary">Back</a>
        </div>
    </div>

    <!-- Bootstrap 5.x JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
            button.addEventListener('click', function() {
                var passwordContainer = this.closest('.password-container');
                if (!passwordContainer) return;

                var passwordFields = passwordContainer.querySelectorAll('.password-field');
                passwordFields.forEach(function(field) {
                    if (field.innerText === '******') {
                        var encryptedPassword = field.getAttribute('data-password');
                        var xhr = new XMLHttpRequest();
                        xhr.onreadystatechange = function() {
                            if (xhr.readyState == 4 && xhr.status == 200) {
                                field.innerText = xhr.responseText;
                                button.innerHTML = '<i class="bi bi-eye-slash"></i>';
                            }
                        };
                        xhr.open("POST", "decrypt.php", true);
                        xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
                        xhr.send("encryptedPassword=" + encodeURIComponent(encryptedPassword) + "&key=your_secret_key");
                    } else {
                        field.innerText = '******';
                        button.innerHTML = '<i class="bi bi-eye"></i>';
                    }
                });
            });
        });
    </script>

    
</body>
</html>