<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database

// Check if debtor_code is passed via URL
if (isset($_GET['debtor_code'])) {
    $debtorCode = $_GET['debtor_code'];

    // Check if company_name is passed via URL; if not, fetch it from the database
    if (isset($_GET['company_name'])) {
        $companyName = $_GET['company_name'];
    } else {
        // Fetch company_name based on debtor_code from item_type_ac_main
        $stmt = $pdo->prepare('SELECT company_name FROM item_type_ac_main WHERE debtor_code = :debtor_code LIMIT 1');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->execute();
        $companyName = $stmt->fetchColumn();

        // If no company name is found, set a default value
        if ($companyName === false) {
            $companyName = "Company name not found for this debtor code.";
        }
    }

    // Define the group names and fields with their respective display labels
    $groups = [
        'Autocount' => [
            'fields' => ['active', 'autocount_edition', 'autocount_version', 'autocount_revision'],
            'labels' => ['Active', 'Edition', 'Version', 'Revision']
        ],
        'Autocount/Payroll Client' => [
            'fields' => ['active', 'autocount_client_version', 'installed_pc'],
            'labels' => ['Active', 'Client Version', 'Installed PC']
        ],
        'Cloud Accounting' => [
            'fields' => ['active', 'login_account', 'onesales_pos', 'onesales_ecommerce'],
            'labels' => ['Active', 'Login Account', 'OneSales POS', 'OneSales ECommerce']
        ],
        'Cloud Payroll' => [
            'fields' => ['active', 'login_account'],
            'labels' => ['Active', 'Login Account']
        ],
        'Million Accounting' => [
            'fields' => ['active', 'version'],
            'labels' => ['Active', 'Version']
        ],
        'Million Payroll' => [
            'fields' => ['active', 'version', 'installed_pc'],
            'labels' => ['Active', 'Version', 'Installed PC']
        ],
        'Offsite Backup' => [
            'fields' => ['active', 'url', 'login_id'],
            'labels' => ['Active', 'URL', 'Login ID']
        ]
    ];

    $dataByGroup = [];
    $hasData = false;

    foreach (array_keys($groups) as $group) {
        if ($group === 'Autocount') {
            // Fetch data from item_type_ac_main for the Autocount group
            $stmt = $pdo->prepare('SELECT * FROM item_type_ac_main WHERE debtor_code = :debtor_code AND item_type_ac_group_name = :group_name');
            $stmt->bindParam(':debtor_code', $debtorCode);
            $stmt->bindParam(':group_name', $group);
            $stmt->execute();
            $dataByGroup[$group] = $stmt->fetchAll(PDO::FETCH_ASSOC);
        } elseif ($group === 'Autocount/Payroll Client') {
            // Fetch data from item_type_ac_client for the Autocount/Payroll Client group
            $stmt = $pdo->prepare('SELECT * FROM item_type_ac_client WHERE debtor_code = :debtor_code');
            $stmt->bindParam(':debtor_code', $debtorCode);
            $stmt->execute();
            $dataByGroup[$group] = $stmt->fetchAll(PDO::FETCH_ASSOC);
        } elseif ($group === 'Cloud Accounting') {
            // Fetch data from item_type_cloud_accounting for the Cloud Accounting group
            $stmt = $pdo->prepare('SELECT * FROM item_type_cloud_accounting WHERE debtor_code = :debtor_code');
            $stmt->bindParam(':debtor_code', $debtorCode);
            $stmt->execute();
            $dataByGroup[$group] = $stmt->fetchAll(PDO::FETCH_ASSOC);
        } elseif ($group === 'Cloud Payroll') {
            // Fetch data from item_type_cloud_payroll for the Cloud Payroll group
            $stmt = $pdo->prepare('SELECT * FROM item_type_cloud_payroll WHERE debtor_code = :debtor_code');
            $stmt->bindParam(':debtor_code', $debtorCode);
            $stmt->execute();
            $dataByGroup[$group] = $stmt->fetchAll(PDO::FETCH_ASSOC);
        } elseif ($group === 'Million Accounting') {
            // Fetch data from item_type_million_accounting for the Million Accounting group
            $stmt = $pdo->prepare('SELECT * FROM item_type_million_accounting WHERE debtor_code = :debtor_code');
            $stmt->bindParam(':debtor_code', $debtorCode);
            $stmt->execute();
            $dataByGroup[$group] = $stmt->fetchAll(PDO::FETCH_ASSOC);
        } elseif ($group === 'Million Payroll') {
            // Fetch data from item_type_million_payroll for the Million Payroll group
            $stmt = $pdo->prepare('SELECT * FROM item_type_million_payroll WHERE debtor_code = :debtor_code');
            $stmt->bindParam(':debtor_code', $debtorCode);
            $stmt->execute();
            $dataByGroup[$group] = $stmt->fetchAll(PDO::FETCH_ASSOC);
        } elseif ($group === 'Offsite Backup') {
            // Fetch data for Offsite Backup group from the new table item_type_ac_offsite_backup
            $stmt = $pdo->prepare('SELECT * FROM item_type_ac_offsite_backup WHERE debtor_code = :debtor_code');
            $stmt->bindParam(':debtor_code', $debtorCode);
            $stmt->execute();
            $dataByGroup[$group] = $stmt->fetchAll(PDO::FETCH_ASSOC);
        } else {
            // Fetch data for other groups from the item_type_ac table
            $stmt = $pdo->prepare('SELECT * FROM item_type_ac WHERE debtor_code = :debtor_code AND item_type_ac_group_name = :group_name');
            $stmt->bindParam(':debtor_code', $debtorCode);
            $stmt->bindParam(':group_name', $group);
            $stmt->execute();
            $dataByGroup[$group] = $stmt->fetchAll(PDO::FETCH_ASSOC);
        }
        // Check if this group has data
        if (!empty($dataByGroup[$group])) {
            $hasData = true;
        }
    }
} else {
    echo "<p>No debtor code provided.</p>";
    $dataByGroup = array_fill_keys(array_keys($groups), []);
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Autocount Info</title>
    <!-- Bootstrap 5.x CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- FontAwesome Icons -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css" rel="stylesheet">
    <!-- Custom CSS for Table Height -->
    <style>
        .table-tall td, .table-tall th {
            padding: 1rem; /* Add vertical padding to make rows taller */
        }
    </style>
</head>
<body>
    <div class="container-fluid mt-5">
        <div class="row justify-content-center">
            <div class="col-md-10">
                <!-- Navigation Tabs -->
                <ul class="nav nav-tabs mb-4">
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'company_details.php' ? 'active' : '' ?>" 
                           href="company_details.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Company Details</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_autocount_table.php' ? 'active' : '' ?>" 
                           href="view_autocount_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Autocount</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_email_citssb_table.php' ? 'active' : '' ?>" 
                           href="view_email_citssb_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Email</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_network_table.php' ? 'active' : '' ?>" 
                           href="view_network_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Network</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_nas_table.php' ? 'active' : '' ?>" 
                           href="view_nas_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">NAS</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hardware_table.php' ? 'active' : '' ?>" 
                           href="view_hardware_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pos_hardware_table.php' ? 'active' : '' ?>" 
                           href="view_pos_hardware_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">POS Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pc_table.php' ? 'active' : '' ?>" 
                           href="view_pc_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Computer</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hosting_table.php' ? 'active' : '' ?>" 
                           href="view_hosting_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Hosting</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_software_table.php' ? 'active' : '' ?>" 
                           href="view_software_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Software</a>
                    </li>
                </ul>

                <!-- Rest of the content remains unchanged -->
                <?php if (isset($debtorCode)): ?>
                    <!-- Card for Company Name and Back Button -->
                    <div class="card mb-4">
                        <div class="card-header d-flex align-items-center">
                            <!-- Centered Company Name -->
                            <div class="flex-grow-1 text-center">
                                <h2 class="mb-0"><?= htmlspecialchars($companyName) ?></h2>
                            </div>
                        </div>
                    </div>
                <?php endif; ?>

                <?php if ($hasData): ?>
                    <?php foreach ($groups as $group => $groupData): ?>
                        <?php if (!empty($dataByGroup[$group])): ?>
                            <!-- Card for each group -->
                            <div class="card mb-4">
                                <div class="card-header">
                                    <h3 class="mb-0"><?= htmlspecialchars($group) ?> Information</h3>
                                </div>
                                <div class="card-body">
                                    <div class="table-responsive">
                                        <table class="table table-striped table-hover table-sm table-borderless table-tall">
                                            <thead>
                                                <tr>
                                                    <?php foreach ($groupData['labels'] as $label): ?>
                                                        <th><?= htmlspecialchars($label) ?></th>
                                                    <?php endforeach; ?>
                                                    <th>Actions</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                <?php foreach ($dataByGroup[$group] as $row): ?>
                                                    <tr>
                                                        <?php foreach ($groupData['fields'] as $field): ?>
                                                            <td>
                                                                <?php if ($field == 'active'): ?>
                                                                    <?= $row['active'] == 1 ? 'Yes' : 'No' ?>
                                                                <?php elseif ($field == 'login_password' || $field == 'payroll_user_login_password'): ?>
                                                                    <!-- Hide password for security -->
                                                                    ********
                                                                <?php else: ?>
                                                                    <?= htmlspecialchars($row[$field] ?? '') ?>
                                                                <?php endif; ?>
                                                            </td>
                                                        <?php endforeach; ?>
                                                        <td>
                                                            <?php
                                                            // URL for the view and edit actions
                                                            if ($group === 'Autocount') {
                                                                // Use item_type_ac_main_id for Autocount
                                                                $viewUrl = '/crm/public/company/view_ac_main_details.php?debtor_code=' . urlencode($debtorCode) . '&company_name=' . urlencode($companyName) . '&item_type_ac_main_id=' . urlencode($row['item_type_ac_main_id']);
                                                                $editUrl = '/crm/public/config_info/edit_ac_autocount.php?debtor_code=' . urlencode($debtorCode) . '&company_name=' . urlencode($companyName) . '&item_type_ac_main_id=' . urlencode($row['item_type_ac_main_id']);
                                                            } elseif ($group === 'Autocount/Payroll Client') {
                                                                // Use item_type_ac_client_id for Autocount/Payroll Client
                                                                $viewUrl = '/crm/public/company/view_ac_client_details.php?debtor_code=' . urlencode($debtorCode) . '&company_name=' . urlencode($companyName) . '&item_type_ac_client_id=' . urlencode($row['item_type_ac_client_id']);
                                                                $editUrl = '/crm/public/config_info/edit_ac_client.php?debtor_code=' . urlencode($debtorCode) . '&company_name=' . urlencode($companyName) . '&item_type_ac_client_id=' . urlencode($row['item_type_ac_client_id']);
                                                            } elseif ($group === 'Cloud Accounting') {
                                                                // Use item_type_cloud_accounting_id for Cloud Accounting
                                                                $viewUrl = '/crm/public/company/view_ac_cloud_accounting_details.php?debtor_code=' . urlencode($debtorCode) . '&company_name=' . urlencode($companyName) . '&item_type_cloud_accounting_id=' . urlencode($row['item_type_cloud_accounting_id']);
                                                                $editUrl = '/crm/public/config_info/edit_ac_cloud_accounting.php?debtor_code=' . urlencode($debtorCode) . '&company_name=' . urlencode($companyName) . '&item_type_cloud_accounting_id=' . urlencode($row['item_type_cloud_accounting_id']);
                                                            } elseif ($group === 'Cloud Payroll') {
                                                                // Use item_type_cloud_payroll_id for Cloud Payroll
                                                                $viewUrl = '/crm/public/company/view_ac_cloud_payroll_details.php?debtor_code=' . urlencode($debtorCode) . '&company_name=' . urlencode($companyName) . '&item_type_cloud_payroll_id=' . urlencode($row['item_type_cloud_payroll_id']);
                                                                $editUrl = '/crm/public/config_info/edit_ac_cloud_payroll.php?debtor_code=' . urlencode($debtorCode) . '&company_name=' . urlencode($companyName) . '&item_type_cloud_payroll_id=' . urlencode($row['item_type_cloud_payroll_id']);
                                                            } elseif ($group === 'Million Accounting') {
                                                                // Use item_type_million_accounting_id for Million Accounting
                                                                $viewUrl = '/crm/public/company/view_ac_million_accounting_details.php?debtor_code=' . urlencode($debtorCode) . '&company_name=' . urlencode($companyName) . '&item_type_million_accounting_id=' . urlencode($row['item_type_million_accounting_id']);
                                                                $editUrl = '/crm/public/config_info/edit_ac_million_accounting.php?debtor_code=' . urlencode($debtorCode) . '&company_name=' . urlencode($companyName) . '&item_type_million_accounting_id=' . urlencode($row['item_type_million_accounting_id']);
                                                            } elseif ($group === 'Million Payroll') {
                                                                // Use item_type_million_payroll_id for Million Payroll
                                                                $viewUrl = '/crm/public/company/view_ac_million_payroll_details.php?debtor_code=' . urlencode($debtorCode) . '&company_name=' . urlencode($companyName) . '&item_type_million_payroll_id=' . urlencode($row['item_type_million_payroll_id']);
                                                                $editUrl = '/crm/public/config_info/edit_ac_million_payroll.php?debtor_code=' . urlencode($debtorCode) . '&company_name=' . urlencode($companyName) . '&item_type_million_payroll_id=' . urlencode($row['item_type_million_payroll_id']);
                                                            } elseif ($group === 'Offsite Backup') {
                                                                // Use item_type_ac_offsite_backup_id for Offsite Backup
                                                                $viewUrl = '/crm/public/company/view_ac_offsite_backup_details.php?debtor_code=' . urlencode($debtorCode) . '&company_name=' . urlencode($companyName) . '&item_type_ac_offsite_backup_id=' . urlencode($row['item_type_ac_offsite_backup_id']);
                                                                $editUrl = '/crm/public/config_info/edit_ac_offsite_backup.php?debtor_code=' . urlencode($debtorCode) . '&company_name=' . urlencode($companyName) . '&item_type_ac_offsite_backup_id=' . urlencode($row['item_type_ac_offsite_backup_id']);
                                                            }
                                                            ?>
                                                            <a href="<?= $viewUrl ?>" class="btn btn-primary btn-sm">
                                                                <i class="fas fa-eye"></i> View
                                                            </a> |
                                                            <a href="<?= $editUrl ?>" class="btn btn-primary btn-sm">
                                                                <i class="fas fa-edit"></i> Edit
                                                            </a>
                                                        </td>
                                                    </tr>
                                                <?php endforeach; ?>
                                            </tbody>
                                        </table>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>
                    <?php endforeach; ?>
                <?php else: ?>
                    <div class="alert alert-warning" role="alert">
                        No related autocount information found for this company.
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.x JS Bundle CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

