<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption

// Get the debtor_code and company_name from the URL
$debtor_code = isset($_GET['debtor_code']) ? $_GET['debtor_code'] : null;
$company_name = isset($_GET['company_name']) ? $_GET['company_name'] : null;

if (!$debtor_code) {
    die("Debtor code is required.");
}

// If company_name is not provided in the URL, fetch it from the database
if (!$company_name) {
    $query = "SELECT company_info.company_name 
              FROM company_info 
              WHERE company_info.debtor_code = :debtor_code";
    $stmt = $pdo->prepare($query);
    $stmt->execute(['debtor_code' => $debtor_code]);
    $result = $stmt->fetch(PDO::FETCH_ASSOC);

    $company_name = $result ? $result['company_name'] : 'Unknown Company';
}

// Fetch data by joining item_type_email_citssb with company_info to get the company_name
$query = "SELECT item_type_email_citssb.* 
          FROM item_type_email_citssb 
          WHERE item_type_email_citssb.debtor_code = :debtor_code";
$stmt = $pdo->prepare($query);
$stmt->execute(['debtor_code' => $debtor_code]);
$results = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Email Info</title>
    <!-- Bootstrap 5.x CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- FontAwesome Icons -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css" rel="stylesheet">
    <!-- Bootstrap Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.11.0/font/bootstrap-icons.css" rel="stylesheet">
    <!-- Custom CSS for Table Height -->
    <style>
        .table-container {
            overflow-x: auto; /* Enable horizontal scrolling */
        }

        .table-tall {
            table-layout: fixed; /* Ensures fixed column widths */
            width: 100%; /* Ensures the table takes up the full width */
        }

        .table-tall td, .table-tall th {
            padding: 1rem; /* Add vertical padding to make rows taller */
            word-break: break-word; /* Ensures long text wraps within the cell */
        }

        .password-container {
            display: flex;
            align-items: center;
            gap: 0.5rem; /* Adds spacing between the password and the eye icon */
        }

        .password-field {
            flex-grow: 1; /* Ensures the password field takes up available space */
            white-space: normal; /* Allows text to wrap */
        }
    </style>
</head>
<body>
    <div class="container-fluid mt-5">
        <div class="row justify-content-center">
            <div class="col-md-10">
                <!-- Navigation Tabs -->
                <ul class="nav nav-tabs mb-4">
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'company_details.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/company_details.php?debtor_code=<?= urlencode($debtor_code); ?>&company_name=<?= urlencode($company_name); ?>">Company Details</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_autocount_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_autocount_table.php?debtor_code=<?= urlencode($debtor_code); ?>&company_name=<?= urlencode($company_name); ?>">Autocount</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_email_citssb_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_email_citssb_table.php?debtor_code=<?= urlencode($debtor_code); ?>&company_name=<?= urlencode($company_name); ?>">Email</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_network_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_network_table.php?debtor_code=<?= urlencode($debtor_code); ?>&company_name=<?= urlencode($company_name); ?>">Network</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_nas_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_nas_table.php?debtor_code=<?= urlencode($debtor_code); ?>&company_name=<?= urlencode($company_name); ?>">NAS</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hardware_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_hardware_table.php?debtor_code=<?= urlencode($debtor_code); ?>&company_name=<?= urlencode($company_name); ?>">Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pos_hardware_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_pos_hardware_table.php?debtor_code=<?= urlencode($debtor_code); ?>&company_name=<?= urlencode($company_name); ?>">POS Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pc_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_pc_table.php?debtor_code=<?= urlencode($debtor_code); ?>&company_name=<?= urlencode($company_name); ?>">Computer</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hosting_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_hosting_table.php?debtor_code=<?= urlencode($debtor_code); ?>&company_name=<?= urlencode($company_name); ?>">Hosting</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_software_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_software_table.php?debtor_code=<?= urlencode($debtor_code); ?>&company_name=<?= urlencode($company_name); ?>">Software</a>
                    </li>
                </ul>

                <!-- Card for Company Name and Back Button -->
                <div class="card mb-4">
                    <div class="card-header d-flex align-items-center">
                        <!-- Centered Company Name -->
                        <div class="flex-grow-1 text-center">
                            <h2 class="mb-0"><?= htmlspecialchars($company_name) ?></h2>
                        </div>
                    </div>
                </div>

                <!-- Card for Email Information -->
                <div class="card mb-4">
                    <div class="card-header">
                        <h3 class="mb-0">Email Information</h3>
                    </div>
                    <div class="card-body">
                        <?php if (empty($results)): ?>
                            <div class="alert alert-warning" role="alert">
                                No related email information found for this company.
                            </div>
                        <?php else: ?>
                            <div class="table-container"> <!-- Added table-container for horizontal scrolling -->
                                <table class="table table-striped table-hover table-sm table-borderless table-tall">
                                    <thead>
                                        <tr>
                                            <th>Email</th>
                                            <th>Used At</th>
                                            <th>Password</th>
                                            <th>Actions</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php foreach ($results as $row): ?>
                                            <tr>
                                                <td><?= htmlspecialchars($row['email']); ?></td>
                                                <td><?= htmlspecialchars($row['used_at']); ?></td>
                                                <td>
                                                    <div class="password-container">
                                                        <span class="password-field" data-password="<?= htmlspecialchars($row['password']); ?>">******</span>
                                                        <button class="btn btn-sm toggle-password-btn">
                                                            <i class="bi bi-eye"></i> <!-- Default icon -->
                                                        </button>
                                                    </div>
                                                </td>
                                                <td>
                                                    <a href="/crm/public/config_info/edit_email_for_citssb_use.php?item_type_email_citssb_id=<?= $row['item_type_email_citssb_id']; ?>&amp;debtor_code=<?= $debtor_code; ?>" class="btn btn-primary btn-sm">
                                                        <i class="fas fa-edit"></i> Edit
                                                    </a>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.x JS Bundle CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
    <!-- Toggle Password Script -->
    <script>
        document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
            button.addEventListener('click', function() {
                var passwordContainer = this.closest('.password-container');
                if (!passwordContainer) return;

                var passwordField = passwordContainer.querySelector('.password-field');
                var icon = this.querySelector('i'); // Get the icon element

                if (passwordField.innerText === '******') {
                    var encryptedPassword = passwordField.getAttribute('data-password');
                    var xhr = new XMLHttpRequest();
                    xhr.onreadystatechange = function() {
                        if (xhr.readyState == 4 && xhr.status == 200) {
                            passwordField.innerText = xhr.responseText; // Show decrypted password
                            icon.classList.remove('bi-eye'); // Remove eye icon
                            icon.classList.add('bi-eye-slash'); // Add eye-slash icon
                        }
                    };
                    xhr.open("POST", "../functions/decrypt.php", true);
                    xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
                    xhr.send("encryptedPassword=" + encodeURIComponent(encryptedPassword) + "&key=your_secret_key");
                } else {
                    passwordField.innerText = '******'; // Hide password
                    icon.classList.remove('bi-eye-slash'); // Remove eye-slash icon
                    icon.classList.add('bi-eye'); // Add eye icon
                }
            });
        });
    </script>
</body>
</html>

