<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database


// Define the group names and fields with their respective display labels
$groups = [
    'UPS' => [
        'General' => [
            'fields' => ['active', 'brand', 'model', 'installed_pc', 'part_no', 'serial_number'],
            'labels' => ['Active', 'Brand', 'Model', 'Installed PC', 'Part No.', 'Serial Number']
        ],
        'Network' => [
            'fields' => ['tcp_ip'],
            'labels' => ['TCP/IP']
        ],
        'Software' => [
            'fields' => ['software_name', 'software_version', 'login', 'password'],
            'labels' => ['Software Name', 'Software Version', 'Login', 'Password']
        ],
        'Others' => [
            'fields' => ['others'],
            'labels' => ['Others']
        ]
    ],
    'Printer' => [
        'General' => [
            'fields' => ['active', 'brand', 'model', 'port', 'type','serial_number', 'print_server', 'tcp_ip','installed_pc', 'others'],
            'labels' => ['Active', 'Brand', 'Model', 'Port', 'Type','Serial Number', 'Print Server', 'TCP/IP','Installed PC', 'Others']
        ]
    ],
    'CCTV' => [
        'General' => [
            'fields' => ['active', 'login', 'password', 'model'],
            'labels' => ['Active', 'Login', 'Password', 'Model']
        ],
        'Network' => [
            'fields' => ['ddns', 'open_port'],
            'labels' => ['DDNS', 'Open Port']
        ],
        'User Login' => [
            'fields' => ['user_login', 'user_password'],
            'labels' => ['User Login', 'User Password']
        ]
    ],
    'Others' => [
        'General' => [
            'fields' => ['active', 'brand', 'model', 'part_no', 'serial_number', 'installed_pc', 'others'],
            'labels' => ['Active', 'Brand', 'Model', 'Part No.', 'Serial Number', 'Installed PC', 'Others']
        ]
    ]
];

// Check if debtor_code is passed via URL
if (isset($_GET['debtor_code'])) {
    $debtorCode = $_GET['debtor_code'];

    // Determine the item ID and table based on the group
    if (isset($_GET['item_type_hw_ups_id'])) {
        $itemTypeId = $_GET['item_type_hw_ups_id'];
        $table = 'item_type_hw_ups';
        $idField = 'item_type_hw_ups_id';
    } elseif (isset($_GET['item_type_hw_printer_id'])) {
        $itemTypeId = $_GET['item_type_hw_printer_id'];
        $table = 'item_type_hw_printer';
        $idField = 'item_type_hw_printer_id';
    } elseif (isset($_GET['item_type_hw_cctv_id'])) {
        $itemTypeId = $_GET['item_type_hw_cctv_id'];
        $table = 'item_type_hw_cctv';
        $idField = 'item_type_hw_cctv_id';
    } elseif (isset($_GET['item_type_hw_others_id'])) {
        $itemTypeId = $_GET['item_type_hw_others_id'];
        $table = 'item_type_hw_others';
        $idField = 'item_type_hw_others_id';
    } else {
        echo "<p>No item ID provided.</p>";
        exit;
    }

    // Fetch the item details based on the table and item ID
    $stmt = $pdo->prepare("SELECT * FROM $table WHERE $idField = :item_id");
    $stmt->bindParam(':item_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($item) {
        // Fetch company_name based on debtor_code
        $stmt = $pdo->prepare('SELECT company_name FROM item_type_hw WHERE debtor_code = :debtor_code LIMIT 1');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->execute();
        $companyName = $stmt->fetchColumn();

        // Determine the group name
        $groupName = $item['item_type_hw_group_name'];
        $groupData = $groups[$groupName];

        // Fetch the item_type_pc_id based on the installed_pc
        if (($groupName == 'Printer' || $groupName == 'Others' || $groupName == 'UPS') && !empty($item['installed_pc'])) {
            $computerName = $item['installed_pc'];
            $stmt = $pdo->prepare('SELECT item_type_pc_id FROM item_type_pc WHERE computer_name = :computer_name LIMIT 1');
            $stmt->bindParam(':computer_name', $computerName);
            $stmt->execute();
            $itemTypePcId = $stmt->fetchColumn();
        }

        // Fetch installed_pc_for_cctv data for CCTV group
        if ($groupName == 'CCTV') {
            $stmt = $pdo->prepare('SELECT * FROM installed_pc_for_cctv WHERE item_type_hw_cctv_id = :item_id');
            $stmt->bindParam(':item_id', $itemTypeId);
            $stmt->execute();
            $installedPcs = $stmt->fetchAll(PDO::FETCH_ASSOC);
        }
    } else {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }
} else {
    echo "<p>No debtor code provided.</p>";
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Hardware Details</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
        .table-fixed {
            table-layout: fixed;
            width: 100%;
        }
        .table-fixed td {
            overflow: hidden;
            text-overflow: ellipsis;
        }
        .installed-pc-list {
            margin-top: 20px;
        }
        .installed-pc-list table {
            width: 100%;
            margin-bottom: 20px;
        }
        .installed-pc-list th, .installed-pc-list td {
            padding: 10px;
            border: 1px solid #ddd;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">Details for <?= htmlspecialchars($groupName) ?></h5>
                <p>Company: <?= htmlspecialchars($companyName) ?></p>
            </div>
            <div class="card-body">
                <!-- Nav tabs -->
                <ul class="nav nav-tabs" id="myTab" role="tablist">
                    <li class="nav-item">
                        <a class="nav-link active" id="general-tab" data-bs-toggle="tab" href="#general" role="tab">General</a>
                    </li>
                    <?php if ($groupName == 'UPS'): ?>
                        <li class="nav-item">
                            <a class="nav-link" id="network-tab" data-bs-toggle="tab" href="#network" role="tab">Network</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="software-tab" data-bs-toggle="tab" href="#software" role="tab">Software</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="others-tab" data-bs-toggle="tab" href="#others" role="tab">Others</a>
                        </li>
                    <?php endif; ?>
                    <?php if ($groupName == 'CCTV'): ?>
                        <li class="nav-item">
                            <a class="nav-link" id="network-tab" data-bs-toggle="tab" href="#network" role="tab">Network</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="user-login-tab" data-bs-toggle="tab" href="#user-login" role="tab">User Login</a>
                        </li>
                    <?php endif; ?>
                </ul>

                <!-- Tab content -->
                <div class="tab-content mt-3" id="myTabContent">
                    <!-- General Tab -->
                    <div class="tab-pane fade show active" id="general" role="tabpanel" aria-labelledby="general-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groupData['General']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groupData['General']['labels'][$index]) ?></th>
                                        <td>
                                            <?php if ($field == 'active'): ?>
                                                <?= $item['active'] == 1 ? 'Yes' : 'No' ?>
                                            <?php elseif ($field == 'password'): ?>
                                                <div class="password-container">
                                                    <?php foreach (explode(',', $item[$field]) as $password): ?>
                                                        <div class="password-field" data-password="<?= htmlspecialchars($password) ?>">******</div>
                                                    <?php endforeach; ?>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php elseif ($field == 'installed_pc' && !empty($item[$field])): ?>
                                                <?php if (isset($itemTypePcId)): ?>
                                                    <a href="view_pc_table_details.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>&item_type_pc_id=<?= htmlspecialchars($itemTypePcId) ?>">
                                                        <?= htmlspecialchars($item[$field]) ?>
                                                    </a>
                                                <?php else: ?>
                                                    <?= htmlspecialchars($item[$field]) ?>
                                                <?php endif; ?>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? '') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>

                        <!-- Display all installed PCs for CCTV -->
                        <?php if ($groupName == 'CCTV' && !empty($installedPcs)): ?>
                            <div class="installed-pc-list">
                                <h6>Installed PCs</h6>
                                <table>
                                    <thead>
                                        <tr>
                                            <th>Computer Name</th>
                                            <th>Software Login</th>
                                            <th>Software Password</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <?php foreach ($installedPcs as $pc): ?>
                                            <?php
                                            // Fetch item_type_pc_id for the current computer_name
                                            $stmt = $pdo->prepare('SELECT item_type_pc_id FROM item_type_pc WHERE computer_name = :computer_name LIMIT 1');
                                            $stmt->bindParam(':computer_name', $pc['computer_name']);
                                            $stmt->execute();
                                            $itemTypePcId = $stmt->fetchColumn();
                                            ?>
                                            <tr>
                                                <td>
                                                    <a href="view_pc_table_details.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>&item_type_pc_id=<?= htmlspecialchars($itemTypePcId) ?>">
                                                        <?= htmlspecialchars($pc['computer_name']) ?>
                                                    </a>
                                                </td>
                                                <td><?= htmlspecialchars($pc['software_login'] ?? '') ?></td>
                                                <td>
                                                    <div class="password-container">
                                                        <div class="password-field" data-password="<?= htmlspecialchars($pc['software_password'] ?? '') ?>">******</div>
                                                        <button class="btn btn-link p-0 toggle-password-btn" data-field="software_password">
                                                            <i class="bi bi-eye"></i>
                                                        </button>
                                                    </div>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    </tbody>
                                </table>
                            </div>
                        <?php endif; ?>
                    </div>

                    <!-- Network Tab for UPS -->
                    <?php if ($groupName == 'UPS'): ?>
                        <div class="tab-pane fade" id="network" role="tabpanel" aria-labelledby="network-tab">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['Network']['fields'] as $index => $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars($groupData['Network']['labels'][$index]) ?></th>
                                            <td><?= htmlspecialchars($item[$field] ?? '') ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>

                    <!-- Software Tab for UPS -->
                    <?php if ($groupName == 'UPS'): ?>
                        <div class="tab-pane fade" id="software" role="tabpanel" aria-labelledby="software-tab">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['Software']['fields'] as $index => $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars($groupData['Software']['labels'][$index]) ?></th>
                                            <td>
                                                <?php if ($field == 'password'): ?>
                                                    <div class="password-container">
                                                        <?php foreach (explode(',', $item[$field]) as $password): ?>
                                                            <div class="password-field" data-password="<?= htmlspecialchars($password) ?>">******</div>
                                                        <?php endforeach; ?>
                                                        <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                            <i class="bi bi-eye"></i>
                                                        </button>
                                                    </div>
                                                <?php else: ?>
                                                    <?= htmlspecialchars($item[$field] ?? '') ?>
                                                <?php endif; ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>

                    <!-- Others Tab for UPS -->
                    <?php if ($groupName == 'UPS'): ?>
                        <div class="tab-pane fade" id="others" role="tabpanel" aria-labelledby="others-tab">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['Others']['fields'] as $index => $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars($groupData['Others']['labels'][$index]) ?></th>
                                            <td><?= htmlspecialchars($item[$field] ?? '') ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>

                    <!-- Network Tab for CCTV -->
                    <?php if ($groupName == 'CCTV'): ?>
                        <div class="tab-pane fade" id="network" role="tabpanel" aria-labelledby="network-tab">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['Network']['fields'] as $index => $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars($groupData['Network']['labels'][$index]) ?></th>
                                            <td><?= htmlspecialchars($item[$field] ?? '') ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>

                    <!-- User Login Tab for CCTV -->
                    <?php if ($groupName == 'CCTV'): ?>
                        <div class="tab-pane fade" id="user-login" role="tabpanel" aria-labelledby="user-login-tab">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['User Login']['fields'] as $index => $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars($groupData['User Login']['labels'][$index]) ?></th>
                                            <td>
                                                <?php if ($field == 'user_password'): ?>
                                                    <div class="password-container">
                                                        <?php foreach (explode(',', $item[$field]) as $password): ?>
                                                            <div class="password-field" data-password="<?= htmlspecialchars($password) ?>">******</div>
                                                        <?php endforeach; ?>
                                                        <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                            <i class="bi bi-eye"></i>
                                                        </button>
                                                    </div>
                                                <?php else: ?>
                                                    <?= htmlspecialchars($item[$field] ?? '') ?>
                                                <?php endif; ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <div style="display: flex; align-items: center; margin-top: 20px;">
            <a href="view_hardware_table.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>" class="btn btn-secondary">Back</a>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
            button.addEventListener('click', function() {
                var passwordContainer = this.closest('.password-container');
                if (!passwordContainer) return;

                var passwordFields = passwordContainer.querySelectorAll('.password-field');
                passwordFields.forEach(function(field) {
                    if (field.innerText === '******') {
                        var encryptedPassword = field.getAttribute('data-password');
                        var xhr = new XMLHttpRequest();
                        xhr.onreadystatechange = function() {
                            if (xhr.readyState == 4 && xhr.status == 200) {
                                field.innerText = xhr.responseText;
                                button.innerHTML = '<i class="bi bi-eye-slash"></i>';
                            }
                        };
                        xhr.open("POST", "decrypt.php", true);
                        xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
                        xhr.send("encryptedPassword=" + encodeURIComponent(encryptedPassword) + "&key=your_secret_key");
                    } else {
                        field.innerText = '******';
                        button.innerHTML = '<i class="bi bi-eye"></i>';
                    }
                });
            });
        });

        // Hide passwords when switching tabs
        document.querySelectorAll('#myTab .nav-link').forEach(function(tab) {
            tab.addEventListener('click', function() {
                document.querySelectorAll('.password-field').forEach(function(field) {
                    field.innerText = '******';
                });
                document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
                    button.innerHTML = '<i class="bi bi-eye"></i>';
                });
            });
        });
    </script>
</body>
</html>

