<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database

// Check if debtor_code is passed via URL
if (isset($_GET['debtor_code'])) {
    $debtorCode = $_GET['debtor_code'];

    // Check if company_name is passed via URL
    if (isset($_GET['company_name'])) {
        $companyName = $_GET['company_name'];
    } else {
        // Fetch company_name based on debtor_code
        $stmt = $pdo->prepare('SELECT company_name FROM item_type_hosting_email WHERE debtor_code = :debtor_code LIMIT 1');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->execute();
        $companyName = $stmt->fetchColumn();

        // If no company name is found, set a default value
        if ($companyName === false) {
            $companyName = "Company name not found for this debtor code.";
        }
    }

    // Define the group names and fields with their respective display labels
    $groups = [
        'Domain' => [
            'fields' => ['active', 'domain_name', 'server_name'],
            'labels' => ['Active', 'Domain Name', 'Server Name'],
            'detail_page' => 'view_hs_domain_details.php' // Domain detail page
        ],
        'Hosting' => [
            'fields' => ['active', 'service_provider', 'hosting_software'],
            'labels' => ['Active', 'Service Provider', 'Hosting Software'],
            'detail_page' => 'view_hs_hosting_details.php' // Hosting detail page
        ],
        'Email' => [
            'fields' => ['active', 'email_account', 'service_provider'],
            'labels' => ['Active', 'Email Account', 'Service Provider'],
            'detail_page' => 'view_hs_email_details.php' // Email detail page
        ]
    ];

    $dataByGroup = [];
    $hasData = false;

    // Fetch data for each group
    foreach ($groups as $group => $groupData) {
        if ($group === 'Domain') {
            // Fetch data for the Domain group from item_type_hosting_domain
            $stmt = $pdo->prepare('SELECT * FROM item_type_hosting_domain WHERE debtor_code = :debtor_code');
            $stmt->bindParam(':debtor_code', $debtorCode);
            $stmt->execute();
            $dataByGroup[$group] = $stmt->fetchAll(PDO::FETCH_ASSOC);
        } elseif ($group === 'Email') {
            // Fetch data for the Email group from item_type_hosting_email
            $stmt = $pdo->prepare('SELECT * FROM item_type_hosting_email WHERE debtor_code = :debtor_code');
            $stmt->bindParam(':debtor_code', $debtorCode);
            $stmt->execute();
            $dataByGroup[$group] = $stmt->fetchAll(PDO::FETCH_ASSOC);
        } else {
            // Fetch data for Hosting group from item_type_hosting_hosting
            $stmt = $pdo->prepare('SELECT * FROM item_type_hosting_hosting WHERE debtor_code = :debtor_code AND item_type_hosting_group_name = :group_name');
            $stmt->bindParam(':debtor_code', $debtorCode);
            $stmt->bindParam(':group_name', $group);
            $stmt->execute();
            $dataByGroup[$group] = $stmt->fetchAll(PDO::FETCH_ASSOC);
        }

        // Check if this group has data
        if (!empty($dataByGroup[$group])) {
            $hasData = true;
        }
    }
} else {
    echo "<p>No debtor code provided.</p>";
    $dataByGroup = array_fill_keys(array_keys($groups), []);
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Hosting Info</title>
    <!-- Bootstrap 5.x CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- FontAwesome Icons -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css" rel="stylesheet">
    <!-- Custom CSS for Table Height -->
    <style>
        .table-tall td, .table-tall th {
            padding: 1rem; /* Add vertical padding to make rows taller */
        }
    </style>
</head>
<body>
    <div class="container-fluid mt-5">
        <div class="row justify-content-center">
            <div class="col-md-10">
                <ul class="nav nav-tabs mb-4">
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'company_details.php' ? 'active' : '' ?>" 
                           href="company_details.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Company Details</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_autocount_table.php' ? 'active' : '' ?>" 
                           href="view_autocount_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Autocount</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_email_citssb_table.php' ? 'active' : '' ?>" 
                           href="view_email_citssb_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Email</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_network_table.php' ? 'active' : '' ?>" 
                           href="view_network_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Network</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_nas_table.php' ? 'active' : '' ?>" 
                           href="view_nas_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">NAS</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hardware_table.php' ? 'active' : '' ?>" 
                           href="view_hardware_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pos_hardware_table.php' ? 'active' : '' ?>" 
                           href="view_pos_hardware_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">POS Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pc_table.php' ? 'active' : '' ?>" 
                           href="view_pc_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Computer</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hosting_table.php' ? 'active' : '' ?>" 
                           href="view_hosting_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Hosting</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_software_table.php' ? 'active' : '' ?>" 
                           href="view_software_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Software</a>
                    </li>
                </ul>

                <!-- Card for Company Name and Back Button -->
                <div class="card mb-4">
                    <div class="card-header d-flex align-items-center">
                        <!-- Centered Company Name -->
                        <div class="flex-grow-1 text-center">
                            <h2 class="mb-0"><?= htmlspecialchars($companyName) ?></h2>
                        </div>
                    </div>
                </div>

                <?php if ($hasData): ?>
                    <?php foreach ($groups as $group => $groupData): ?>
                        <?php if (!empty($dataByGroup[$group])): ?>
                            <!-- Card for each group -->
                            <div class="card mb-4">
                                <div class="card-header">
                                    <h3 class="mb-0"><?= htmlspecialchars($group) ?> Information</h3>
                                </div>
                                <div class="card-body">
                                    <div class="table-responsive">
                                        <table class="table table-striped table-hover table-sm table-borderless table-tall">
                                            <thead>
                                                <tr>
                                                    <?php foreach ($groupData['labels'] as $label): ?>
                                                        <th><?= htmlspecialchars($label) ?></th>
                                                    <?php endforeach; ?>
                                                    <th>Actions</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                <?php foreach ($dataByGroup[$group] as $row): ?>
                                                    <tr>
                                                        <?php foreach ($groupData['fields'] as $field): ?>
                                                            <td>
                                                                <?php if ($field == 'active'): ?>
                                                                    <?= $row['active'] == 1 ? 'Yes' : 'No' ?>
                                                                <?php else: ?>
                                                                    <?= htmlspecialchars($row[$field] ?? '') ?>
                                                                <?php endif; ?>
                                                            </td>
                                                        <?php endforeach; ?>
                                                        <td>
                                                            <?php
                                                            // Determine the primary key based on the group
                                                            if ($group === 'Domain') {
                                                                $primaryKey = 'item_type_hosting_domain_id';
                                                            } elseif ($group === 'Email') {
                                                                $primaryKey = 'item_type_hosting_email_id';
                                                            } else {
                                                                $primaryKey = 'item_type_hosting_hosting_id'; // Updated primary key
                                                            }
                                                            $primaryKeyValue = $row[$primaryKey];

                                                            // Build the view and edit URLs
                                                            $viewUrl = '/crm/public/company/' . $groupData['detail_page'] . '?debtor_code=' . urlencode($debtorCode) . '&' . $primaryKey . '=' . urlencode($primaryKeyValue);
                                                            $editUrl = ($group === 'Domain') ? '/crm/public/config_info/edit_hs_domain.php' : ($group === 'Email' ? '/crm/public/config_info/edit_hs_email.php' : '/crm/public/config_info/edit_hs_hosting.php');
                                                            $editUrl .= '?debtor_code=' . urlencode($debtorCode) . '&' . $primaryKey . '=' . urlencode($primaryKeyValue);
                                                            ?>
                                                            <a href="<?= $viewUrl ?>" class="btn btn-primary btn-sm">
                                                                <i class="fas fa-eye"></i> View
                                                            </a> |
                                                            <a href="<?= $editUrl ?>" class="btn btn-primary btn-sm">
                                                                <i class="fas fa-edit"></i> Edit
                                                            </a>
                                                        </td>
                                                    </tr>
                                                <?php endforeach; ?>
                                            </tbody>
                                        </table>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>
                    <?php endforeach; ?>
                <?php else: ?>
                    <div class="alert alert-warning" role="alert">
                        No related hosting information found for this company.
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.x JS Bundle CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>