<?php
// Ensure user is authenticated
require '../config/auth.php';

// Include necessary files
require '../../layout/header.php';
require '../../database/db.php'; // Database connection
require '../functions/decrypt.php';

// Define the group fields and labels for the Email group
$groups = [
    'Email' => [
        'General' => [
            'fields' => ['active', 'email_account', 'service_provider', 'customer_username', 'installed_pc', 'login_password', 'incoming_mail_server', 'outgoing_server', 'incoming_mail_server_port', 'outgoing_mail_server_port'],
            'labels' => ['Active', 'Email Account', 'Service Provider', 'Customer Username', 'Installed PC', 'Login Password', 'Incoming Mail Server', 'Outgoing Server', 'Incoming Mail Server Port', 'Outgoing Mail Server Port']
        ],
        'Others' => [
            'fields' => ['others'],
            'labels' => ['Others']
        ]
    ]
];

// Check if debtor_code and item_type_hosting_email_id are passed via URL
if (isset($_GET['debtor_code']) && isset($_GET['item_type_hosting_email_id'])) {
    $debtorCode = $_GET['debtor_code'];
    $itemTypeId = $_GET['item_type_hosting_email_id'];

    // Define the table and ID field for the Email group
    $table = 'item_type_hosting_email';
    $idField = 'item_type_hosting_email_id';
    $groupName = 'Email';

    // Fetch the item details from the database
    $stmt = $pdo->prepare("SELECT * FROM $table WHERE debtor_code = :debtor_code AND $idField = :item_id LIMIT 1");
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($item) {
        // Fetch company_name based on debtor_code
        $stmt = $pdo->prepare('SELECT company_name FROM item_type_hosting_hosting WHERE debtor_code = :debtor_code LIMIT 1');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->execute();
        $companyName = $stmt->fetchColumn();
    } else {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }
} else {
    echo "<p>No debtor code or item ID provided.</p>";
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Email Details</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons CDN -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
        .table-fixed {
            table-layout: fixed;
            width: 100%;
        }
        .table-fixed td {
            overflow: hidden;
            text-overflow: ellipsis;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">Details for <?= htmlspecialchars($groupName) ?></h5>
                <p>Company: <?= htmlspecialchars($companyName) ?></p>
            </div>
            <div class="card-body">
                <!-- Nav tabs -->
                <ul class="nav nav-tabs" id="myTab" role="tablist">
                    <li class="nav-item">
                        <a class="nav-link active" id="general-tab" data-bs-toggle="tab" href="#general" role="tab">General</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="others-tab" data-bs-toggle="tab" href="#others" role="tab">Others</a>
                    </li>
                </ul>

                <!-- Tab content -->
                <div class="tab-content mt-3" id="myTabContent">
                    <!-- General Tab -->
                    <div class="tab-pane fade show active" id="general" role="tabpanel" aria-labelledby="general-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groups[$groupName]['General']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groups[$groupName]['General']['labels'][$index]) ?></th>
                                        <td>
                                            <?php if ($field == 'active'): ?>
                                                <?= $item['active'] == 1 ? 'Yes' : 'No' ?>
                                            <?php elseif ($field == 'login_password'): ?>
                                                <div class="password-container">
                                                    <div class="password-field" data-password="<?= htmlspecialchars($item[$field]) ?>">******</div>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? '') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Others Tab -->
                    <div class="tab-pane fade" id="others" role="tabpanel" aria-labelledby="others-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groups[$groupName]['Others']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groups[$groupName]['Others']['labels'][$index]) ?></th>
                                        <td><?= htmlspecialchars($item[$field] ?? '') ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
        <div style="display: flex; align-items: center; margin-top: 20px;">
            <a href="view_hosting_table.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>" class="btn btn-secondary">Back</a>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Toggle password visibility
        document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
            button.addEventListener('click', function() {
                var passwordContainer = this.closest('.password-container');
                if (!passwordContainer) return;

                var passwordField = passwordContainer.querySelector('.password-field');
                if (passwordField.innerText === '******') {
                    passwordField.innerText = passwordField.getAttribute('data-password');
                    this.innerHTML = '<i class="bi bi-eye-slash"></i>';
                } else {
                    passwordField.innerText = '******';
                    this.innerHTML = '<i class="bi bi-eye"></i>';
                }
            });
        });
    </script>
</body>
</html>