<?php
require '../config/auth.php';
require '../../layout/header.php';
require '../../database/db.php'; // Database connection
require '../functions/decrypt.php'; // For password encryption (if needed)

// Define the group fields and labels for the Hosting group
$groups = [
    'Hosting' => [
        'General' => [
            'fields' => ['active', 'service_provider', 'hosting_software', 'login_url', 'login_id', 'login_password', 'dns', 'mail_sentinel', 'mailbox', 'mx_record'],
            'labels' => ['Active', 'Service Provider', 'Hosting Software', 'Login URL', 'Login ID', 'Login Password', 'DNS', 'Mail Sentinel', 'Mailbox', 'MX Record']
        ],
        'WordPress' => [
            'fields' => ['wordpress_url', 'wordpress_admin_login', 'wordpress_admin_password'],
            'labels' => ['Wordpress URL', 'Wordpress Admin Login', 'Wordpress Admin Password']
        ],
        'SQL' => [
            'fields' => ['sql_id', 'sql_database', 'sql_password'],
            'labels' => ['SQL ID', 'SQL Database', 'SQL Password']
        ],
        'Others' => [
            'fields' => ['others'],
            'labels' => ['Others']
        ]
    ]
];

// Check if debtor_code and item_type_hosting_hosting_id are passed via URL
if (isset($_GET['debtor_code']) && isset($_GET['item_type_hosting_hosting_id'])) {
    $debtorCode = $_GET['debtor_code'];
    $itemTypeId = $_GET['item_type_hosting_hosting_id'];

    // Define the table and ID field for the Hosting group
    $table = 'item_type_hosting_hosting';
    $idField = 'item_type_hosting_hosting_id';
    $groupName = 'Hosting';

    // Fetch the item details from the database
    $stmt = $pdo->prepare("SELECT * FROM $table WHERE debtor_code = :debtor_code AND $idField = :item_id LIMIT 1");
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($item) {
        // Fetch company_name based on debtor_code
        $stmt = $pdo->prepare('SELECT company_name FROM item_type_hosting_hosting WHERE debtor_code = :debtor_code LIMIT 1');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->execute();
        $companyName = $stmt->fetchColumn();
    } else {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }
} else {
    echo "<p>No debtor code or item ID provided.</p>";
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Hosting Details</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons CDN -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
        .table-fixed {
            table-layout: fixed;
            width: 100%;
        }
        .table-fixed td {
            overflow: hidden;
            text-overflow: ellipsis;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">Details for <?= htmlspecialchars($groupName) ?></h5>
                <p>Company: <?= htmlspecialchars($companyName) ?></p>
            </div>
            <div class="card-body">
                <!-- Nav tabs -->
                <ul class="nav nav-tabs" id="myTab" role="tablist">
                    <li class="nav-item">
                        <a class="nav-link active" id="general-tab" data-bs-toggle="tab" href="#general" role="tab">General</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="wordpress-tab" data-bs-toggle="tab" href="#wordpress" role="tab">WordPress</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="sql-tab" data-bs-toggle="tab" href="#sql" role="tab">SQL</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="others-tab" data-bs-toggle="tab" href="#others" role="tab">Others</a>
                    </li>
                </ul>

                <!-- Tab content -->
                <div class="tab-content mt-3" id="myTabContent">
                    <!-- General Tab -->
                    <div class="tab-pane fade show active" id="general" role="tabpanel" aria-labelledby="general-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groups[$groupName]['General']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groups[$groupName]['General']['labels'][$index]) ?></th>
                                        <td>
                                            <?php if ($field == 'active'): ?>
                                                <?= $item['active'] == 1 ? 'Yes' : 'No' ?>
                                            <?php elseif (in_array($field, ['login_password', 'wordpress_admin_password', 'sql_password'])): ?>
                                                <div class="password-container">
                                                    <div class="password-field" data-password="<?= htmlspecialchars($item[$field]) ?>">******</div>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? '') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- WordPress Tab -->
                    <div class="tab-pane fade" id="wordpress" role="tabpanel" aria-labelledby="wordpress-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groups[$groupName]['WordPress']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groups[$groupName]['WordPress']['labels'][$index]) ?></th>
                                        <td>
                                            <?php if ($field == 'wordpress_admin_password'): ?>
                                                <div class="password-container">
                                                    <div class="password-field" data-password="<?= htmlspecialchars($item[$field]) ?>">******</div>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? '') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- SQL Tab -->
                    <div class="tab-pane fade" id="sql" role="tabpanel" aria-labelledby="sql-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groups[$groupName]['SQL']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groups[$groupName]['SQL']['labels'][$index]) ?></th>
                                        <td>
                                            <?php if ($field == 'sql_password'): ?>
                                                <div class="password-container">
                                                    <div class="password-field" data-password="<?= htmlspecialchars($item[$field]) ?>">******</div>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? '') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Others Tab -->
                    <div class="tab-pane fade" id="others" role="tabpanel" aria-labelledby="others-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groups[$groupName]['Others']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groups[$groupName]['Others']['labels'][$index]) ?></th>
                                        <td><?= htmlspecialchars($item[$field] ?? '') ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
        <div style="display: flex; align-items: center; margin-top: 20px;">
            <a href="view_hosting_table.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>" class="btn btn-secondary">Back</a>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
            button.addEventListener('click', function() {
                var passwordContainer = this.closest('.password-container');
                if (!passwordContainer) return;

                var passwordField = passwordContainer.querySelector('.password-field');
                if (passwordField.innerText === '******') {
                    var encryptedPassword = passwordField.getAttribute('data-password');
                    var xhr = new XMLHttpRequest();
                    xhr.onreadystatechange = function() {
                        if (xhr.readyState == 4 && xhr.status == 200) {
                            passwordField.innerText = xhr.responseText;
                            button.innerHTML = '<i class="bi bi-eye-slash"></i>';
                        }
                    };
                    xhr.open("POST", "../functions/decrypt.php", true);
                    xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
                    xhr.send("encryptedPassword=" + encodeURIComponent(encryptedPassword) + "&key=your_secret_key");
                } else {
                    passwordField.innerText = '******';
                    button.innerHTML = '<i class="bi bi-eye"></i>';
                }
            });
        });

        // Hide passwords when switching tabs
        document.querySelectorAll('#myTab .nav-link').forEach(function(tab) {
            tab.addEventListener('click', function() {
                document.querySelectorAll('.password-field').forEach(function(field) {
                    field.innerText = '******';
                });
                document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
                    button.innerHTML = '<i class="bi bi-eye"></i>';
                });
            });
        });
    </script>
</body>
</html>