<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database

// Define the Others group and its fields with respective display labels
$groups = [
    'Others' => [
        'General' => [
            'fields' => ['active', 'brand', 'model', 'part_no', 'serial_number', 'installed_pc', 'others'],
            'labels' => ['Active', 'Brand', 'Model', 'Part No.', 'Serial Number', 'Installed PC', 'Others']
        ]
    ]
];

// Check if debtor_code is passed via URL
if (isset($_GET['debtor_code'])) {
    $debtorCode = $_GET['debtor_code'];

    // Determine the item ID and table based on the group
    if (isset($_GET['item_type_hw_others_id'])) {
        $itemTypeId = $_GET['item_type_hw_others_id'];
        $table = 'item_type_hw_others';
        $idField = 'item_type_hw_others_id';
    } else {
        echo "<p>No item ID provided.</p>";
        exit;
    }

    // Fetch the item details based on the table and item ID
    $stmt = $pdo->prepare("SELECT * FROM $table WHERE $idField = :item_id");
    $stmt->bindParam(':item_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($item) {
        // Fetch company_name based on debtor_code
        $stmt = $pdo->prepare('SELECT company_name FROM item_type_hw WHERE debtor_code = :debtor_code LIMIT 1');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->execute();
        $companyName = $stmt->fetchColumn();

        // Determine the group name (Others in this case)
        $groupName = $item['item_type_hw_group_name'];
        $groupData = $groups[$groupName];

        // Fetch the item_type_pc_id based on the installed_pc
        if (!empty($item['installed_pc'])) {
            $computerName = $item['installed_pc'];
            $stmt = $pdo->prepare('SELECT item_type_pc_id FROM item_type_pc WHERE computer_name = :computer_name LIMIT 1');
            $stmt->bindParam(':computer_name', $computerName);
            $stmt->execute();
            $itemTypePcId = $stmt->fetchColumn();
        }
    } else {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }
} else {
    echo "<p>No debtor code provided.</p>";
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Others Hardware Details</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
        .table-fixed {
            table-layout: fixed;
            width: 100%;
        }
        .table-fixed td {
            overflow: hidden;
            text-overflow: ellipsis;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">Details for <?= htmlspecialchars($groupName) ?></h5>
                <p>Company: <?= htmlspecialchars($companyName) ?></p>
            </div>
            <div class="card-body">
                <!-- Nav tabs -->
                <ul class="nav nav-tabs" id="myTab" role="tablist">
                    <li class="nav-item">
                        <a class="nav-link active" id="general-tab" data-bs-toggle="tab" href="#general" role="tab">General</a>
                    </li>
                </ul>

                <!-- Tab content -->
                <div class="tab-content mt-3" id="myTabContent">
                    <!-- General Tab -->
                    <div class="tab-pane fade show active" id="general" role="tabpanel" aria-labelledby="general-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groupData['General']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groupData['General']['labels'][$index]) ?></th>
                                        <td>
                                            <?php if ($field == 'active'): ?>
                                                <?= $item['active'] == 1 ? 'Yes' : 'No' ?>
                                            <?php elseif ($field == 'password'): ?>
                                                <div class="password-container">
                                                    <?php foreach (explode(',', $item[$field]) as $password): ?>
                                                        <div class="password-field" data-password="<?= htmlspecialchars($password) ?>">******</div>
                                                    <?php endforeach; ?>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php elseif ($field == 'installed_pc' && !empty($item[$field])): ?>
                                                <?php if (isset($itemTypePcId)): ?>
                                                    <a href="view_pc_table_details.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>&item_type_pc_id=<?= htmlspecialchars($itemTypePcId) ?>">
                                                        <?= htmlspecialchars($item[$field]) ?>
                                                    </a>
                                                <?php else: ?>
                                                    <?= htmlspecialchars($item[$field]) ?>
                                                <?php endif; ?>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? '') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
        <div style="display: flex; align-items: center; margin-top: 20px;">
            <a href="view_hardware_table.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>" class="btn btn-secondary">Back</a>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
            button.addEventListener('click', function() {
                var passwordContainer = this.closest('.password-container');
                if (!passwordContainer) return;

                var passwordFields = passwordContainer.querySelectorAll('.password-field');
                passwordFields.forEach(function(field) {
                    if (field.innerText === '******') {
                        var encryptedPassword = field.getAttribute('data-password');
                        var xhr = new XMLHttpRequest();
                        xhr.onreadystatechange = function() {
                            if (xhr.readyState == 4 && xhr.status == 200) {
                                field.innerText = xhr.responseText;
                                button.innerHTML = '<i class="bi bi-eye-slash"></i>';
                            }
                        };
                        xhr.open("POST", "decrypt.php", true);
                        xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
                        xhr.send("encryptedPassword=" + encodeURIComponent(encryptedPassword) + "&key=your_secret_key");
                    } else {
                        field.innerText = '******';
                        button.innerHTML = '<i class="bi bi-eye"></i>';
                    }
                });
            });
        });

        // Hide passwords when switching tabs
        document.querySelectorAll('#myTab .nav-link').forEach(function(tab) {
            tab.addEventListener('click', function() {
                document.querySelectorAll('.password-field').forEach(function(field) {
                    field.innerText = '******';
                });
                document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
                    button.innerHTML = '<i class="bi bi-eye"></i>';
                });
            });
        });
    </script>
</body>
</html>