<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/decrypt.php'; // For password encryption

// Define only the Active Backup for Google group
$groups = [
    'Active Backup for Google' => [
        'General' => [
            'fields' => [
                'ab_g_domain_for_backup',
                'ab_g_service_from',
                'ab_g_service_to_folder',
                'ab_g_service_schedule',
                'ab_g_service_time',
                'ab_g_previous_version_days',
                'ab_g_acc',
                'ab_g_tenant_id',
                'ab_g_app_id',
                'ab_g_certificate_file'
            ],
            'labels' => [
                'Active Backup for Google Domain For Backup',
                'Active Backup for Google Service From',
                'Active Backup for Google Service To Folder',
                'Active Backup for Google Service Schedule',
                'Active Backup for Google Service Time',
                'Active Backup for Google Keep Previous Version of Days',
                'Active Backup for Google Account',
                'Active Backup for Google Tenant ID',
                'Active Backup for Google Application ID',
                'Active Backup for Google Certificate File'
            ]
        ]
    ]
];

// Check if debtor_code is passed via URL
if (isset($_GET['debtor_code'])) {
    $debtorCode = $_GET['debtor_code'];

    // Check if the item ID for Active Backup for Google is provided
    if (isset($_GET['item_type_nas_ab_google_id'])) {
        $itemTypeId = $_GET['item_type_nas_ab_google_id'];
        $table = 'item_type_nas_ab_google';
        $idField = 'item_type_nas_ab_google_id';
    } else {
        echo "<p>No item ID provided.</p>";
        exit;
    }

    // Fetch the item details based on debtor_code and item ID
    $stmt = $pdo->prepare("SELECT * FROM $table WHERE debtor_code = :debtor_code AND $idField = :item_id LIMIT 1");
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$item) {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }

    // Fetch company_name based on debtor_code
    $stmt = $pdo->prepare('SELECT company_name FROM item_type_nas WHERE debtor_code = :debtor_code LIMIT 1');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->execute();
    $companyName = $stmt->fetchColumn();

    // Determine the group name
    $groupName = 'Active Backup for Google'; // Hardcoded for this page
    $groupData = $groups[$groupName] ?? [];

    if (empty($groupData)) {
        echo "<p>Invalid group name.</p>";
        exit;
    }
} else {
    echo "<p>No debtor code provided.</p>";
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Active Backup for Google Details</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
        .table-fixed {
            table-layout: fixed;
            width: 100%;
        }
        .table-fixed td {
            overflow: hidden;
            text-overflow: ellipsis;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">Details for <?= htmlspecialchars($groupName) ?></h5>
                <p>Company: <?= htmlspecialchars($companyName) ?></p>
            </div>
            <div class="card-body">
                <!-- General Tab -->
                <div class="tab-pane fade show active" id="general" role="tabpanel" aria-labelledby="general-tab">
                    <table class="table table-bordered table-fixed">
                        <tbody>
                            <?php foreach ($groupData['General']['fields'] as $index => $field): ?>
                                <tr>
                                    <th><?= htmlspecialchars($groupData['General']['labels'][$index]) ?></th>
                                    <td>
                                        <?php if ($field == 'ab_g_certificate_file'): ?>
                                            <?php if (!empty($item[$field])): ?>
                                                <a href="<?= htmlspecialchars($item[$field]) ?>" target="_blank">View Certificate File</a>
                                            <?php else: ?>
                                                No certificate file
                                            <?php endif; ?>
                                        <?php else: ?>
                                            <?= htmlspecialchars($item[$field] ?? '') ?>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
        <div style="display: flex; align-items: center; margin-top: 20px;">
            <a href="view_nas_table.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>" class="btn btn-secondary">Back</a>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>