<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/decrypt.php'; // For password encryption

// Define the NAS group fields and labels
$groups = [
    'NAS' => [
        'General' => [
            'fields' => ['active', 'login', 'password', 'backup_user_id', 'backup_user_password', 'device_name', 'model',
                         'dms_version', 'quickconnect_id', 'serial_number', 'purchase_date', 'warranty_expire_date', 'extend_warranty', 'others'],
            'labels' => ['Active', 'Login', 'Password', 'Backup User ID', 'Backup User Password', 'Device Name', 'Model',
                         'DMS Version', 'QuickConnect ID', 'Serial Number', 'Purchase Date', 'Warranty Expire Date', 'Extend Warranty', 'Others']
        ],
        'Hardware' => [
            'fields' => ['harddisk_raid', 'harddisk_unit', 'harddisk_size', 'harddisk_sn'],
            'labels' => ['Hard Disk Raid', 'Hard Disk Unit', 'Hard Disk Size', 'Hard Disk Serial Number']
        ],
        'Synology' => [
            'fields' => ['synology_email', 'physical_backup', 'file_server', 'hyper_backup', 'synology_drive',
                         'active_backup_for_google', 'active_backup_for_o365'],
            'labels' => ['Synology Email', 'Physical Server Backup', 'File Server Backup', 'Hyper Backup', 'Synology Drive Backup',
                         'Active Backup for Google', 'Active Backup for Office 365']
        ],
        'Network' => [
            'fields' => ['tcp_ip'],
            'labels' => ['TCP/IP']
        ]
    ]
];

// Check if debtor_code and item_type_nas_id are passed via URL
if (isset($_GET['debtor_code']) && isset($_GET['item_type_nas_id'])) {
    $debtorCode = $_GET['debtor_code'];
    $itemTypeId = $_GET['item_type_nas_id'];
    $table = 'item_type_nas_nas';
    $idField = 'item_type_nas_id';

    // Fetch the NAS item details based on debtor_code and item ID
    $stmt = $pdo->prepare("SELECT * FROM $table WHERE debtor_code = :debtor_code AND $idField = :item_id LIMIT 1");
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$item) {
        echo "<p>No NAS item found with the provided ID.</p>";
        exit;
    }

    // Fetch company_name based on debtor_code
    $stmt = $pdo->prepare('SELECT company_name FROM item_type_nas WHERE debtor_code = :debtor_code LIMIT 1');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->execute();
    $companyName = $stmt->fetchColumn();

    // Fetch email details for synology_email
    if (!empty($item['synology_email'])) {
        $stmt = $pdo->prepare('SELECT debtor_code, company_name, email FROM item_type_email_citssb WHERE email = :email LIMIT 1');
        $stmt->bindParam(':email', $item['synology_email']);
        $stmt->execute();
        $emailDetails = $stmt->fetch(PDO::FETCH_ASSOC);
    }
} else {
    echo "<p>No debtor code or NAS item ID provided.</p>";
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>NAS Details</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
        .table-fixed {
            table-layout: fixed;
            width: 100%;
        }
        .table-fixed td {
            overflow: hidden;
            text-overflow: ellipsis;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">NAS Details</h5>
                <p>Company: <?= htmlspecialchars($companyName) ?></p>
            </div>
            <div class="card-body">
                <!-- Nav tabs -->
                <ul class="nav nav-tabs" id="myTab" role="tablist">
                    <li class="nav-item">
                        <a class="nav-link active" id="general-tab" data-bs-toggle="tab" href="#general" role="tab">General</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="hardware-tab" data-bs-toggle="tab" href="#hardware" role="tab">Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="synology-tab" data-bs-toggle="tab" href="#synology" role="tab">Synology</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="network-tab" data-bs-toggle="tab" href="#network" role="tab">Network</a>
                    </li>
                </ul>

                <!-- Tab content -->
                <div class="tab-content mt-3" id="myTabContent">
                    <!-- General Tab -->
                    <div class="tab-pane fade show active" id="general" role="tabpanel" aria-labelledby="general-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groups['NAS']['General']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groups['NAS']['General']['labels'][$index]) ?></th>
                                        <td>
                                            <?php if ($field == 'active'): ?>
                                                <?= $item['active'] == 1 ? 'Yes' : 'No' ?>
                                            <?php elseif (in_array($field, ['password', 'backup_user_password'])): ?>
                                                <div class="password-container">
                                                    <div class="password-field" data-password="<?= htmlspecialchars($item[$field]) ?>">******</div>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php elseif ($field == 'synology_email'): ?>
                                                <?php if (!empty($item['synology_email']) && !empty($emailDetails)): ?>
                                                    <a href="view_email_citssb_table.php?debtor_code=<?= htmlspecialchars($emailDetails['debtor_code']) ?>&company_name=<?= urlencode($emailDetails['company_name']) ?>">
                                                        <?= htmlspecialchars($item['synology_email']) ?>
                                                    </a>
                                                <?php else: ?>
                                                    <?= htmlspecialchars($item['synology_email'] ?? '') ?>
                                                <?php endif; ?>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? '') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Hardware Tab -->
                    <div class="tab-pane fade" id="hardware" role="tabpanel" aria-labelledby="hardware-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <tr>
                                    <th>Hard Disk Raid</th>
                                    <td><?= htmlspecialchars($item['harddisk_raid'] ?? '') ?></td>
                                </tr>
                                <tr>
                                    <td colspan="2"><hr></td>
                                </tr>
                                <?php
                                $hardDiskUnits = explode(',', $item['harddisk_unit'] ?? '');
                                $hardDiskSizes = explode(',', $item['harddisk_size'] ?? '');
                                $hardDiskSerialNumbers = explode(',', $item['harddisk_sn'] ?? '');

                                $maxDisks = max(count($hardDiskUnits), count($hardDiskSizes), count($hardDiskSerialNumbers));

                                for ($i = 0; $i < $maxDisks; $i++): ?>
                                    <tr>
                                        <th colspan="2">Disk <?= $i + 1 ?></th>
                                    </tr>
                                    <tr>
                                        <th style="padding-left: 40px;">Hard Disk Unit</th>
                                        <td><?= htmlspecialchars($hardDiskUnits[$i] ?? '') ?></td>
                                    </tr>
                                    <tr>
                                        <th style="padding-left: 40px;">Hard Disk Size</th>
                                        <td><?= htmlspecialchars($hardDiskSizes[$i] ?? '') ?></td>
                                    </tr>
                                    <tr>
                                        <th style="padding-left: 40px;">Hard Disk Serial Number</th>
                                        <td><?= htmlspecialchars($hardDiskSerialNumbers[$i] ?? '') ?></td>
                                    </tr>
                                <?php endfor; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Synology Tab -->
                    <div class="tab-pane fade" id="synology" role="tabpanel" aria-labelledby="synology-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groups['NAS']['Synology']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groups['NAS']['Synology']['labels'][$index]) ?></th>
                                        <td>
                                            <?php if (in_array($field, ['physical_backup', 'file_server', 'hyper_backup', 'synology_drive', 'active_backup_for_google', 'active_backup_for_o365'])): ?>
                                                <?= $item[$field] == 1 ? 'Yes' : 'No' ?>
                                            <?php elseif ($field == 'synology_email'): ?>
                                                <?php if (!empty($item['synology_email']) && !empty($emailDetails)): ?>
                                                    <a href="view_email_citssb_table.php?debtor_code=<?= htmlspecialchars($emailDetails['debtor_code']) ?>&company_name=<?= urlencode($emailDetails['company_name']) ?>">
                                                        <?= htmlspecialchars($item['synology_email']) ?>
                                                    </a>
                                                <?php else: ?>
                                                    <?= htmlspecialchars($item['synology_email'] ?? '') ?>
                                                <?php endif; ?>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? '') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Network Tab -->
                    <div class="tab-pane fade" id="network" role="tabpanel" aria-labelledby="network-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groups['NAS']['Network']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groups['NAS']['Network']['labels'][$index]) ?></th>
                                        <td><?= htmlspecialchars($item[$field] ?? '') ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
        <div style="display: flex; align-items: center; margin-top: 20px;">
            <a href="view_nas_table.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>" class="btn btn-secondary">Back</a>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
            button.addEventListener('click', function() {
                var passwordContainer = this.closest('.password-container');
                if (!passwordContainer) return;

                var passwordField = passwordContainer.querySelector('.password-field');
                if (passwordField.innerText === '******') {
                    var encryptedPassword = passwordField.getAttribute('data-password');
                    var xhr = new XMLHttpRequest();
                    xhr.onreadystatechange = function() {
                        if (xhr.readyState == 4 && xhr.status == 200) {
                            passwordField.innerText = xhr.responseText;
                            button.innerHTML = '<i class="bi bi-eye-slash"></i>';
                        }
                    };
                    xhr.open("POST", "decrypt.php", true);
                    xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
                    xhr.send("encryptedPassword=" + encodeURIComponent(encryptedPassword) + "&key=your_secret_key");
                } else {
                    passwordField.innerText = '******';
                    button.innerHTML = '<i class="bi bi-eye"></i>';
                }
            });
        });
    </script>
</body>
</html>