<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/decrypt.php'; // For password encryption

// Define only the Synology Drive group
$groups = [
    'Synology Drive' => [
        'General' => [
            'fields' => [
                'sd_login_id',
                'sd_login_password',
                'sd_backup_url',
                'sd_service_from',
                'sd_service_to_folder',
                'sd_service_schedule',
                'sd_service_time',
                'sd_backup_mode',
                'sd_installed_pc'
            ],
            'labels' => [
                'Synology Drive Login ID',
                'Synology Drive Login Password',
                'Synology Drive Backup URL',
                'Synology Drive Service From',
                'Synology Drive Service To Folder',
                'Synology Drive Service Schedule Start Time',
                'Synology Drive Service Time',
                'Synology Drive Backup Mode',
                'Synology Drive Installed PC'
            ]
        ]
    ]
];

// Check if debtor_code is passed via URL
if (isset($_GET['debtor_code'])) {
    $debtorCode = $_GET['debtor_code'];

    // Check if the item ID for Synology Drive is provided
    if (isset($_GET['item_type_nas_sd_id'])) {
        $itemTypeId = $_GET['item_type_nas_sd_id'];
        $table = 'item_type_nas_sd';
        $idField = 'item_type_nas_sd_id';
    } else {
        echo "<p>No item ID provided.</p>";
        exit;
    }

    // Fetch the item details based on debtor_code and item ID
    $stmt = $pdo->prepare("SELECT * FROM $table WHERE debtor_code = :debtor_code AND $idField = :item_id LIMIT 1");
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$item) {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }

    // Fetch company_name based on debtor_code
    $stmt = $pdo->prepare('SELECT company_name FROM item_type_nas WHERE debtor_code = :debtor_code LIMIT 1');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->execute();
    $companyName = $stmt->fetchColumn();

    // Determine the group name
    $groupName = 'Synology Drive'; // Hardcoded for this page
    $groupData = $groups[$groupName] ?? [];

    if (empty($groupData)) {
        echo "<p>Invalid group name.</p>";
        exit;
    }
} else {
    echo "<p>No debtor code provided.</p>";
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Synology Drive Details</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
        .table-fixed {
            table-layout: fixed;
            width: 100%;
        }
        .table-fixed td {
            overflow: hidden;
            text-overflow: ellipsis;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">Details for <?= htmlspecialchars($groupName) ?></h5>
                <p>Company: <?= htmlspecialchars($companyName) ?></p>
            </div>
            <div class="card-body">
                <!-- General Tab -->
                <div class="tab-pane fade show active" id="general" role="tabpanel" aria-labelledby="general-tab">
                    <table class="table table-bordered table-fixed">
                        <tbody>
                            <?php foreach ($groupData['General']['fields'] as $index => $field): ?>
                                <tr>
                                    <th><?= htmlspecialchars($groupData['General']['labels'][$index]) ?></th>
                                    <td>
                                        <?php if (in_array($field, ['sd_login_password'])): ?>
                                            <div class="password-container">
                                                <div class="password-field" data-password="<?= htmlspecialchars($item[$field]) ?>">******</div>
                                                <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                    <i class="bi bi-eye"></i>
                                                </button>
                                            </div>
                                        <?php elseif ($field == 'sd_installed_pc'): ?>
                                            <?php
                                            // Fetch the computer name based on the installed PC ID
                                            $computerName = $item[$field];
                                            $stmt = $pdo->prepare('SELECT item_type_pc_id FROM item_type_pc WHERE computer_name = :computer_name LIMIT 1');
                                            $stmt->bindParam(':computer_name', $computerName);
                                            $stmt->execute();
                                            $itemTypePcId = $stmt->fetchColumn();

                                            if ($itemTypePcId) {
                                                $pcLink = "view_pc_table_details.php?debtor_code=$debtorCode&item_type_pc_id=$itemTypePcId";
                                                ?>
                                                <a href="<?= htmlspecialchars($pcLink) ?>"><?= htmlspecialchars($computerName) ?></a>
                                            <?php } else { ?>
                                                <?= htmlspecialchars($computerName) ?>
                                            <?php } ?>
                                        <?php else: ?>
                                            <?= htmlspecialchars($item[$field] ?? '') ?>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
        <div style="display: flex; align-items: center; margin-top: 20px;">
            <a href="view_nas_table.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>" class="btn btn-secondary">Back</a>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
            button.addEventListener('click', function() {
                var passwordContainer = this.closest('.password-container');
                if (!passwordContainer) return;

                var passwordField = passwordContainer.querySelector('.password-field');
                if (passwordField.innerText === '******') {
                    var encryptedPassword = passwordField.getAttribute('data-password');
                    var xhr = new XMLHttpRequest();
                    xhr.onreadystatechange = function() {
                        if (xhr.readyState == 4 && xhr.status == 200) {
                            passwordField.innerText = xhr.responseText;
                            button.innerHTML = '<i class="bi bi-eye-slash"></i>';
                        }
                    };
                    xhr.open("POST", "decrypt.php", true);
                    xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
                    xhr.send("encryptedPassword=" + encodeURIComponent(encryptedPassword) + "&key=your_secret_key");
                } else {
                    passwordField.innerText = '******';
                    button.innerHTML = '<i class="bi bi-eye"></i>';
                }
            });
        });
    </script>
</body>
</html>