<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database

// Check if debtor_code is passed via URL
if (isset($_GET['debtor_code'])) {
    $debtorCode = $_GET['debtor_code'];

    // Check if company_name is passed via URL
    if (isset($_GET['company_name'])) {
        $companyName = $_GET['company_name'];
    } else {
        // Fetch company_name based on debtor_code
        $stmt = $pdo->prepare('SELECT company_name FROM item_type_nas_nas WHERE debtor_code = :debtor_code LIMIT 1');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->execute();
        $companyName = $stmt->fetchColumn();

        // If no company name is found, set a default value
        if ($companyName === false) {
            $companyName = "Company name not found for this debtor code.";
        }
    }

    // Define the group names, tables, fields, and primary key columns
    $groups = [
        'NAS' => [
            'table' => 'item_type_nas_nas', // Table for NAS
            'id_column' => 'item_type_nas_id', // Primary key column for NAS
            'fields' => ['active', 'device_name', 'tcp_ip', 'serial_number'],
            'labels' => ['Active', 'Device Name', 'TCP/IP', 'Serial Number'],
            'view_page' => 'view_nas_nas_details.php' // Specific view page for NAS
        ],
        'Active Backup Physical Server' => [
            'table' => 'item_type_nas_pb', // Table for Active Backup Physical Server
            'id_column' => 'item_type_nas_pb_id', // Primary key column for Active Backup Physical Server
            'fields' => ['active', 'pb_service_name'],
            'labels' => ['Active', 'Physical Backup Service Name'],
            'view_page' => 'view_nas_physical_server_details.php' // Specific view page for Physical Server
        ],
        'Active Backup File Server' => [
            'table' => 'item_type_nas_fs', // Table for NAS (example)
            'id_column' => 'item_type_nas_fs_id', // Primary key column for NAS
            'fields' => ['active', 'fs_service_name'],
            'labels' => ['Active', 'File Server Service Name'],
            'view_page' => 'view_nas_file_server_details.php' // Default view page
        ],
        'Hyper Backup' => [
            'table' => 'item_type_nas_hb', // Table for NAS (example)
            'id_column' => 'item_type_nas_hb_id', // Primary key column for NAS
            'fields' => ['active', 'hb_service_name'],
            'labels' => ['Active', 'Hyper Backup Service Name'],
            'view_page' => 'view_nas_hyper_backup_details.php' // Default view page
        ],
        'Synology Drive' => [
            'table' => 'item_type_nas_sd', // Table for NAS (example)
            'id_column' => 'item_type_nas_sd_id', // Primary key column for NAS
            'fields' => ['active'],
            'labels' => ['Active'],
            'view_page' => 'view_nas_synology_drive_details.php' // Default view page
        ],
        'Active Backup for Office 365' => [
            'table' => 'item_type_nas_ab_o365', // Table for NAS (example)
            'id_column' => 'item_type_nas_ab_o365_id', // Primary key column for NAS
            'fields' => ['active', 'ab_o365_service_name'],
            'labels' => ['Active', 'Active Backup for Office 365 Service Name'],
            'view_page' => 'view_nas_ab_o365_details.php' // Default view page
        ],
        'Active Backup for Google' => [
            'table' => 'item_type_nas_ab_google', // Table for NAS (example)
            'id_column' => 'item_type_nas_ab_google_id', // Primary key column for NAS
            'fields' => ['active', 'ab_g_domain_for_backup'],
            'labels' => ['Active', 'Active Backup for Google Domain For Backup'],
            'view_page' => 'view_nas_ab_google_details.php' // Default view page
        ]
    ];

    $dataByGroup = [];
    $hasData = false;

    foreach ($groups as $group => $groupData) {
        // Fetch data from the appropriate table based on the group
        $stmt = $pdo->prepare('SELECT * FROM ' . $groupData['table'] . ' WHERE debtor_code = :debtor_code AND item_type_nas_group_name = :group_name');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->bindValue(':group_name', $group);
        $stmt->execute();
        $dataByGroup[$group] = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Check if this group has data
        if (!empty($dataByGroup[$group])) {
            $hasData = true;
        }
    }
} else {
    echo "<p>No debtor code provided.</p>";
    $dataByGroup = array_fill_keys(array_keys($groups), []);
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>NAS Info</title>
    <!-- Bootstrap 5.x CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- FontAwesome Icons -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css" rel="stylesheet">
    <!-- Custom CSS for Table Height -->
    <style>
        .table-tall td, .table-tall th {
            padding: 1rem; /* Add vertical padding to make rows taller */
        }
    </style>
</head>
<body>
    <div class="container-fluid mt-5">
        <div class="row justify-content-center">
            <div class="col-md-10">
                <!-- Navigation Tabs -->
                <ul class="nav nav-tabs mb-4">
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'company_details.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/company_details.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Company Details</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_autocount_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_autocount_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Autocount</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_email_citssb_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_email_citssb_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Email</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_network_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_network_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Network</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_nas_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_nas_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">NAS</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hardware_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_hardware_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pos_hardware_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_pos_hardware_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">POS Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pc_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_pc_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Computer</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hosting_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_hosting_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Hosting</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_software_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_software_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Software</a>
                    </li>
                </ul>

                <!-- Card for Company Name and Back Button -->
                <div class="card mb-4">
                    <div class="card-header d-flex align-items-center">
                        <!-- Centered Company Name -->
                        <div class="flex-grow-1 text-center">
                            <h2 class="mb-0"><?= htmlspecialchars($companyName) ?></h2>
                        </div>
                    </div>
                </div>

                <?php if ($hasData): ?>
                    <?php foreach ($groups as $group => $groupData): ?>
                        <?php if (!empty($dataByGroup[$group])): ?>
                            <!-- Card for each group -->
                            <div class="card mb-4">
                                <div class="card-header">
                                    <h3 class="mb-0"><?= htmlspecialchars($group) ?> Information</h3>
                                </div>
                                <div class="card-body">
                                    <div class="table-responsive">
                                        <table class="table table-striped table-hover table-sm table-borderless table-tall">
                                            <thead>
                                                <tr>
                                                    <?php foreach ($groupData['labels'] as $label): ?>
                                                        <th><?= htmlspecialchars($label) ?></th>
                                                    <?php endforeach; ?>
                                                    <th>Actions</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                <?php foreach ($dataByGroup[$group] as $row): ?>
                                                    <tr>
                                                        <?php foreach ($groupData['fields'] as $field): ?>
                                                            <td>
                                                                <?php if ($field == 'active'): ?>
                                                                    <?= $row['active'] == 1 ? 'Yes' : 'No' ?>
                                                                <?php else: ?>
                                                                    <?= htmlspecialchars($row[$field] ?? '') ?>
                                                                <?php endif; ?>
                                                            </td>
                                                        <?php endforeach; ?>
                                                        <td>
                                                            <?php
                                                            // Determine the primary key column for the current group
                                                            $idColumn = $groupData['id_column'];
                                                            $idValue = $row[$idColumn];

                                                            // Build the view URL dynamically based on the group's view page
                                                            $viewUrl = '/crm/public/company/' . $groupData['view_page'] . '?debtor_code=' . urlencode($debtorCode) . '&' . $idColumn . '=' . urlencode($idValue);

                                                            // Determine the edit page based on the group
                                                            $editPage = '';
                                                            switch ($group) {
                                                                case 'NAS':
                                                                    $editPage = '/crm/public/config_info/edit_nas.php';
                                                                    break;
                                                                case 'Active Backup Physical Server':
                                                                    $editPage = '/crm/public/config_info/edit_nas_physical_server.php';
                                                                    break;
                                                                case 'Active Backup File Server':
                                                                    $editPage = '/crm/public/config_info/edit_nas_file_server.php';
                                                                    break;
                                                                case 'Hyper Backup':
                                                                    $editPage = '/crm/public/config_info/edit_nas_hyper_backup.php';
                                                                    break;
                                                                case 'Synology Drive':
                                                                    $editPage = '/crm/public/config_info/edit_nas_synology_drive.php';
                                                                    break;
                                                                case 'Active Backup for Office 365':
                                                                    $editPage = '/crm/public/config_info/edit_nas_ab_o365.php';
                                                                    break;
                                                                case 'Active Backup for Google':
                                                                    $editPage = '/crm/public/config_info/edit_nas_ab_google.php';
                                                                    break;
                                                                default:
                                                                    $editPage = '/crm/public/company/search_company.php';
                                                                    break;
                                                            }

                                                            // Build the edit URL dynamically
                                                            $editUrl = $editPage . '?debtor_code=' . urlencode($debtorCode) . '&' . $idColumn . '=' . urlencode($idValue);
                                                            ?>
                                                            <a href="<?= $viewUrl ?>" class="btn btn-primary btn-sm">
                                                                <i class="fas fa-eye"></i> View
                                                            </a> |
                                                            <a href="<?= $editUrl ?>" class="btn btn-primary btn-sm">
                                                                <i class="fas fa-edit"></i> Edit
                                                            </a>
                                                        </td>
                                                    </tr>
                                                <?php endforeach; ?>
                                            </tbody>
                                        </table>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>
                    <?php endforeach; ?>
                <?php else: ?>
                    <div class="alert alert-warning" role="alert">
                        No related NAS information found for this company.
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.x JS Bundle CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>