<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/decrypt.php'; // For password encryption

// Define the group names and fields with their respective display labels
$groups = [
    'NAS' => [
        'General' => [
            'fields' => ['active', 'login', 'password', 'backup_user_id','backup_user_password','device_name','model',
                         'dms_version','quickconnect_id',
                         'serial_number', 'purchase_date', 'warranty_expire_date','extend_warranty',
                         'others'],
            'labels' => ['Active', 'Login', 'Password','Backup User ID','Backup User Password','Device Name','Model',
                         'DMS Version','QuickConnect ID',
                         'Serial Number', 'Purchase Date', 'Warranty Expire Date','Extend Warranty',
                         'Others']
        ],
        'Hardware' => [
            'fields' => ['harddisk_raid','harddisk_unit','harddisk_size','harddisk_sn'],
            'labels' => ['Hard Disk Raid','Hard Disk Unit','Hard Disk Size','Hard Disk Serial Number']
        ],
        'Synology' => [
            'fields' => ['synology_email','physical_backup','file_server','hyper_backup','synology_drive',
                         'active_backup_for_google','active_backup_for_o365'],
            'labels' => ['Synology Email','Physical Server Backup','File Server Backup','Hyper Backup','Synology Drive Backup',
                         'Active Backup for Google','Active Backup for Office 365']
        ],
        'Network' => [
            'fields' => ['tcp_ip'],
            'labels' => ['TCP/IP']
        ]
    ],
    'Active Backup Physical Server' => [
        'General' => [
            'fields' => ['pb_service_name',
                         'pb_service_from',
                         'pb_service_to_folder',
                         'pb_service_schedule',
                         'pb_service_time',
                         'pb_service_retention',
                         'pb_installed_pc'],
            'labels' => ['Physical Server Backup Service Name',
                         'Physical Backup Service From',
                         'Physical Backup Service To Folder',
                         'Physical Backup Service Schedule',
                         'Physical Backup Service Time',
                         'Physical Backup Service Retention',
                         'Physical Backup Installed PC']
        ]
    ],
    'Active Backup File Server' => [
        'General' => [
            'fields' => ['fs_service_name',
                         'fs_service_from',
                         'fs_service_to_folder',
                         'fs_service_schedule',
                         'fs_service_time',
                         'fs_service_retention',
                         'fs_installed_pc'],
            'labels' => ['File Server Service Name',
                         'File Server Service From',
                         'File Server Service To Folder',
                         'File Server Service Schedule',
                         'File Server Service Time',
                         'File Server Service Retention',
                         'File Server Installed PC']
        ]
    ],
    'Hyper Backup' => [
        'General' => [
            'fields' => ['hb_service_name',
                         'hb_service_from',
                         'hb_service_to_folder',
                         'hb_service_schedule',
                         'hb_service_time',
                         'hb_service_retention',
                         'hb_service_sec_synology',
                         'hb_service_ext_hd'],
            'labels' => ['Hyper Backup Service Name',
                         'Hyper Backup Service From',
                         'Hyper Backup Service To Folder',
                         'Hyper Backup Service Schedule',
                         'Hyper Backup Service Time',
                         'Hyper Backup Service Retention',
                         'Hyper Backup Service Second Synology',
                         'Hyper Backup Service Extend Hard Disk']
        ]
    ],
    'Synology Drive' => [
        'General' => [
            'fields' => ['sd_login_id',
                         'sd_login_password',
                         'sd_backup_url',
                         'sd_service_from',
                         'sd_service_to_folder',
                         'sd_service_schedule',
                         'sd_service_time',
                         'sd_backup_mode',
                         'sd_installed_pc'],
            'labels' => ['Synology Drive Login ID',
                         'Synology Drive Login Password',
                         'Synology Drive Backup URL',
                         'Synology Drive Service From',
                         'Synology Drive Service To Folder',
                         'Synology Drive Service Schedule Start Time',
                         'Synology Drive Service Time',
                         'Synology Drive Backup Mode',
                         'Synology Drive Installed PC']
        ]
    ],
    'Active Backup for Office 365' => [
        'General' => [
            'fields' => ['ab_o365_service_name',
                         'ab_o365_domain_admin_email_address',
                         'ab_o365_service_to_folder',
                         'ab_o365_service_schedule',
                         'ab_o365_service_time',
                         'ab_o365_previous_version_days',
                         'ab_o365_acc',
                         'ab_o365_tenant_id',
                         'ab_o365_app_id',
                         'ab_o365_certificate_file',
                         'ab_o365_picture'],
            'labels' => ['Active Backup for Office 365 Service Name',
                         'Domain Admin Email Address',
                         'Active Backup for Office 365 Service To Folder',
                         'Active Backup for Office 365 Service Schedule',
                         'Active Backup for Office 365 Service Time',
                         'Active Backup for Office 365 Previous Version of Days',
                         'Active Backup for Office 365 Account',
                         'Active Backup for Office 365 Tenant ID',
                         'Active Backup for Office 365 Application ID',
                         'Active Backup for Office 365 Certificate File',
                         'Active Backup for Office 365 Picture']
        ]
    ],
    'Active Backup for Google' => [
        'General' => [
            'fields' => ['ab_g_domain_for_backup',
                         'ab_g_service_from',
                         'ab_g_service_to_folder',
                         'ab_g_service_schedule',
                         'ab_g_service_time',
                         'ab_g_previous_version_days',
                         'ab_g_acc',
                         'ab_g_tenant_id',
                         'ab_g_app_id',
                         'ab_g_certificate_file'],
            'labels' => ['Active Backup for Google Domain For Backup',
                         'Active Backup for Google Service From',
                         'Active Backup for Google Service To Folder',
                         'Active Backup for Google Service Schedule',
                         'Active Backup for Google Service Time',
                         'Active Backup for Google Keep Previous Version of Days',
                         'Active Backup for Google Account',
                         'Active Backup for Google Tenant ID',
                         'Active Backup for Google Application ID',
                         'Active Backup for Google Certificate File']
        ]
    ]
];

// Check if debtor_code is passed via URL
if (isset($_GET['debtor_code'])) {
    $debtorCode = $_GET['debtor_code'];

    // Determine the item ID and table based on the group
    if (isset($_GET['item_type_nas_id'])) {
        // For NAS group
        $itemTypeId = $_GET['item_type_nas_id'];
        $table = 'item_type_nas_nas';
        $idField = 'item_type_nas_id';
    } elseif (isset($_GET['item_type_nas_pb_id'])) {
        // For Active Backup Physical Server group
        $itemTypeId = $_GET['item_type_nas_pb_id'];
        $table = 'item_type_nas_pb';
        $idField = 'item_type_nas_pb_id';
    } elseif (isset($_GET['item_type_nas_fs_id'])) {
        // For Active Backup File Server group
        $itemTypeId = $_GET['item_type_nas_fs_id'];
        $table = 'item_type_nas_fs';
        $idField = 'item_type_nas_fs_id';
    } elseif (isset($_GET['item_type_nas_hb_id'])) {
        // For Hyper Backup group
        $itemTypeId = $_GET['item_type_nas_hb_id'];
        $table = 'item_type_nas_hb';
        $idField = 'item_type_nas_hb_id';
    } elseif (isset($_GET['item_type_nas_sd_id'])) {
        // For Synology Drive group
        $itemTypeId = $_GET['item_type_nas_sd_id'];
        $table = 'item_type_nas_sd';
        $idField = 'item_type_nas_sd_id';
    } elseif (isset($_GET['item_type_nas_ab_o365_id'])) {
        // For Active Backup for Office 365 group
        $itemTypeId = $_GET['item_type_nas_ab_o365_id'];
        $table = 'item_type_nas_ab_o365';
        $idField = 'item_type_nas_ab_o365_id';
    } elseif (isset($_GET['item_type_nas_ab_google_id'])) {
        // For Active Backup for Google group
        $itemTypeId = $_GET['item_type_nas_ab_google_id'];
        $table = 'item_type_nas_ab_google';
        $idField = 'item_type_nas_ab_google_id';
    } else {
        echo "<p>No item ID provided.</p>";
        exit;
    }

    // Fetch the item details based on debtor_code and item ID
    $stmt = $pdo->prepare("SELECT * FROM $table WHERE debtor_code = :debtor_code AND $idField = :item_id LIMIT 1");
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$item) {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }

    // Fetch company_name based on debtor_code
    $stmt = $pdo->prepare('SELECT company_name FROM item_type_nas WHERE debtor_code = :debtor_code LIMIT 1');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->execute();
    $companyName = $stmt->fetchColumn();

    // Determine the group name
    $groupName = $item['item_type_nas_group_name'];
    $groupData = $groups[$groupName] ?? [];

    if (empty($groupData)) {
        echo "<p>Invalid group name.</p>";
        exit;
    }

    // Fetch email details for synology_email
    if (!empty($item['synology_email'])) {
        $stmt = $pdo->prepare('SELECT debtor_code, company_name, email FROM item_type_email_citssb WHERE email = :email LIMIT 1');
        $stmt->bindParam(':email', $item['synology_email']);
        $stmt->execute();
        $emailDetails = $stmt->fetch(PDO::FETCH_ASSOC);
    }
} else {
    echo "<p>No debtor code provided.</p>";
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>NAS Details</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
        .table-fixed {
            table-layout: fixed;
            width: 100%;
        }
        .table-fixed td {
            overflow: hidden;
            text-overflow: ellipsis;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">Details for <?= htmlspecialchars($groupName) ?></h5>
                <p>Company: <?= htmlspecialchars($companyName) ?></p>
            </div>
            <div class="card-body">
                <!-- Nav tabs -->
                <ul class="nav nav-tabs" id="myTab" role="tablist">
                    <li class="nav-item">
                        <a class="nav-link active" id="general-tab" data-bs-toggle="tab" href="#general" role="tab">General</a>
                    </li>
                    <?php if ($groupName == 'NAS'): ?>
                        <li class="nav-item">
                            <a class="nav-link" id="hardware-tab" data-bs-toggle="tab" href="#hardware" role="tab">Hardware</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="synology-tab" data-bs-toggle="tab" href="#synology" role="tab">Synology</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" id="network-tab" data-bs-toggle="tab" href="#network" role="tab">Network</a>
                        </li>
                    <?php endif; ?>
                </ul>

                <!-- Tab content -->
                <div class="tab-content mt-3" id="myTabContent">
                    <!-- General Tab -->
                    <div class="tab-pane fade show active" id="general" role="tabpanel" aria-labelledby="general-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groupData['General']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groupData['General']['labels'][$index]) ?></th>
                                        <td>
                                            <?php if ($field == 'active'): ?>
                                                <?= $item['active'] == 1 ? 'Yes' : 'No' ?>
                                            <?php elseif ($field == 'ab_o365_picture'): ?>
                                                <?php if (!empty($item[$field])): ?>
                                                    <img src="<?= htmlspecialchars($item[$field]) ?>" alt="Active Backup for Office 365 Picture" style="max-width: 600px; max-height: 600px;">
                                                <?php else: ?>
                                                    No picture
                                                <?php endif; ?>
                                            <?php elseif (in_array($field, ['password', 'backup_user_password', '', 'sd_login_password'])): ?>
                                                <div class="password-container">
                                                    <div class="password-field" data-password="<?= htmlspecialchars($item[$field]) ?>">******</div>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php elseif ($field == 'pb_installed_pc' || $field == 'fs_installed_pc' || $field == 'sd_installed_pc'): ?>
                                                <?php
                                                // Fetch the computer name based on the installed PC ID
                                                $computerName = $item[$field];
                                                $stmt = $pdo->prepare('SELECT item_type_pc_id FROM item_type_pc WHERE computer_name = :computer_name LIMIT 1');
                                                $stmt->bindParam(':computer_name', $computerName);
                                                $stmt->execute();
                                                $itemTypePcId = $stmt->fetchColumn();

                                                if ($itemTypePcId) {
                                                    $pcLink = "view_pc_table_details.php?debtor_code=$debtorCode&item_type_pc_id=$itemTypePcId";
                                                    ?>
                                                    <a href="<?= htmlspecialchars($pcLink) ?>"><?= htmlspecialchars($computerName) ?></a>
                                                <?php } else { ?>
                                                    <?= htmlspecialchars($computerName) ?>
                                                <?php } ?>
                                            <?php elseif ($field == 'ab_g_certificate_file'): ?>
                                                <?php if (!empty($item[$field])): ?>
                                                    <a href="<?= htmlspecialchars($item[$field]) ?>" target="_blank">View Certificate File</a>
                                                <?php else: ?>
                                                    No certificate file
                                                <?php endif; ?>
                                            <?php elseif ($field == 'ab_o365_certificate_file'): ?>
                                                <?php if (!empty($item[$field])): ?>
                                                    <a href="<?= htmlspecialchars($item[$field]) ?>" target="_blank">View Certificate File</a>
                                                <?php else: ?>
                                                    No certificate file
                                                <?php endif; ?>
                                            <?php elseif ($field == 'synology_email'): ?>
                                                <?php if (!empty($item['synology_email']) && !empty($emailDetails)): ?>
                                                    <a href="view_email_citssb_table.php?debtor_code=<?= htmlspecialchars($emailDetails['debtor_code']) ?>&company_name=<?= urlencode($emailDetails['company_name']) ?>">
                                                        <?= htmlspecialchars($item['synology_email']) ?>
                                                    </a>
                                                <?php else: ?>
                                                    <?= htmlspecialchars($item['synology_email'] ?? '') ?>
                                                <?php endif; ?>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? '') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Hardware Tab for NAS -->
                    <?php if ($groupName == 'NAS'): ?>
                        <div class="tab-pane fade" id="hardware" role="tabpanel" aria-labelledby="hardware-tab">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <!-- Display the Hard Disk Raid field at the top -->
                                    <tr>
                                        <th>Hard Disk Raid</th>
                                        <td><?= htmlspecialchars($item['harddisk_raid'] ?? '') ?></td>
                                    </tr>
                                    <!-- Separate the Hard Disk Raid field with a horizontal line -->
                                    <tr>
                                        <td colspan="2"><hr></td>
                                    </tr>
                                    <?php
                                    // Initialize arrays to hold the parts
                                    $hardDiskUnits = explode(',', $item['harddisk_unit'] ?? '');
                                    $hardDiskSizes = explode(',', $item['harddisk_size'] ?? '');
                                    $hardDiskSerialNumbers = explode(',', $item['harddisk_sn'] ?? '');

                                    // Determine the maximum number of disks
                                    $maxDisks = max(count($hardDiskUnits), count($hardDiskSizes), count($hardDiskSerialNumbers));

                                    // Loop through each disk
                                    for ($i = 0; $i < $maxDisks; $i++) {
                                        $diskLabel = ($i + 1); // Disk label (First, Second, Third, etc.)
                                        ?>
                                        <tr>
                                            <th colspan="2">Disk <?= $diskLabel ?></th>
                                        </tr>
                                        <tr>
                                            <th style="padding-left: 40px;">Hard Disk Unit</th>
                                            <td><?= htmlspecialchars($hardDiskUnits[$i] ?? '') ?></td>
                                        </tr>
                                        <tr>
                                            <th style="padding-left: 40px;">Hard Disk Size</th>
                                            <td><?= htmlspecialchars($hardDiskSizes[$i] ?? '') ?></td>
                                        </tr>
                                        <tr>
                                            <th style="padding-left: 40px;">Hard Disk Serial Number</th>
                                            <td><?= htmlspecialchars($hardDiskSerialNumbers[$i] ?? '') ?></td>
                                        </tr>
                                    <?php } ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>

                <!-- Synology Tab for NAS -->
                    <?php if ($groupName == 'NAS'): ?>
                        <div class="tab-pane fade" id="synology" role="tabpanel" aria-labelledby="synology-tab">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['Synology']['fields'] as $index => $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars($groupData['Synology']['labels'][$index]) ?></th>
                                            <td>
                                                <?php if (in_array($field, ['physical_backup', 'file_server', 'hyper_backup', 'synology_drive', 'active_backup_for_google', 'active_backup_for_o365'])): ?>
                                                    <?= $item[$field] == 1 ? 'Yes' : 'No' ?>
                                                <?php elseif ($field == 'synology_email'): ?>
                                                    <?php if (!empty($item['synology_email']) && !empty($emailDetails)): ?>
                                                        <a href="view_email_citssb_table.php?debtor_code=<?= htmlspecialchars($emailDetails['debtor_code']) ?>&company_name=<?= urlencode($emailDetails['company_name']) ?>">
                                                            <?= htmlspecialchars($item['synology_email']) ?>
                                                        </a>
                                                    <?php else: ?>
                                                        <?= htmlspecialchars($item['synology_email'] ?? '') ?>
                                                    <?php endif; ?>
                                                <?php else: ?>
                                                    <?= htmlspecialchars($item[$field] ?? '') ?>
                                                <?php endif; ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>

                    <!-- Network Tab for NAS -->
                    <?php if ($groupName == 'NAS'): ?>
                        <div class="tab-pane fade" id="network" role="tabpanel" aria-labelledby="network-tab">
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach ($groupData['Network']['fields'] as $index => $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars($groupData['Network']['labels'][$index]) ?></th>
                                            <td><?= htmlspecialchars($item[$field] ?? '') ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <div style="display: flex; align-items: center; margin-top: 20px;">
            <a href="view_nas_table.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>" class="btn btn-secondary">Back</a>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
            button.addEventListener('click', function() {
                var passwordContainer = this.closest('.password-container');
                if (!passwordContainer) return;

                var passwordField = passwordContainer.querySelector('.password-field');
                if (passwordField.innerText === '******') {
                    var encryptedPassword = passwordField.getAttribute('data-password');
                    var xhr = new XMLHttpRequest();
                    xhr.onreadystatechange = function() {
                        if (xhr.readyState == 4 && xhr.status == 200) {
                            passwordField.innerText = xhr.responseText;
                            button.innerHTML = '<i class="bi bi-eye-slash"></i>';
                        }
                    };
                    xhr.open("POST", "decrypt.php", true);
                    xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
                    xhr.send("encryptedPassword=" + encodeURIComponent(encryptedPassword) + "&key=your_secret_key");
                } else {
                    passwordField.innerText = '******';
                    button.innerHTML = '<i class="bi bi-eye"></i>';
                }
            });
        });
    </script>
</body>
</html>

