<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption

// Check if debtor_code is passed via URL
if (isset($_GET['debtor_code'])) {
    $debtorCode = $_GET['debtor_code'];

    // Check if company_name is passed via URL; if not, fetch it from the database
    if (isset($_GET['company_name'])) {
        $companyName = $_GET['company_name'];
    } else {
        // Fetch company_name based on debtor_code from item_type_nw
        $stmt = $pdo->prepare('SELECT company_name FROM item_type_nw WHERE debtor_code = :debtor_code LIMIT 1');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->execute();
        $companyName = $stmt->fetchColumn();

        // If no company name is found, set a default value
        if ($companyName === false) {
            $companyName = "Company name not found for this debtor code.";
        }
    }

    // Define the group names and fields with their respective display labels
    $groups = [
        'Access Point' => [
            'fields' => ['active', 'model', 'tcp_ip', 'serial_number'],
            'labels' => ['Active', 'Model', 'TCP/IP', 'Serial Number'],
            'table' => 'item_type_nw_ap',
            'id_field' => 'item_type_nw_ap_id'
        ],
        'Network Switch' => [
            'fields' => ['active', 'model', 'tcp_ip', 'serial_number'],
            'labels' => ['Active', 'Model', 'TCP/IP', 'Serial Number'],
            'table' => 'item_type_nw_ns',
            'id_field' => 'item_type_nw_ns_id'
        ],
        'Firewall' => [
            'fields' => ['active', 'model', 'tcp_ip', 'serial_number'],
            'labels' => ['Active', 'Model', 'TCP/IP', 'Serial Number'],
            'table' => 'item_type_nw_fw',
            'id_field' => 'item_type_nw_fw_id'
        ],
        'VPN' => [
            'fields' => ['active', 'vpn_type'],
            'labels' => ['Active', 'VPN Type'],
            'table' => 'item_type_nw_vpn',
            'id_field' => 'item_type_nw_vpn_id'
        ],
        'Internet Service Provider' => [
            'fields' => ['active', 'telephone_no', 'service_provider'],
            'labels' => ['Active', 'Telephone No', 'Service Provider'],
            'table' => 'item_type_nw_isp',
            'id_field' => 'item_type_nw_isp_id'
        ],
        'Printer Server/Network Printer' => [
            'fields' => ['active', 'model', 'tcp_ip', 'printer_model', 'serial_number'],
            'labels' => ['Active', 'Model', 'TCP/IP', 'Printer Model', 'Serial Number'],
            'table' => 'item_type_nw_ps',
            'id_field' => 'item_type_nw_ps_id'
        ],
        'Router' => [
            'fields' => ['active', 'model', 'tcp_ip', 'serial_number'],
            'labels' => ['Active', 'Model', 'TCP/IP', 'Serial Number'],
            'table' => 'item_type_nw_router',
            'id_field' => 'item_type_nw_router_id'
        ]
    ];

    $dataByGroup = [];
    $hasData = false;

    foreach ($groups as $group => $groupData) {
        // Fetch data for each group from its respective table
        $stmt = $pdo->prepare('SELECT * FROM ' . $groupData['table'] . ' WHERE debtor_code = :debtor_code');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->execute();
        $dataByGroup[$group] = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Check if this group has data
        if (!empty($dataByGroup[$group])) {
            $hasData = true;
        }
    }
} else {
    echo "<p>No debtor code provided.</p>";
    $dataByGroup = array_fill_keys(array_keys($groups), []);
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Network Info</title>
    <!-- Bootstrap 5.x CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- FontAwesome Icons -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css" rel="stylesheet">
    <!-- Custom CSS for Table Height -->
    <style>
        .table-tall td, .table-tall th {
            padding: 1rem; /* Add vertical padding to make rows taller */
        }
    </style>
</head>
<body>
    <div class="container-fluid mt-5">
        <div class="row justify-content-center">
            <div class="col-md-10">
                <!-- Navigation Tabs -->
                <ul class="nav nav-tabs mb-4">
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'company_details.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/company_details.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Company Details</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_autocount_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_autocount_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Autocount</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_email_citssb_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_email_citssb_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Email</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_network_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_network_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Network</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_nas_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_nas_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">NAS</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hardware_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_hardware_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pos_hardware_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_pos_hardware_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">POS Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pc_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_pc_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Computer</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hosting_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_hosting_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Hosting</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_software_table.php' ? 'active' : '' ?>" 
                           href="/crm/public/company/view_software_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Software</a>
                    </li>
                </ul>

                <!-- Rest of the content remains unchanged -->
                <?php if (isset($debtorCode)): ?>
                    <!-- Card for Company Name and Back Button -->
                    <div class="card mb-4">
                        <div class="card-header d-flex align-items-center">
                            <!-- Centered Company Name -->
                            <div class="flex-grow-1 text-center">
                                <h2 class="mb-0"><?= htmlspecialchars($companyName) ?></h2>
                            </div>
                        </div>
                    </div>
                <?php endif; ?>

                <?php if ($hasData): ?>
                    <?php foreach ($groups as $group => $groupData): ?>
                        <?php if (!empty($dataByGroup[$group])): ?>
                            <!-- Card for each group -->
                            <div class="card mb-4">
                                <div class="card-header">
                                    <h3 class="mb-0"><?= htmlspecialchars($group) ?> Information</h3>
                                </div>
                                <div class="card-body">
                                    <div class="table-responsive">
                                        <table class="table table-striped table-hover table-sm table-borderless table-tall">
                                            <thead>
                                                <tr>
                                                    <?php foreach ($groupData['labels'] as $label): ?>
                                                        <th><?= htmlspecialchars($label) ?></th>
                                                    <?php endforeach; ?>
                                                    <th>Actions</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                <?php foreach ($dataByGroup[$group] as $row): ?>
                                                    <tr>
                                                        <?php foreach ($groupData['fields'] as $field): ?>
                                                            <td>
                                                                <?php if ($field == 'active'): ?>
                                                                    <?= $row['active'] == 1 ? 'Yes' : 'No' ?>
                                                                <?php else: ?>
                                                                    <?= htmlspecialchars($row[$field] ?? '') ?>
                                                                <?php endif; ?>
                                                            </td>
                                                        <?php endforeach; ?>
                                                        <td>
                                                            <?php
                                                            // URL for the view action
                                                            if ($group === 'Access Point') {
                                                                $viewUrl = '/crm/public/company/view_nw_ap_details.php?debtor_code=' . urlencode($debtorCode) . 
                                                                           '&company_name=' . urlencode($companyName) . 
                                                                           '&' . $groupData['id_field'] . '=' . urlencode($row[$groupData['id_field']]);
                                                            }
                                                            else if ($group === 'Network Switch') {
                                                                $viewUrl = '/crm/public/company/view_nw_ns_details.php?debtor_code=' . urlencode($debtorCode) . 
                                                                           '&company_name=' . urlencode($companyName) . 
                                                                           '&' . $groupData['id_field'] . '=' . urlencode($row[$groupData['id_field']]);
                                                            }
                                                            else if ($group === 'Firewall') {
                                                                $viewUrl = '/crm/public/company/view_nw_fw_details.php?debtor_code=' . urlencode($debtorCode) . 
                                                                           '&company_name=' . urlencode($companyName) . 
                                                                           '&' . $groupData['id_field'] . '=' . urlencode($row[$groupData['id_field']]);
                                                            }
                                                            else if ($group === 'VPN') {
                                                                $viewUrl = '/crm/public/company/view_nw_vpn_details.php?debtor_code=' . urlencode($debtorCode) . 
                                                                           '&company_name=' . urlencode($companyName) . 
                                                                           '&' . $groupData['id_field'] . '=' . urlencode($row[$groupData['id_field']]);
                                                            }
                                                            else if ($group === 'Internet Service Provider') {
                                                                $viewUrl = '/crm/public/company/view_nw_isp_details.php?debtor_code=' . urlencode($debtorCode) . 
                                                                           '&company_name=' . urlencode($companyName) . 
                                                                           '&' . $groupData['id_field'] . '=' . urlencode($row[$groupData['id_field']]);
                                                            }
                                                            else if ($group === 'Printer Server/Network Printer') {
                                                                $viewUrl = '/crm/public/company/view_nw_ps_details.php?debtor_code=' . urlencode($debtorCode) . 
                                                                           '&company_name=' . urlencode($companyName) . 
                                                                           '&' . $groupData['id_field'] . '=' . urlencode($row[$groupData['id_field']]);
                                                            }
                                                            else {
                                                                $viewUrl = '/crm/public/company/view_nw_router_details.php?debtor_code=' . urlencode($debtorCode) . 
                                                                           '&company_name=' . urlencode($companyName) . 
                                                                           '&' . $groupData['id_field'] . '=' . urlencode($row[$groupData['id_field']]);
                                                            }

                                                            // Define a mapping of group names to their corresponding edit file names
                                                            $editFileMapping = [
                                                                'Access Point' => '/crm/public/config_info/edit_nw_ap.php',
                                                                'Network Switch' => '/crm/public/config_info/edit_nw_ns.php',
                                                                'Firewall' => '/crm/public/config_info/edit_nw_fw.php',
                                                                'VPN' => '/crm/public/config_info/edit_nw_vpn.php',
                                                                'Internet Service Provider' => '/crm/public/config_info/edit_nw_isp.php',
                                                                'Printer Server/Network Printer' => '/crm/public/config_info/edit_nw_ps.php',
                                                                'Router' => '/crm/public/config_info/edit_nw_router.php'
                                                            ];

                                                            // Generate the edit URL dynamically based on the group
                                                            $editUrl = $editFileMapping[$group] . '?debtor_code=' . urlencode($debtorCode) . 
                                                                       '&company_name=' . urlencode($companyName) . 
                                                                       '&' . $groupData['id_field'] . '=' . urlencode($row[$groupData['id_field']]);
                                                            ?>
                                                            <a href="<?= $viewUrl ?>" class="btn btn-primary btn-sm">
                                                                <i class="fas fa-eye"></i> View
                                                            </a> |
                                                            <a href="<?= $editUrl ?>" class="btn btn-primary btn-sm">
                                                                <i class="fas fa-edit"></i> Edit
                                                            </a>
                                                        </td>
                                                    </tr>
                                                <?php endforeach; ?>
                                            </tbody>
                                        </table>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>
                    <?php endforeach; ?>
                <?php else: ?>
                    <div class="alert alert-warning" role="alert">
                        No related network information found for this company.
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.x JS Bundle CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>