<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Define the VPN group and its fields
$vpnGroup = [
    'General' => ['active', 'installed_pc', 'others'],
    'Fortinet' => ['forticlient_username', 'forticlient_login', 'forticlient_password'],
    'Cisco Meraki' => ['cisco_meraki_username', 'cisco_meraki_login', 'cisco_meraki_password'],
    'Radmin' => ['radmin_tcp_ip', 'radmin_network_group', 'radmin_password', 'radmin_master_host'],
    'Hamachi' => ['hamachi_tcp_ip', 'hamachi_network_group', 'hamachi_master_host'],
    'Others' => ['others'],
    'table' => 'item_type_nw_vpn',
    'id_field' => 'item_type_nw_vpn_id'
];

// Check if debtor_code and item ID are passed via URL
if (isset($_GET['debtor_code']) && isset($_GET['item_type_nw_vpn_id'])) {
    $debtorCode = $_GET['debtor_code'];
    $itemTypeId = $_GET['item_type_nw_vpn_id'];
    $table = 'item_type_nw_vpn';
    $idField = 'item_type_nw_vpn_id';

    // Fetch the item details and company_name based on debtor_code and item ID
    $stmt = $pdo->prepare("SELECT * FROM $table WHERE debtor_code = :debtor_code AND $idField = :item_id LIMIT 1");
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$item) {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }

    // Extract company_name from the fetched item
    $companyName = $item['company_name'];
} else {
    echo "<p>No debtor code or item ID provided.</p>";
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>VPN Details</title>
    <!-- Bootstrap 5.x CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
        .table-fixed {
            table-layout: fixed;
            width: 100%;
        }
        .table-fixed td {
            overflow: hidden;
            text-overflow: ellipsis;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">Details for VPN</h5>
                <p>Company: <?= htmlspecialchars($companyName) ?></p>
            </div>
            <div class="card-body">
                <!-- Nav tabs -->
                <ul class="nav nav-tabs" id="myTab" role="tablist">
                    <li class="nav-item">
                        <a class="nav-link active" id="general-tab" data-bs-toggle="tab" href="#general" role="tab">General</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="fortinet-tab" data-bs-toggle="tab" href="#fortinet" role="tab">Fortinet</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="cisco-meraki-tab" data-bs-toggle="tab" href="#cisco-meraki" role="tab">Cisco Meraki</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="radmin-tab" data-bs-toggle="tab" href="#radmin" role="tab">Radmin</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="hamachi-tab" data-bs-toggle="tab" href="#hamachi" role="tab">Hamachi</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="others-tab" data-bs-toggle="tab" href="#others" role="tab">Others</a>
                    </li>
                </ul>

                <!-- Tab content -->
                <div class="tab-content mt-3" id="myTabContent">
                    <!-- General Tab -->
                    <div class="tab-pane fade show active" id="general" role="tabpanel" aria-labelledby="general-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($vpnGroup['General'] as $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                        <td>
                                            <?php if ($field == 'active'): ?>
                                                <?= $item['active'] == 1 ? 'Yes' : 'No' ?>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? '') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Fortinet Tab -->
                    <div class="tab-pane fade" id="fortinet" role="tabpanel" aria-labelledby="fortinet-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($vpnGroup['Fortinet'] as $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                        <td>
                                            <?php if ($field == 'forticlient_password'): ?>
                                                <div class="password-container">
                                                    <?php foreach (explode(',', $item[$field]) as $password): ?>
                                                        <div class="password-field" data-password="<?= htmlspecialchars($password) ?>">******</div>
                                                    <?php endforeach; ?>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? '') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Cisco Meraki Tab -->
                    <div class="tab-pane fade" id="cisco-meraki" role="tabpanel" aria-labelledby="cisco-meraki-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($vpnGroup['Cisco Meraki'] as $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                        <td>
                                            <?php if ($field == 'cisco_meraki_password'): ?>
                                                <div class="password-container">
                                                    <?php foreach (explode(',', $item[$field]) as $password): ?>
                                                        <div class="password-field" data-password="<?= htmlspecialchars($password) ?>">******</div>
                                                    <?php endforeach; ?>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? '') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Radmin Tab -->
                    <div class="tab-pane fade" id="radmin" role="tabpanel" aria-labelledby="radmin-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($vpnGroup['Radmin'] as $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                        <td>
                                            <?php if ($field == 'radmin_password'): ?>
                                                <div class="password-container">
                                                    <?php foreach (explode(',', $item[$field]) as $password): ?>
                                                        <div class="password-field" data-password="<?= htmlspecialchars($password) ?>">******</div>
                                                    <?php endforeach; ?>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? '') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Hamachi Tab -->
                    <div class="tab-pane fade" id="hamachi" role="tabpanel" aria-labelledby="hamachi-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($vpnGroup['Hamachi'] as $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                        <td><?= htmlspecialchars($item[$field] ?? '') ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Others Tab -->
                    <div class="tab-pane fade" id="others" role="tabpanel" aria-labelledby="others-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($vpnGroup['Others'] as $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                        <td><?= htmlspecialchars($item[$field] ?? '') ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
        <div style="display: flex; align-items: center; margin-top: 20px;">
            <a href="view_network_table.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>" class="btn btn-secondary">Back</a>
        </div>
    </div>

    <!-- Bootstrap 5.x JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <script>
    document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
        button.addEventListener('click', function() {
            var passwordContainer = this.closest('.password-container');
            if (!passwordContainer) return;

            var passwordFields = passwordContainer.querySelectorAll('.password-field');
            passwordFields.forEach(function(field) {
                if (field.innerText === '******') {
                    var encryptedPassword = field.getAttribute('data-password');
                    var xhr = new XMLHttpRequest();
                    xhr.onreadystatechange = function() {
                        if (xhr.readyState == 4 && xhr.status == 200) {
                            field.innerText = xhr.responseText;
                            button.innerHTML = '<i class="bi bi-eye-slash"></i>';
                        }
                    };
                    xhr.open("POST", "../functions/decrypt.php", true);
                    xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
                    xhr.send("encryptedPassword=" + encodeURIComponent(encryptedPassword) + "&key=your_secret_key");
                } else {
                    field.innerText = '******';
                    button.innerHTML = '<i class="bi bi-eye"></i>';
                }
            });
        });
    });

    // Hide passwords when switching tabs
    document.querySelectorAll('#myTab .nav-link').forEach(function(tab) {
        tab.addEventListener('click', function() {
            document.querySelectorAll('.password-field').forEach(function(field) {
                field.innerText = '******';
            });
            document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
                button.innerHTML = '<i class="bi bi-eye"></i>';
            });
        });
    });
    </script>
</body>
</html>