<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption

// Check if debtor_code is passed via URL
if (isset($_GET['debtor_code'])) {
    $debtorCode = $_GET['debtor_code'];

    // Check if company_name is passed via URL
    if (isset($_GET['company_name'])) {
        $companyName = $_GET['company_name'];
    } else {
        // Fetch company_name based on debtor_code
        $stmt = $pdo->prepare('SELECT company_name FROM item_type_pc WHERE debtor_code = :debtor_code LIMIT 1');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->execute();
        $companyName = $stmt->fetchColumn();

        // If no company name is found, set a default value
        if ($companyName === false) {
            $companyName = "Company name not found for this debtor code.";
        }
    }

    // Define the group names and fields with their respective display labels
    $groups = [
        'Desktop/Laptop' => [
            'fields' => ['active', 'computer_name','customer_username', 'serial_number'],
            'labels' => ['Active', 'Computer Name','Customer Username', 'Serial Number']
        ],
        'Server' => [
            'fields' => ['active','computer_name','domain','serial_number'],
            'labels' => ['Active','Computer Name','Domain','Serial Number']
        ]
    ];

    $dataByGroup = [];
    $hasData = false;

    foreach (array_keys($groups) as $group) {
        $stmt = $pdo->prepare('SELECT * FROM item_type_pc WHERE debtor_code = :debtor_code AND item_type_pc_group_name = :group_name');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->bindParam(':group_name', $group);
        $stmt->execute();
        $dataByGroup[$group] = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        // Check if this group has data
        if (!empty($dataByGroup[$group])) {
            $hasData = true;
        }
    }
} else {
    echo "<p>No debtor code provided.</p>";
    $dataByGroup = array_fill_keys(array_keys($groups), []);
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Computer Info</title>
    <!-- Bootstrap 5.x CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- FontAwesome Icons -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css" rel="stylesheet">
    <!-- Custom CSS for Table Height -->
    <style>
        .table-tall td, .table-tall th {
            padding: 1rem; /* Add vertical padding to make rows taller */
        }
    </style>
</head>
<body>
    <div class="container-fluid mt-5">
        <div class="row justify-content-center">
            <div class="col-md-10">
                <!-- Navigation Tabs -->
                <ul class="nav nav-tabs mb-4">
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'company_details.php' ? 'active' : '' ?>" 
                           href="company_details.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Company Details</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_autocount_table.php' ? 'active' : '' ?>" 
                           href="view_autocount_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Autocount</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_email_citssb_table.php' ? 'active' : '' ?>" 
                           href="view_email_citssb_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Email</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_network_table.php' ? 'active' : '' ?>" 
                           href="view_network_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Network</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_nas_table.php' ? 'active' : '' ?>" 
                           href="view_nas_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">NAS</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hardware_table.php' ? 'active' : '' ?>" 
                           href="view_hardware_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pos_hardware_table.php' ? 'active' : '' ?>" 
                           href="view_pos_hardware_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">POS Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pc_table.php' ? 'active' : '' ?>" 
                           href="view_pc_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Computer</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hosting_table.php' ? 'active' : '' ?>" 
                           href="view_hosting_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Hosting</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_software_table.php' ? 'active' : '' ?>" 
                           href="view_software_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Software</a>
                    </li>
                </ul>
                <!-- Card for Company Name and Back Button -->
                <div class="card mb-4">
                    <div class="card-header d-flex align-items-center">
                        <!-- Centered Company Name -->
                        <div class="flex-grow-1 text-center">
                            <h2 class="mb-0"><?= htmlspecialchars($companyName) ?></h2>
                        </div>
                    </div>
                </div>

                <?php if ($hasData): ?>
                    <?php foreach ($groups as $group => $groupData): ?>
                        <?php if (!empty($dataByGroup[$group])): ?>
                            <!-- Card for each group -->
                            <div class="card mb-4">
                                <div class="card-header">
                                    <h3 class="mb-0"><?= htmlspecialchars($group) ?> Information</h3>
                                </div>
                                <div class="card-body">
                                    <div class="table-responsive">
                                        <table class="table table-striped table-hover table-sm table-borderless table-tall">
                                            <thead>
                                                <tr>
                                                    <?php foreach ($groupData['labels'] as $label): ?>
                                                        <th><?= htmlspecialchars($label) ?></th>
                                                    <?php endforeach; ?>
                                                    <th>Actions</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                <?php foreach ($dataByGroup[$group] as $row): ?>
                                                    <tr>
                                                        <?php foreach ($groupData['fields'] as $field): ?>
                                                            <td>
                                                                <?php if ($field == 'active'): ?>
                                                                    <?= $row['active'] == 1 ? 'Yes' : 'No' ?>
                                                                <?php else: ?>
                                                                    <?= htmlspecialchars($row[$field] ?? '') ?>
                                                                <?php endif; ?>
                                                            </td>
                                                        <?php endforeach; ?>
                                                        <td>
                                                            <?php
                                                            $viewUrl = '/crm/public/company/view_pc_table_details.php?debtor_code=' . urlencode($debtorCode) . '&item_type_pc_id=' . urlencode($row['item_type_pc_id']);
                                                            
                                                            // Determine the edit page based on the group
                                                            $editPage = '';
                                                            switch ($group) {
                                                                case 'Desktop/Laptop':
                                                                    $editPage = '/crm/public/config_info/edit_pc.php';
                                                                    break;
                                                                case 'Server':
                                                                    $editPage = '/crm/public/config_info/edit_server.php';
                                                                    break;
                                                                default:
                                                                    $editPage = '/crm/public/compnay/view_pc_table.php';
                                                                    break;
                                                            }

                                                            // Build the URL for the respective edit page
                                                            $editUrl = $editPage . '?debtor_code=' . urlencode($debtorCode) . '&item_type_pc_id=' . urlencode($row['item_type_pc_id']);
                                                            ?>
                                                            <a href="<?= $viewUrl ?>" class="btn btn-primary btn-sm">
                                                                <i class="fas fa-eye"></i> View
                                                            </a> |
                                                            <a href="<?= $editUrl ?>" class="btn btn-primary btn-sm">
                                                                <i class="fas fa-edit"></i> Edit
                                                            </a>
                                                        </td>
                                                    </tr>
                                                <?php endforeach; ?>
                                            </tbody>
                                        </table>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>
                    <?php endforeach; ?>
                <?php else: ?>
                    <div class="alert alert-warning" role="alert">
                        No related PC information found for this company.
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.x JS Bundle CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>