<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption

// Define the group names and fields with their respective display labels
$groups = [
    'Desktop/Laptop' => [
        'General' => ['active', 'customer_username', 'brand', 'model', 'computer_name', 'domain', 'login_id', 'login_password', 'windows_product_key', 'os_version', 'part_no', 'serial_number', 'purchase_date', 'warranty_expire_date', 'user_email', 'pc_email_account', 'pc_email_password', 'pin'],
        'Hardware' => ['processor', 'harddisk_type', 'harddisk_space', 'harddisk_total_unit', 'ram_type', 'ram_gb', 'ram_total_unit'],
        'Software' => ['installed_software', 'antivirus', 'office_365'],
        'Network' => ['tcp_ip', 'subnet_mask', 'gateway', 'dns', 'vpn'],
        'Printers' => ['installed_printer'], // Printers tab added
        'Others' => ['others'] // You can add any additional fields here for the Others tab
    ],
    'Server' => [
        'General' => ['active', 'brand', 'model', 'computer_name', 'domain', 'login_id', 'login_password', 'windows_product_key', 'os_version', 'part_no', 'serial_number', 'purchase_date', 'warranty_expire_date', 'user_email'],
        'Hardware' => ['processor', 'harddisk_type', 'harddisk_space', 'harddisk_total_unit', 'ram_type', 'ram_gb', 'ram_total_unit'],
        'Software' => ['installed_software', 'antivirus', 'office_365', 'is_autocount_main', 'is_remote', 'is_hyper_v'],
        'Network' => ['tcp_ip', 'subnet_mask', 'gateway', 'dns', 'vpn'],
        'Printers' => ['installed_printer'], // Printers tab added
        'Others' => ['others'], // Additional fields for the Others tab
        'ILO' => ['ilo_tcp_ip', 'ilo_username', 'ilo_password'] // New ILO tab
    ]
];

// Check if debtor_code and item_type_pc_id are passed via URL
if (isset($_GET['debtor_code']) && isset($_GET['item_type_pc_id'])) {
    $debtorCode = $_GET['debtor_code'];
    $itemTypeId = $_GET['item_type_pc_id'];

    // Fetch the item details based on debtor_code and item_type_pc_id
    $stmt = $pdo->prepare('SELECT * FROM item_type_pc WHERE debtor_code = :debtor_code AND item_type_pc_id = :item_type_pc_id LIMIT 1');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_type_pc_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($item) {
        // Fetch company_name based on debtor_code
        $stmt = $pdo->prepare('SELECT company_name FROM item_type_pc WHERE debtor_code = :debtor_code LIMIT 1');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->execute();
        $companyName = $stmt->fetchColumn();

        // Determine the group name
        $groupName = $item['item_type_pc_group_name'];
        $groupData = $groups[$groupName];

        // Fetch the software details associated with the computer item
        $computerName = $item['computer_name'];
        $stmt = $pdo->prepare('SELECT item_type_sw_id, software_name, item_type_sw_group_name, client_account_id, master_account_id, license FROM item_type_sw WHERE installed_pc = :computer_name');
        $stmt->bindParam(':computer_name', $computerName);
        $stmt->execute();
        $softwareDetails = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Fetch all printers associated with the computer_name
        $stmt = $pdo->prepare('SELECT item_type_hw_printer_id, model FROM item_type_hw_printer WHERE installed_pc = :computer_name');
        $stmt->bindParam(':computer_name', $computerName);
        $stmt->execute();
        $printerDetails = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Fetch the VPN details associated with the computer_name
        $stmt = $pdo->prepare('SELECT item_type_nw_vpn_id, vpn_type, forticlient_username FROM item_type_nw_vpn WHERE installed_pc = :computer_name');
        $stmt->bindParam(':computer_name', $computerName);
        $stmt->execute();
        $vpnDetails = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Fetch Office 365 details based on the computer_name
        $office365Details = [];
        $installedSoftwareDetails = [];
        $antivirusDetails = [];
        foreach ($softwareDetails as $software) {
            if ($software['item_type_sw_group_name'] == 'Office 365 Master Account' || $software['item_type_sw_group_name'] == 'Office 365 Client Account') {
                $office365Details[] = $software;
            } elseif (in_array($software['item_type_sw_group_name'], ['Antivirus Endpoint Client', 'Antivirus Endpoint Master', 'Antivirus Internet Security'])) {
                $antivirusDetails[] = $software;
            } else {
                $installedSoftwareDetails[] = $software;
            }
        }

        // Fetch the item_type_sw_id for office_365 based on client_account_id
        $office365Id = null;
        if (!empty($item['office_365'])) {
            $stmt = $pdo->prepare('SELECT item_type_sw_id FROM item_type_sw WHERE client_account_id = :client_account_id LIMIT 1');
            $stmt->bindParam(':client_account_id', $item['office_365']);
            $stmt->execute();
            $office365Id = $stmt->fetchColumn();
        }

        // Fetch Autocount Client Version details
        $stmt = $pdo->prepare('SELECT item_type_ac_id, autocount_client_version FROM item_type_ac WHERE installed_pc = :computer_name');
        $stmt->bindParam(':computer_name', $computerName);
        $stmt->execute();
        $autocountDetails = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Fetch Autocount Main details
        $stmt = $pdo->prepare('SELECT item_type_ac_id, autocount_edition, autocount_version, autocount_revision, item_type_ac_group_name FROM item_type_ac WHERE installed_pc = :computer_name');
        $stmt->bindParam(':computer_name', $computerName);
        $stmt->execute();
        $autocountMainDetails = $stmt->fetchAll(PDO::FETCH_ASSOC);
    } else {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }
} else {
    echo "<p>No debtor code or item ID provided.</p>";
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>PC Details</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
        .table-fixed {
            table-layout: fixed;
            width: 100%;
        }
        .table-fixed td {
            overflow: hidden;
            text-overflow: ellipsis;
        }
        .group-header {
            background-color: #f8f9fa;
            font-weight: bold;
            padding: 8px;
            margin-top: 16px;
            border-bottom: 1px solid #dee2e6;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">PC Details for <?= htmlspecialchars($groupName) ?></h5>
                <p>Details for Company: <?= htmlspecialchars($companyName) ?></p>
            </div>
            <div class="card-body">
                <!-- Nav tabs -->
                <ul class="nav nav-tabs" id="myTab" role="tablist">
                    <li class="nav-item">
                        <a class="nav-link active" id="general-tab" data-bs-toggle="tab" href="#general" role="tab">General</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="hardware-tab" data-bs-toggle="tab" href="#hardware" role="tab">Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="software-tab" data-bs-toggle="tab" href="#software" role="tab">Software</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="network-tab" data-bs-toggle="tab" href="#network" role="tab">Network</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="printers-tab" data-bs-toggle="tab" href="#printers" role="tab">Printers</a>
                    </li>
                    <?php if ($groupName === 'Server'): ?>
                        <li class="nav-item">
                            <a class="nav-link" id="ilo-tab" data-bs-toggle="tab" href="#ilo" role="tab">ILO</a>
                        </li>
                    <?php endif; ?>
                    <li class="nav-item">
                        <a class="nav-link" id="others-tab" data-bs-toggle="tab" href="#others" role="tab">Others</a>
                    </li>
                </ul>

                <!-- Tab content -->
                <div class="tab-content mt-3" id="myTabContent">
                    <!-- General Tab -->
                    <div class="tab-pane fade show active" id="general" role="tabpanel">
                        <div class="group-header">Basic Information</div>
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach (['active', 'customer_username'] as $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                        <td>
                                            <?php if ($field == 'active'): ?>
                                                <?= $item['active'] == 1 ? 'Yes' : 'No' ?>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? 'N/A') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>

                        <div class="group-header">Login Details</div>
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach (['login_id', 'login_password', 'windows_product_key', 'os_version'] as $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                        <td>
                                            <?php if ($field == 'login_password' || $field == 'windows_product_key'): ?>
                                                <div class="password-container">
                                                    <div class="password-field" data-password="<?= htmlspecialchars($item[$field]) ?>">******</div>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? 'N/A') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>

                        <div class="group-header">Computer Information</div>
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach (['brand', 'model', 'computer_name', 'domain', 'part_no', 'serial_number', 'purchase_date', 'warranty_expire_date'] as $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                        <td><?= htmlspecialchars($item[$field] ?? 'N/A') ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>

                        <div class="group-header">Email Details</div>
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach (['user_email', 'pc_email_account', 'pc_email_password', 'pin'] as $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                        <td>
                                            <?php if ($field == 'pc_email_password'): ?>
                                                <div class="password-container">
                                                    <div class="password-field" data-password="<?= htmlspecialchars($item[$field]) ?>">******</div>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? 'N/A') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Hardware Tab -->
                    <div class="tab-pane fade" id="hardware" role="tabpanel">
                        <div class="group-header">Processor & RAM</div>
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach (['processor', 'ram_type', 'ram_gb', 'ram_total_unit'] as $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                        <td><?= htmlspecialchars($item[$field] ?? 'N/A') ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>

                        <div class="group-header">Hard Disk</div>
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <tr>
                                    <th>Hard Disk Information</th>
                                    <td>
                                        <?php
                                        $harddiskTypes = explode(',', $item['harddisk_type']);
                                        $harddiskSpaces = explode(',', $item['harddisk_space']);
                                        ?>
                                        <ul class="list-unstyled">
                                            <?php for ($i = 0; $i < count($harddiskTypes); $i++): ?>
                                                <?php if (!empty(trim($harddiskTypes[$i])) && !empty(trim($harddiskSpaces[$i]))): ?>
                                                    <li>
                                                        <strong>Hard Disk <?= $i + 1 ?>:</strong>
                                                        <?= htmlspecialchars(trim($harddiskTypes[$i])) ?> - <?= htmlspecialchars(trim($harddiskSpaces[$i])) ?>
                                                    </li>
                                                <?php endif; ?>
                                            <?php endfor; ?>
                                        </ul>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                    </div>

                    <!-- Software Tab -->
                    <div class="tab-pane fade" id="software" role="tabpanel">
                        <div class="group-header">Autocount</div>
                        <?php if (!empty($autocountMainDetails)): ?>
                            <table class="table table-bordered table-fixed">
                                <thead>
                                    <tr>
                                        <th>Details</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($autocountMainDetails as $autocountMain): ?>
                                        <?php if ($autocountMain['item_type_ac_group_name'] == 'Autocount'): ?>
                                            <tr>
                                                <td>
                                                    <a href="view_ac_main_details.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>&company_name=<?= htmlspecialchars($companyName) ?>&item_type_ac_id=<?= htmlspecialchars($autocountMain['item_type_ac_id']) ?>">
                                                        Edition: <?= htmlspecialchars($autocountMain['autocount_edition']) ?>, Version: <?= htmlspecialchars($autocountMain['autocount_version']) ?>, Revision: <?= htmlspecialchars($autocountMain['autocount_revision']) ?>
                                                    </a>
                                                </td>
                                            </tr>
                                        <?php endif; ?>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        <?php else: ?>
                            <p>No Autocount Main data available.</p>
                        <?php endif; ?>

                        <?php if (!empty($autocountDetails)): ?>
                            <h5>Autocount Client Version</h5>
                            <table class="table table-bordered table-fixed">
                                <thead>
                                    <tr>
                                        <th>Client Version</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($autocountDetails as $autocount): ?>
                                        <tr>
                                            <td>
                                                <a href="view_ac_client_details.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>&company_name=<?= htmlspecialchars($companyName) ?>&item_type_ac_id=<?= htmlspecialchars($autocount['item_type_ac_id']) ?>">
                                                    <?= htmlspecialchars($autocount['autocount_client_version']) ?>
                                                </a>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        <?php else: ?>
                            <p>No Autocount/Payroll data available.</p>
                        <?php endif; ?>

                        <div class="group-header">Installed Software</div>
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php if (!empty($installedSoftwareDetails)): ?>
                                    <?php foreach ($installedSoftwareDetails as $software): ?>
                                        <tr>
                                            <th><?= htmlspecialchars($software['software_name']) ?></th>
                                            <td>
                                                <a href="view_software_table_details.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>&item_type_sw_id=<?= htmlspecialchars($software['item_type_sw_id']) ?>">
                                                    View Details
                                                </a>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td>No software installed.</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>

                        <div class="group-header">Antivirus</div>
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php if (!empty($antivirusDetails)): ?>
                                    <?php foreach ($antivirusDetails as $antivirus): ?>
                                        <tr>
                                            <th><?= htmlspecialchars($antivirus['software_name']) ?></th>
                                            <td>
                                                <a href="view_software_table_details.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>&item_type_sw_id=<?= htmlspecialchars($antivirus['item_type_sw_id']) ?>">
                                                    View Details
                                                </a>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td>No antivirus installed.</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>

                        <div class="group-header">Office 365</div>
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <tr>
                                    <td>
                                        <?php if (!empty($item['office_365']) && !empty($office365Id)): ?>
                                            <a href="view_software_table_details.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>&item_type_sw_id=<?= htmlspecialchars($office365Id) ?>">
                                                <?= htmlspecialchars($item['office_365']) ?>
                                            </a>
                                        <?php else: ?>
                                            No Office 365 License
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                    </div>

                    <!-- Network Tab -->
                    <div class="tab-pane fade" id="network" role="tabpanel">
                        <div class="group-header">Network Configuration</div>
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach (['tcp_ip', 'subnet_mask', 'gateway', 'dns'] as $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                        <td><?= htmlspecialchars($item[$field] ?? 'N/A') ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>

                        <div class="group-header">VPN</div>
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php if (!empty($vpnDetails)): ?>
                                    <?php foreach ($vpnDetails as $vpn): ?>
                                        <tr>
                                            <th><?= htmlspecialchars($vpn['vpn_type']) ?></th>
                                            <td>
                                                <a href="view_nw_vpn_details.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>&item_type_nw_vpn_id=<?= htmlspecialchars($vpn['item_type_nw_vpn_id']) ?>">
                                                    View Details
                                                </a>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td>No VPN configured.</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Printers Tab -->
                    <div class="tab-pane fade" id="printers" role="tabpanel">
                        <div class="group-header">Installed Printers</div>
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php if (!empty($printerDetails)): ?>
                                    <?php foreach ($printerDetails as $printer): ?>
                                        <tr>
                                            <th><?= htmlspecialchars($printer['model']) ?></th>
                                            <td>
                                                <a href="view_hw_printer_details.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>&item_type_hw_printer_id=<?= htmlspecialchars($printer['item_type_hw_printer_id']) ?>">
                                                    View Details
                                                </a>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <tr>
                                        <td>No printers installed.</td>
                                    </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>

                    <?php if ($groupName === 'Server'): ?>
                        <!-- ILO Tab -->
                        <div class="tab-pane fade" id="ilo" role="tabpanel">
                            <div class="group-header">ILO Configuration</div>
                            <table class="table table-bordered table-fixed">
                                <tbody>
                                    <?php foreach (['ilo_tcp_ip', 'ilo_username', 'ilo_password'] as $field): ?>
                                        <tr>
                                            <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                            <td>
                                                <?php if ($field == 'ilo_password'): ?>
                                                    <div class="password-container">
                                                        <div class="password-field" data-password="<?= htmlspecialchars($item[$field]) ?>">******</div>
                                                        <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                            <i class="bi bi-eye"></i>
                                                        </button>
                                                    </div>
                                                <?php else: ?>
                                                    <?= htmlspecialchars($item[$field] ?? 'N/A') ?>
                                                <?php endif; ?>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                            </table>
                        </div>
                    <?php endif; ?>

                    <!-- Others Tab -->
                    <div class="tab-pane fade" id="others" role="tabpanel">
                        <div class="group-header">Additional Information</div>
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach (['others'] as $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars(ucwords(str_replace('_', ' ', $field))) ?></th>
                                        <td><?= htmlspecialchars($item[$field] ?? 'N/A') ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
                <!-- Back Button -->
                <a href="view_pc_table.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>" class="btn btn-secondary mt-3">Back to List</a>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
            button.addEventListener('click', function() {
                var passwordContainer = this.closest('.password-container');
                if (!passwordContainer) return;

                var passwordField = passwordContainer.querySelector('.password-field');
                if (passwordField.innerText === '******') {
                    var encryptedPassword = passwordField.getAttribute('data-password');
                    var xhr = new XMLHttpRequest();
                    xhr.onreadystatechange = function() {
                        if (xhr.readyState == 4 && xhr.status == 200) {
                            passwordField.innerText = xhr.responseText;
                            button.innerHTML = '<i class="bi bi-eye-slash"></i>';
                        }
                    };
                    xhr.open("POST", "decrypt.php", true);
                    xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
                    xhr.send("encryptedPassword=" + encodeURIComponent(encryptedPassword) + "&key=your_secret_key");
                } else {
                    passwordField.innerText = '******';
                    button.innerHTML = '<i class="bi bi-eye"></i>';
                }
            });
        });

        // Hide passwords when switching tabs
        document.querySelectorAll('#myTab .nav-link').forEach(function(tab) {
            tab.addEventListener('click', function() {
                document.querySelectorAll('.password-field').forEach(function(field) {
                    field.innerText = '******';
                });
                document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
                    button.innerHTML = '<i class="bi bi-eye"></i>';
                });
            });
        });
    </script>
</body>
</html>

