<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password decryption

// Define the group name and fields with their respective display labels
$groupName = 'All In One PC';
$groups = [
    'All In One PC' => [
        'General' => [
            'fields' => ['active', 'brand', 'model', 'login_id', 'login_password', 'os_version', 'installed_ac_software', 'part_no', 'serial_number', 'purchase_date', 'warranty_expire_date'],
            'labels' => ['Active', 'Brand', 'Model', 'Login ID', 'Login Password', 'OS Version', 'Installed AC Software', 'Part No.', 'Serial Number', 'Purchase Date', 'Warranty Expire Date']
        ],
        'Hardware' => [
            'fields' => ['computer_name', 'processor', 'harddisk_type', 'harddisk_space', 'harddisk_total_unit', 'ram_type', 'ram_gb', 'ram_total_unit'],
            'labels' => ['Computer Name', 'Processor', 'Hard Disk Type', 'Hard Disk Space', 'Hard Disk Total Unit', 'RAM Type', 'RAM GB', 'RAM Total Unit']
        ],
        'Network' => [
            'fields' => ['tcp_ip', 'subnet_mask', 'gateway', 'dns'],
            'labels' => ['TCP/IP', 'Subnet Mask', 'Gateway', 'DNS']
        ],
        'Others' => [
            'fields' => ['others'],
            'labels' => ['Others']
        ]
    ]
];

// Check if debtor_code and item ID are passed via URL
if (isset($_GET['debtor_code']) && isset($_GET['item_type_pos_hw_aio_pc_id'])) {
    $debtorCode = $_GET['debtor_code'];
    $itemTypeId = $_GET['item_type_pos_hw_aio_pc_id'];
    $table = 'item_type_pos_hw_aio_pc';
    $idField = 'item_type_pos_hw_aio_pc_id';

    // Fetch the item details from the appropriate table
    $stmt = $pdo->prepare("SELECT * FROM $table WHERE debtor_code = :debtor_code AND $idField = :item_id LIMIT 1");
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($item) {
        // Fetch company_name directly from the item_type_pos_hw_aio_pc table
        $companyName = $item['company_name'] ?? 'N/A'; // Use 'N/A' if company_name is not set

        // Determine the group data
        $groupData = $groups[$groupName];
    } else {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }
} else {
    echo "<p>No debtor code or item ID provided.</p>";
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>All In One PC Details</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
        .table-fixed {
            table-layout: fixed;
            width: 100%;
        }
        .table-fixed td {
            overflow: hidden;
            text-overflow: ellipsis;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">Details for <?= htmlspecialchars($groupName) ?></h5>
                <p>Company: <?= htmlspecialchars($companyName) ?></p>
            </div>
            <div class="card-body">
                <!-- Nav tabs -->
                <ul class="nav nav-tabs" id="myTab" role="tablist">
                    <li class="nav-item">
                        <a class="nav-link active" id="general-tab" data-bs-toggle="tab" href="#general" role="tab">General</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="hardware-tab" data-bs-toggle="tab" href="#hardware" role="tab">Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="network-tab" data-bs-toggle="tab" href="#network" role="tab">Network</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" id="others-tab" data-bs-toggle="tab" href="#others" role="tab">Others</a>
                    </li>
                </ul>

                <!-- Tab content -->
                <div class="tab-content mt-3" id="myTabContent">
                    <!-- General Tab -->
                    <div class="tab-pane fade show active" id="general" role="tabpanel" aria-labelledby="general-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groupData['General']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groupData['General']['labels'][$index]) ?></th>
                                        <td>
                                            <?php if ($field == 'active'): ?>
                                                <?= $item['active'] == 1 ? 'Yes' : 'No' ?>
                                            <?php elseif ($field == 'login_password'): ?>
                                                <div class="password-container">
                                                    <div class="password-field" data-password="<?= htmlspecialchars($item[$field]) ?>">******</div>
                                                    <button class="btn btn-link p-0 toggle-password-btn" data-field="<?= $field ?>">
                                                        <i class="bi bi-eye"></i>
                                                    </button>
                                                </div>
                                            <?php else: ?>
                                                <?= htmlspecialchars($item[$field] ?? '') ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Hardware Tab -->
                    <div class="tab-pane fade" id="hardware" role="tabpanel" aria-labelledby="hardware-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groupData['Hardware']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groupData['Hardware']['labels'][$index]) ?></th>
                                        <td><?= htmlspecialchars($item[$field] ?? '') ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Network Tab -->
                    <div class="tab-pane fade" id="network" role="tabpanel" aria-labelledby="network-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groupData['Network']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groupData['Network']['labels'][$index]) ?></th>
                                        <td><?= htmlspecialchars($item[$field] ?? '') ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>

                    <!-- Others Tab -->
                    <div class="tab-pane fade" id="others" role="tabpanel" aria-labelledby="others-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php foreach ($groupData['Others']['fields'] as $index => $field): ?>
                                    <tr>
                                        <th><?= htmlspecialchars($groupData['Others']['labels'][$index]) ?></th>
                                        <td><?= htmlspecialchars($item[$field] ?? '') ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
        <div style="display: flex; align-items: center; margin-top: 20px;">
            <a href="view_pos_hardware_table.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>" class="btn btn-secondary">Back</a>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
            button.addEventListener('click', function() {
                var passwordContainer = this.closest('.password-container');
                if (!passwordContainer) return;

                var passwordField = passwordContainer.querySelector('.password-field');
                if (passwordField.innerText === '******') {
                    var encryptedPassword = passwordField.getAttribute('data-password');
                    var xhr = new XMLHttpRequest();
                    xhr.onreadystatechange = function() {
                        if (xhr.readyState == 4 && xhr.status == 200) {
                            passwordField.innerText = xhr.responseText;
                            button.innerHTML = '<i class="bi bi-eye-slash"></i>';
                        }
                    };
                    xhr.open("POST", "decrypt.php", true);
                    xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
                    xhr.send("encryptedPassword=" + encodeURIComponent(encryptedPassword) + "&key=your_secret_key");
                } else {
                    passwordField.innerText = '******';
                    button.innerHTML = '<i class="bi bi-eye"></i>';
                }
            });
        });

        // Hide passwords when switching tabs
        document.querySelectorAll('#myTab .nav-link').forEach(function(tab) {
            tab.addEventListener('click', function() {
                document.querySelectorAll('.password-field').forEach(function(field) {
                    field.innerText = '******';
                });
                document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
                    button.innerHTML = '<i class="bi bi-eye"></i>';
                });
            });
        });
    </script>
</body>
</html>