<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption

// Check if debtor_code is passed via URL
if (isset($_GET['debtor_code'])) {
    $debtorCode = $_GET['debtor_code'];

    // Check if company_name is passed via URL
    if (isset($_GET['company_name'])) {
        $companyName = $_GET['company_name'];
    } else {
        // Fetch company_name based on debtor_code
        $stmt = $pdo->prepare('SELECT company_name FROM item_type_sw_av_ep_master WHERE debtor_code = :debtor_code LIMIT 1');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->execute();
        $companyName = $stmt->fetchColumn();

        // If no company name is found, set a default value
        if ($companyName === false) {
            $companyName = "Company name not found for this debtor code.";
        }
    }

    // Define the groups
    $groups = [
        'Antivirus Endpoint Master' => [
            'fields' => ['active', 'software_name', 'quantity'],
            'labels' => ['Active', 'Software Name', 'Quantity'],
            'table' => 'item_type_sw_av_ep_master', // Table for this group
            'primary_key' => 'item_type_sw_av_ep_master_id', // Primary key for this group
            'edit_page' => '/crm/public/config_info/edit_sw_av_ep_master.php', // Edit page for this group
            'view_page' => '/crm/public/company/view_sw_av_ep_master_details.php' // View page for this group
        ],
        'Antivirus Endpoint Client' => [
            'fields' => ['active', 'software_name', 'software_version', 'install_path', 'others'],
            'labels' => ['Active', 'Software Name', 'Software Version', 'Install Path', 'Others'],
            'table' => 'item_type_sw_av_ep_client', // Table for this group
            'primary_key' => 'item_type_sw_av_ep_client_id', // Primary key for this group
            'edit_page' => '/crm/public/config_info/edit_sw_av_ep_client.php', // Edit page for this group
            'view_page' => '/crm/public/company/view_sw_av_ep_client_details.php' // View page for this group
        ],
        'Internet Security' => [
            'fields' => ['active', 'software_name', 'software_version', 'others'],
            'labels' => ['Active', 'Software Name', 'Software Version', 'Others'],
            'table' => 'item_type_sw_av_is', // Table for this group
            'primary_key' => 'item_type_sw_av_is_id', // Primary key for this group
            'edit_page' => '/crm/public/config_info/edit_sw_av_is.php', // Edit page for this group
            'view_page' => '/crm/public/company/view_sw_av_is_details.php' // View page for this group
        ],
        'Microsoft (No Renewal)' => [
            'fields' => ['active', 'software_name', 'software_version', 'others'],
            'labels' => ['Active', 'Software Name', 'Software Version', 'Others'],
            'table' => 'item_type_sw_microsoft_nr', // Table for this group
            'primary_key' => 'item_type_sw_microsoft_nr_id', // Primary key for this group
            'edit_page' => '/crm/public/config_info/edit_sw_microsoft_nr.php', // Edit page for this group
            'view_page' => '/crm/public/company/view_sw_microsoft_nr_details.php' // View page for this group
        ],
        'Office 365 Master Account' => [
            'fields' => ['active', 'master_account_id', 'others'],
            'labels' => ['Active', 'Master Account ID', 'Others'],
            'table' => 'item_type_sw_o365_master', // Table for this group
            'primary_key' => 'item_type_sw_o365_master_id', // Primary key for this group
            'edit_page' => '/crm/public/config_info/edit_sw_o365_master.php', // Edit page for this group
            'view_page' => '/crm/public/company/view_sw_o365_master_details.php' // View page for this group
        ],
        'Office 365 Client Account' => [
            'fields' => ['active', 'client_account_id', 'others'],
            'labels' => ['Active', 'Client Account ID', 'Others'],
            'table' => 'item_type_sw_o365_client', // Table for this group
            'primary_key' => 'item_type_sw_o365_client_id', // Primary key for this group
            'edit_page' => '/crm/public/config_info/edit_sw_o365_client.php', // Edit page for this group
            'view_page' => '/crm/public/company/view_sw_o365_client_details.php' // View page for this group
        ]
    ];

    $dataByGroup = [];
    $hasData = false;

    // Fetch data for each group
    foreach ($groups as $group => $groupData) {
        // Fetch data from the appropriate table
        $stmt = $pdo->prepare("SELECT * FROM {$groupData['table']} WHERE debtor_code = :debtor_code");
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->execute();
        $dataByGroup[$group] = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Check if this group has data
        if (!empty($dataByGroup[$group])) {
            $hasData = true;
        }
    }
} else {
    echo "<p>No debtor code provided.</p>";
    $dataByGroup = array_fill_keys(array_keys($groups), []);
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Antivirus Endpoint Info</title>
    <!-- Bootstrap 5.x CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- FontAwesome Icons -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.2/css/all.min.css" rel="stylesheet">
    <!-- Custom CSS for Table Height -->
    <style>
        .table-tall td, .table-tall th {
            padding: 1rem; /* Add vertical padding to make rows taller */
        }
    </style>
</head>
<body>
    <div class="container-fluid mt-5">
        <div class="row justify-content-center">
            <div class="col-md-10">
                <!-- Navigation Tabs -->
                <ul class="nav nav-tabs mb-4">
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'company_details.php' ? 'active' : '' ?>" 
                           href="company_details.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Company Details</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_autocount_table.php' ? 'active' : '' ?>" 
                           href="view_autocount_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Autocount</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_email_citssb_table.php' ? 'active' : '' ?>" 
                           href="view_email_citssb_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Email</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_network_table.php' ? 'active' : '' ?>" 
                           href="view_network_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Network</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_nas_table.php' ? 'active' : '' ?>" 
                           href="view_nas_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">NAS</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hardware_table.php' ? 'active' : '' ?>" 
                           href="view_hardware_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pos_hardware_table.php' ? 'active' : '' ?>" 
                           href="view_pos_hardware_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">POS Hardware</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_pc_table.php' ? 'active' : '' ?>" 
                           href="view_pc_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Computer</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_hosting_table.php' ? 'active' : '' ?>" 
                           href="view_hosting_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Hosting</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link <?= basename($_SERVER['PHP_SELF']) === 'view_software_table.php' ? 'active' : '' ?>" 
                           href="view_software_table.php?debtor_code=<?= urlencode($debtorCode); ?>&company_name=<?= urlencode($companyName); ?>">Software</a>
                    </li>
                </ul>

                <!-- Card for Company Name and Back Button -->
                <div class="card mb-4">
                    <div class="card-header d-flex align-items-center">
                        <!-- Centered Company Name -->
                        <div class="flex-grow-1 text-center">
                            <h2 class="mb-0"><?= htmlspecialchars($companyName) ?></h2>
                        </div>
                    </div>
                </div>

                <?php if ($hasData): ?>
                    <?php foreach ($groups as $group => $groupData): ?>
                        <?php if (!empty($dataByGroup[$group])): ?>
                            <!-- Card for each group -->
                            <div class="card mb-4">
                                <div class="card-header">
                                    <h3 class="mb-0"><?= htmlspecialchars($group) ?> Information</h3>
                                </div>
                                <div class="card-body">
                                    <div class="table-responsive">
                                        <table class="table table-striped table-hover table-sm table-borderless table-tall">
                                            <thead>
                                                <tr>
                                                    <?php foreach ($groupData['labels'] as $label): ?>
                                                        <th><?= htmlspecialchars($label) ?></th>
                                                    <?php endforeach; ?>
                                                    <th>Actions</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                <?php foreach ($dataByGroup[$group] as $row): ?>
                                                    <tr>
                                                        <?php foreach ($groupData['fields'] as $field): ?>
                                                            <td>
                                                                <?php if ($field == 'active'): ?>
                                                                    <?= $row['active'] == 1 ? 'Yes' : 'No' ?>
                                                                <?php else: ?>
                                                                    <?= htmlspecialchars($row[$field] ?? '') ?>
                                                                <?php endif; ?>
                                                            </td>
                                                        <?php endforeach; ?>
                                                        <td>
                                                            <?php
                                                            // Determine the primary key and edit page
                                                            $primaryKey = $groupData['primary_key'];
                                                            $editPage = $groupData['edit_page']; // Use the edit page from the group definition
                                                            $viewPage = $groupData['view_page']; // Use the view page from the group definition

                                                            // Build the view and edit URLs dynamically
                                                            $viewUrl = $viewPage . '?debtor_code=' . urlencode($debtorCode) . '&' . $primaryKey . '=' . urlencode($row[$primaryKey]);
                                                            $editUrl = $editPage . '?debtor_code=' . urlencode($debtorCode) . '&company_name=' . urlencode($companyName) . '&' . $primaryKey . '=' . urlencode($row[$primaryKey]);
                                                            ?>
                                                            <a href="<?= $viewUrl ?>" class="btn btn-primary btn-sm">
                                                                <i class="fas fa-eye"></i> View
                                                            </a> |
                                                            <a href="<?= $editUrl ?>" class="btn btn-primary btn-sm">
                                                                <i class="fas fa-edit"></i> Edit
                                                            </a>
                                                        </td>
                                                    </tr>
                                                <?php endforeach; ?>
                                            </tbody>
                                        </table>
                                    </div>
                                </div>
                            </div>
                        <?php endif; ?>
                    <?php endforeach; ?>
                <?php else: ?>
                    <div class="alert alert-warning" role="alert">
                        No related information found for this company.
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.x JS Bundle CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>