<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
// Check if debtor_code is passed via URL
if (isset($_GET['debtor_code'])) {
    $debtorCode = $_GET['debtor_code'];

    // Determine the item ID and table based on the group
    if (isset($_GET['item_type_sw_av_ep_master_id'])) {
        $itemTypeId = $_GET['item_type_sw_av_ep_master_id'];
        $table = 'item_type_sw_av_ep_master';
        $idField = 'item_type_sw_av_ep_master_id';
        $groupName = 'Antivirus Endpoint Master';
    } elseif (isset($_GET['item_type_sw_av_ep_client_id'])) {
        $itemTypeId = $_GET['item_type_sw_av_ep_client_id'];
        $table = 'item_type_sw_av_ep_client';
        $idField = 'item_type_sw_av_ep_client_id';
        $groupName = 'Antivirus Endpoint Client';
    } elseif (isset($_GET['item_type_sw_av_is_id'])) {
        $itemTypeId = $_GET['item_type_sw_av_is_id'];
        $table = 'item_type_sw_av_is';
        $idField = 'item_type_sw_av_is_id';
        $groupName = 'Antivirus Internet Security';
    } elseif (isset($_GET['item_type_sw_microsoft_nr_id'])) {
        $itemTypeId = $_GET['item_type_sw_microsoft_nr_id'];
        $table = 'item_type_sw_microsoft_nr';
        $idField = 'item_type_sw_microsoft_nr_id';
        $groupName = 'Microsoft (No Renewal)';
    } elseif (isset($_GET['item_type_sw_o365_master_id'])) {
        $itemTypeId = $_GET['item_type_sw_o365_master_id'];
        $table = 'item_type_sw_o365_master';
        $idField = 'item_type_sw_o365_master_id';
        $groupName = 'Office 365 Master Account';
    } elseif (isset($_GET['item_type_sw_o365_client_id'])) {
        $itemTypeId = $_GET['item_type_sw_o365_client_id'];
        $table = 'item_type_sw_o365_client';
        $idField = 'item_type_sw_o365_client_id';
        $groupName = 'Office 365 Client Account';
    } elseif (isset($_GET['item_type_sw_other_id'])) {
        $itemTypeId = $_GET['item_type_sw_other_id'];
        $table = 'item_type_sw_other';
        $idField = 'item_type_sw_other_id';
        $groupName = 'Other Software';
    } else {
        echo "<p>No item ID provided.</p>";
        exit;
    }

    // Fetch the item details based on debtor_code and item ID from the appropriate table
    $stmt = $pdo->prepare("SELECT * FROM $table WHERE debtor_code = :debtor_code AND $idField = :item_id LIMIT 1");
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($item) {
        // Fetch company_name based on debtor_code from the appropriate table
        $stmt = $pdo->prepare("SELECT company_name FROM $table WHERE debtor_code = :debtor_code LIMIT 1");
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->execute();
        $companyName = $stmt->fetchColumn();

        // Fetch all PCs associated with this license only if installed_pc exists and is not empty
        if (isset($item['installed_pc']) && !empty($item['installed_pc'])) {
            $installedPc = $item['installed_pc'];
            $stmt = $pdo->prepare('
                SELECT computer_name, item_type_pc_id 
                FROM item_type_pc 
                WHERE computer_name = :installed_pc
            ');
            $stmt->bindParam(':installed_pc', $installedPc);
            $stmt->execute();
            $pcDetails = $stmt->fetchAll(PDO::FETCH_ASSOC);
        } else {
            $pcDetails = []; // Set pcDetails to an empty array if no installed_pc is found
        }
    } else {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }
} else {
    echo "<p>No debtor code provided.</p>";
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Software Details</title>
    <!-- Bootstrap 5.3 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Bootstrap Icons -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
    <style>
        .password-container {
            display: flex;
            align-items: center;
            gap: 10px;
        }
        .password-field {
            word-wrap: break-word;
            white-space: pre-wrap;
            max-width: 200px;
            overflow: hidden;
        }
        .table-fixed {
            table-layout: fixed;
            width: 100%;
        }
        .table-fixed th,
        .table-fixed td {
            overflow: hidden;
            text-overflow: ellipsis;
            white-space: nowrap;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card">
            <div class="card-header">
                <h5 class="card-title">Details for <?= htmlspecialchars($groupName) ?></h5>
                <p>Company: <?= htmlspecialchars($companyName) ?></p>
            </div>
            <div class="card-body">
                <!-- Nav tabs -->
                <ul class="nav nav-tabs" id="myTab" role="tablist">
                    <li class="nav-item">
                        <a class="nav-link active" id="general-tab" data-bs-toggle="tab" href="#general" role="tab">General</a>
                    </li>
                    <!-- Add other tabs here if needed -->
                </ul>

                <!-- Tab content -->
                <div class="tab-content mt-3" id="myTabContent">
                    <!-- General Tab -->
                    <div class="tab-pane fade show active" id="general" role="tabpanel" aria-labelledby="general-tab">
                        <table class="table table-bordered table-fixed">
                            <tbody>
                                <?php
                                // Define fields and labels for each group
                                $fields = [];
                                $labels = [];
                                switch ($groupName) {
                                    case 'Antivirus Endpoint Master':
                                        $fields = ['active', 'contract_number', 'enterprise_site_id', 'installed_pc', 'management_console_url', 'quantity', 'login', 'password', 'software_name', 'software_version', 'others'];
                                        $labels = ['Active', 'Contract Number', 'Enterprise Site ID', 'Installed PC', 'Management Console URL', 'Quantity', 'Login', 'Password', 'Software Name', 'Software Version', 'Others'];
                                        break;
                                    case 'Antivirus Endpoint Client':
                                        $fields = ['active','installed_pc', 'software_name', 'software_version', 'install_path', 'others'];
                                        $labels = ['Active','Installed PC', 'Software Name', 'Software Version', 'Install Path','Others'];
                                        break;
                                    case 'Antivirus Internet Security':
                                        $fields = ['active', 'installed_pc', 'login', 'password', 'software_name', 'software_version', 'public_license_id', 'activation_key', 'others'];
                                        $labels = ['Active', 'Installed PC', 'Login', 'Password', 'Software Name', 'Software Version', 'Public License ID', 'Activation Key', 'Others'];
                                        break;
                                    case 'Microsoft (No Renewal)':
                                        $fields = ['active', 'installed_pc', 'login', 'password', 'software_name', 'software_version', 'authenticator', 'license', 'others'];
                                        $labels = ['Active', 'Installed PC', 'Login', 'Password', 'Software Name', 'Software Version', 'Authenticator', 'License', 'Others'];
                                        break;
                                    case 'Office 365 Master Account':
                                        $fields = ['active', 'installed_pc', 'master_account_id', 'master_account_password', 'license', 'login', 'password', 'authenticator', 'others'];
                                        $labels = ['Active', 'Installed PC', 'Master Account ID', 'Master Account Password', 'License', 'Login', 'Password', 'Authenticator', 'Others'];
                                        break;
                                    case 'Office 365 Client Account':
                                        $fields = ['active', 'installed_pc', 'client_account_id', 'client_account_password', 'license', 'authenticator', 'others'];
                                        $labels = ['Active', 'Installed PC', 'Client Account ID', 'Client Account Password', 'License', 'Authenticator', 'Others'];
                                        break;
                                    case 'Other Software':
                                        $fields = ['active', 'installed_pc', 'license', 'login', 'password', 'software_provider', 'provider_telephone_no', 'others'];
                                        $labels = ['Active', 'Installed PC', 'License', 'Login', 'Password', 'Software Provider', 'Provider Telephone Number', 'Others'];
                                        break;
                                }

                                // Display fields and values
                                foreach ($fields as $index => $field) {
                                    echo "<tr>";
                                    echo "<th>" . htmlspecialchars($labels[$index]) . "</th>";
                                    echo "<td>";
                                    if ($field == 'active') {
                                        echo $item['active'] == 1 ? 'Yes' : 'No';
                                    } elseif ($field == 'installed_pc') {
                                        if (!empty($pcDetails)) {
                                            echo "<ul>";
                                            foreach ($pcDetails as $pc) {
                                                echo "<li>";
                                                echo "<a href='view_pc_table_details.php?debtor_code=" . htmlspecialchars($debtorCode) . "&item_type_pc_id=" . htmlspecialchars($pc['item_type_pc_id']) . "'>";
                                                echo htmlspecialchars($pc['computer_name']);
                                                echo "</a>";
                                                echo "</li>";
                                            }
                                            echo "</ul>";
                                        } else {
                                            echo "N/A"; // Display N/A if no installed PC is found
                                        }
                                    } elseif (in_array($field, ['password', 'activation_key', 'master_account_password', 'client_account_password'])) {
                                        echo "<div class='password-container'>";
                                        echo "<div class='password-field' data-password='" . htmlspecialchars($item[$field]) . "'>******</div>";
                                        echo "<button class='btn btn-link p-0 toggle-password-btn' data-field='$field'>";
                                        echo "<i class='bi bi-eye'></i>";
                                        echo "</button>";
                                        echo "</div>";
                                    } else {
                                        echo htmlspecialchars($item[$field] ?? '');
                                    }
                                    echo "</td>";
                                    echo "</tr>";
                                }
                                ?>
                            </tbody>
                        </table>
                    </div>
                    <!-- Add other tabs content here if needed -->
                </div>
            </div>
        </div>
        <div style="display: flex; align-items: center; margin-top: 20px;">
            <a href="view_software_table.php?debtor_code=<?= htmlspecialchars($debtorCode) ?>" class="btn btn-secondary">Back to List</a>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
            button.addEventListener('click', function() {
                var passwordContainer = this.closest('.password-container');
                if (!passwordContainer) return;

                var passwordField = passwordContainer.querySelector('.password-field');
                if (passwordField.innerText === '******') {
                    var encryptedPassword = passwordField.getAttribute('data-password');
                    var xhr = new XMLHttpRequest();
                    xhr.onreadystatechange = function() {
                        if (xhr.readyState == 4 && xhr.status == 200) {
                            passwordField.innerText = xhr.responseText;
                            button.innerHTML = '<i class="bi bi-eye-slash"></i>';
                        }
                    };
                    xhr.open("POST", "decrypt.php", true);
                    xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
                    xhr.send("encryptedPassword=" + encodeURIComponent(encryptedPassword) + "&key=your_secret_key");
                } else {
                    passwordField.innerText = '******';
                    button.innerHTML = '<i class="bi bi-eye"></i>';
                }
            });
        });

        // Hide passwords and activation keys when switching tabs
        document.querySelectorAll('#myTab .nav-link').forEach(function(tab) {
            tab.addEventListener('click', function() {
                document.querySelectorAll('.password-field').forEach(function(field) {
                    field.innerText = '******';
                });
                document.querySelectorAll('.toggle-password-btn').forEach(function(button) {
                    button.innerHTML = '<i class="bi bi-eye"></i>';
                });
            });
        });
    </script>
</body>
</html>

