<?php
// Set session expiration time to 1 hour (3600 seconds)
session_set_cookie_params(3600, '/', '', true, true); // Secure and HttpOnly flags enabled
session_start();
session_regenerate_id(true); // Regenerate session ID to prevent session fixation

// Include the database connection file using an absolute path
require __DIR__ . '/../../database/db.php';

// Check if the user is already logged in
if (!isset($_SESSION['username']) || !isset($_SESSION['role']) || !isset($_SESSION['active'])) {
    header('Location: /crm/public/config/login.php');
    exit();
}

// Ensure the user has a valid role
$validRoles = ['super_admin', 'admin', 'user'];
if (!in_array($_SESSION['role'], $validRoles)) {
    header('Location: /crm/public/config/login.php');
    exit();
}

// Check if the user is active
if ($_SESSION['active'] != 1) {
    header('Location: /crm/public/config/login.php');
    exit();
}

// Fetch the user group from the database if not already set in the session
if (!isset($_SESSION['id']) || !isset($_SESSION['user_group'])) {
    $username = $_SESSION['username'];
    
    // Fetch user id and group from the database
    $query = "SELECT id, user_group FROM admins WHERE username = :username";
    $stmt = $pdo->prepare($query);
    $stmt->execute(['username' => $username]);
    $userData = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($userData) {
        // Store both user id and group in session
        $_SESSION['id'] = $userData['id'];
        $_SESSION['user_group'] = $userData['user_group'];
    } else {
        die("User not found");
    }
}

// Debug output to verify session variables (Remove in production)
// echo 'User ID: ' . $_SESSION['id'] . '<br>';
// echo 'Username: ' . $_SESSION['username'] . '<br>';
// echo 'Role: ' . $_SESSION['role'] . '<br>';
// echo 'Active: ' . $_SESSION['active'] . '<br>';
// echo 'User Group: ' . $_SESSION['user_group'] . '<br>';

// Function to check access permissions
function hasAccess($pdo, $url, $userGroup) {
    // Fetch permissions that contain the URL substring and match the user group
    $stmt = $pdo->prepare("SELECT can_access, url FROM permissions WHERE user_group = :user_group");
    $stmt->execute(['user_group' => $userGroup]);
    $permissions = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Debug: Print the current URL and user group (Remove in production)
    echo 'Current URL: ' . $url . '<br>';
    echo 'User Group: ' . $userGroup . '<br>';

    // Check if any stored URL is a substring of the current URL
    foreach ($permissions as $permission) {
        // Debug: Print each permission URL being checked (Remove in production)
        echo 'Checking permission URL: ' . $permission['url'] . '<br>';

        if (strpos($url, $permission['url']) !== false) {
            // If can_access is 1, the user has access
            if ($permission['can_access'] == 1) {
                echo 'Access granted for URL: ' . $permission['url'] . '<br>';
                return true;
            } else {
                echo 'Access denied for URL: ' . $permission['url'] . '<br>';
            }
        }
    }

    // Debug: No matching permission found (Remove in production)
    echo 'No matching permission found. Access denied.<br>';
    return false;
}

function hasAccessMenu($menu_item) {
    // Fetch the current user's group from the session or database
    $current_user_group = $_SESSION['user_group']; // Assuming user_group is stored in the session

    // Fetch permissions for the current user's group
    global $pdo; // Assuming $pdo is your database connection
    $stmt = $pdo->prepare("SELECT can_access FROM menu_permissions WHERE user_group = :user_group AND menu_item = :menu_item");
    $stmt->bindParam(':user_group', $current_user_group);
    $stmt->bindParam(':menu_item', $menu_item);
    $stmt->execute();

    $permission = $stmt->fetch(PDO::FETCH_ASSOC);

    // Check if the user's group has permission to access the menu item
    if ($permission && $permission['can_access'] == 1) {
        return true;
    }
    return false;
}
?>