<?php
// Enforce HTTPS
if (!isset($_SERVER['HTTPS']) || $_SERVER['HTTPS'] !== 'on') {
    header("Location: https://" . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI']);
    exit();
}

require_once '../../database/db.php';
session_start();
date_default_timezone_set('Asia/Kuala_Lumpur');



// Generate CSRF token
if (empty($_SESSION['csrf_token'])) {
    $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
}

$error = ''; // Variable to store error messages

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate CSRF token
    if (!isset($_POST['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
        $error = "CSRF token validation failed.";
    } else {
        // Sanitize and validate inputs
        $username = filter_var($_POST['username'], FILTER_SANITIZE_STRING);
        $password = $_POST['password']; // No need to sanitize passwords

        if (empty($username) || empty($password)) {
            $error = "Username and password are required.";
        } else {
            // Fetch user from the database
            $stmt = $pdo->prepare('SELECT * FROM admins WHERE username = ?');
            $stmt->execute([$username]);
            $user = $stmt->fetch(PDO::FETCH_ASSOC);

            if ($user) {
                // Check if the user is active
                if ($user['active'] == 1) {
                    // Verify password (plain text comparison for now)
                    if ($password === $user['password']) {
                        // Regenerate session ID to prevent session fixation
                        session_regenerate_id(true);

                        // Set session variables
                        $_SESSION['username'] = $user['username'];
                        $_SESSION['role'] = $user['role'];
                        $_SESSION['active'] = $user['active'];

                        // Log the login activity (username in plain text)
                        $logMessage = "User logged in!";

                        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                                   VALUES (:username, :timestamp, :role, :activity)";
                        $stmtLog = $pdo->prepare($sqlLog);
                        $stmtLog->execute([
                            ':username' => $user['username'], // Log username in plain text
                            ':timestamp' => date('Y-m-d H:i:s'),
                            ':role' => $user['role'],
                            ':activity' => $logMessage
                        ]);

                        // Redirect to dashboard after a delay
                        echo "<script>
                                setTimeout(function() {
                                    window.location.href = '../main/dashboard.php';
                                }, 1000); // 1-second delay
                              </script>";
                        exit();
                    } else {
                        $error = "Invalid username or password.";
                    }
                } else {
                    $error = "Your account is inactive. Please contact the admin.";
                }
            } else {
                $error = "Invalid username or password.";
            }
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Login</title>
    <!-- Bootstrap CSS -->
    <link href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css" rel="stylesheet">
    <!-- Custom CSS -->
    <style>
        body {
            background-color: #f8f9fa;
        }
        .login-container {
            margin-top: 100px;
        }
        .login-form {
            background-color: #ffffff;
            border-radius: 10px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }
        .login-form h2 {
            color: #343a40;
        }
        .login-form .form-control {
            border-radius: 5px;
        }
        .login-form .btn-primary {
            background-color: #007bff;
            border-color: #007bff;
            border-radius: 5px;
        }
        .login-form .btn-primary:hover {
            background-color: #0056b3;
            border-color: #0056b3;
        }
        .error-message {
            color: #dc3545;
            font-size: 0.9rem;
            margin-top: 0.5rem;
        }
        #loading {
            display: none;
            text-align: center;
            margin-top: 20px;
        }
    </style>
</head>
<body>
    <div class="container login-container">
        <div class="row justify-content-center">
            <div class="col-md-6">
                <form method="POST" class="p-4 login-form" id="loginForm">
                    <h2 class="text-center mb-4">Login</h2>
                    <?php if (!empty($error)): ?>
                        <div class="alert alert-danger"><?php echo htmlspecialchars($error); ?></div>
                    <?php endif; ?>
                    <input type="hidden" name="csrf_token" value="<?php echo $_SESSION['csrf_token']; ?>">
                    <div class="form-group">
                        <input type="text" name="username" id="username" class="form-control" placeholder="Username" required>
                        <div class="error-message" id="usernameError"></div>
                    </div>
                    <div class="form-group">
                        <input type="password" name="password" id="password" class="form-control" placeholder="Password" required>
                        <div class="error-message" id="passwordError"></div>
                    </div>
                    <button type="submit" class="btn btn-primary btn-block">Login</button>
                </form>
                <!-- Loading Spinner -->
                <div id="loading">
                    <p>Redirecting to dashboard...</p>
                    <div class="spinner-border text-primary" role="status">
                        <span class="sr-only">Loading...</span>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Optional: Bootstrap JS and dependencies -->
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.9.3/dist/umd/popper.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
    <!-- Custom JS -->
    <script>
        document.getElementById('loginForm').addEventListener('submit', function(event) {
            let isValid = true;
            const username = document.getElementById('username').value.trim();
            const password = document.getElementById('password').value.trim();

            // Clear previous error messages
            document.getElementById('usernameError').innerText = '';
            document.getElementById('passwordError').innerText = '';

            // Validate username
            if (username === '') {
                document.getElementById('usernameError').innerText = 'Username is required';
                isValid = false;
            }

            // Validate password
            if (password === '') {
                document.getElementById('passwordError').innerText = 'Password is required';
                isValid = false;
            }

            if (isValid) {
                // Show loading spinner
                document.getElementById('loading').style.display = 'block';
            } else {
                event.preventDefault();
            }
        });
    </script>
</body>
</html>