<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeAcGroup = isset($_GET['itemTypeAcGroup']) ? $_GET['itemTypeAcGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Directly get debtor_code from URL

$installedPcOptions = [];
try {
    // Fetch necessary data
    $itemtype = $pdo->query("SELECT item_type_id, item_type_name FROM item_type")->fetchAll(PDO::FETCH_ASSOC);
    $itemtype_ac_group = $pdo->query("SELECT item_type_ac_group_id, item_type_ac_group_name FROM item_type_ac_group")->fetchAll(PDO::FETCH_ASSOC);
    // Fetch installed PC options from item_type_pc where debtor_code and company_name match
    $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtorCode AND company_name = :companyName");
    $stmt->execute([':debtorCode' => $debtorCode, ':companyName' => $companyName]);
    $installedPcOptions = $stmt->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}

// Handle form submission to save data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $active = 1; // Always set active to 1
    $installedPc = $_POST['installed_pc'] ?? '';
    $others = $_POST['others'] ?? null;
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included
    $autocountClientVersion = $_POST['autocount_client_version'] ?? null; // Capture the selected AutoCount Client Version

    try {
        // Insert into the new table `item_type_ac_client`
        $stmt = $pdo->prepare("INSERT INTO item_type_ac_client (
            item_type_name, 
            item_type_ac_group_name,
            company_name, 
            active,
            installed_pc,
            others,
            debtor_code,
            autocount_client_version
        ) VALUES (
            :item_type_name,
            :item_type_ac_group_name,
            :company_name,
            :active,
            :installed_pc,
            :others,
            :debtor_code,
            :autocount_client_version
        )");

        $stmt->execute([
            ':item_type_name' => $itemType,
            ':item_type_ac_group_name' => $itemTypeAcGroup,
            ':company_name' => $companyName,
            ':active' => $active,
            ':installed_pc' => $installedPc,
            ':others' => $others,
            ':debtor_code' => $debtorCode, // Include debtor_code
            ':autocount_client_version' => $autocountClientVersion, // Include AutoCount Client Version
        ]);

        // Construct log message
        $logMessage = "Item inserted into Autocount Client for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = '/crm/public/config_info/add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display Information Section -->
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Ac Group: <strong><?php echo htmlspecialchars($itemTypeAcGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Installed PC and Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-control" id="installed_pc" name="installed_pc" data-placeholder="Choose installed PC">
                                        <!-- Placeholder option -->
                                        <option value="" disabled selected>Please select a PC</option>
                                        
                                        <!-- Iterate through installed PC options -->
                                        <?php foreach ($installedPcOptions as $option): ?>
                                            <option value="<?php echo htmlspecialchars($option); ?>"><?php echo htmlspecialchars($option); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="installed_pc">Installed PC</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-control" id="autocount_client_version" name="autocount_client_version" data-placeholder="Choose AutoCount Client Version">
                                        <option value="" disabled selected>Please select a version</option>
                                        <option value="AutoCount Accounting Client">AutoCount Accounting Client</option>
                                        <option value="AutoCount POS A">AutoCount POS A</option>
                                        <option value="AutoCount POS B">AutoCount POS B</option>
                                        <option value="AutoCount POS Branch">AutoCount POS Branch</option>
                                        <option value="Million Payroll Client">Million Payroll Client</option>
                                        <option value="Million Accounting Client">Million Accounting Client</option>
                                    </select>
                                    <label for="autocount_client_version">AutoCount Client Version</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-floating">
                                    <textarea class="form-control" id="others" name="others" placeholder="Enter other information"></textarea>
                                    <label for="others">Others:</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Save</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>

