<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur'); // Fixed timezone setting

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeAcGroup = isset($_GET['itemTypeAcGroup']) ? $_GET['itemTypeAcGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

$add_on_module = [];
$add_on_pos_module = [];
$plug_in = [];
$installedPcOptions = [];

try {
    // Fetch necessary data
    $add_on_module = $pdo->query("SELECT ac_function_module_id, ac_function_module_name FROM ac_function_module")->fetchAll(PDO::FETCH_ASSOC);
    $add_on_pos_module = $pdo->query("SELECT ac_function_pos_module_id, ac_function_pos_module_name FROM ac_function_pos_module")->fetchAll(PDO::FETCH_ASSOC);
    $plug_in = $pdo->query("SELECT ac_function_plug_in_id, ac_function_plug_in_name FROM ac_function_plug_in")->fetchAll(PDO::FETCH_ASSOC);

    // Fetch installed PC options from item_type_pc where debtor_code and company_name match
    $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtorCode AND company_name = :companyName");
    $stmt->execute([':debtorCode' => $debtorCode, ':companyName' => $companyName]);
    $installedPcOptions = $stmt->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}

// Handle form submission to save data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Debugging: Print out the POST data
    error_log(print_r($_POST, true));

    $active = 1; // Always set active to 1
    $offsiteBackup = isset($_POST['offsite_backup']) ? 1 : 0;
    $tax = isset($_POST['tax']) ? 1 : 0;
    $plugIn = isset($_POST['plug_in']) ? $_POST['plug_in'] : [];
    $implementAndTrainingEInvoice = isset($_POST['implement_and_training_e_invoice']) ? 1 : 0;
    $backupTime = $_POST['backup_time'] ?? null;
    $autocountEdition = $_POST['autocount_edition'] ?? null;
    $autocountVersion = $_POST['autocount_version'] ?? null;
    $autocountRevision = $_POST['autocount_revision'] ?? null;
    $sqlName = $_POST['sql_name'] ?? null;
    $sqlPort = $_POST['sql_port'] ?? null;
    $sqlServerVersion = $_POST['sql_server_version'] ?? null;
    $adminPassword = $_POST['admin_password'] ?? null;
    $installedPc = $_POST['installed_pc'] ?? '';
    $autoEmailAddress = $_POST['auto_email_address'] ?? null;
    $mainPcInstallerComputerTcpIp = $_POST['main_pc_installer_computer_tcpip'] ?? null;
    $numberOfAccountBook = $_POST['number_of_account_book'] ?? null;
    $accountingPid = $_POST['accounting_pid'] ?? null;
    $eInvoiceInstalledCompanyNames = $_POST['einvoice_installed_company_name'] ?? [];
    $eInvoiceInstalledCompanyNamesString = implode(',', $eInvoiceInstalledCompanyNames);
    $addOnModules = $_POST['add_on_module'] ?? [];
    $addOnPosModules = $_POST['add_on_pos_module'] ?? [];
    $others = $_POST['others'] ?? null;

    // Encrypt the admin password
    $encryptionKey = 'your_secret_key'; // This should be a secure key
    $encryptedAdminPassword = encryptPassword($adminPassword, $encryptionKey);

    try {
        $stmt = $pdo->prepare("INSERT INTO item_type_ac_main (
            item_type_name, 
            item_type_ac_group_name,
            company_name, 
            debtor_code, 
            active,
            backup_time,
            autocount_edition,
            autocount_version,
            autocount_revision,
            sql_name,
            sql_port,
            sql_server_version,
            admin_password,
            offsite_backup,
            tax,
            installed_pc,
            auto_email_address,
            main_pc_installer_computer_tcpip, 
            number_of_account_book,
            accounting_pid, 
            implement_and_training_e_invoice, 
            einvoice_installed_company_name,
            others
        ) VALUES (
            :item_type_name,
            :item_type_ac_group_name,
            :company_name,
            :debtor_code,
            :active,
            :backup_time,
            :autocount_edition,
            :autocount_version,
            :autocount_revision,
            :sql_name,
            :sql_port,
            :sql_server_version,
            :admin_password,
            :offsite_backup,
            :tax,
            :installed_pc,
            :auto_email_address,
            :main_pc_installer_computer_tcpip, 
            :number_of_account_book, 
            :accounting_pid,
            :implement_and_training_e_invoice, 
            :einvoice_installed_company_name,
            :others
        )");

        // Execute the insert query
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':item_type_ac_group_name' => $itemTypeAcGroup,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':active' => $active,
            ':backup_time' => $backupTime,
            ':autocount_edition' => $autocountEdition,
            ':autocount_version' => $autocountVersion,
            ':autocount_revision' => $autocountRevision,
            ':sql_name' => $sqlName,
            ':sql_port' => $sqlPort,
            ':sql_server_version' => $sqlServerVersion,
            ':admin_password' => $encryptedAdminPassword,
            ':offsite_backup' => $offsiteBackup,
            ':tax' => $tax,
            ':installed_pc' => $installedPc,
            ':auto_email_address' => $autoEmailAddress,
            ':main_pc_installer_computer_tcpip' => $mainPcInstallerComputerTcpIp,
            ':number_of_account_book' => $numberOfAccountBook,
            ':accounting_pid' => $accountingPid,
            ':implement_and_training_e_invoice' => $implementAndTrainingEInvoice,
            ':einvoice_installed_company_name' => $eInvoiceInstalledCompanyNamesString,
            ':others' => $others
        ]);

        $lastInsertId = $pdo->lastInsertId();

        // Insert add-on modules
        foreach ($addOnModules as $moduleId) {
            $stmt = $pdo->prepare("INSERT INTO add_on_modules (module_name, item_type_ac_main_id) VALUES (:module_name, :item_type_ac_main_id)");
            $stmt->execute([
                ':module_name' => $moduleId,
                ':item_type_ac_main_id' => $lastInsertId
            ]);
        }

        // Insert plug-ins
        foreach ($plugIn as $plugInId) {
            $stmt = $pdo->prepare("INSERT INTO plug_ins (plug_in_name, item_type_ac_main_id) VALUES (:plug_in_name, :item_type_ac_main_id)");
            $stmt->execute([
                ':plug_in_name' => $plugInId,
                ':item_type_ac_main_id' => $lastInsertId
            ]);
        }

        // Insert add-on POS modules
        foreach ($addOnPosModules as $posModuleId) {
            $stmt = $pdo->prepare("INSERT INTO add_on_pos_modules (pos_module_name, item_type_ac_main_id) VALUES (:pos_module_name, :item_type_ac_main_id)");
            $stmt->execute([
                ':pos_module_name' => $posModuleId,
                ':item_type_ac_main_id' => $lastInsertId
            ]);
        }

        // Collect POS fields data
        $posEditions = $_POST['pos_edition'] ?? [];
        $posRevisions = $_POST['pos_revision'] ?? [];
        $posVersions = $_POST['pos_version'] ?? [];
        $posPids = $_POST['pos_pid'] ?? [];

        for ($i = 0; $i < count($posEditions); $i++) {
            $stmt = $pdo->prepare("INSERT INTO ac_pos_fields (
                pos_edition,
                pos_revision,
                pos_version,
                pos_pid,
                item_type_ac_main_id
            ) VALUES (
                :pos_edition,
                :pos_revision,
                :pos_version,
                :pos_pid,
                :item_type_ac_main_id
            )");

            $stmt->execute([
                ':pos_edition' => $posEditions[$i],
                ':pos_revision' => $posRevisions[$i],
                ':pos_version' => $posVersions[$i],
                ':pos_pid' => $posPids[$i],
                ':item_type_ac_main_id' => $lastInsertId
            ]);
        }

        // Construct log message
        $logMessage = "Item inserted into Autocount Main for company_name: $companyName";

        // Insert log into activity_logs
        $stmtLog = $pdo->prepare("INSERT INTO activity_logs (username, timestamp, role, activity)
                                    VALUES (:username, :timestamp, :role, :activity)");
        $stmtLog->execute([
            ':username' => isset($_SESSION['username']) ? $_SESSION['username'] : 'N/A',
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => isset($_SESSION['role']) ? $_SESSION['role'] : 'N/A',
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = '/crm/public/config_info/add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.'); window.location.href = '/crm/public/config_info/add_config_info.php';</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
    <style>
        .einvoice-field {
            margin-bottom: 10px;
        }
    </style>
</head>
<body>
<div class="container mt-5">
    <form method="POST">
        <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Confirm and Save Details</h1>
            </div>
            <div class="card-body">
                <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                <p>Item Type Ac Group: <strong><?php echo htmlspecialchars($itemTypeAcGroup); ?></strong></p>

                <!-- Autocount Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Autocount Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select name="autocount_edition" id="autocount_edition" class="form-select">
                                        <option value="">Select an edition</option>
                                        <option value="express_accounting">Express Accounting</option>
                                        <option value="express_invoicing">Express Invoicing</option>
                                        <option value="express_complete">Express Complete</option>
                                        <option value="accountant">Accountant</option>
                                        <option value="account_plus">Account Plus</option>
                                        <option value="express_plus">Express Plus</option>
                                        <option value="basic">Basic</option>
                                        <option value="pro">Pro</option>
                                        <option value="premium">Premium</option>
                                        <option value="ultimate">Ultimate</option>
                                    </select>
                                    <label for="autocount_edition">Autocount Edition:</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <select name="autocount_version" id="autocount_version" class="form-select">
                                        <option value="">Select an Autocount Version</option>
                                        <option value="1.5">1.5</option>
                                        <option value="1.8">1.8</option>
                                        <option value="1.9">1.9</option>
                                        <option value="2.0">2.0</option>
                                        <option value="2.1">2.1</option>
                                        <option value="2.2">2.2</option>
                                        <option value="2.3">2.3</option>
                                        <option value="2.4">2.4</option>
                                        <option value="2.5">2.5</option>
                                    </select>
                                    <label for="autocount_version">Autocount Version:</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="autocount_revision" id="autocount_revision" class="form-control">
                                    <label for="autocount_revision">Autocount Revision</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="number" name="number_of_account_book" id="number_of_account_book" class="form-control">
                                    <label for="number_of_account_book">Number of Account Book</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Autocount Login Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Autocount Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="admin_password" id="admin_password" class="form-control">
                                    <label for="admin_password">Admin Password</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="auto_email_address" id="auto_email_address" class="form-control">
                                    <label for="auto_email_address">Autocount Email Address</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- SQL Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">SQL Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select name="sql_server_version" id="sql_server_version" class="form-select">
                                        <option value="">Select a SQL Server Version</option>
                                        <option value="2005">2005</option>
                                        <option value="2008">2008</option>
                                        <option value="2012">2012</option>
                                        <option value="2016">2016</option>
                                        <option value="2019">2019</option>
                                    </select>
                                    <label for="sql_server_version">SQL Server Version:</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="sql_name" id="sql_name" class="form-control">
                                    <label for="sql_name">SQL Name</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="sql_port" id="sql_port" class="form-control">
                                    <label for="sql_port">SQL Port</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Backup Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Backup Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="time" name="backup_time" id="backup_time" class="form-control">
                                    <label for="backup_time">Backup Time:</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-check">
                                    <input type="checkbox" name="offsite_backup" value="1" class="form-check-input" <?php if (isset($_POST['offsite_backup'])) echo 'checked'; ?>>
                                    <label class="form-check-label" for="offsite_backup">Offsite Backup</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Tax Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Tax Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-check">
                                    <input type="checkbox" name="tax" value="1" class="form-check-input" <?php if (isset($_POST['tax'])) echo 'checked'; ?>>
                                    <label class="form-check-label" for="tax">Tax</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Autocount Main PC Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Autocount Main PC Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-select" id="installed_pc" name="installed_pc" data-placeholder="Choose installed PC">
                                        <option value="" disabled selected>Please select a PC</option>
                                        <?php foreach ($installedPcOptions as $option): ?>
                                            <option value="<?php echo htmlspecialchars($option); ?>"><?php echo htmlspecialchars($option); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="installed_pc">Installed PC</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="main_pc_installer_computer_tcpip" id="main_pc_installer_computer_tcpip" class="form-control">
                                    <label for="main_pc_installer_computer_tcpip">Main PC Installer Computer TCP/IP</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="accounting_pid" id="accounting_pid" class="form-control">
                                    <label for="accounting_pid">Accounting PID</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- E-Invoice Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">E-Invoice Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-check">
                                    <input type="checkbox" name="implement_and_training_e_invoice" value="1" class="form-check-input" <?php if (isset($_POST['implement_and_training_e_invoice'])) echo 'checked'; ?>>
                                    <label class="form-check-label" for="implement_and_training_e_invoice">Implement and Training E Invoice</label>
                                </div>
                            </div>
                        </div>
                        <div class="row mt-3">
                            <div class="col-md-12">
                                <label for="einvoice_installed_company_name">E Invoice Installed Company Name</label>
                                <div id="einvoiceContainer">
                                    <div class="einvoice-field mb-2">
                                        <div class="input-group">
                                            <input type="text" name="einvoice_installed_company_name[]" id="einvoice_installed_company_name" class="form-control" placeholder="Enter company name">
                                            <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
                                        </div>
                                    </div>
                                </div>
                                <button type="button" class="btn btn-primary mb-3" onclick="addField()">Add More</button>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Modules and Plug-Ins -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Modules and Plug-Ins</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-group">
                                    <label for="add_on_module">Add-On Module</label>
                                    <select id="add_on_module" name="add_on_module[]" class="form-select select2-multiple" multiple="multiple" data-placeholder="Choose add-on modules" style="width: 100%;">
                                        <?php foreach ($add_on_module as $addOnModule): ?>
                                            <option value="<?php echo htmlspecialchars($addOnModule['ac_function_module_id']); ?>">
                                                <?php echo htmlspecialchars($addOnModule['ac_function_module_name']); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                                <div class="form-group">
                                    <label for="plug_in">Select Plug In:</label>
                                    <select id="plug_in" name="plug_in[]" class="form-select select2-multiple" multiple="multiple" data-placeholder="Choose plug-ins" style="width: 100%;">
                                        <?php foreach ($plug_in as $plugInModule): ?>
                                            <option value="<?php echo htmlspecialchars($plugInModule['ac_function_plug_in_id']); ?>">
                                                <?php echo htmlspecialchars($plugInModule['ac_function_plug_in_name']); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                                <div class="form-group">
                                    <label for="add_on_pos_module">Add On POS Module: </label>
                                    <br>
                                    <select id="add_on_pos_module" name="add_on_pos_module[]" class="form-select select2-multiple" multiple="multiple" data-placeholder="Choose add-on POS modules" style="width: 100%;">
                                        <?php foreach ($add_on_pos_module as $addOnPosModule): ?>
                                            <option value="<?php echo htmlspecialchars($addOnPosModule['ac_function_pos_module_id']); ?>">
                                                <?php echo htmlspecialchars($addOnPosModule['ac_function_pos_module_name']); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-group">
                            <label for="others">Others</label>
                            <textarea id="others" name="others" class="form-control"></textarea>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- POS Fields Card -->
        <div id="posFieldsContainer">
            <div class="card mt-4 shadow-lg pos-field-card">
                <div class="card-header bg-primary text-white">
                    <h5 class="mb-0">POS Fields</h5>
                </div>
                <div class="card-body">
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <select name="pos_edition[]" id="pos_edition" class="form-select">
                                    <option value="" disabled selected>Please select a POS edition</option>
                                    <option value="pos_basic">POS Basic</option>
                                    <option value="pos_standard">POS Standard</option>
                                    <option value="pos_counter_a">POS Counter A</option>
                                    <option value="pos_counter_b">POS Counter B</option>
                                    <option value="pos_counter_branch">POS Counter Branch</option>
                                </select>
                                <label for="pos_edition">POS Edition:</label>
                            </div>
                            <div class="form-floating mb-3">
                                <select name="pos_version[]" id="pos_version" class="form-select">
                                    <option value="">Select a Pos Version</option>
                                    <option value="3.0">3.0</option>
                                    <option value="3.1">3.1</option>
                                    <option value="5.0">5.0</option>
                                    <option value="5.1">5.1</option>
                                    <option value="5.2">5.2</option>
                                </select>
                                <label for="pos_version">POS Version:</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="text" name="pos_revision[]" id="pos_revision" class="form-control">
                                <label for="pos_revision">POS Revision</label>
                            </div>
                            <div class="form-floating mb-3">
                                <input type="text" name="pos_pid[]" id="pos_pid" class="form-control">
                                <label for="pos_pid">POS PID</label>
                            </div>
                        </div>
                    </div>
                    <button type="button" class="btn btn-danger mt-3" onclick="removePosFieldCard(this)">Remove</button>
                    <button type="button" class="btn btn-primary mt-3" onclick="addPosFieldCard()">Add POS Field Card</button>
                </div>
            </div>
        </div>
        <br>
        <button type="submit" class="btn btn-primary">Save</button>
    </form>
</div>
</body>
</html>

<!-- Select2 CSS -->
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet">
<link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet">

<!-- jQuery -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>

<!-- Bootstrap 5.x JS via CDN -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

<script>
    $(document).ready(function() {
        initializeSelect2ForFields();

        // Initialize Select2 for the moved Add On POS Module
        $('#add_on_pos_module').select2({
            theme: "bootstrap-5",
            width: '100%',
            placeholder: "Choose add-on POS modules",
            closeOnSelect: false,
        });
    });

    function initializeSelect2ForFields() {
        $('.pos-field-card #add_on_pos_module').each(function() {
            initializeSelect2ForElement($(this));
        });

        if (!$('#plug_in').hasClass("select2-hidden-accessible")) {
            $('#plug_in').select2({
                theme: "bootstrap-5",
                width: '100%',
                placeholder: "Choose plug-ins",
                closeOnSelect: false,
            });
        }

        if (!$('#add_on_module').hasClass("select2-hidden-accessible")) {
            $('#add_on_module').select2({
                theme: "bootstrap-5",
                width: '100%',
                placeholder: "Choose add-on modules",
                closeOnSelect: false,
            });
        }
    }

    function initializeSelect2ForElement(element) {
        if (!element.hasClass("select2-hidden-accessible")) {
            element.select2({
                theme: "bootstrap-5",
                width: '100%',
                placeholder: "Choose add-on POS modules",
                closeOnSelect: false,
            });
        }
    }

    function addPosFieldCard() {
        const container = document.getElementById('posFieldsContainer');
        const cardCount = container.childElementCount;

        // Create a new card
        const newCard = document.createElement('div');
        newCard.className = 'card mt-4 shadow-lg pos-field-card';
        newCard.innerHTML = `
            <div class="card-header bg-secondary text-white">
                <h5 class="mb-0">POS Fields</h5>
            </div>
            <div class="card-body">
                <div class="row">
                    <div class="col-md-6">
                        <div class="form-floating mb-3">
                            <select name="pos_edition[]" id="pos_edition_${cardCount}" class="form-select">
                                <option value="" disabled selected>Please select a POS edition</option>
                                <option value="pos_basic">POS Basic</option>
                                <option value="pos_standard">POS Standard</option>
                                <option value="pos_counter_a">POS Counter A</option>
                                <option value="pos_counter_b">POS Counter B</option>
                                <option value="pos_counter_branch">POS Counter Branch</option>
                            </select>
                            <label for="pos_edition_${cardCount}">POS Edition:</label>
                        </div>
                        <div class="form-floating mb-3">
                            <select name="pos_version[]" id="pos_version_${cardCount}" class="form-select">
                                <option value="">Select a Pos Version</option>
                                <option value="3.0">3.0</option>
                                <option value="3.1">3.1</option>
                                <option value="5.0">5.0</option>
                                <option value="5.1">5.1</option>
                                <option value="5.2">5.2</option>
                            </select>
                            <label for="pos_version_${cardCount}">POS Version:</label>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="form-floating mb-3">
                            <input type="text" name="pos_revision[]" id="pos_revision_${cardCount}" class="form-control">
                            <label for="pos_revision_${cardCount}">POS Revision</label>
                        </div>
                        <div class="form-floating mb-3">
                            <input type="text" name="pos_pid[]" id="pos_pid_${cardCount}" class="form-control">
                            <label for="pos_pid_${cardCount}">POS PID</label>
                        </div>
                    </div>
                </div>
                <button type="button" class="btn btn-danger mt-3" onclick="removePosFieldCard(this)">Remove</button>
                <button type="button" class="btn btn-primary mt-3" onclick="addPosFieldCard()">Add POS Field Card</button>
            </div>
        `;

        // Append the new card
        container.appendChild(newCard);

        // Initialize Select2 for the new add_on_pos_module field
        initializeSelect2ForElement($(`#add_on_pos_module_${cardCount}`));
    }

    function removePosFieldCard(button) {
        const container = document.getElementById('posFieldsContainer');
        if (container.childElementCount > 1) {
            button.closest('.pos-field-card').remove();
        } else {
            alert('You must have at least one POS field card.');
        }
    }

    // Function to add E-Invoice field
    function addField() {
        const container = document.getElementById('einvoiceContainer');
        const newField = document.createElement('div');
        newField.className = 'einvoice-field mb-2';
        newField.innerHTML = `
            <div class="input-group">
                <input type="text" name="einvoice_installed_company_name[]" class="form-control" placeholder="Enter company name">
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            </div>
        `;
        container.appendChild(newField);
    }

    function removeField(button) {
        // Find the closest parent element with the class 'einvoice-field'
        const field = button.closest('.einvoice-field');

        // Check if there's more than one field
        const fields = document.querySelectorAll('.einvoice-field');
        if (fields.length > 1) {
            // If there's more than one field, remove the current field
            field.remove();
        } else {
            // If there's only one field, alert the user or provide some feedback
            alert('You cannot remove the last field.');
        }
    }
</script>

