<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeAcGroup = isset($_GET['itemTypeAcGroup']) ? $_GET['itemTypeAcGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : '';

// Handle form submission to save data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $active = 1; // Always set active to 1
    $loginAccount = $_POST['login_account'] ?? null;
    $loginPassword = $_POST['login_password'] ?? null;
    $oneSalesPos = isset($_POST['onesales_pos']) ? 1 : 0;
    $oneSalesECommerce = isset($_POST['onesales_ecommerce']) ? 1 : 0;
    $others = $_POST['others'] ?? null;
    $debtorCode = $_POST['debtor_code'] ?? null;

    // Encrypt the login password
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $encryptedPassword = encryptPassword($loginPassword, $encryptionKey);

    try {
        // Prepare and execute the insert into item_type_cloud_accounting
        $stmt = $pdo->prepare("INSERT INTO item_type_cloud_accounting (
            item_type_name, 
            item_type_ac_group_name,
            company_name, 
            active,
            login_account,
            login_password,
            onesales_pos,
            onesales_ecommerce,
            others,
            debtor_code
        ) VALUES (
            :item_type_name,
            :item_type_ac_group_name,
            :company_name,
            :active,
            :login_account,
            :login_password,
            :onesales_pos,
            :onesales_ecommerce,
            :others,
            :debtor_code
        )");
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':item_type_ac_group_name' => $itemTypeAcGroup,
            ':company_name' => $companyName,
            ':active' => $active,
            ':login_account' => $loginAccount,
            ':login_password' => $encryptedPassword,
            ':onesales_pos' => $oneSalesPos,
            ':onesales_ecommerce' => $oneSalesECommerce,
            ':others' => $others,
            ':debtor_code' => $debtorCode
        ]);

        // Construct log message
        $logMessage = "Item inserted into Cloud Accounting for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = '/crm/public/config_info/add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display Information Section -->
                <div class="mb-3">
                    <p><strong>Company Name:</strong> <?php echo htmlspecialchars($companyName); ?></p>
                    <p><strong>Item Type:</strong> <?php echo htmlspecialchars($itemType); ?></p>
                    <p><strong>Item Type Ac Group:</strong> <?php echo htmlspecialchars($itemTypeAcGroup); ?></p>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_account" id="login_account" class="form-control" placeholder=" ">
                                    <label for="login_account">Login Account</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_password" id="login_password" class="form-control" placeholder=" ">
                                    <label for="login_password">Login Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">OneSales Options</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-check mb-3">
                                    <input type="checkbox" name="onesales_pos" id="onesales_pos" class="form-check-input">
                                    <label class="form-check-label" for="onesales_pos">OneSales POS</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-check mb-3">
                                    <input type="checkbox" name="onesales_ecommerce" id="onesales_ecommerce" class="form-check-input">
                                    <label class="form-check-label" for="onesales_ecommerce">OneSales E Commerce</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea name="others" id="others" class="form-control" rows="4" placeholder=" "></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Hidden input for debtor_code -->
                <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5 JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>

