<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set(timezoneId: 'Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeAcGroup = isset($_GET['itemTypeAcGroup']) ? $_GET['itemTypeAcGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : '';

// Handle form submission to save data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $active = 1;
    $loginAccount = $_POST['login_account'] ?? null;
    $loginPassword = $_POST['login_password'] ?? null;
    $hardwareId = isset($_POST['hardware_id']) && is_array($_POST['hardware_id']) ? implode(',', $_POST['hardware_id']) : '';
    $linkingHardware = isset($_POST['linking_hardware']) && is_array($_POST['linking_hardware']) ? implode(',', $_POST['linking_hardware']) : '';
    $location = isset($_POST['location']) && is_array($_POST['location']) ? implode(',', $_POST['location']) : '';
    $payrollUserLoginId = $_POST['payroll_user_login_id'] ?? null;
    $payrollUserLoginPassword = $_POST['payroll_user_login_password'] ?? null;
    $others = $_POST['others'] ?? null;
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included

    // Encrypt the login password
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $encryptedPassword = encryptPassword($loginPassword, $encryptionKey);

    // Decrypt the login password for logging
    $decryptedLoginPassword = decryptPassword($encryptedPassword, $encryptionKey);

    // Encrypt the payroll user login passwords
    $encryptedPayrollUserLoginPasswords = [];
    if (is_array($payrollUserLoginPassword)) {
        foreach ($payrollUserLoginPassword as $password) {
            $encrypted = encryptPassword($password, $encryptionKey);
            $encryptedPayrollUserLoginPasswords[] = $encrypted;
        }
    }
    $payrollUserLoginPasswordEncrypted = implode(',', $encryptedPayrollUserLoginPasswords);

    // Ensure payrollUserLoginId is a string
    if (is_array($payrollUserLoginId)) {
        $payrollUserLoginId = implode(',', $payrollUserLoginId);
    }

    try {
        $stmt = $pdo->prepare("INSERT INTO item_type_cloud_payroll (
            item_type_name, 
            item_type_ac_group_name,
            company_name, 
            active,
            login_account,
            login_password,
            hardware_id,
            linking_hardware,
            payroll_user_login_id,
            payroll_user_login_password,
            location,
            others,
            debtor_code
        ) VALUES (
            :item_type_name,
            :item_type_ac_group_name,
            :company_name,
            :active,
            :login_account,
            :login_password,
            :hardware_id,
            :linking_hardware,
            :payroll_user_login_id,
            :payroll_user_login_password,
            :location,
            :others,
            :debtor_code
        )");
        // Execute the insert query with encrypted passwords
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':item_type_ac_group_name' => $itemTypeAcGroup,
            ':company_name' => $companyName,
            ':active' => $active,
            ':login_account' => $loginAccount,
            ':login_password' => $encryptedPassword,
            ':hardware_id' => $hardwareId,
            ':linking_hardware' => $linkingHardware,
            ':payroll_user_login_id' => $payrollUserLoginId,
            ':payroll_user_login_password' => $payrollUserLoginPasswordEncrypted,
            ':location' => $location,
            ':others' => $others,
            ':debtor_code' => $debtorCode, // Include debtor_code
        ]);

        // Simplified log message
        $logMessage = "Item inserted into Cloud Payroll for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display Information Section -->
                <div class="mb-3">
                    <p><strong>Company Name:</strong> <?php echo htmlspecialchars($companyName); ?></p>
                    <p><strong>Item Type:</strong> <?php echo htmlspecialchars($itemType); ?></p>
                    <p><strong>Item Type Ac Group:</strong> <?php echo htmlspecialchars($itemTypeAcGroup); ?></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_account" id="login_account" class="form-control" placeholder="Login Account">
                                    <label for="login_account">Login Account</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_password" id="login_password" class="form-control" placeholder="Login Password">
                                    <label for="login_password">Login Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Cloud Payroll Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="mb-3">
                            <div id="cloudPayrollContainer">
                                <!-- Initial Cloud Payroll fields -->
                                <div class="input-group mb-2">
                                    <div class="form-floating me-2">
                                        <input type="text" class="form-control form-control-custom" name="hardware_id[]" id="hardware_id1" placeholder="Hardware ID">
                                        <label for="hardware_id1">Hardware ID</label>
                                    </div>
                                    <div class="form-floating me-2">
                                        <input type="text" class="form-control form-control-custom" name="linking_hardware[]" id="linking_hardware1" placeholder="Linking Hardware">
                                        <label for="linking_hardware1">Linking Hardware</label>
                                    </div>
                                    <div class="form-floating me-2">
                                        <input type="text" class="form-control form-control-custom" name="location[]" id="location1" placeholder="Location">
                                        <label for="location1">Location</label>
                                    </div>
                                    <button type="button" class="btn btn-danger" onclick="removeContainer(this)">Remove</button>
                                </div>
                            </div>
                            <button type="button" class="btn btn-secondary" onclick="addContainer('cloudPayroll')">Add Fields</button>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Payroll User Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="mb-3">
                            <div id="payrollUserLoginContainer">
                                <!-- Initial Payroll User Login fields -->
                                <div class="input-group mb-2">
                                    <div class="form-floating me-2">
                                        <input type="text" class="form-control form-control-custom" name="payroll_user_login_id[]" id="payroll_user_login_id1" placeholder="Payroll User Login ID">
                                        <label for="payroll_user_login_id1">Payroll User Login ID</label>
                                    </div>
                                    <div class="form-floating me-2">
                                        <input type="text" class="form-control form-control-custom" name="payroll_user_login_password[]" id="payroll_user_login_password1" placeholder="Payroll User Login Password">
                                        <label for="payroll_user_login_password1">Payroll User Login Password</label>
                                    </div>
                                    <button type="button" class="btn btn-danger" onclick="removeContainer(this)">Remove</button>
                                </div>
                            </div>
                            <button type="button" class="btn btn-secondary" onclick="addContainer('payrollUserLogin')">Add Fields</button>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea class="form-control" id="others" name="others" placeholder="Others"></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap JS and dependencies -->
<script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.4/dist/umd/popper.min.js"></script>
<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>

<script>
function addContainer(containerId) {
    const container = document.getElementById(containerId + 'Container');

    if (containerId === 'cloudPayroll') {
        const fieldGroup = `
            <div class="input-group mb-2">
                <div class="form-floating me-2">
                    <input type="text" class="form-control form-control-custom" name="hardware_id[]" placeholder="Hardware ID">
                    <label>Hardware ID</label>
                </div>
                <div class="form-floating me-2">
                    <input type="text" class="form-control form-control-custom" name="linking_hardware[]" placeholder="Linking Hardware">
                    <label>Linking Hardware</label>
                </div>
                <div class="form-floating me-2">
                    <input type="text" class="form-control form-control-custom" name="location[]" placeholder="Location">
                    <label>Location</label>
                </div>
                <button type="button" class="btn btn-danger" onclick="removeContainer(this)">Remove</button>
            </div>
        `;
        container.insertAdjacentHTML('beforeend', fieldGroup);
    } else if (containerId === 'payrollUserLogin') {
        const fieldGroup = `
            <div class="input-group mb-2">
                <div class="form-floating me-2">
                    <input type="text" class="form-control form-control-custom" name="payroll_user_login_id[]" placeholder="Payroll User Login ID">
                    <label>Payroll User Login ID</label>
                </div>
                <div class="form-floating me-2">
                    <input type="text" class="form-control form-control-custom" name="payroll_user_login_password[]" placeholder="Payroll User Login Password">
                    <label>Payroll User Login Password</label>
                </div>
                <button type="button" class="btn btn-danger" onclick="removeContainer(this)">Remove</button>
            </div>
        `;
        container.insertAdjacentHTML('beforeend', fieldGroup);
    }
}

function removeContainer(button) {
    const container = button.closest('.input-group').parentElement;
    if (container.childElementCount > 1) {
        button.closest('.input-group').remove();
    } else {
        alert('The last field cannot be removed.');
    }
}
</script>
</body>
</html>

