<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set(timezoneId: 'Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeAcGroup = isset($_GET['itemTypeAcGroup']) ? $_GET['itemTypeAcGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Directly get debtor_code from URL

$installedPcOptions = [];

try {
    // Fetch necessary data
    $itemtype = $pdo->query("SELECT item_type_id, item_type_name FROM item_type")->fetchAll(PDO::FETCH_ASSOC);
    $itemtype_ac_group = $pdo->query("SELECT item_type_ac_group_id, item_type_ac_group_name FROM item_type_ac_group")->fetchAll(PDO::FETCH_ASSOC);

    // Fetch installed PC options from item_type_pc where debtor_code and company_name match
    $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtorCode AND company_name = :companyName");
    $stmt->execute([':debtorCode' => $debtorCode, ':companyName' => $companyName]);
    $installedPcOptions = $stmt->fetchAll(PDO::FETCH_COLUMN);

} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}

// Handle form submission to save data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Debugging: Print out the POST data
    error_log(print_r($_POST, true));

    $active = 1; // Always set active to 1
    $sqlServerVersion = $_POST['sql_server_version'] ?? null;
    $version = $_POST['version'] ?? null;
    $loginId = $_POST['login_id'] ?? null;
    $password = $_POST['password'] ?? null;
    $installedPc = $_POST['installed_pc'] ?? '';
    $others = $_POST['others'] ?? null;
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included

    // Debugging: Print out the debtor_code
    error_log('Debtor Code: ' . $debtorCode);

    // Encrypt the password
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $encryptedPassword = encryptPassword($password, $encryptionKey);

    // Decrypt the login password for logging
    $decryptedPassword = decryptPassword($encryptedPassword, $encryptionKey);        

    try {
        // Updated query to use item_type_million_payroll table
        $stmt = $pdo->prepare("INSERT INTO item_type_million_payroll (
            item_type_name, 
            item_type_ac_group_name,
            company_name, 
            active,
            sql_server_version,
            version,
            login_id,
            password,
            installed_pc,
            others,
            debtor_code
        ) VALUES (
            :item_type_name,
            :item_type_ac_group_name,
            :company_name,
            :active,
            :sql_server_version,
            :version,
            :login_id,
            :password,
            :installed_pc,
            :others,
            :debtor_code
        )");
        // Execute the insert query
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':item_type_ac_group_name' => $itemTypeAcGroup,
            ':company_name' => $companyName,
            ':active' => $active,
            ':sql_server_version' => $sqlServerVersion,
            ':version' => $version,
            ':login_id' => $loginId,
            ':password' => $encryptedPassword,
            ':installed_pc' => $installedPc,
            ':others' => $others,
            ':debtor_code' => $debtorCode
        ]);

        // Simplified log message
        $logMessage = "Item inserted into Million Payroll for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);    

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display Information Section -->
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Ac Group: <strong><?php echo htmlspecialchars($itemTypeAcGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                 <!-- SQL Server Details Card -->
                 <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">SQL Server Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select name="sql_server_version" id="sql_server_version" class="form-control">
                                        <option value="">Select a SQL Server Version</option>
                                        <option value="2005">2005</option>
                                        <option value="2008">2008</option>
                                        <option value="2012">2012</option>
                                        <option value="2016">2016</option>
                                        <option value="2019">2019</option>
                                        <option value="2024">2024</option>
                                    </select>
                                    <label for="sql_server_version">SQL Server Version</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="version" id="version" class="form-control" placeholder="Version">
                                    <label for="version">Version</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Login Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_id" id="login_id" class="form-control" placeholder="Login ID">
                                    <label for="login_id">Login ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="password" id="password" class="form-control" placeholder="Password">
                                    <label for="password">Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">PC Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="installed_pc">Installed PC</label>
                                    <select class="form-control" id="installed_pc" name="installed_pc" data-placeholder="Choose installed PC">
                                        <!-- Placeholder option -->
                                        <option value="" disabled selected>Please select a PC</option>
                                        
                                        <!-- Iterate through installed PC options -->
                                        <?php foreach ($installedPcOptions as $option): ?>
                                            <option value="<?php echo htmlspecialchars($option); ?>"><?php echo htmlspecialchars($option); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-floating mb-3">
                                    <textarea class="form-control" id="others" name="others" placeholder="Others"></textarea>
                                    <label for="others">Others</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Save</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
$(document).ready(function() {
    $('#installed_pc').select2({
        theme: "bootstrap-5",
        width: $(this).data('width') ? $(this).data('width') : $(this).hasClass('w-100') ? '100%' : 'style',
        placeholder: $(this).data('placeholder'),
        closeOnSelect: false,
    });
});
</script>
</body>
</html>

