<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set(timezoneId: 'Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeAcGroup = isset($_GET['itemTypeAcGroup']) ? $_GET['itemTypeAcGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Directly get debtor_code from URL

$add_on_module = [];
try {
    // Fetch necessary data
    $itemtype = $pdo->query("SELECT item_type_id, item_type_name FROM item_type")->fetchAll(PDO::FETCH_ASSOC);
    $itemtype_ac_group = $pdo->query("SELECT item_type_ac_group_id, item_type_ac_group_name FROM item_type_ac_group")->fetchAll(PDO::FETCH_ASSOC);
    $add_on_module = $pdo->query("SELECT ac_function_module_id, ac_function_module_name FROM ac_function_module")->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}

// Handle form submission to save data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Debugging: Print out the POST data
    error_log(print_r($_POST, true));

    $active = 1; // Always set active to 1
    $url = $_POST['url'] ?? null;
    $loginId = $_POST['login_id'] ?? null;
    $password = $_POST['password'] ?? null;
    $monitorService = isset($_POST['monitor_service']) ? 1 : 0;
    $others = $_POST['others'] ?? null;
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included
    $destination = $_POST['destination'] ?? null; // Add destination

    // Debugging: Print out the debtor_code
    error_log('Debtor Code: ' . $debtorCode);

    // Encrypt the password
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $encryptedPassword = encryptPassword($password, $encryptionKey);

    // Decrypt the login password for logging
    $decryptedPassword = decryptPassword($encryptedPassword, $encryptionKey);        

    try {
        // Insert into the new table `item_type_ac_offsite_backup`
        $stmt = $pdo->prepare("INSERT INTO item_type_ac_offsite_backup (
            item_type_name, 
            item_type_ac_group_name,
            company_name, 
            active,
            url,
            login_id,
            password,
            monitor_service,
            others,
            debtor_code,
            destination
        ) VALUES (
            :item_type_name,
            :item_type_ac_group_name,
            :company_name,
            :active,
            :url,
            :login_id,
            :password,
            :monitor_service,
            :others,
            :debtor_code,
            :destination
        )");
        // Execute the insert query
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':item_type_ac_group_name' => $itemTypeAcGroup,
            ':company_name' => $companyName,
            ':active' => $active,
            ':url' => $url,
            ':login_id' => $loginId,
            ':password' => $encryptedPassword,
            ':monitor_service' => $monitorService,
            ':others' => $others,
            ':debtor_code' => $debtorCode, // Include debtor_code
            ':destination' => $destination, // Include destination
        ]);

        // Simplified log message
        $logMessage = "Item inserted into Offsite Backup Autocount for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);    

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display Information Section -->
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Ac Group: <strong><?php echo htmlspecialchars($itemTypeAcGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                <!-- Login Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_id" id="login_id" class="form-control" placeholder="Enter Login ID">
                                    <label for="login_id">Login ID</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="url" id="url" class="form-control" placeholder="Enter URL">
                                    <label for="url">URL</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="password" id="password" class="form-control" placeholder="Enter Password">
                                    <label for="password">Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Destination and Others -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Destination</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select name="destination" id="destination" class="form-select">
                                        <option value="CITSSB">CITSSB</option>
                                        <option value="Google Drive">Google Drive</option>
                                    </select>
                                    <label for="destination">Destination</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Monitor Service -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Monitor Service</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input type="checkbox" name="monitor_service" id="monitor_service" value="1" class="form-check-input" <?php if (isset($_POST['monitor_service'])) echo 'checked'; ?>>
                            <label class="form-check-label" for="monitor_service">Monitor Service</label>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-floating mb-3">
                                    <textarea class="form-control" id="others" name="others" placeholder="Enter Others"></textarea>
                                    <label for="others">Others</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Save</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>

