<?php
header("Cache-Control: no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");
header("Expires: Fri, 01 Jan 1990 00:00:00 GMT");
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
$itemtype = [];
try {
    $stmt = $pdo->prepare("SELECT item_type_id, item_type_name FROM item_type");
    $stmt->execute();
    $itemtype = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta http-equiv="Cache-Control" content="no-store, no-cache, must-revalidate, max-age=0">
    <meta http-equiv="Pragma" content="no-cache">
    <meta http-equiv="Expires" content="Fri, 01 Jan 1990 00:00:00 GMT">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add Item Type</title>
    <!-- Bootstrap 5.3 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Custom CSS for additional styling -->
    <style>
        .form-container {
            background: #f8f9fa;
            padding: 2rem;
            border-radius: 10px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        }
        .form-group label {
            font-weight: 500;
            color: #495057;
        }
        .form-control {
            border-radius: 5px;
            border: 1px solid #ced4da;
        }
        .form-control:focus {
            border-color: #80bdff;
            box-shadow: 0 0 0 0.2rem rgba(0, 123, 255, 0.25);
        }
        .dropdown-list {
            max-height: 200px;
            overflow-y: auto;
            border: 1px solid #ced4da;
            border-radius: 5px;
            background: #fff;
            margin-top: 0.5rem;
        }
        .dropdown-list p {
            padding: 0.5rem;
            margin: 0;
        }
        .dropdown-list p:hover {
            background: #f1f1f1;
            cursor: pointer;
        }
        .btn-custom {
            background: #007bff;
            color: #fff;
            border-radius: 5px;
            padding: 0.5rem 1rem;
            border: none;
        }
        .btn-custom:hover {
            background: #0056b3;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="form-container">
            <h1 class="text-center mb-4">Add Configuration Information</h1>
            <!-- Disable autocomplete for the form -->
            <form method="POST" id="itemForm" autocomplete="off">
                <!-- Search Bar for Company Name -->
                <div class="form-group mb-4">
                    <label for="companySearch" class="form-label">Search Company Name:</label>
                    <input type="text" class="form-control" id="companySearch" name="company_name" placeholder="Search for a company...">
                    <div id="companyList" class="dropdown-list"></div>
                </div>
                <input type="hidden" id="debtorCode" name="debtorCode">

                <!-- Item Type Dropdown (Initially Hidden) -->
                <div class="form-group mb-4" id="itemTypeRow" style="display:none;">
                    <label for="itemType" class="form-label">Select Item Type:</label>
                    <select id="itemType" class="form-control" name="itemType">
                        <option value="">-- Select an Item Type --</option>
                        <?php foreach ($itemtype as $type): ?>
                            <option value="<?php echo htmlspecialchars($type['item_type_name']); ?>">
                                <?php echo htmlspecialchars($type['item_type_name']); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <!-- Dynamic Dropdowns (Initially Hidden) -->
                <div id="dynamicDropdowns">
                    <!-- Item Type Ac Group Dropdown -->
                    <div class="form-group mb-4" id="itemTypeAcGroupLabel" style="display:none;">
                        <label for="itemTypeAcGroup" class="form-label">Select Item Type Ac Group:</label>
                        <select id="itemTypeAcGroup" class="form-control" name="itemTypeAcGroup">
                            <option value="">-- Select an Item Type Ac Group --</option>
                            <option value="Autocount">Autocount</option>
                            <option value="Autocount/Payroll Client">Autocount/Payroll Client</option>
                            <option value="Cloud Accounting">Cloud Accounting</option>
                            <option value="Cloud Payroll">Cloud Payroll</option>
                            <option value="Million Accounting">Million Accounting</option>
                            <option value="Million Payroll">Million Payroll</option>
                            <option value="Offsite Backup">Offsite Backup</option>
                        </select>
                    </div>

                    <!-- Hosting Group Dropdown -->
                    <div class="form-group mb-4" id="itemTypeHostingGroupLabel" style="display:none;">
                        <label for="itemTypeHostingGroup" class="form-label">Select Item Type Hosting Group:</label>
                        <select id="itemTypeHostingGroup" class="form-control" name="itemTypeHostingGroup">
                            <option value="">-- Select an Item Type Hosting Group --</option>
                            <option value="Domain">Domain</option>
                            <option value="Hosting">Hosting</option>
                            <option value="Email">Email</option>
                        </select>
                    </div>

                    <!-- Software Group Dropdown -->
                    <div class="form-group mb-4" id="itemTypeSoftwareGroupLabel" style="display:none;">
                        <label for="itemTypeSoftwareGroup" class="form-label">Select Item Type Software Group:</label>
                        <select id="itemTypeSoftwareGroup" class="form-control" name="itemTypeSoftwareGroup">
                            <option value="">-- Select an Item Type Software Group --</option>
                            <option value="Antivirus Endpoint Master">Antivirus Endpoint Master</option>
                            <option value="Antivirus Endpoint Client">Antivirus Endpoint Client</option>
                            <option value="Antivirus Internet Security">Antivirus Internet Security</option>
                            <option value="Microsoft (No Renewal)">Microsoft (No Renewal)</option>
                            <option value="Office 365 Master Account">Office 365 Master Account</option>
                            <option value="Office 365 Client Account">Office 365 Client Account</option>
                            <option value="Other Software">Other Software</option>
                        </select>
                    </div>

                    <!-- Hardware Group Dropdown -->
                    <div class="form-group mb-4" id="itemTypeHardwareGroupLabel" style="display:none;">
                        <label for="itemTypeHardwareGroup" class="form-label">Select Item Type Hardware Group:</label>
                        <select id="itemTypeHardwareGroup" class="form-control" name="itemTypeHardwareGroup">
                            <option value="">-- Select an Item Type Hardware Group --</option>
                            <option value="UPS">UPS</option>
                            <option value="Printer">Printer</option>
                            <option value="CCTV">CCTV</option>
                            <option value="Others">Others</option>
                        </select>
                    </div>

                    <!-- POS Hardware Group Dropdown -->
                    <div class="form-group mb-4" id="itemTypePosHardwareGroupLabel" style="display:none;">
                        <label for="itemTypePosHardwareGroup" class="form-label">Select Item Type POS Hardware Group:</label>
                        <select id="itemTypePosHardwareGroup" class="form-control" name="itemTypePosHardwareGroup">
                            <option value="">-- Select an Item Type POS Hardware Group --</option>
                            <option value="All In One PC">All In One PC</option>
                            <option value="PALM">PALM</option>
                            <option value="Others">Others</option>
                        </select>
                    </div>

                    <!-- PC Group Dropdown -->
                    <div class="form-group mb-4" id="itemTypePcGroupLabel" style="display:none;">
                        <label for="itemTypePcGroup" class="form-label">Select Item Type PC Group:</label>
                        <select id="itemTypePcGroup" class="form-control" name="itemTypePcGroup">
                            <option value="">-- Select an Item Type PC Group --</option>
                            <option value="Desktop/Laptop">Desktop/Laptop</option>
                            <option value="Server">Server</option>
                        </select>
                    </div>

                    <!-- Network Group Dropdown -->
                    <div class="form-group mb-4" id="itemTypeNetworkGroupLabel" style="display:none;">
                        <label for="itemTypeNetworkGroup" class="form-label">Select Item Type Network Group:</label>
                        <select id="itemTypeNetworkGroup" class="form-control" name="itemTypeNetworkGroup">
                            <option value="">-- Select an Item Type Network Group --</option>
                            <option value="Access Point">Access Point</option>
                            <option value="Network Switch">Network Switch</option>
                            <option value="Firewall">Firewall</option>
                            <option value="VPN">VPN</option>
                            <option value="Internet Service Provider">Internet Service Provider</option>
                            <option value="Printer Server/Network Printer">Printer Server/Network Printer</option>
                            <option value="Router">Router</option>
                        </select>
                    </div>

                    <!-- NAS Group Dropdown -->
                    <div class="form-group mb-4" id="itemTypeNasGroupLabel" style="display:none;">
                        <label for="itemTypeNasGroup" class="form-label">Select Item Type NAS Group:</label>
                        <select id="itemTypeNasGroup" class="form-control" name="itemTypeNasGroup">
                            <option value="">-- Select an Item Type NAS Group --</option>
                            <option value="NAS">NAS</option>
                            <option value="Active Backup Physical Server">Active Backup Physical Server</option>
                            <option value="Active Backup File Server">Active Backup File Server</option>
                            <option value="Hyper Backup">Hyper Backup</option>
                            <option value="Synology Drive">Synology Drive</option>
                            <option value="Active Backup for Office 365">Active Backup for Office 365</option>
                            <option value="Active Backup for Google">Active Backup for Google</option>
                        </select>
                    </div>
                </div>
            </form>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <!-- JavaScript for Functionality -->
    <script>
        let debounceTimeout;

        function showDropdown(dropdownId) {
            // Hide all dropdowns
            document.querySelectorAll('#dynamicDropdowns .form-group').forEach(el => el.style.display = 'none');
            // Show the selected dropdown
            document.getElementById(dropdownId).style.display = 'block';
        }

        function checkAndRedirect() {
            const itemType = document.getElementById('itemType').value;
            const companyName = document.getElementById('companySearch').value.trim();
            const debtorCode = document.getElementById('debtorCode').value;

            if (itemType === 'Hosting') {
                showDropdown('itemTypeHostingGroupLabel');
            } else if (itemType === 'Accounting/Payroll') {
                showDropdown('itemTypeAcGroupLabel');
            } else if (itemType === 'Software') {
                showDropdown('itemTypeSoftwareGroupLabel');
            } else if (itemType === 'Hardware') {
                showDropdown('itemTypeHardwareGroupLabel');
            } else if (itemType === 'POS Hardware') {
                showDropdown('itemTypePosHardwareGroupLabel');
            } else if (itemType === 'Computer') {
                showDropdown('itemTypePcGroupLabel');
            } else if (itemType === 'Network') {
                showDropdown('itemTypeNetworkGroupLabel');
            } else if (itemType === 'NAS') {
                showDropdown('itemTypeNasGroupLabel');
            } else if (itemType === 'Email for CITSSB use') {
                const url = '/crm/public/config_info/add_email_for_citssb_use.php?' +
                    'itemType=' + encodeURIComponent(itemType) + 
                    '&debtorCode=' + encodeURIComponent(debtorCode) +
                    '&companyName=' + encodeURIComponent(companyName);
                window.location.href = url;
            } else {
                document.querySelectorAll('#dynamicDropdowns .form-group').forEach(el => el.style.display = 'none');
            }

            validateAndRedirect();
        }

        function validateAndRedirect() {
            const itemType = document.getElementById('itemType').value;
            const itemTypeAcGroup = document.getElementById('itemTypeAcGroup').value;
            const itemTypeHostingGroup = document.getElementById('itemTypeHostingGroup').value;
            const itemTypeSoftwareGroup = document.getElementById('itemTypeSoftwareGroup').value;
            const itemTypeHardwareGroup = document.getElementById('itemTypeHardwareGroup').value;
            const itemTypePosHardwareGroup = document.getElementById('itemTypePosHardwareGroup').value;
            const itemTypePcGroup = document.getElementById('itemTypePcGroup').value;
            const itemTypeNetworkGroup = document.getElementById('itemTypeNetworkGroup').value;
            const itemTypeNasGroup = document.getElementById('itemTypeNasGroup').value;
            const debtorCode = document.getElementById('debtorCode').value;
            const companyName = document.getElementById('companySearch').value;

            if (debtorCode === '') {
                alert('Please select a company.');
                window.location.href = '/crm/public/config_info/add_item_type.php';
                return;
            }

            const urlMappings = {
                'Accounting/Payroll': {
                    'Autocount': '/crm/public/config_info/add_ac_autocount_main.php',
                    'Autocount/Payroll Client': '/crm/public/config_info/add_ac_autocount_client.php',
                    'Cloud Payroll': '/crm/public/config_info/add_ac_cloud_payroll.php',
                    'Cloud Accounting': '/crm/public/config_info/add_ac_cloud_accounting.php',
                    'Million Accounting': '/crm/public/config_info/add_ac_million_accounting.php',
                    'Million Payroll': '/crm/public/config_info/add_ac_million_payroll.php',
                    'Offsite Backup': '/crm/public/config_info/add_ac_offsite_backup.php'
                },
                'Email for CITSSB use': '/crm/public/config_info/add_email_for_citssb_use.php',
                'NAS': {
                    'NAS': 'add_nas.php',
                    'Active Backup Physical Server': '/crm/public/config_info/add_nas_physical_server.php',
                    'Active Backup File Server': '/crm/public/config_info/add_nas_file_server.php',
                    'Hyper Backup': '/crm/public/config_info/add_nas_hyper_backup.php',
                    'Synology Drive': '/crm/public/config_info/add_nas_synology_drive.php',
                    'Active Backup for Office 365': '/crm/public/config_info/add_nas_ab_o365.php',
                    'Active Backup for Google': '/crm/public/config_info/add_nas_ab_google.php'
                },
                'Network': {
                    'Access Point': '/crm/public/config_info/add_nw_ap.php',
                    'Network Switch': '/crm/public/config_info/add_nw_ns.php',
                    'Firewall': '/crm/public/config_info/add_nw_fw.php',
                    'VPN': '/crm/public/config_info/add_nw_vpn.php',
                    'Internet Service Provider': '/crm/public/config_info/add_nw_isp.php',
                    'Printer Server/Network Printer': '/crm/public/config_info/add_nw_ps.php',
                    'Router': '/crm/public/config_info/add_nw_router.php'
                },
                'Computer': {
                    'Desktop/Laptop': '/crm/public/config_info/add_pc.php',
                    'Server': '/crm/public/config_info/add_server.php'
                },
                'Hosting': {
                    'Domain': '/crm/public/config_info/add_hs_domain.php',
                    'Hosting': '/crm/public/config_info/add_hs_hosting.php',
                    'Email': '/crm/public/config_info/add_hs_email.php'
                },
                'Hardware': {
                    'UPS': '/crm/public/config_info/add_hw_ups.php',
                    'Printer': '/crm/public/config_info/add_hw_printer.php',
                    'CCTV': '/crm/public/config_info/add_hw_cctv.php',
                    'Others': '/crm/public/config_info/add_hw_others.php'
                },
                'POS Hardware': {
                    'All In One PC': '/crm/public/config_info/add_pos_hw_aio_pc.php',
                    'PALM': '/crm/public/config_info/add_pos_hw_palm.php',
                    'Others': '/crm/public/config_info/add_pos_hw_others.php'
                },
                'Software': {
                    'Antivirus Endpoint Master': '/crm/public/config_info/add_sw_av_ep_master.php',
                    'Antivirus Endpoint Client': '/crm/public/config_info/add_sw_av_ep_client.php',
                    'Antivirus Internet Security': '/crm/public/config_info/add_sw_av_is.php',
                    'Microsoft (No Renewal)': '/crm/public/config_info/add_sw_microsoft_nr.php',
                    'Office 365 Master Account': '/crm/public/config_info/add_sw_o365_master.php',
                    'Office 365 Client Account': '/crm/public/config_info/add_sw_o365_client.php',
                    'Other Software': '/crm/public/config_info/add_sw_others.php'
                }
            };

            const baseUrl = urlMappings[itemType];
            if (!baseUrl) return;

            let url;
            if (typeof baseUrl === 'string') {
                url = baseUrl;
            } else {
                url = baseUrl[itemTypeAcGroup || itemTypeHostingGroup || itemTypeSoftwareGroup || itemTypeHardwareGroup || itemTypePosHardwareGroup || itemTypePcGroup || itemTypeNetworkGroup || itemTypeNasGroup];
            }

            if (url) {
                url += '?' +
                    'itemType=' + encodeURIComponent(itemType) +
                    '&debtorCode=' + encodeURIComponent(debtorCode) +
                    '&companyName=' + encodeURIComponent(companyName);

                if (itemTypeAcGroup) url += '&itemTypeAcGroup=' + encodeURIComponent(itemTypeAcGroup);
                if (itemTypeHostingGroup) url += '&itemTypeHostingGroup=' + encodeURIComponent(itemTypeHostingGroup);
                if (itemTypeSoftwareGroup) url += '&itemTypeSoftwareGroup=' + encodeURIComponent(itemTypeSoftwareGroup);
                if (itemTypeHardwareGroup) url += '&itemTypeHardwareGroup=' + encodeURIComponent(itemTypeHardwareGroup);
                if (itemTypePosHardwareGroup) url += '&itemTypePosHardwareGroup=' + encodeURIComponent(itemTypePosHardwareGroup);
                if (itemTypePcGroup) url += '&itemTypePcGroup=' + encodeURIComponent(itemTypePcGroup);
                if (itemTypeNetworkGroup) url += '&itemTypeNetworkGroup=' + encodeURIComponent(itemTypeNetworkGroup);
                if (itemTypeNasGroup) url += '&itemTypeNasGroup=' + encodeURIComponent(itemTypeNasGroup);

                window.location.href = url;
            }
        }

        function searchCompany() {
            // Clear any existing timeout
            clearTimeout(debounceTimeout);

            // Debounce the function to prevent excessive requests
            debounceTimeout = setTimeout(() => {
                const query = document.getElementById('companySearch').value;
                const companyList = document.getElementById('companyList');

                // Clear the list if the query is too short
                if (query.length < 2) {
                    companyList.innerHTML = "";
                    handleCompanyInput(); // Hide the dropdown if the query is too short
                    return;
                }

                // Show loading indicator
                companyList.innerHTML = "<p>Loading...</p>";

                // Create a new XMLHttpRequest object
                const xhr = new XMLHttpRequest();

                // Define the request
                xhr.open("GET", `/crm/public/functions/search_company_function.php?q=${encodeURIComponent(query)}`, true);

                // Define the callback function
                xhr.onreadystatechange = () => {
                    if (xhr.readyState === 4) {
                        if (xhr.status === 200) {
                            // Update the company list with the response
                            const response = xhr.responseText.trim();
                            if (response === "") {
                                // If no companies are found, display "No company found"
                                companyList.innerHTML = "<p>No company found.</p>";
                            } else {
                                companyList.innerHTML = response;
                            }
                        } else {
                            // Handle errors
                            companyList.innerHTML = "<p>Error loading data. Please try again.</p>";
                        }
                    }
                };

                // Send the request
                xhr.send();
            }, 300); // 300ms delay before making the request
        }

        function selectCompany(companyName, debtorCode) {
            document.getElementById('companySearch').value = companyName;
            document.getElementById('debtorCode').value = debtorCode; // Set the debtor code in a hidden input field
            document.getElementById('companyList').innerHTML = "";
            document.getElementById('itemTypeRow').style.display = 'block'; // Show the item type dropdown
        }

        function handleCompanyInput() {
            const companyName = document.getElementById('companySearch').value.trim();
            const debtorCode = document.getElementById('debtorCode').value;

            // If the company name is empty or invalid, hide the item type dropdown
            if (companyName === '' || debtorCode === '') {
                document.getElementById('itemTypeRow').style.display = 'none';
                document.getElementById('debtorCode').value = ''; // Clear the debtor code
            }
        }

        document.addEventListener('DOMContentLoaded', function() {
            // Add event listener for the company search input
            document.getElementById('companySearch').addEventListener('input', function() {
                searchCompany(); // Existing search functionality
                handleCompanyInput(); // New logic to handle dropdown visibility
            });

            // Add event listeners for dropdown changes
            document.getElementById('itemType').addEventListener('change', checkAndRedirect);
            document.getElementById('itemTypeAcGroup').addEventListener('change', checkAndRedirect);
            document.getElementById('itemTypeHostingGroup').addEventListener('change', checkAndRedirect);
            document.getElementById('itemTypeSoftwareGroup').addEventListener('change', checkAndRedirect);
            document.getElementById('itemTypeHardwareGroup').addEventListener('change', checkAndRedirect);
            document.getElementById('itemTypePosHardwareGroup').addEventListener('change', checkAndRedirect);
            document.getElementById('itemTypePcGroup').addEventListener('change', checkAndRedirect);
            document.getElementById('itemTypeNetworkGroup').addEventListener('change', checkAndRedirect);
            document.getElementById('itemTypeNasGroup').addEventListener('change', checkAndRedirect);
        });
    </script>
</body>
</html>

