<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Retrieve debtorCode

try {
    // Fetch necessary data
    $itemtype = $pdo->query("SELECT item_type_id, item_type_name FROM item_type")->fetchAll(PDO::FETCH_ASSOC);
    $itemtype = $pdo->query("SELECT item_type_email_citssb_id, item_type_email_citssb_name FROM item_type_email_citssb")->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}

// Handle form submission to save data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Debugging: Print out the POST data
    error_log(print_r($_POST, true));

    $active = 1; // Always set active to 1
    $email = $_POST['email'] ?? null;
    $password = $_POST['password'] ?? null;
    $usedAt = $_POST['used_at'] ?? null;
    $updateOfficePhoneDate = $_POST['update_office_phone_date'] ?? null;
    $others = $_POST['others'] ?? null;

    // Encrypt the password
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $encryptedPassword = encryptPassword($password, $encryptionKey);

    // Decrypt the login password for logging
    $decryptedPassword = decryptPassword($encryptedPassword, $encryptionKey);

    try {
        $stmt = $pdo->prepare("INSERT INTO item_type_email_citssb (
            item_type_name, 
            company_name, 
            debtor_code, 
            active,
            used_at,
            email,
            password,
            update_office_phone_date,
            others
        ) VALUES (
            :item_type_name,
            :company_name, 
            :debtor_code, 
            :active,
            :used_at,
            :email,
            :password,
            :update_office_phone_date,
            :others
        )");
        // Execute the insert query
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode, // Include debtorCode in the insert query
            ':active' => $active,
            ':email' => $email,
            ':used_at' => $usedAt,
            ':password' => $encryptedPassword,
            ':update_office_phone_date' => $updateOfficePhoneDate,
            ':others' => $others,
        ]);

        // Build the log message
        $logMessage = "Email inserted into $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-4">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Confirm and Save Details</h1>
            </div>
            <div class="card-body">
                <form method="POST">
                    <!-- Hidden input for debtor code -->
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">

                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Email Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <!-- Hidden input to always set active to 1 -->
                                    <input type="hidden" name="active" value="1">

                                    <div class="form-floating mb-3">
                                        <input type="email" class="form-control" name="email" id="floatingEmail" placeholder="name@example.com">
                                        <label for="floatingEmail">Email</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="password" id="floatingPassword" placeholder="Password">
                                        <label for="floatingPassword">Password</label>
                                    </div>
                                    </div>
                                    <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" name="update_office_phone_date" id="floatingDate" placeholder="Update Office Phone Date">
                                        <label for="floatingDate">Update Office Phone Date</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <select class="form-select" name="used_at" id="floatingUsedAt" placeholder="Used At">
                                            <option value="">Select an option</option>
                                            <option value="Fortinet">Fortinet</option>
                                            <option value="Synology">Synology</option>
                                        </select>
                                        <label for="floatingUsedAt">Used At</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Others Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="form-floating mb-3">
                                        <textarea class="form-control" id="floatingOthers" name="others" placeholder="Others"></textarea>
                                        <label for="floatingOthers">Others</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Save Button -->
                    <div class="text-center">
                        <button type="submit" class="btn btn-primary">Save</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap JS and dependencies -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
