<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeHostingGroup = isset($_GET['itemTypeHostingGroup']) ? $_GET['itemTypeHostingGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Directly get debtor_code from URL

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1;
    $domainName = $_POST['domain_name'] ?? '';
    $serverNames = $_POST['server_name'] ?? []; // Array for multiple server names
    $registerOn = $_POST['register_on'] ?? '';
    $serviceProvider = $_POST['service_provider'] ?? '';
    $others = $_POST['others'] ?? '';
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included

    // Convert server names array to JSON or comma-separated string
    $serverNamesString = implode(", ", $serverNames); 

    try {
        // Prepare and execute the insert query
        $stmt = $pdo->prepare("INSERT INTO item_type_hosting_domain (
            item_type_name, 
            item_type_hosting_group_name,
            company_name, 
            debtor_code,
            active,
            domain_name,
            server_name,
            register_on,
            service_provider,
            others
        ) VALUES (
            :item_type_name,
            :item_type_hosting_group_name,
            :company_name, 
            :debtor_code,
            :active,
            :domain_name,
            :server_name,
            :register_on,
            :service_provider,
            :others
        )");

        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':item_type_hosting_group_name' => $itemTypeHostingGroup,
            ':active' => $active,
            ':domain_name' => $domainName,
            ':server_name' => $serverNamesString, // Save as a single string or JSON
            ':register_on' => $registerOn,
            ':service_provider' => $serviceProvider,
            ':others' => $others
        ]);

        // Build the log message without itemTypeAcId
        $logMessage = "Item inserted into Domain for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]); 

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeHostingGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Domain Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="domain_name" id="domain_name" class="form-control" placeholder="Domain Name">
                                    <label for="domain_name">Domain Name</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" name="register_on" id="register_on" class="form-control" placeholder="Register On">
                                    <label for="register_on">Register On</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Server Names</h5>
                    </div>
                    <div class="card-body">
                        <div class="mb-3 row">
                            <label for="server_name" class="col-md-12 col-form-label">Server Names:</label>
                            <div class="col-md-12" id="server-container">
                                <!-- Initial Server Name Field -->
                                <div class="input-group mb-2">
                                    <div class="form-floating">
                                        <input type="text" class="form-control form-control-custom" name="server_name[]" placeholder="Server Name">
                                        <label for="server_name">Server Name</label>
                                    </div>
                                    <button type="button" class="btn btn-secondary" onclick="addServerField()">Add</button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Service Provider</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <input type="text" name="service_provider" id="service_provider" class="form-control" placeholder="Service Provider">
                            <label for="service_provider">Service Provider</label>
                        </div>
                    </div>
                </div>

                <!-- Others Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea 
                                id="others" 
                                name="others" 
                                class="form-control" 
                                placeholder="Others" 
                                style="height: 200px; resize: vertical; overflow-y: hidden;" 
                                oninput="this.style.height = ''; this.style.height = this.scrollHeight + 'px';"
                            ></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- JavaScript for dynamic server name fields -->
<script>
    function addServerField() {
        const container = document.getElementById('server-container');
        const newField = document.createElement('div');
        newField.className = 'input-group mb-2';
        newField.innerHTML = `
            <div class="form-floating">
                <input type="text" class="form-control form-control-custom" name="server_name[]" placeholder="Server Name">
                <label for="server_name">Server Name</label>
            </div>
            <button type="button" class="btn btn-danger" onclick="removeServerField(this)">Remove</button>
        `;
        container.appendChild(newField);
    }

    function removeServerField(button) {
        const container = document.getElementById('server-container');
        if (container.childElementCount > 1) {
            button.parentElement.remove();
        }
    }
</script>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>

