<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeHostingGroup = isset($_GET['itemTypeHostingGroup']) ? $_GET['itemTypeHostingGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Directly get debtor_code from URL

$customerUsernames = [];
if (!empty($debtorCode) && !empty($companyName)) {
    $stmt = $pdo->prepare("SELECT customer_username FROM customer_info WHERE debtor_code = :debtor_code AND company_name = :company_name");
    $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
    $customerUsernames = $stmt->fetchAll(PDO::FETCH_COLUMN);
}

// Fetch the list of installed PCs from the database
$installedPcs = [];
if ($debtorCode && $companyName) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Initialize variables to store form data
if (isset($_SESSION['retain_fields'])) {
    $emailAccount = $_SESSION['retain_fields']['emailAccount'];
    $loginPassword = $_SESSION['retain_fields']['loginPassword'];
    $serviceProvider = $_SESSION['retain_fields']['serviceProvider'];
    unset($_SESSION['retain_fields']);
} else {
    $emailAccount = '';
    $loginPassword = '';
    $serviceProvider = '';
}

// Other fields are empty
$customerUsername = '';
$installedPc = '';
$incomingMailServer = '';
$outgoingServer = '';
$incomingMailServerPort = '';
$outgoingMailServerPort = '';
$others = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1;
    $emailAccount = $_POST['email_account'] ?? '';
    $serviceProvider = $_POST['service_provider'] ?? '';
    $customerUsername = $_POST['customer_username'] ?? '';
    $installedPc = $_POST['installed_pc'] ?? '';
    $loginPassword = $_POST['login_password'] ?? '';
    $incomingMailServer = $_POST['incoming_mail_server'] ?? '';
    $outgoingServer = $_POST['outgoing_server'] ?? '';
    $incomingMailServerPort = $_POST['incoming_mail_server_port'] ?? '';
    $outgoingMailServerPort = $_POST['outgoing_mail_server_port'] ?? '';
    $others = $_POST['others'] ?? '';
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included

    // Validate required fields
    if (empty($emailAccount) || empty($loginPassword) || empty($serviceProvider)) {
        echo "<script>alert('Please fill in all required fields: Email Account, Login Password, and Service Provider.');</script>";
    } else {
        $encryptionKey = 'your_secret_key'; // This should be a secure key
        $encryptedLoginPassword = encryptPassword($loginPassword, $encryptionKey);

        try {
            // Prepare and execute the insert query
            $stmt = $pdo->prepare("INSERT INTO item_type_hosting_email (
                item_type_name, 
                item_type_hosting_group_name,
                company_name, 
                debtor_code,
                active,
                email_account,
                service_provider,
                customer_username,
                installed_pc,
                login_password,
                incoming_mail_server,
                outgoing_server,
                incoming_mail_server_port,
                outgoing_mail_server_port,
                others
            ) VALUES (
                :item_type_name,
                :item_type_hosting_group_name,
                :company_name, 
                :debtor_code,
                :active,
                :email_account,
                :service_provider,
                :customer_username,
                :installed_pc,
                :login_password,
                :incoming_mail_server,
                :outgoing_server,
                :incoming_mail_server_port,
                :outgoing_mail_server_port,
                :others
            )");

            $stmt->execute([
                ':item_type_name' => $itemType,
                ':company_name' => $companyName,
                ':debtor_code' => $debtorCode,
                ':item_type_hosting_group_name' => $itemTypeHostingGroup,
                ':active' => $active,
                ':email_account' => $emailAccount,
                ':service_provider' => $serviceProvider,
                ':customer_username' => $customerUsername,
                ':installed_pc' => $installedPc,
                ':login_password' => $encryptedLoginPassword,
                ':incoming_mail_server' => $incomingMailServer,
                ':outgoing_server' => $outgoingServer,
                ':incoming_mail_server_port' => $incomingMailServerPort,
                ':outgoing_mail_server_port' => $outgoingMailServerPort, 
                ':others' => $others
            ]);

            $logMessage = "Item inserted into Hosting Email for company_name: $companyName";

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]); 

            // Check if "Save and Add New" button was clicked
            if (isset($_POST['save_and_add_new'])) {
                // Store only specified fields in session array
                $_SESSION['retain_fields'] = array(
                    'emailAccount' => $emailAccount,
                    'loginPassword' => $loginPassword,
                    'serviceProvider' => $serviceProvider
                );
                // Clear other fields
                $customerUsername = '';
                $installedPc = '';
                $incomingMailServer = '';
                $outgoingServer = '';
                $incomingMailServerPort = '';
                $outgoingMailServerPort = '';
                $others = '';
                // Redirect using JavaScript
                echo "<script>
                        alert('Save successful and please add new.');
                        window.location.href = '" . $_SERVER['PHP_SELF'] . "?" . http_build_query($_GET) . "';
                      </script>";
                exit;
            } else {
                // Clear session array after save
                unset($_SESSION['retain_fields']);
                // Success alert and redirect
                echo "<script>
                        alert('Data saved successfully!');
                        window.location.href = 'add_config_info.php';
                      </script>";
                exit;
            }
        } catch (PDOException $e) {
            error_log('Database insert error: ' . $e->getMessage());
            echo "<script>alert('Failed to save data. Please try again.');</script>";
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST" id="saveForm">
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeHostingGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                <!-- Email and Service Provider Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Email and Service Provider</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <!-- Email Account -->
                                <div class="form-floating mb-3">
                                    <input type="text" name="email_account" id="email_account" class="form-control" placeholder="Email Account" value="<?php echo htmlspecialchars($emailAccount); ?>">
                                    <label for="email_account">Email Account</label>
                                </div>

                                <!-- Login Password -->
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_password" id="login_password" class="form-control" placeholder="Login Password" value="<?php echo htmlspecialchars($loginPassword); ?>">
                                    <label for="login_password">Login Password</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <!-- Service Provider -->
                                <div class="form-floating mb-3">
                                    <select name="service_provider" id="service_provider" class="form-select">
                                        <option value="">Select a Service Provider</option>
                                        <option value="cPanel" <?php echo $serviceProvider === 'cPanel' ? 'selected' : ''; ?>>cPanel</option>
                                        <option value="Dynamail" <?php echo $serviceProvider === 'Dynamail' ? 'selected' : ''; ?>>Dynamail</option>
                                        <option value="Microsoft" <?php echo $serviceProvider === 'Microsoft' ? 'selected' : ''; ?>>Microsoft</option>
                                        <option value="Google" <?php echo $serviceProvider === 'Google' ? 'selected' : ''; ?>>Google</option>
                                        <option value="Other" <?php echo $serviceProvider === 'Other' ? 'selected' : ''; ?>>Other</option>
                                    </select>
                                    <label for="service_provider">Service Provider</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Customer Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Customer Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <!-- Customer Username -->
                                <div class="form-group">
                                    <label for="customer_username">Customer Username</label>
                                    <select name="customer_username" id="customer_username" class="form-control">
                                        <option value="">Select Customer Username</option>
                                        <?php foreach ($customerUsernames as $username): ?>
                                            <option value="<?php echo htmlspecialchars($username); ?>" <?php echo $customerUsername === $username ? 'selected' : ''; ?>>
                                                <?php echo htmlspecialchars($username); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>

                            <div class="col-md-6">
                                <!-- Installed PC -->
                                <div class="form-group">
                                    <label for="installed_pc">Installed PC</label>
                                    <select class="form-control" id="installed_pc" name="installed_pc">
                                        <option value="">Select Installed PC</option>
                                        <?php foreach ($installedPcs as $option): ?>
                                            <option value="<?php echo htmlspecialchars($option); ?>" <?php echo $installedPc === $option ? 'selected' : ''; ?>>
                                                <?php echo htmlspecialchars($option); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Mail Server Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Mail Server Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Incoming Mail Server</label>
                                    <div class="input-group mb-2">
                                        <div class="form-floating">
                                            <input type="text" class="form-control" name="incoming_mail_server" id="incoming_mail_server" placeholder=" " value="<?php echo htmlspecialchars($incomingMailServer); ?>">
                                            <label for="incoming_mail_server">Server</label>
                                        </div>
                                        <div class="form-floating">
                                            <input type="text" class="form-control" name="incoming_mail_server_port" id="incoming_mail_server_port" placeholder=" " value="<?php echo htmlspecialchars($incomingMailServerPort); ?>">
                                            <label for="incoming_mail_server_port">Port</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Outgoing Mail Server</label>
                                    <div class="input-group mb-2">
                                        <div class="form-floating">
                                            <input type="text" class="form-control" name="outgoing_server" id="outgoing_server" placeholder="" value="<?php echo htmlspecialchars($outgoingServer); ?>">
                                            <label for="outgoing_server">Server</label>
                                        </div>
                                        <div class="form-floating">
                                            <input type="text" class="form-control" name="outgoing_mail_server_port" id="outgoing_mail_server_port" placeholder="" value="<?php echo htmlspecialchars($outgoingMailServerPort); ?>">
                                            <label for="outgoing_mail_server_port">Port</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating">
                            <textarea id="others" name="others" class="form-control" placeholder="Others"><?php echo htmlspecialchars($others); ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
                <!-- Save and Add New Button -->
                <button type="submit" name="save_and_add_new" class="btn btn-secondary">Save and Add New</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5 JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
$(document).ready(function() {
    $('#installed_pc, #customer_username').select2({
        theme: "bootstrap-5",
        width: $(this).data('width') ? $(this).data('width') : $(this).hasClass('w-100') ? '100%' : 'style',
        placeholder: $(this).data('placeholder'),
    });
});
</script>
</body>
</html>

