<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Encryption key (must match the key used in encrypt.php)
$encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeHostingGroup = isset($_GET['itemTypeHostingGroup']) ? $_GET['itemTypeHostingGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Directly get debtor_code from URL

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1;
    $serviceProvider = $_POST['service_provider'] ?? '';
    $hostingSoftware = $_POST['hosting_software'] ?? '';
    $loginUrl = $_POST['login_url'] ?? '';
    $secondLoginUrl = $_POST['second_login_url'] ?? '';
    $ftpHostName = $_POST['ftp_host_name'] ?? '';
    $secondFtpHostName = $_POST['second_ftp_host_name'] ?? '';
    $nameserver1 = $_POST['nameserver_1'] ?? '';
    $nameserver2 = $_POST['nameserver_2'] ?? '';
    $loginId = $_POST['login_id'] ?? '';
    $loginPassword = $_POST['login_password'] ?? '';
    $dns = $_POST['dns'] ?? '';
    $mailSentinel = isset($_POST['mail_sentinel']) ? 1 : 0;
    $mailbox = $_POST['mailbox'] ?? '';
    $mxRecord = $_POST['mx_record'] ?? '';
    $wordpressUrl = $_POST['wordpress_url'] ?? '';
    $wordpressAdminLogin = $_POST['wordpress_admin_login'] ?? '';
    $wordpressAdminPassword = $_POST['wordpress_admin_password'] ?? '';
    $sqlId = $_POST['sql_id'] ?? '';
    $sqlPassword = $_POST['sql_password'] ?? '';
    $sqlDatabase = $_POST['sql_database'] ?? '';
    $others = $_POST['others'] ?? '';
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included

    // Encrypt sensitive passwords
    $loginPasswordEncrypted = encryptPassword($loginPassword, $encryptionKey);
    $wordpressAdminPasswordEncrypted = encryptPassword($wordpressAdminPassword, $encryptionKey);
    $sqlPasswordEncrypted = encryptPassword($sqlPassword, $encryptionKey);

    try {
        // Prepare and execute the insert query
        $stmt = $pdo->prepare("INSERT INTO item_type_hosting_hosting (
            item_type_name, 
            item_type_hosting_group_name,
            company_name, 
            debtor_code,
            active,
            service_provider,
            hosting_software,
            login_url,
            second_login_url,
            ftp_host_name,
            second_ftp_host_name,
            nameserver_1,
            nameserver_2,
            login_id,
            login_password,
            dns,
            mail_sentinel,
            mailbox,
            mx_record,
            wordpress_url,
            wordpress_admin_login,
            wordpress_admin_password,
            sql_id,
            sql_password,
            sql_database,
            others
        ) VALUES (
            :item_type_name,
            :item_type_hosting_group_name,
            :company_name, 
            :debtor_code,
            :active,
            :service_provider,
            :hosting_software,
            :login_url,
            :second_login_url,
            :ftp_host_name,
            :second_ftp_host_name,
            :nameserver_1,
            :nameserver_2,
            :login_id,
            :login_password,
            :dns,
            :mail_sentinel,
            :mailbox,
            :mx_record,
            :wordpress_url,
            :wordpress_admin_login,
            :wordpress_admin_password,
            :sql_id,
            :sql_password,
            :sql_database,
            :others
        )");

        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':item_type_hosting_group_name' => $itemTypeHostingGroup,
            ':active' => $active,
            ':service_provider' => $serviceProvider,
            ':hosting_software' => $hostingSoftware,
            ':login_url' => $loginUrl,
            ':second_login_url' => $secondLoginUrl,
            ':ftp_host_name' => $ftpHostName,
            ':second_ftp_host_name' => $secondFtpHostName,
            ':nameserver_1' => $nameserver1,
            ':nameserver_2' => $nameserver2,
            ':login_id' => $loginId,
            ':login_password' => $loginPasswordEncrypted, // Encrypted password
            ':dns' => $dns,
            ':mail_sentinel' => $mailSentinel,
            ':mailbox' => $mailbox,
            ':mx_record' => $mxRecord,
            ':wordpress_url' => $wordpressUrl,
            ':wordpress_admin_login' => $wordpressAdminLogin,
            ':wordpress_admin_password' => $wordpressAdminPasswordEncrypted, // Encrypted password
            ':sql_id' => $sqlId,
            ':sql_password' => $sqlPasswordEncrypted, // Encrypted password
            ':sql_database' => $sqlDatabase,
            ':others' => $others
        ]);

        // Build the log message with plaintext passwords
        $logMessage = "Item inserted into Hosting for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeHostingGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                <!-- Login Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-select" id="service_provider" name="service_provider">
                                        <option value="">Select a Service Provider</option>
                                        <option value="Shinjuru">Shinjuru</option>
                                        <option value="ITWIN">ITWIN</option>
                                        <option value="Other">Other</option>
                                    </select>
                                    <label for="service_provider">Service Provider</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="login_url" name="login_url" placeholder="Login URL">
                                    <label for="login_url">Login URL</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="login_id" name="login_id" placeholder="Login ID">
                                    <label for="login_id">Login ID</label>
                                </div>
                                <div class="form-check mb-3">
                                    <input type="checkbox" class="form-check-input" id="mail_sentinel" name="mail_sentinel" value="1">
                                    <label class="form-check-label" for="mail_sentinel">Mail Sentinel</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="hosting_software" name="hosting_software" placeholder="Hosting Software">
                                    <label for="hosting_software">Hosting Software</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="second_login_url" name="second_login_url" placeholder=" Second Login URL">
                                    <label for="second_login_url">Second Login URL</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="login_password" name="login_password" placeholder="Login Password">
                                    <label for="login_password">Login Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- FTP Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">FTP Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="ftp_host_name" name="ftp_host_name" placeholder="FTP Host Name">
                                    <label for="ftp_host_name">FTP Host Name</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="second_ftp_host_name" name="second_ftp_host_name" placeholder="Second FTP Host Name">
                                    <label for="second_ftp_host_name">Second FTP Host Name</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- DNS Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">DNS Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="nameserver_1" name="nameserver_1" placeholder="NameServer 1">
                                    <label for="nameserver_1">NameServer 1</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="dns" name="dns" placeholder="DNS">
                                    <label for="dns">DNS</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="nameserver_2" name="nameserver_2" placeholder="NameServer 2">
                                    <label for="nameserver_2">NameServer 2</label>
                                </div>

                            </div>
                        </div>
                    </div>
                </div>

                <!-- Mailbox Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Mailbox Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-select" id="mailbox" name="mailbox">
                                        <option value="">Select a Mailbox</option>
                                        <option value="cPanel">cPanel</option>
                                        <option value="Dynamail">Dynamail</option>
                                        <option value="Microsoft">Microsoft</option>
                                        <option value="Google">Google</option>
                                        <option value="Other">Other</option>
                                    </select>
                                    <label for="mailbox">Mailbox</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <textarea class="form-control" id="mx_record" name="mx_record" placeholder="MX Record"></textarea>
                                    <label for="mx_record">MX Record</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- WordPress Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">WordPress Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="wordpress_url" name="wordpress_url" placeholder="Wordpress URL">
                                    <label for="wordpress_url">Wordpress URL</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="wordpress_admin_login" name="wordpress_admin_login" placeholder="Wordpress Admin Login">
                                    <label for="wordpress_admin_login">Wordpress Admin Login</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="wordpress_admin_password" name="wordpress_admin_password" placeholder="Wordpress Admin Password">
                                    <label for="wordpress_admin_password">Wordpress Admin Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- SQL Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">SQL Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="sql_id" name="sql_id" placeholder="SQL ID">
                                    <label for="sql_id">SQL ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="sql_database" name="sql_database" placeholder="SQL Database">
                                    <label for="sql_database">SQL Database</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="sql_password" name="sql_password" placeholder="SQL Password">
                                    <label for="sql_password">SQL Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea class="form-control" id="others" name="others" placeholder="Others"></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
</body>
</html>