<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeHardwareGroup = isset($_GET['itemTypeHardwareGroup']) ? $_GET['itemTypeHardwareGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the list of installed PCs for the selected company based on debtor_code and company_name
$installedPcs = [];
if ($debtorCode && $companyName) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $login = $_POST['login'] ?? null;
    $password = $_POST['password'] ?? null;
    $ddns = $_POST['ddns'] ?? null;
    $brand = $_POST['brand'] ?? null;
    $model = $_POST['model'] ?? null;
    $openPort = $_POST['open_port'] ?? null;
    $tcpIp = $_POST['tcp_ip'] ?? null; // TCP/IP field
    $userLogin = $_POST['user_login'] ?? [];
    $userPassword = $_POST['user_password'] ?? [];
    $installedPc = $_POST['installed_pc'] ?? [];
    $software = $_POST['software'] ?? null;
    $softwareLogin = $_POST['software_login'] ?? [];
    $softwarePassword = $_POST['software_password'] ?? [];

    // Encrypt the passwords
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $encryptedPassword = encryptPassword($password, $encryptionKey);

    // Encrypt user passwords
    $encryptedUserPasswords = array_map(function($pwd) use ($encryptionKey) {
        return encryptPassword($pwd, $encryptionKey);
    }, $userPassword);

    // Encrypt software passwords
    $encryptedSoftwarePasswords = array_map(function($pwd) use ($encryptionKey) {
        return encryptPassword($pwd, $encryptionKey);
    }, $softwarePassword);

    // Convert arrays to comma-separated strings for user logins and passwords
    $userLoginString = implode(',', $userLogin);
    $userPasswordString = implode(',', $encryptedUserPasswords);

    try {
        // Prepare and execute the insert query for the main record
        $stmt = $pdo->prepare("INSERT INTO item_type_hw_cctv (
            item_type_name, 
            company_name, 
            debtor_code,
            active,
            item_type_hw_group_name,
            login,
            password,
            ddns,
            brand,
            model,
            open_port,
            tcp_ip,
            user_login,
            user_password,
            software
        ) VALUES (
            :item_type_name, 
            :company_name, 
            :debtor_code,
            :active,
            :item_type_hw_group_name,
            :login,
            :password,
            :ddns,
            :brand,
            :model,
            :open_port,
            :tcp_ip,
            :user_login,
            :user_password,
            :software
        )");

        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':active' => $active,
            ':item_type_hw_group_name' => $itemTypeHardwareGroup,
            ':login' => $login,
            ':password' => $encryptedPassword,
            ':ddns' => $ddns,
            ':brand' => $brand,
            ':model' => $model,
            ':open_port' => $openPort,
            ':tcp_ip' => $tcpIp,
            ':user_login' => $userLoginString,
            ':user_password' => $userPasswordString,
            ':software' => $software
        ]);

        // Get the last inserted ID
        $itemTypeHwCctvId = $pdo->lastInsertId();

        $logMessage = "Item inserted into CCTV for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Insert installed_pc_for_cctv entries with software login and password
        foreach ($installedPc as $index => $pc) {
            $stmt = $pdo->prepare("INSERT INTO installed_pc_for_cctv (
                item_type_hw_cctv_id, 
                computer_name, 
                software_login, 
                software_password
            ) VALUES (
                :item_type_hw_cctv_id, 
                :computer_name, 
                :software_login, 
                :software_password
            )");
            $stmt->execute([
                ':item_type_hw_cctv_id' => $itemTypeHwCctvId,
                ':computer_name' => $pc,
                ':software_login' => $softwareLogin[$index] ?? null,
                ':software_password' => $encryptedSoftwarePasswords[$index] ?? null
            ]);
        }

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-1">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display the passed values -->
                <div class="mb-3">
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeHardwareGroup); ?></strong></p>
                </div>

                <!-- Login Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="brand" name="brand" placeholder="Brand">
                                    <label for="brand">Brand</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="login" name="login" placeholder="Login">
                                    <label for="login">Login</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="tcp_ip" name="tcp_ip" placeholder="TCP/IP">
                                    <label for="tcp_ip">TCP/IP</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="ddns" name="ddns" placeholder="DDNS">
                                    <label for="ddns">DDNS</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="model" name="model" placeholder="Model">
                                    <label for="model">Model</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="password" name="password" placeholder="Password">
                                    <label for="password">Password</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="open_port" name="open_port" placeholder="Open Port">
                                    <label for="open_port">Open Port</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- User Login Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">User Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-12">
                                <div class="input-group">
                                    <div class="form-floating">
                                        <input type="text" name="user_login[]" class="form-control" placeholder="User Login">
                                        <label>User Login</label>
                                    </div>
                                    <div class="form-floating">
                                        <input type="text" name="user_password[]" class="form-control" placeholder="User Password">
                                        <label>User Password</label>
                                    </div>
                                    <button type="button" onclick="addUserLogin()" class="btn btn-primary">Add</button>
                                </div>
                                <div id="userLoginContainer" class="mt-3"></div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Installed PC and Software Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Installed PC and Software Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="software" name="software" placeholder="Software Name">
                            <label for="software">Software Name</label>
                        </div>
                        <div id="installedPcAndSoftwareContainer">
                            <!-- Default fields -->
                            <div class="form-group row mb-3">
                                <div class="col-sm-12">
                                    <div class="input-group">
                                        <div class="form-floating">
                                            <select class="form-select" name="installed_pc[]" id="installed_pc">
                                                <option value="" disabled selected>Please select a PC</option>
                                                <?php foreach ($installedPcs as $option): ?>
                                                    <option value="<?php echo htmlspecialchars($option); ?>"><?php echo htmlspecialchars($option); ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                            <label for="installed_pc">Installed PC</label>
                                        </div>
                                        <div class="form-floating">
                                            <input type="text" name="software_login[]" class="form-control" placeholder="Software Login ID">
                                            <label>Software Login ID</label>
                                        </div>
                                        <div class="form-floating">
                                            <input type="text" name="software_password[]" class="form-control" placeholder="Software Login Password">
                                            <label>Software Login Password</label>
                                        </div>
                                        <button type="button" class="btn btn-secondary" onclick="addInstalledPcAndSoftware(this)">Add</button>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea id="others" name="others" class="form-control" placeholder="Others"></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Save</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5 JS and dependencies -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
<script>
function addUserLogin() {
    const container = document.getElementById('userLoginContainer');
    const div = document.createElement('div');
    div.className = 'input-group mt-3';

    div.innerHTML = `
        <div class="form-floating">
            <input type="text" name="user_login[]" class="form-control" placeholder="User Login">
            <label>User Login</label>
        </div>
        <div class="form-floating">
            <input type="text" name="user_password[]" class="form-control" placeholder="User Password">
            <label>User Password</label>
        </div>
        <button type="button" class="btn btn-danger" onclick="removeUserLogin(this)">Remove</button>
    `;

    container.appendChild(div);
}

function removeUserLogin(button) {
    button.parentElement.remove();
}

function addInstalledPcAndSoftware() {
    const container = document.getElementById('installedPcAndSoftwareContainer');

    const rowDiv = document.createElement('div');
    rowDiv.className = 'form-group row mb-3';

    const label = document.createElement('label');
    label.className = 'col-sm-2 col-form-label';
    label.innerText = 'Installed PC and Software';

    const inputGroupDiv = document.createElement('div');
    inputGroupDiv.className = 'col-sm-10';

    const inputGroup = document.createElement('div');
    inputGroup.className = 'input-group';

    const selectDiv = document.createElement('div');
    selectDiv.className = 'form-floating';
    const select = document.createElement('select');
    select.className = 'form-select';
    select.name = 'installed_pc[]';
    select.innerHTML = `
        <option value="" disabled selected>Please select a PC</option>
        <?php foreach ($installedPcs as $option): ?>
            <option value="<?php echo htmlspecialchars($option); ?>"><?php echo htmlspecialchars($option); ?></option>
        <?php endforeach; ?>
    `;
    const selectLabel = document.createElement('label');
    selectLabel.innerText = 'Installed PC';
    selectDiv.appendChild(select);
    selectDiv.appendChild(selectLabel);

    const input1Div = document.createElement('div');
    input1Div.className = 'form-floating';
    const input1 = document.createElement('input');
    input1.type = 'text';
    input1.name = 'software_login[]';
    input1.placeholder = 'Software Login ID';
    input1.className = 'form-control';
    const input1Label = document.createElement('label');
    input1Label.innerText = 'Software Login ID';
    input1Div.appendChild(input1);
    input1Div.appendChild(input1Label);

    const input2Div = document.createElement('div');
    input2Div.className = 'form-floating';
    const input2 = document.createElement('input');
    input2.type = 'text';
    input2.name = 'software_password[]';
    input2.placeholder = 'Software Login Password';
    input2.className = 'form-control';
    const input2Label = document.createElement('label');
    input2Label.innerText = 'Software Login Password';
    input2Div.appendChild(input2);
    input2Div.appendChild(input2Label);

    const removeButton = document.createElement('button');
    removeButton.type = 'button';
    removeButton.className = 'btn btn-secondary';
    removeButton.innerText = 'Remove';
    removeButton.onclick = function () {
        container.removeChild(rowDiv);
    };

    inputGroup.appendChild(selectDiv);
    inputGroup.appendChild(input1Div);
    inputGroup.appendChild(input2Div);
    inputGroup.appendChild(removeButton);

    inputGroupDiv.appendChild(inputGroup);

    rowDiv.appendChild(label);
    rowDiv.appendChild(inputGroupDiv);

    container.appendChild(rowDiv);
}
</script>

