<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeHardwareGroup = isset($_GET['itemTypeHardwareGroup']) ? $_GET['itemTypeHardwareGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the list of installed PCs from the database
$installedPcs = [];
if ($debtorCode && $companyName) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $installedPc = $_POST['installed_pc'] ?? null;
    $brand = $_POST['brand'] ?? null;
    $model = $_POST['model'] ?? null;
    $partNo = $_POST['part_no'] ?? null;
    $serialNumber = $_POST['serial_number'] ?? null;
    $others = $_POST['others'] ?? null;

    try {
        // Prepare and execute the insert query for the new table
        $stmt = $pdo->prepare("INSERT INTO item_type_hw_others (
            item_type_name, 
            company_name, 
            debtor_code,
            active,
            item_type_hw_group_name,
            installed_pc,
            brand,
            model,
            part_no,
            serial_number,
            others
        ) VALUES (
            :item_type_name, 
            :company_name, 
            :debtor_code,
            :active,
            :item_type_hw_group_name,
            :installed_pc,
            :brand,
            :model,
            :part_no,
            :serial_number,
            :others
        )");
    
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':item_type_hw_group_name' => $itemTypeHardwareGroup,
            ':active' => $active,
            ':installed_pc' => $installedPc,
            ':brand' => $brand,
            ':model' => $model,
            ':part_no' => $partNo,
            ':serial_number' => $serialNumber,
            ':others' => $others
        ]);
    
        $logMessage = "Item inserted into Others hardware for company_name: $companyName";
    
        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);
    
        // Success alert and redirect
        echo "<script>alert('Data added successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to add data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add Details</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-4">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Add Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display the passed values -->
                <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                <p>Item Type Network Group: <strong><?php echo htmlspecialchars($itemTypeHardwareGroup); ?></strong></p>

                <!-- Installed PC Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Installed PC</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <select class="form-select" name="installed_pc" id="installed_pc">
                                <option value="">Select Installed PC</option>
                                <?php foreach ($installedPcs as $pc): ?>
                                    <option value="<?php echo htmlspecialchars($pc); ?>"><?php echo htmlspecialchars($pc); ?></option>
                                <?php endforeach; ?>
                            </select>
                            <label for="installed_pc">Installed PC</label>
                        </div>
                    </div>
                </div>

                <!-- General Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">General Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="brand" id="brand" placeholder="Brand">
                                    <label for="brand">Brand</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="model" id="model" placeholder="Model">
                                    <label for="model">Model</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="part_no" id="part_no" placeholder="Part No">
                                    <label for="part_no">Part No</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="serial_number" id="serial_number" placeholder="Serial Number">
                                    <label for="serial_number">Serial Number</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea class="form-control" id="others" name="others" placeholder="Others"></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Add</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5 JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>

