<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeHardwareGroup = isset($_GET['itemTypeHardwareGroup']) ? $_GET['itemTypeHardwareGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the list of installed PCs for the selected company based on debtor_code and company_name
$installedPcs = [];
if ($debtorCode && $companyName) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $installedPc = $_POST['installed_pc'] ?? []; // Array of selected PCs
    $brand = $_POST['brand'] ?? null;
    $model = $_POST['model'] ?? null;
    $port = $_POST['port'] ?? null;
    $serialNumber = $_POST['serial_number'] ?? null;
    $others = $_POST['others'] ?? null;
    $printServer = $_POST['print_server'] ?? 'default_value_or_empty'; // Ensure default value is set
    $department = $_POST['department'] ?? null;
    $type = $_POST['type'] ?? null;
    $tcpIp = $_POST['tcp_ip'] ?? null; // New TCP/IP field

    // Validate that the type is selected
    if (empty($type) || $type === 'Please select a type') {
        echo "<script>alert('Please select a type.');</script>";
    } else {
        try {
            // If no installed_pc is selected, insert a single record with installed_pc as NULL
            if (empty($installedPc)) {
                $stmt = $pdo->prepare("INSERT INTO item_type_hw_printer (
                    item_type_name, 
                    company_name, 
                    debtor_code,
                    active,
                    item_type_hw_group_name,
                    installed_pc,
                    brand,
                    model,
                    port,
                    serial_number,
                    others,
                    print_server,
                    department,
                    type,
                    tcp_ip
                ) VALUES (
                    :item_type_name, 
                    :company_name, 
                    :debtor_code,
                    :active,
                    :item_type_hw_group_name,
                    :installed_pc,
                    :brand,
                    :model,
                    :port,
                    :serial_number,
                    :others,
                    :print_server,
                    :department,
                    :type,
                    :tcp_ip
                )");

                $stmt->execute([
                    ':item_type_name' => $itemType,
                    ':company_name' => $companyName,
                    ':debtor_code' => $debtorCode,
                    ':active' => $active,
                    ':item_type_hw_group_name' => $itemTypeHardwareGroup,
                    ':installed_pc' => null, // Set installed_pc as NULL
                    ':brand' => $brand,
                    ':model' => $model,
                    ':port' => $port,
                    ':serial_number' => $serialNumber,
                    ':others' => $others,
                    ':print_server' => $printServer,
                    ':department' => $department,
                    ':type' => $type,
                    ':tcp_ip' => $tcpIp
                ]);
            } else {
                // Loop through each installed_pc value and insert a new record for each printer
                foreach ($installedPc as $pc) {
                    $stmt = $pdo->prepare("INSERT INTO item_type_hw_printer (
                        item_type_name, 
                        company_name, 
                        debtor_code,
                        active,
                        item_type_hw_group_name,
                        installed_pc,
                        brand,
                        model,
                        port,
                        serial_number,
                        others,
                        print_server,
                        department,
                        type,
                        tcp_ip
                    ) VALUES (
                        :item_type_name, 
                        :company_name, 
                        :debtor_code,
                        :active,
                        :item_type_hw_group_name,
                        :installed_pc,
                        :brand,
                        :model,
                        :port,
                        :serial_number,
                        :others,
                        :print_server,
                        :department,
                        :type,
                        :tcp_ip
                    )");

                    $stmt->execute([
                        ':item_type_name' => $itemType,
                        ':company_name' => $companyName,
                        ':debtor_code' => $debtorCode,
                        ':active' => $active,
                        ':item_type_hw_group_name' => $itemTypeHardwareGroup,
                        ':installed_pc' => $pc,
                        ':brand' => $brand,
                        ':model' => $model,
                        ':port' => $port,
                        ':serial_number' => $serialNumber,
                        ':others' => $others,
                        ':print_server' => $printServer,
                        ':department' => $department,
                        ':type' => $type,
                        ':tcp_ip' => $tcpIp
                    ]);

                    // Update the installed_printer field in item_type_pc
                    $stmt = $pdo->prepare("UPDATE item_type_pc SET installed_printer = :model WHERE computer_name = :computer_name");
                    $stmt->execute([':model' => $model, ':computer_name' => $pc]);
                }
            }

            $logMessage = "Item inserted into Printer for company_name: $companyName";

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // Success alert and redirect
            echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
        } catch (PDOException $e) {
            error_log('Database insert/update error: ' . $e->getMessage());
            echo "<script>alert('Failed to save data. Please try again.');</script>";
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-1">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display the passed values -->
                <div class="mb-3">
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeHardwareGroup); ?></strong></p>
                </div>

                <!-- Hardware Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Printer Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="brand" name="brand" placeholder="Brand">
                                    <label for="brand">Brand</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="model" name="model" placeholder="Model">
                                    <label for="model">Model</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="department" name="department" placeholder="Department">
                                    <label for="department">Department</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="tcp_ip" name="tcp_ip" placeholder="TCP/IP Address">
                                    <label for="tcp_ip">TCP/IP Address</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="serial_number" name="serial_number" placeholder="Serial Number">
                                    <label for="serial_number">Serial Number</label>
                                </div>
                                
                                <div class="form-floating mb-3">
                                    <select class="form-select" id="port" name="port">
                                        <option value="USB">USB</option>
                                        <option value="BT">BT</option>
                                        <option value="WIFI">WIFI</option>
                                        <option value="NETWORK">NETWORK</option>
                                        <option value="COM">COM</option>
                                        <option value="PARALLEL">PARALLEL</option>
                                    </select>
                                    <label for="port">Port</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <select class="form-select" id="type" name="type" required>
                                        <option value="Please select a type">Please select a type</option>
                                        <option value="Copier">Copier</option>
                                        <option value="Printer">Printer</option>
                                    </select>
                                    <label for="type">Type</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- PC Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">PC Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-select" id="installed_pc" name="installed_pc[]" data-placeholder="Choose a PC" multiple>
                                        <?php foreach ($installedPcs as $option): ?>
                                            <option value="<?php echo htmlspecialchars($option); ?>"><?php echo htmlspecialchars($option); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea id="others" name="others" class="form-control" placeholder="Others"></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Hidden input for print_server -->
                <input type="hidden" name="print_server" id="print_server" value="">

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5 JS and dependencies -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        $('#installed_pc').select2({
            theme: "bootstrap-5",
            width: '100%',
            placeholder: "Choose anything",
            closeOnSelect: false,
        });
    });
</script>

