<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeNasGroup = isset($_GET['itemTypeNasGroup']) ? $_GET['itemTypeNasGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch unique emails and decrypt passwords
$uniqueEmails = [];
if ($debtorCode && $companyName) {
    try {
        // Fetch emails from item_type_email_citssb where used_at is 'Synology'
        $stmt = $pdo->prepare("
            SELECT email, password 
            FROM item_type_email_citssb 
            WHERE debtor_code = ? 
              AND company_name = ? 
              AND used_at = 'Synology'
        ");
        $stmt->execute([$debtorCode, $companyName]);
        $emails = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Decrypt passwords and store unique emails
        foreach ($emails as $emailData) {
            $email = $emailData['email'];
            $password = decryptPassword($emailData['password'], 'your_secret_key'); // Replace with your actual encryption key
            $uniqueEmails[$email] = $password; // Associative array to handle duplicates
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $login = htmlspecialchars($_POST['login']);
    $password = htmlspecialchars($_POST['password']);
    $backupUserId = htmlspecialchars($_POST['backup_user_id']);
    $backupUserPassword = htmlspecialchars($_POST['backup_user_password']);
    $deviceName = htmlspecialchars($_POST['device_name']);
    $model = htmlspecialchars($_POST['model']);
    $quickconnectId = htmlspecialchars($_POST['quickconnect_id']);
    $hardDiskUnit = isset($_POST['harddisk_unit']) && is_array($_POST['harddisk_unit']) ? implode(',', $_POST['harddisk_unit']) : '';
    $hardDiskSize = isset($_POST['harddisk_size']) && is_array($_POST['harddisk_size']) ? implode(',', $_POST['harddisk_size']) : '';
    $hardDiskSn = isset($_POST['harddisk_sn']) && is_array($_POST['harddisk_sn']) ? implode(',', $_POST['harddisk_sn']) : '';
    $hardDiskRaid = htmlspecialchars($_POST['harddisk_raid']);
    $tcpIp = htmlspecialchars($_POST['tcp_ip']);
    $dmsVersion = htmlspecialchars($_POST['dms_version']);
    $serialNumber = htmlspecialchars($_POST['serial_number']);
    $purchaseDate = htmlspecialchars($_POST['purchase_date']);
    $warrantyExpireDate = htmlspecialchars($_POST['warranty_expire_date']);
    $extendWarranty = htmlspecialchars($_POST['extend_warranty']);
    $physicalBackup = isset($_POST['physical_backup']) ? 1 : 0;
    $fileServer = isset($_POST['file_server']) ? 1 : 0;
    $hyperBackup = isset($_POST['hyper_backup']) ? 1 : 0;
    $synologyDrive = isset($_POST['synology_drive']) ? 1 : 0;
    $activeBackupForGoogle = isset($_POST['active_backup_for_google']) ? 1 : 0;
    $activeBackupForO365 = isset($_POST['active_backup_for_o365']) ? 1 : 0;
    $others = htmlspecialchars($_POST['others']);

    // Retrieve the selected email
    $synologyEmail = htmlspecialchars($_POST['synology_email']);

    // Encrypt the sensitive fields
    $encryptionKey = 'your_secret_key'; // This should be a secure key
    $encryptedPassword = encryptPassword($password, $encryptionKey); // Encrypt password
    $encryptedBackupUserPassword = encryptPassword($backupUserPassword, $encryptionKey); // Encrypt backup user password

    try {
        // Prepare and execute the insert query
        $stmt = $pdo->prepare("INSERT INTO item_type_nas_nas (
            item_type_name,
            item_type_nas_group_name,
            company_name,
            debtor_code,
            active,
            login,
            password,
            backup_user_id,
            backup_user_password,
            device_name,
            model,
            quickconnect_id,
            harddisk_unit,
            harddisk_size,
            harddisk_raid,
            tcp_ip,
            dms_version,
            serial_number,
            harddisk_sn,
            purchase_date,
            warranty_expire_date,
            extend_warranty,
            physical_backup,
            file_server,
            hyper_backup,
            synology_drive,
            active_backup_for_google,
            active_backup_for_o365,
            others,
            synology_email
        ) VALUES (
            :item_type_name,
            :item_type_nas_group_name,
            :company_name,
            :debtor_code,
            :active,
            :login,
            :password,
            :backup_user_id,
            :backup_user_password,
            :device_name,
            :model,
            :quickconnect_id,
            :harddisk_unit,
            :harddisk_size,
            :harddisk_raid,
            :tcp_ip,
            :dms_version,
            :serial_number,
            :harddisk_sn,
            :purchase_date,
            :warranty_expire_date,
            :extend_warranty,
            :physical_backup,
            :file_server,
            :hyper_backup,
            :synology_drive,
            :active_backup_for_google,
            :active_backup_for_o365,
            :others,
            :synology_email
        )");

        // Execute the statement
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':item_type_nas_group_name' => $itemTypeNasGroup,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':active' => $active,
            ':login' => $login,
            ':password' => $encryptedPassword, // Use the encrypted password
            ':backup_user_id' => $backupUserId,
            ':backup_user_password' => $encryptedBackupUserPassword, // Use the encrypted backup user password
            ':device_name' => $deviceName,
            ':model' => $model,
            ':quickconnect_id' => $quickconnectId,
            ':harddisk_unit' => $hardDiskUnit,
            ':harddisk_size' => $hardDiskSize,
            ':harddisk_raid' => $hardDiskRaid,
            ':tcp_ip' => $tcpIp,
            ':dms_version' => $dmsVersion,
            ':serial_number' => $serialNumber,
            ':harddisk_sn' => $hardDiskSn,
            ':purchase_date' => $purchaseDate,
            ':warranty_expire_date' => $warrantyExpireDate,
            ':extend_warranty' => $extendWarranty,
            ':physical_backup' => $physicalBackup,
            ':file_server' => $fileServer,
            ':hyper_backup' => $hyperBackup,
            ':synology_drive' => $synologyDrive,
            ':active_backup_for_google' => $activeBackupForGoogle,
            ':active_backup_for_o365' => $activeBackupForO365,
            ':others' => $others,
            ':synology_email' => $synologyEmail
        ]);

        // Build the log message
        $logMessage = "Item inserted into NAS for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]); 
        
        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display the passed values -->
                <div class="mb-3">
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeNasGroup); ?></strong></p>
                </div>

                <!-- Login and Password -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Login and Password</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="login" id="login" placeholder="Login">
                                    <label for="login">Login</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="password" id="password" placeholder="Password">
                                    <label for="password">Password</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="backup_user_id" id="backup_user_id" placeholder="Backup User ID">
                                    <label for="backup_user_id">Backup User ID</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="backup_user_password" id="backup_user_password" placeholder="Backup User Password">
                                    <label for="backup_user_password">Backup User Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Device and Model -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Device and Model</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="device_name" id="device_name" placeholder="Device Name">
                                    <label for="device_name">Device Name</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="serial_number" id="serial_number" placeholder="Synology Serial Number">
                                    <label for="serial_number">Synology Serial Number</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="model" id="model" placeholder="Model">
                                    <label for="model">Model</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="dms_version" id="dms_version" placeholder="DMS Version">
                                    <label for="dms_version">DMS Version</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Serial Number and Hard Disks -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Hard Disk Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="harddisk_raid" id="harddisk_raid" placeholder="Hard Disk Raid">
                                    <label for="harddisk_raid">Hard Disk Raid</label>
                                </div>
                            </div>
                            <div class="col-md-12">
                                <div id="hardDiskContainer">
                                    <!-- Initial hard disk fields -->
                                    <div class="input-group mb-2">
                                        <div class="form-floating">
                                            <input type="text" class="form-control" name="harddisk_unit[]" id="floatingUnit" placeholder="Unit">
                                            <label for="floatingUnit">Unit</label>
                                        </div>
                                        <div class="form-floating">
                                            <input type="text" class="form-control" name="harddisk_size[]" id="floatingSize" placeholder="Size">
                                            <label for="floatingSize">Size</label>
                                        </div>
                                        <div class="form-floating">
                                            <input type="text" class="form-control" name="harddisk_sn[]" id="floatingSN" placeholder="S/N">
                                            <label for="floatingSN">S/N</label>
                                        </div>
                                        <button type="button" class="btn btn-danger" onclick="removeHardDisk(this)">Remove</button>
                                    </div>
                                </div>
                                <button type="button" class="btn btn-secondary" onclick="addHardDisk()">Add Hard Disk</button>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Hard Disk Raid and TCP/IP -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Network Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="tcp_ip" id="tcp_ip" placeholder="TCP/IP">
                                    <label for="tcp_ip">TCP/IP</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="quickconnect_id" id="quickconnect_id" placeholder="QuickConnect ID">
                                    <label for="quickconnect_id">QuickConnect ID</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- DMS Version and Warranty Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Warranty Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" class="form-control" name="purchase_date" id="purchase_date" placeholder="Purchase Date">
                                    <label for="purchase_date">Purchase Date</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="extend_warranty" id="extend_warranty" placeholder="Extend Warranty">
                                    <label for="extend_warranty">Extend Warranty</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" class="form-control" name="warranty_expire_date" id="warranty_expire_date" placeholder="Warranty Expire Date">
                                    <label for="warranty_expire_date">Warranty Expire Date</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Synology Account -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Synology Account</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-control" id="synology_email" name="synology_email">
                                        <option value="">Select an Email</option>
                                        <?php foreach ($emails as $email): ?>
                                            <option value="<?php echo htmlspecialchars($email['email']); ?>"><?php echo htmlspecialchars($email['email']); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="synology_email">Select Email</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Synology Services -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Synology Services</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-check mb-3">
                                    <input type="checkbox" class="form-check-input" name="physical_backup" id="physical_backup" value="1" <?php if (isset($_POST['physical_backup'])) echo 'checked'; ?>>
                                    <label class="form-check-label" for="physical_backup">Physical Backup</label>
                                </div>
                                <div class="form-check mb-3">
                                    <input type="checkbox" class="form-check-input" name="file_server" id="file_server" value="1" <?php if (isset($_POST['file_server'])) echo 'checked'; ?>>
                                    <label class="form-check-label" for="file_server">File Server</label>
                                </div>
                                <div class="form-check mb-3">
                                    <input type="checkbox" class="form-check-input" name="hyper_backup" id="hyper_backup" value="1" <?php if (isset($_POST['hyper_backup'])) echo 'checked'; ?>>
                                    <label class="form-check-label" for="hyper_backup">Hyper Backup</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-check mb-3">
                                    <input type="checkbox" class="form-check-input" name="synology_drive" id="synology_drive" value="1" <?php if (isset($_POST['synology_drive'])) echo 'checked'; ?>>
                                    <label class="form-check-label" for="synology_drive">Synology Drive</label>
                                </div>
                                <div class="form-check mb-3">
                                    <input type="checkbox" class="form-check-input" name="active_backup_for_google" id="active_backup_for_google" value="1" <?php if (isset($_POST['active_backup_for_google'])) echo 'checked'; ?>>
                                    <label class="form-check-label" for="active_backup_for_google">Active Backup For Google</label>
                                </div>
                                <div class="form-check mb-3">
                                    <input type="checkbox" class="form-check-input" name="active_backup_for_o365" id="active_backup_for_o365" value="1" <?php if (isset($_POST['active_backup_for_o365'])) echo 'checked'; ?>>
                                    <label class="form-check-label" for="active_backup_for_o365">Active Backup For Office 365</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea class="form-control" id="others" name="others" rows="3" placeholder="Others"></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Save</button>
                </div>
            </form>
        </div>
    </div>
</div>

<script>
function addHardDisk() {
    const container = document.getElementById('hardDiskContainer');
    const inputGroup = document.createElement('div');
    inputGroup.className = 'input-group mb-2';

    const unitInput = document.createElement('div');
    unitInput.className = 'form-floating';
    unitInput.innerHTML = `
        <input type="text" class="form-control" name="harddisk_unit[]" id="floatingUnit" placeholder="Unit">
        <label for="floatingUnit">Unit</label>
    `;

    const sizeInput = document.createElement('div');
    sizeInput.className = 'form-floating';
    sizeInput.innerHTML = `
        <input type="text" class="form-control" name="harddisk_size[]" id="floatingSize" placeholder="Size">
        <label for="floatingSize">Size</label>
    `;

    const snInput = document.createElement('div');
    snInput.className = 'form-floating';
    snInput.innerHTML = `
        <input type="text" class="form-control" name="harddisk_sn[]" id="floatingSN" placeholder="S/N">
        <label for="floatingSN">S/N</label>
    `;

    const removeButton = document.createElement('button');
    removeButton.type = 'button';
    removeButton.className = 'btn btn-danger';
    removeButton.textContent = 'Remove';
    removeButton.onclick = function() {
        removeHardDisk(this);
    };

    inputGroup.appendChild(unitInput);
    inputGroup.appendChild(sizeInput);
    inputGroup.appendChild(snInput);
    inputGroup.appendChild(removeButton);
    container.appendChild(inputGroup);
}

function removeHardDisk(button) {
    const inputGroup = button.parentElement;
    if (document.querySelectorAll('#hardDiskContainer .input-group').length === 1) {
        alert('The last field cannot be removed.');
    } else {
        inputGroup.remove();
    }
}
</script>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>

