<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');
// Define the upload directory
$uploadDirectory = '/crm/images/NAS/Active Backup for Google/';

// Ensure the directory exists, if not, create it
if (!is_dir($uploadDirectory)) {
    mkdir($uploadDirectory, 0777, true);
}

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeNasGroup = isset($_GET['itemTypeNasGroup']) ? $_GET['itemTypeNasGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the list of installed PCs from the database
$installedPcs = [];
try {
    $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc");
    $stmt->execute();
    $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $abGDomainForBackup = $_POST['ab_g_domain_for_backup'] ?? null;
    $abGServiceFrom = $_POST['ab_g_service_from'] ?? null;
    $abGServiceToFolder = $_POST['ab_g_service_to_folder'] ?? null;
    $abGServiceSchedule = $_POST['ab_g_service_schedule'] ?? null;
    $abGServiceTime = $_POST['ab_g_service_time'] ?? null;
    $abGPreviousVersionDays = $_POST['ab_g_previous_version_days'] ?? null;
    $abGAcc = $_POST['ab_g_acc'] ?? null;
    $abGTenantId = $_POST['ab_g_tenant_id'] ?? null;
    $abGAppId = $_POST['ab_g_app_id'] ?? null;

    // Handle certificate file upload
    $abGCertificateFile = null;
    if (isset($_FILES['ab_g_certificate_file']) && $_FILES['ab_g_certificate_file']['error'] == 0) {
        $uploadDir = '/crm/images/NAS/Active Backup for Google/';
        $absoluteUploadDir = $_SERVER['DOCUMENT_ROOT'] . $uploadDir;

        // Ensure the directory exists
        if (!is_dir($absoluteUploadDir)) {
            if (!mkdir($absoluteUploadDir, 0777, true)) {
                echo "<script>alert('Failed to create directory. Please check permissions.');</script>";
                exit;
            }
        }

        $uploadFile = $absoluteUploadDir . basename($_FILES['ab_g_certificate_file']['name']);
        $fileType = strtolower(pathinfo($uploadFile, PATHINFO_EXTENSION));

        // Generate a garbled name for the file
        $garbledName = substr(md5(uniqid(rand(), true)), 0, 20) . '.' . $fileType;
        $uploadFile = $absoluteUploadDir . $garbledName;

        // Move the uploaded file to the desired directory
        if (move_uploaded_file($_FILES['ab_g_certificate_file']['tmp_name'], $uploadFile)) {
            $abGCertificateFile = $uploadDir . $garbledName; // Save the relative path in the database
        } else {
            echo "<script>alert('Failed to upload certificate file. Please try again.');</script>";
        }
    }

    try {
        // Prepare and execute the insert query for the new table
        $stmt = $pdo->prepare("INSERT INTO item_type_nas_ab_google (
            item_type_name,
            item_type_nas_group_name,
            company_name,
            debtor_code,
            active,
            ab_g_domain_for_backup,
            ab_g_service_from,
            ab_g_service_to_folder,
            ab_g_service_schedule,
            ab_g_service_time,
            ab_g_previous_version_days,
            ab_g_acc,
            ab_g_tenant_id,
            ab_g_app_id,
            ab_g_certificate_file
        ) VALUES (
            :item_type_name,
            :item_type_nas_group_name,
            :company_name,
            :debtor_code,
            :active,
            :ab_g_domain_for_backup,
            :ab_g_service_from,
            :ab_g_service_to_folder,
            :ab_g_service_schedule,
            :ab_g_service_time,
            :ab_g_previous_version_days,
            :ab_g_acc,
            :ab_g_tenant_id,
            :ab_g_app_id,
            :ab_g_certificate_file
        )");
    
        // Execute the statement
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':item_type_nas_group_name' => $itemTypeNasGroup,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':active' => $active,
            ':ab_g_domain_for_backup' => $abGDomainForBackup,
            ':ab_g_service_from' => $abGServiceFrom,
            ':ab_g_service_to_folder' => $abGServiceToFolder,
            ':ab_g_service_schedule' => $abGServiceSchedule,
            ':ab_g_service_time' => $abGServiceTime,
            ':ab_g_previous_version_days' => $abGPreviousVersionDays,
            ':ab_g_acc' => $abGAcc,
            ':ab_g_tenant_id' => $abGTenantId,
            ':ab_g_app_id' => $abGAppId,
            ':ab_g_certificate_file' => $abGCertificateFile
        ]);
    
        // Log the activity
        $logMessage = "Item inserted into Active Backup for Google for company_name: $companyName";
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);
    
        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST" enctype="multipart/form-data">
                <!-- Display the passed values -->
                <div class="mb-3">
                    <p>Debtor Code: <strong><?php echo htmlspecialchars($debtorCode); ?></strong></p>
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeNasGroup); ?></strong></p>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Active Backup for Google</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_domain_for_backup" id="ab_g_domain_for_backup" placeholder="Active Backup for Google Domain For Backup">
                                    <label for="ab_g_domain_for_backup">Active Backup for Google Domain For Backup</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_service_from" id="ab_g_service_from" placeholder="Active Backup for Google Service From">
                                    <label for="ab_g_service_from">Active Backup for Google Service From</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_service_to_folder" id="ab_g_service_to_folder" placeholder="Active Backup for Google Service To Folder">
                                    <label for="ab_g_service_to_folder">Active Backup for Google Service To Folder</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_service_schedule" id="ab_g_service_schedule" placeholder="Active Backup for Google Service Schedule">
                                    <label for="ab_g_service_schedule">Active Backup for Google Service Schedule</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="time" class="form-control" name="ab_g_service_time" id="ab_g_service_time" placeholder="Active Backup for Google Service Time">
                                    <label for="ab_g_service_time">Active Backup for Google Service Time</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_previous_version_days" id="ab_g_previous_version_days" placeholder="Active Backup for Google Keep Previous Version of Days">
                                    <label for="ab_g_previous_version_days">Active Backup for Google Keep Previous Version of Days</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_acc" id="ab_g_acc" placeholder="Active Backup for Google Account">
                                    <label for="ab_g_acc">Active Backup for Google Account</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_tenant_id" id="ab_g_tenant_id" placeholder="Active Backup for Google Tenant ID">
                                    <label for="ab_g_tenant_id">Active Backup for Google Tenant ID</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_g_app_id" id="ab_g_app_id" placeholder="Active Backup for Google Application ID">
                                    <label for="ab_g_app_id">Active Backup for Google Application ID</label>
                                </div>
                                <div class="mb-3">
                                    <label for="ab_g_certificate_file" class="form-label">Upload Certificate File for Google</label>
                                    <input type="file" class="form-control" name="ab_g_certificate_file" id="ab_g_certificate_file">
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
</body>
</html>

