<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');
// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeNasGroup = isset($_GET['itemTypeNasGroup']) ? $_GET['itemTypeNasGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $abO365ServiceName = $_POST['ab_o365_service_name'] ?? null;    
    $abO365DomainAdminEmailAddress = $_POST['ab_o365_domain_admin_email_address'] ?? null;
    $abO365ServiceToFolder = $_POST['ab_o365_service_to_folder'] ?? null;
    $abO365ServiceSchedule = $_POST['ab_o365_service_schedule'] ?? null;
    $abO365ServiceTime = $_POST['ab_o365_service_time'] ?? null;
    $abO365PreviousVersionDays = $_POST['ab_o365_previous_version_days'] ?? null;
    $abO365Acc = $_POST['ab_o365_acc'] ?? null;
    $abO365TenantId = $_POST['ab_o365_tenant_id'] ?? null;
    $abO365AppId = $_POST['ab_o365_app_id'] ?? null;

    // Handle picture upload
    $abO365Picture = null;
    if (isset($_FILES['ab_o365_picture']) && $_FILES['ab_o365_picture']['error'] == 0) {
        $uploadDir = '/crm/images/NAS/Active Backup for Office 365/';
        $absoluteUploadDir = $_SERVER['DOCUMENT_ROOT'] . $uploadDir;

        // Ensure the directory exists
        if (!is_dir($absoluteUploadDir)) {
            if (!mkdir($absoluteUploadDir, 0777, true)) {
                echo "<script>alert('Failed to create directory. Please check permissions.');</script>";
                exit;
            }
        }

        $uploadFile = $absoluteUploadDir . basename($_FILES['ab_o365_picture']['name']);
        $imageFileType = strtolower(pathinfo($uploadFile, PATHINFO_EXTENSION));

        // Generate a garbled name for the image
        $garbledName = substr(md5(uniqid(rand(), true)), 0, 20) . '.' . $imageFileType;
        $uploadFile = $absoluteUploadDir . $garbledName;

        // Move the uploaded file to the desired directory
        if (move_uploaded_file($_FILES['ab_o365_picture']['tmp_name'], $uploadFile)) {
            $abO365Picture = $uploadDir . $garbledName; // Save the relative path in the database
        } else {
            echo "<script>alert('Failed to upload image. Please try again.');</script>";
        }
    }

    // Handle certificate file upload
    $abO365CertificateFile = null;
    if (isset($_FILES['ab_o365_certificate_file']) && $_FILES['ab_o365_certificate_file']['error'] == 0) {
        $uploadDir = '/crm/images/NAS/Active Backup for Office 365/';
        $absoluteUploadDir = $_SERVER['DOCUMENT_ROOT'] . $uploadDir;

        // Ensure the directory exists
        if (!is_dir($absoluteUploadDir)) {
            if (!mkdir($absoluteUploadDir, 0777, true)) {
                echo "<script>alert('Failed to create directory. Please check permissions.');</script>";
                exit;
            }
        }

        $uploadFile = $absoluteUploadDir . basename($_FILES['ab_o365_certificate_file']['name']);
        $fileType = strtolower(pathinfo($uploadFile, PATHINFO_EXTENSION));

        // Generate a garbled name for the file
        $garbledName = substr(md5(uniqid(rand(), true)), 0, 20) . '.' . $fileType;
        $uploadFile = $absoluteUploadDir . $garbledName;

        // Move the uploaded file to the desired directory
        if (move_uploaded_file($_FILES['ab_o365_certificate_file']['tmp_name'], $uploadFile)) {
            $abO365CertificateFile = $uploadDir . $garbledName; // Save the relative path in the database
        } else {
            echo "<script>alert('Failed to upload certificate file. Please try again.');</script>";
        }
    }
        
    try {
        // Prepare and execute the insert query
        $stmt = $pdo->prepare("INSERT INTO item_type_nas_ab_o365 (
            item_type_name,
            item_type_nas_group_name,
            company_name,
            debtor_code,
            active,
            ab_o365_service_name,
            ab_o365_domain_admin_email_address,
            ab_o365_service_to_folder,
            ab_o365_service_schedule,
            ab_o365_service_time,
            ab_o365_previous_version_days,
            ab_o365_acc,
            ab_o365_tenant_id,
            ab_o365_app_id,
            ab_o365_certificate_file,
            ab_o365_picture
        ) VALUES (
            :item_type_name,
            :item_type_nas_group_name,
            :company_name,
            :debtor_code,
            :active,
            :ab_o365_service_name,
            :ab_o365_domain_admin_email_address,
            :ab_o365_service_to_folder,
            :ab_o365_service_schedule,
            :ab_o365_service_time,
            :ab_o365_previous_version_days,
            :ab_o365_acc,
            :ab_o365_tenant_id,
            :ab_o365_app_id,
            :ab_o365_certificate_file,
            :ab_o365_picture
        )");
    
        // Execute the statement
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':item_type_nas_group_name' => $itemTypeNasGroup,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':active' => $active,
            ':ab_o365_service_name' => $abO365ServiceName,
            ':ab_o365_domain_admin_email_address' => $abO365DomainAdminEmailAddress,
            ':ab_o365_service_to_folder' => $abO365ServiceToFolder,
            ':ab_o365_service_schedule' => $abO365ServiceSchedule,
            ':ab_o365_service_time' => $abO365ServiceTime,
            ':ab_o365_previous_version_days' => $abO365PreviousVersionDays,
            ':ab_o365_acc' => $abO365Acc,
            ':ab_o365_tenant_id' => $abO365TenantId,
            ':ab_o365_app_id' => $abO365AppId,
            ':ab_o365_certificate_file' => $abO365CertificateFile,
            ':ab_o365_picture' => $abO365Picture
        ]);
    
        $logMessage = "Item inserted into Active Backup for Office 365 for company_name: $companyName";
    
        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);
    
        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST" enctype="multipart/form-data">
                <!-- Display the passed values -->
                <div class="mb-3">
                    <p>Debtor Code: <strong><?php echo htmlspecialchars($debtorCode); ?></strong></p>
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeNasGroup); ?></strong></p>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Active Backup for Office 365</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_service_name" id="ab_o365_service_name" placeholder="Active Backup for Office 365 Service Name">
                                    <label for="ab_o365_service_name">Active Backup for Office 365 Service Name</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_domain_admin_email_address" id="ab_o365_domain_admin_email_address" placeholder="Domain Admin Email Address">
                                    <label for="ab_o365_domain_admin_email_address">Domain Admin Email Address</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_service_to_folder" id="ab_o365_service_to_folder" placeholder="Active Backup for Office 365 Service To Folder">
                                    <label for="ab_o365_service_to_folder">Active Backup for Office 365 Service To Folder</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_service_schedule" id="ab_o365_service_schedule" placeholder="Active Backup for Office 365 Service Schedule">
                                    <label for="ab_o365_service_schedule">Active Backup for Office 365 Service Schedule</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="time" class="form-control" name="ab_o365_service_time" id="ab_o365_service_time" placeholder="Active Backup for Office 365 Service Time">
                                    <label for="ab_o365_service_time">Active Backup for Office 365 Service Time</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_previous_version_days" id="ab_o365_previous_version_days" placeholder="Active Backup for Office 365 Keep Previous Version of Days">
                                    <label for="ab_o365_previous_version_days">Active Backup for Office 365 Keep Previous Version of Days</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_acc" id="ab_o365_acc" placeholder="Active Backup for Office 365 Account">
                                    <label for="ab_o365_acc">Active Backup for Office 365 Account</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_tenant_id" id="ab_o365_tenant_id" placeholder="Active Backup for Office 365 Tenant ID">
                                    <label for="ab_o365_tenant_id">Active Backup for Office 365 Tenant ID</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_app_id" id="ab_o365_app_id" placeholder="Active Backup for Office 365 Application ID">
                                    <label for="ab_o365_app_id">Active Backup for Office 365 Application ID</label>
                                </div>
                                <div class="mb-3">
                                    <label for="ab_o365_certificate_file" class="form-label">Upload Certificate File for Office 365</label>
                                    <input type="file" class="form-control" name="ab_o365_certificate_file" id="ab_o365_certificate_file">
                                </div>
                                <div class="mb-3">
                                    <label for="ab_o365_picture" class="form-label">Upload Picture</label>
                                    <input type="file" class="form-control" name="ab_o365_picture" id="ab_o365_picture">
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
</body>
</html>

