<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');
// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeNasGroup = isset($_GET['itemTypeNasGroup']) ? $_GET['itemTypeNasGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the list of installed PCs from the database
$installedPcs = [];
try {
    $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc");
    $stmt->execute();
    $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $hbServiceName = $_POST['hb_service_name'] ?? null;
    $hbServiceFrom = $_POST['hb_service_from'] ?? null;
    $hbServiceToFolder = $_POST['hb_service_to_folder'] ?? null;
    $hbServiceSchedule = $_POST['hb_service_schedule'] ?? null;
    $hbServiceTime = $_POST['hb_service_time'] ?? null;
    $hbServiceRetention = $_POST['hb_service_retention'] ?? null;
    $hbServiceSecSynology = $_POST['hb_service_sec_synology'] ?? null;
    $hbServiceExtHd = $_POST['hb_service_ext_hd'] ?? null;

    try {
        // Prepare and execute the insert query
        $stmt = $pdo->prepare("INSERT INTO item_type_nas_hb (
            item_type_name,
            item_type_nas_group_name,
            company_name,
            debtor_code,
            active,
            hb_service_name,
            hb_service_from,
            hb_service_to_folder,
            hb_service_schedule,
            hb_service_time,
            hb_service_retention,
            hb_service_sec_synology,
            hb_service_ext_hd
        ) VALUES (
            :item_type_name,
            :item_type_nas_group_name,
            :company_name,
            :debtor_code,
            :active,
            :hb_service_name,
            :hb_service_from,
            :hb_service_to_folder,
            :hb_service_schedule,
            :hb_service_time,
            :hb_service_retention,
            :hb_service_sec_synology,
            :hb_service_ext_hd
        )");

        // Execute the statement
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':item_type_nas_group_name' => $itemTypeNasGroup,
            ':active' => $active,
            ':hb_service_name' => $hbServiceName,
            ':hb_service_from' => $hbServiceFrom,
            ':hb_service_to_folder' => $hbServiceToFolder,
            ':hb_service_schedule' => $hbServiceSchedule,
            ':hb_service_time' => $hbServiceTime,
            ':hb_service_retention' => $hbServiceRetention,
            ':hb_service_sec_synology' => $hbServiceSecSynology,
            ':hb_service_ext_hd' => $hbServiceExtHd
        ]);

        $logMessage = "Item inserted into Hyper Backup for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]); 
                
        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display the passed values -->
                <div class="mb-3">
                    <p>Debtor Code: <strong><?php echo htmlspecialchars($debtorCode); ?></strong></p>
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeNasGroup); ?></strong></p>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Hyper Backup</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="hb_service_name" id="hb_service_name" placeholder="Hyper Backup Service Name">
                                    <label for="hb_service_name">Hyper Backup Service Name</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="hb_service_from" id="hb_service_from" placeholder="Hyper Backup Service From">
                                    <label for="hb_service_from">Hyper Backup Service From</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="hb_service_to_folder" id="hb_service_to_folder" placeholder="Hyper Backup Service To Folder">
                                    <label for="hb_service_to_folder">Hyper Backup Service To Folder</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="hb_service_schedule" id="hb_service_schedule" placeholder="Hyper Backup Service Schedule">
                                    <label for="hb_service_schedule">Hyper Backup Service Schedule</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="time" class="form-control" name="hb_service_time" id="hb_service_time" placeholder="Hyper Backup Service Time">
                                    <label for="hb_service_time">Hyper Backup Service Time</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="hb_service_retention" id="hb_service_retention" placeholder="Hyper Backup Service Retention">
                                    <label for="hb_service_retention">Hyper Backup Service Retention</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="hb_service_sec_synology" id="hb_service_sec_synology" placeholder="Second Synology">
                                    <label for="hb_service_sec_synology">Second Synology</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="hb_service_ext_hd" id="hb_service_ext_hd" placeholder="Extend Hard Disk">
                                    <label for="hb_service_ext_hd">Extend Hard Disk</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
</body>
</html>

