<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeNasGroup = isset($_GET['itemTypeNasGroup']) ? $_GET['itemTypeNasGroup'] : 'Active Backup Physical Server'; // Default to "Active Backup Physical Server"
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the list of installed PCs for the selected company based on debtor_code and company_name
$installedPcs = [];
if ($debtorCode && $companyName) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $pbServiceName = $_POST['pb_service_name'] ?? null;
    $pbServiceFrom = $_POST['pb_service_from'] ?? null;
    $pbServiceToFolder = $_POST['pb_service_to_folder'] ?? null;
    $pbServiceSchedule = $_POST['pb_service_schedule'] ?? null;
    $pbServiceTime = $_POST['pb_service_time'] ?? null;
    $pbServiceRetention = $_POST['pb_service_retention'] ?? null;
    $pbInstalledPc = $_POST['pb_installed_pc'] ?? null;

    try {
        // Prepare and execute the insert query for the new table `item_type_nas_pb`
        $stmt = $pdo->prepare("INSERT INTO item_type_nas_pb (
            item_type_name,
            item_type_nas_group_name,
            company_name,
            debtor_code,
            active,
            pb_service_name,
            pb_service_from,
            pb_service_to_folder,
            pb_service_schedule,
            pb_service_time,
            pb_service_retention,
            pb_installed_pc
        ) VALUES (
            :item_type_name,
            :item_type_nas_group_name,
            :company_name,
            :debtor_code,
            :active,
            :pb_service_name,
            :pb_service_from,
            :pb_service_to_folder,
            :pb_service_schedule,
            :pb_service_time,
            :pb_service_retention,
            :pb_installed_pc
        )");

        // Build the log message
        $logMessage = "Item inserted into Active Backup Physical Server for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Execute the statement
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':item_type_nas_group_name' => $itemTypeNasGroup, // Retrieved from URL or default
            ':active' => $active,
            ':pb_service_name' => $pbServiceName,
            ':pb_service_from' => $pbServiceFrom,
            ':pb_service_to_folder' => $pbServiceToFolder,
            ':pb_service_schedule' => $pbServiceSchedule,
            ':pb_service_time' => $pbServiceTime,
            ':pb_service_retention' => $pbServiceRetention,
            ':pb_installed_pc' => $pbInstalledPc
        ]);

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display the passed values -->
                <div class="mb-3">
                    <p>Debtor Code: <strong><?php echo htmlspecialchars($debtorCode); ?></strong></p>
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeNasGroup); ?></strong></p>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Active Backup Physical Server</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="pb_service_name" id="pb_service_name" placeholder="Physical Backup Service Name">
                                    <label for="pb_service_name">Physical Backup Service Name</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="pb_service_from" id="pb_service_from" placeholder="Physical Backup Service From">
                                    <label for="pb_service_from">Physical Backup Service From</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="pb_service_to_folder" id="pb_service_to_folder" placeholder="Physical Backup Service To Folder">
                                    <label for="pb_service_to_folder">Physical Backup Service To Folder</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="pb_service_schedule" id="pb_service_schedule" placeholder="Physical Backup Service Schedule">
                                    <label for="pb_service_schedule">Physical Backup Service Schedule</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="time" class="form-control" name="pb_service_time" id="pb_service_time" placeholder="Physical Backup Service Time">
                                    <label for="pb_service_time">Physical Backup Service Time</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="pb_service_retention" id="pb_service_retention" placeholder="Physical Backup Service Retention">
                                    <label for="pb_service_retention">Physical Backup Service Retention</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <select class="form-select" name="pb_installed_pc" id="pb_installed_pc">
                                        <option value="">Select Installed PC</option>
                                        <?php foreach ($installedPcs as $pc): ?>
                                            <option value="<?php echo htmlspecialchars($pc); ?>"><?php echo htmlspecialchars($pc); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="pb_installed_pc">Physical Backup Installed PC</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
</body>
</html>

