<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeNasGroup = isset($_GET['itemTypeNasGroup']) ? $_GET['itemTypeNasGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the list of installed PCs for the selected company based on debtor_code and company_name
$installedPcs = [];
if ($debtorCode && $companyName) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $sdLoginId = $_POST['sd_login_id'] ?? null;
    $sdLoginPassword = $_POST['sd_login_password'] ?? null;
    $sdBackupUrl = $_POST['sd_backup_url'] ?? null;
    $sdServiceFrom = $_POST['sd_service_from'] ?? null;
    $sdServiceToFolder = $_POST['sd_service_to_folder'] ?? null;
    $sdServiceTime = $_POST['sd_service_time'] ?? null;
    $sdBackupMode = $_POST['sd_backup_mode'] ?? null;
    $sdServiceSchedule = $_POST['sd_service_schedule'] ?? null;
    $sdInstalledPc = $_POST['sd_installed_pc'] ?? null;

    $encryptionKey = 'your_secret_key'; // This should be a secure key
    $encryptedSdLoginPassword = encryptPassword($sdLoginPassword, $encryptionKey);

    try {
        // Prepare and execute the insert query for item_type_nas_sd
        $stmt = $pdo->prepare("INSERT INTO item_type_nas_sd (
            item_type_name,
            item_type_nas_group_name,
            company_name,
            debtor_code,
            active,
            sd_login_id,
            sd_login_password,
            sd_backup_url,
            sd_service_from,
            sd_service_to_folder,
            sd_service_schedule,
            sd_service_time,
            sd_backup_mode,
            sd_installed_pc
        ) VALUES (
            :item_type_name,
            :item_type_nas_group_name,
            :company_name,
            :debtor_code,
            :active,
            :sd_login_id,
            :sd_login_password,
            :sd_backup_url,
            :sd_service_from,
            :sd_service_to_folder,
            :sd_service_schedule,
            :sd_service_time,
            :sd_backup_mode,
            :sd_installed_pc
        )");

        // Execute the statement
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':item_type_nas_group_name' => $itemTypeNasGroup,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':active' => $active,
            ':sd_login_id' => $sdLoginId,
            ':sd_login_password' => $encryptedSdLoginPassword,
            ':sd_backup_url' => $sdBackupUrl,
            ':sd_service_from' => $sdServiceFrom,
            ':sd_service_to_folder' => $sdServiceToFolder,
            ':sd_service_schedule' => $sdServiceSchedule,
            ':sd_service_time' => $sdServiceTime,
            ':sd_backup_mode' => $sdBackupMode,
            ':sd_installed_pc' => $sdInstalledPc
        ]);

        $logMessage = "Item inserted into Synology Drive for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display the passed values -->
                <div class="mb-3">
                    <p>Debtor Code: <strong><?php echo htmlspecialchars($debtorCode); ?></strong></p>
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeNasGroup); ?></strong></p>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Synology Drive</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="sd_login_id" id="sd_login_id" placeholder="Synology Drive Login ID">
                                    <label for="sd_login_id">Synology Drive Login ID</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="sd_login_password" id="sd_login_password" placeholder="Synology Drive Login Password">
                                    <label for="sd_login_password">Synology Drive Login Password</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <select class="form-select" name="sd_installed_pc" id="sd_installed_pc">
                                        <option value="">Select Installed PC</option>
                                        <?php foreach ($installedPcs as $pc): ?>
                                            <option value="<?php echo htmlspecialchars($pc); ?>"><?php echo htmlspecialchars($pc); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="sd_installed_pc">Synology Drive Installed PC</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="sd_backup_url" id="sd_backup_url" placeholder="Synology Drive Backup URL">
                                    <label for="sd_backup_url">Synology Drive Backup URL</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="sd_service_from" id="sd_service_from" placeholder="Synology Drive Service From">
                                    <label for="sd_service_from">Synology Drive Service From</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="sd_service_to_folder" id="sd_service_to_folder" placeholder="Synology Drive Service To Folder">
                                    <label for="sd_service_to_folder">Synology Drive Service To Folder</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="sd_service_schedule" id="sd_service_schedule" placeholder="Synology Drive Service Schedule Start Time">
                                    <label for="sd_service_schedule">Synology Drive Service Schedule Start Time</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="time" class="form-control" name="sd_service_time" id="sd_service_time" placeholder="Synology Drive Service Time">
                                    <label for="sd_service_time">Synology Drive Service Time</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <select class="form-select" name="sd_backup_mode" id="sd_backup_mode">
                                        <option value="Continuous Backup">Continuous Backup</option>
                                        <option value="Manual Backup">Manual Backup</option>
                                        <option value="Schedule Backup">Schedule Backup</option>
                                    </select>
                                    <label for="sd_backup_mode">Synology Drive Backup Mode</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
</body>
</html>

