<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeNetworkGroup = isset($_GET['itemTypeNetworkGroup']) ? $_GET['itemTypeNetworkGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $login = $_POST['login'] ?? null;
    $password = $_POST['password'] ?? null;
    $model = $_POST['model'] ?? null;
    $brand = $_POST['brand'] ?? null;
    $ssid = isset($_POST['ssid']) ? implode(',', $_POST['ssid']) : null; // Implode SSID values
    $ssidKey = isset($_POST['ssid_key']) ? implode(',', $_POST['ssid_key']) : null; // Implode SSID key values
    $tcpIp = $_POST['tcp_ip'] ?? null;
    $serialNumber = $_POST['serial_number'] ?? null;
    $purchaseDate = $_POST['purchase_date'] ?? null;
    $warrantyExpireDate = $_POST['warranty_expire_date'] ?? null;
    $others = $_POST['others'] ?? null;

    // Encrypt the password and SSID key
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $encryptedPassword = encryptPassword($password, $encryptionKey);
    $encryptedSsidKey = encryptPassword($ssidKey, $encryptionKey);
    
    // Decrypt the login password for logging
    $decryptedPassword = decryptPassword($encryptedPassword, $encryptionKey);          
    $decryptedSsidKey = decryptPassword($encryptedSsidKey, $encryptionKey);      

    // Create log message
    $logMessage = "Item inserted into Access Point for company_name: $companyName";

    try {
        // Prepare and execute the insert query for item_type_nw_ap
        $stmt = $pdo->prepare("INSERT INTO item_type_nw_ap (
            item_type_name,
            item_type_nw_group_name,
            company_name,
            debtor_code,
            active,
            login,
            password,
            model,
            brand,
            ssid,
            ssid_key,
            tcp_ip,
            serial_number,
            purchase_date,
            warranty_expire_date,
            others
        ) VALUES (
            :item_type_name,
            :item_type_nw_group_name,
            :company_name,
            :debtor_code,
            :active,
            :login,
            :password,
            :model,
            :brand,
            :ssid,
            :ssid_key,
            :tcp_ip,
            :serial_number,
            :purchase_date,
            :warranty_expire_date,
            :others
        )");

        // Execute the statement
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':item_type_nw_group_name' => $itemTypeNetworkGroup,
            ':debtor_code' => $debtorCode,
            ':active' => $active,
            ':login' => $login,
            ':password' => $encryptedPassword,
            ':model' => $model,
            ':brand' => $brand,
            ':ssid' => $ssid,
            ':ssid_key' => $encryptedSsidKey,
            ':tcp_ip' => $tcpIp,
            ':serial_number' => $serialNumber,
            ':purchase_date' => $purchaseDate,
            ':warranty_expire_date' => $warrantyExpireDate,
            ':others' => $others
        ]);

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]); 

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .form-control-custom {
            max-width: 100%; /* Adjust as needed */
        }
    </style>
</head>
<body>
    <div class="container mt-4">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Confirm and Save Details</h1>
            </div>
            <div class="card-body">
                <form method="POST">
                    <!-- Display the passed values -->
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Network Group: <strong><?php echo htmlspecialchars($itemTypeNetworkGroup); ?></strong></p>

                    <!-- Hardware Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Hardware Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control form-control-custom" name="model" id="model" placeholder="Model">
                                        <label for="model">Model</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control form-control-custom" name="brand" id="brand" placeholder="Brand">
                                        <label for="brand">Brand</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control form-control-custom" name="serial_number" id="serial_number" placeholder="Serial Number">
                                        <label for="serial_number">Serial Number</label>
                                    </div>
                                </div>  
                            </div>
                        </div>
                    </div>

                    <!-- Network Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Login Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control form-control-custom" name="login" id="login" placeholder="Login">
                                        <label for="login">Login</label>
                                    </div>

                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control form-control-custom" name="password" id="password" placeholder="Password">
                                        <label for="password">Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Network Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Network Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control form-control-custom" name="tcp_ip" id="tcp_ip" placeholder="TCP/IP">
                                        <label for="tcp_ip">TCP/IP</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="mb-3">
                                        <div id="ssid-container">
                                            <!-- Initial SSID and Key fields -->
                                            <div class="input-group mb-2">
                                                <div class="form-floating me-2">
                                                    <input type="text" class="form-control form-control-custom" name="ssid[]" id="ssid1" placeholder="SSID">
                                                    <label for="ssid1">SSID</label>
                                                </div>
                                                <div class="form-floating me-2">
                                                    <input type="text" class="form-control form-control-custom" name="ssid_key[]" id="ssid_key1" placeholder="SSID Key">
                                                    <label for="ssid_key1">SSID Key</label>
                                                </div>
                                                <button type="button" class="btn btn-secondary" onclick="addSSIDField()">Add</button>
                                            </div>
                                        </div>
                                    </div>

                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Warranty Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Warranty Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control form-control-custom" name="purchase_date" id="purchase_date" placeholder="Purchase Date">
                                        <label for="purchase_date">Purchase Date</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control form-control-custom" name="warranty_expire_date" id="warranty_expire_date" placeholder="Warranty Expire Date">
                                        <label for="warranty_expire_date">Warranty Expire Date</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Others Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Others Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="form-floating mb-3">
                                        <textarea class="form-control form-control-custom" id="others" name="others" placeholder="Others"></textarea>
                                        <label for="others">Others</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Save Button -->
                    <div class="text-center">
                        <button type="submit" class="btn btn-primary">Save</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        let ssidCounter = 1; // Counter for unique IDs

        function addSSIDField() {
            ssidCounter++; // Increment the counter for unique IDs
            const container = document.getElementById('ssid-container');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <div class="form-floating me-2">
                    <input type="text" class="form-control form-control-custom" name="ssid[]" id="ssid${ssidCounter}" placeholder="SSID">
                    <label for="ssid${ssidCounter}">SSID</label>
                </div>
                <div class="form-floating me-2">
                    <input type="text" class="form-control form-control-custom" name="ssid_key[]" id="ssid_key${ssidCounter}" placeholder="SSID Key">
                    <label for="ssid_key${ssidCounter}">SSID Key</label>
                </div>
                <button type="button" class="btn btn-danger" onclick="removeSSIDField(this)">Remove</button>
            `;
            container.appendChild(newField);
        }

        function removeSSIDField(button) {
            const container = document.getElementById('ssid-container');
            if (container.childElementCount > 1) {
                button.parentElement.remove();
            }
        }
    </script>
</body>
</html>

