<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');
// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeNetworkGroup = isset($_GET['itemTypeNetworkGroup']) ? $_GET['itemTypeNetworkGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch unique emails and decrypt passwords
$uniqueEmails = [];
if ($debtorCode && $companyName) {
    try {
        // Fetch emails from item_type_email_citssb where used_at is 'Fortinet'
        $stmt = $pdo->prepare("
            SELECT email, password 
            FROM item_type_email_citssb 
            WHERE debtor_code = ? 
              AND company_name = ? 
              AND used_at = 'Fortinet'
        ");
        $stmt->execute([$debtorCode, $companyName]);
        $emails = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Decrypt passwords and store unique emails
        foreach ($emails as $emailData) {
            $email = $emailData['email'];
            $password = decryptPassword($emailData['password'], 'your_secret_key'); // Replace with your actual encryption key
            $uniqueEmails[$email] = $password; // Associative array to handle duplicates
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Handle POST request
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $login = $_POST['login'] ?? null;
    $password = $_POST['password'] ?? null;
    $brand = $_POST['brand'] ?? null;
    $model = $_POST['model'] ?? null;
    $tcpIp = $_POST['tcp_ip'] ?? null;
    $externalAccessUrl = $_POST['external_access_url'] ?? null;
    $serialNumber = $_POST['serial_number'] ?? null;
    $allowList = $_POST['allow_list'] ?? [];
    $fullAccessGroup = $_POST['full_access_group'] ?? [];
    $blockAccessGroup = $_POST['block_access_group'] ?? [];
    $limitedAccessGroup = $_POST['limited_access_group'] ?? [];
    $guestGroup = $_POST['guest_group'] ?? [];
    $blockList = $_POST['block_list'] ?? [];
    $ddns = $_POST['ddns'] ?? [];
    $fixTcpIp = $_POST['fix_tcp_ip'] ?? [];
    $networkGroup = $_POST['network_group'] ?? [];
    $openPort = $_POST['open_port'] ?? [];
    $openPortFor = $_POST['open_port_for'] ?? [];
    $forticareUrl = $_POST['forticare_url'] ?? [];
    $forticareId = $_POST['forticare_id'] ?? [];
    $forticarePassword = $_POST['forticare_password'] ?? null;
    $hardwareId = $_POST['hardware_id'] ?? null;
    $forticlientPort = $_POST['forticlient_port'] ?? null;
    $purchaseDate = $_POST['purchase_date'] ?? null;
    $warrantyExpireDate = $_POST['warranty_expire_date'] ?? null;
    $others = $_POST['others'] ?? null;
    $fortinetEmail = $_POST['fortinet_email'] ?? null;

    // Encrypt the password and SSID key
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $encryptedPassword = encryptPassword($password, $encryptionKey);
    $encryptedForticarePassword = encryptPassword($forticarePassword, $encryptionKey);

    // Convert the allow list array into a comma-separated string
    $allowListString = implode(',', $allowList);
    $fullAccessGroupString = implode(',', $fullAccessGroup);
    $blockAccessGroupString = implode(',', $blockAccessGroup);
    $limitedAccessGroupString = implode(',', $limitedAccessGroup);
    $guestGroupString = implode(',', $guestGroup);
    $blockListString = implode(',', $blockList);
    $openPortString = implode(',', $openPort);
    $openPortForString = implode(',', $openPortFor);

    try {
        // Prepare and execute the insert query
        $stmt = $pdo->prepare("INSERT INTO item_type_nw_fw (
            item_type_name,
            item_type_nw_group_name,
            company_name,
            debtor_code,
            active,
            login,
            password,
            brand,
            model,
            tcp_ip,
            external_access_url,
            serial_number,
            allow_list,
            full_access_group,
            block_access_group,
            limited_access_group,
            guest_group,
            block_list,
            ddns,
            fix_tcp_ip,
            network_group,
            open_port,
            open_port_for,
            forticare_url,
            forticare_id,
            forticare_password,
            hardware_id,
            forticlient_port,
            purchase_date,
            warranty_expire_date,
            others,
            fortinet_email
        ) VALUES (
            :item_type_name,
            :item_type_nw_group_name,
            :company_name,
            :debtor_code,
            :active,
            :login,
            :password,
            :brand,
            :model,
            :tcp_ip,
            :external_access_url,
            :serial_number,
            :allow_list,
            :full_access_group,
            :block_access_group,
            :limited_access_group,
            :guest_group,
            :block_list,
            :ddns,
            :fix_tcp_ip,
            :network_group,
            :open_port,
            :open_port_for,
            :forticare_url,
            :forticare_id,
            :forticare_password,
            :hardware_id,
            :forticlient_port,
            :purchase_date,
            :warranty_expire_date,
            :others,
            :fortinet_email
        )");

        // Execute the statement
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':item_type_nw_group_name' => $itemTypeNetworkGroup,
            ':debtor_code' => $debtorCode,
            ':active' => $active,
            ':login' => $login,
            ':password' => $encryptedPassword,
            ':brand' => $brand,
            ':model' => $model,
            ':tcp_ip' => $tcpIp,
            ':external_access_url' => $externalAccessUrl,
            ':serial_number' => $serialNumber,
            ':allow_list' => $allowListString,
            ':full_access_group' => $fullAccessGroupString,
            ':block_access_group' => $blockAccessGroupString,
            ':limited_access_group' => $limitedAccessGroupString,
            ':guest_group' => $guestGroupString,
            ':block_list' => $blockListString,
            ':ddns' => $ddns,
            ':fix_tcp_ip' => $fixTcpIp,
            ':network_group' => $networkGroup,
            ':open_port' => $openPortString,
            ':open_port_for' => $openPortForString,
            ':forticare_url' => $forticareUrl,
            ':forticare_id' => $forticareId,
            ':forticare_password' => $encryptedForticarePassword,
            ':hardware_id' => $hardwareId,
            ':forticlient_port' => $forticlientPort,
            ':purchase_date' => $purchaseDate,
            ':warranty_expire_date' => $warrantyExpireDate,
            ':others' => $others,
            ':fortinet_email' => $fortinetEmail
        ]);

        // Build the log message
        $logMessage = "Item inserted into Firewall for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
        // Debugging: Print the error message
        echo "<pre>" . $e->getMessage() . "</pre>";
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .form-control-custom {
            max-width: 100%; /* Adjust as needed */
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Confirm and Save Details</h1>
            </div>
            <div class="card-body">
                <form method="POST">
                    <!-- Display the passed values -->
                    <div class="mb-3">
                        <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                        <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                        <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                        <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeNetworkGroup); ?></strong></p>
                    </div>

                    <!-- Hardware Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Hardware Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="brand" id="brand" placeholder="Brand">
                                        <label for="brand">Brand</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="serial_number" id="serial_number" placeholder="Serial Number">
                                        <label for="serial_number">Serial Number</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="model" id="model" placeholder="Model">
                                        <label for="model">Model</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="hardware_id" id="hardware_id" placeholder="Hardware ID">
                                        <label for="hardware_id">Hardware ID</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Login Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Login Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="login" id="login" placeholder="Login">
                                        <label for="login">Login</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="password" id="password" placeholder="Password">
                                        <label for="password">Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Network Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Network Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="tcp_ip" id="tcp_ip" placeholder="TCP/IP with Port Number">
                                        <label for="tcp_ip">TCP/IP with Port Number</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="external_access_url" id="external_access_url" placeholder="External Access URL">
                                        <label for="external_access_url">External Access URL</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="ddns" id="ddns" placeholder="DDNS">
                                        <label for="ddns">DDNS</label>
                                    </div>    
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="fix_tcp_ip" id="fix_tcp_ip" placeholder="Fix TCP/IP">
                                        <label for="fix_tcp_ip">Fix TCP/IP</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="forticlient_port" id="forticlient_port" placeholder="Forticlient Port">
                                        <label for="forticlient_port">Forticlient Port</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="network_group" id="network_group" placeholder="Network Group">
                                        <label for="network_group">Network Group</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Open Port and Description</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-12">
                                <!-- Floating Labels for Open Port and Description -->
                                    <div class="mb-3" id="openPortContainer">
                                        <div class="input-group mb-2">
                                            <div class="form-floating me-2">
                                                <input type="text" class="form-control open_port" name="open_port[]" id="open_port" placeholder="Open Port">
                                                <label for="open_port">Open Port</label>
                                            </div>
                                            <div class="form-floating me-2">
                                                <input type="text" class="form-control open_port_for" name="open_port_for[]" id="open_port_for" placeholder="Description">
                                                <label for="open_port_for">Description</label>
                                            </div>
                                            <button type="button" class="btn btn-secondary" onclick="addOpenPort()">Add</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Allow List</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="mb-3" id="allowListContainer">
                                        <label for="allow_list" class="form-label">Allow List:</label>
                                        <div class="input-group mb-2">
                                            <input type="text" class="form-control allow_list" name="allow_list[]">
                                            <button type="button" class="btn btn-secondary" onclick="addAllowList()">Add</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Block Access Group</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="mb-3" id="blockAccessGroupContainer">
                                        <label for="block_access_group" class="form-label">Block Access Group:</label>
                                        <div class="input-group mb-2">
                                            <input type="text" class="form-control block_access_group" name="block_access_group[]">
                                            <button type="button" class="btn btn-secondary" onclick="addBlockAccessGroup()">Add</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Full Access Group</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="mb-3" id="fullAccessGroupContainer">
                                        <label for="full_access_group" class="form-label">Full Access Group:</label>
                                        <div class="input-group mb-2">
                                            <input type="text" class="form-control full_access_group" name="full_access_group[]">
                                            <button type="button" class="btn btn-secondary" onclick="addFullAccessGroup()">Add</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Limited Access Group</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="mb-3" id="limitedAccessGroupContainer">
                                        <label for="limited_access_group" class="form-label">Limited Access Group:</label>
                                        <div class="input-group mb-2">
                                            <input type="text" class="form-control limited_access_group" name="limited_access_group[]">
                                            <button type="button" class="btn btn-secondary" onclick="addLimitedAccessGroup()">Add</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Guest Access Group</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="mb-3" id="guestGroupContainer">
                                        <label for="guest_group" class="form-label">Guest Group:</label>
                                        <div class="input-group mb-2">
                                            <input type="text" class="form-control guest_group" name="guest_group[]">
                                            <button type="button" class="btn btn-secondary" onclick="addGuestGroup()">Add</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Block List</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="mb-3" id="blockListContainer">
                                        <label for="block_list" class="form-label">Block List:</label>
                                        <div class="input-group mb-2">
                                            <input type="text" class="form-control block_list" name="block_list[]">
                                            <button type="button" class="btn btn-secondary" onclick="addBlockList()">Add</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Warranty Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" name="purchase_date" id="purchase_date" placeholder="Purchase Date">
                                        <label for="purchase_date">Purchase Date</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" name="warranty_expire_date" id="warranty_expire_date" placeholder="Warranty Expire Date">
                                        <label for="warranty_expire_date">Warranty Expire Date</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Fortinet Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="forticare_id" id="forticare_id" placeholder="Forticare ID">
                                        <label for="forticare_id">Forticare ID</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="forticare_url" id="forticare_url" placeholder="Forticare URL">
                                        <label for="forticare_url">Forticare URL</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="forticare_password" id="forticare_password" placeholder="Forticare Password">
                                        <label for="forticare_password">Forticare Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Fortinet Email Fields</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <select class="form-control" id="fortinet_email" name="fortinet_email" onchange="fillFortinetCredentials(this.value)">
                                            <option value="">Select an Email</option>
                                            <?php foreach (array_keys($uniqueEmails) as $email): ?>
                                                <option value="<?php echo htmlspecialchars($email); ?>"><?php echo htmlspecialchars($email); ?></option>
                                            <?php endforeach; ?>
                                        </select>
                                        <label for="fortinet_email">Select Email</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="fortinet_email_account" id="fortinet_email_account" placeholder="Fortinet Email Account">
                                        <label for="fortinet_email_account">Fortinet Email Account</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="fortinet_email_password" id="fortinet_email_password" placeholder="Fortinet Email Password">
                                        <label for="fortinet_email_password">Fortinet Email Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Others Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Others Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="form-floating mb-3">
                                        <textarea class="form-control form-control-custom" id="others" name="others" placeholder="Others"></textarea>
                                        <label for="others">Others</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Save Button -->
                    <div class="text-center">
                        <button type="submit" class="btn btn-primary">Save</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.x JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Function to add a new Open Port field
        function addOpenPort() {
            const container = document.getElementById('openPortContainer');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <div class="form-floating me-2">
                    <input type="text" class="form-control open_port" name="open_port[]" placeholder="Open Port">
                    <label>Open Port</label>
                </div>
                <div class="form-floating me-2">
                    <input type="text" class="form-control open_port_for" name="open_port_for[]" placeholder="Description">
                    <label>Description</label>
                </div>
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            `;
            container.appendChild(newField);
        }

        // Function to remove a field
        function removeField(button) {
            button.parentElement.remove();
        }

        // Function to fill Fortinet credentials based on selected email
        function fillFortinetCredentials(fortinetEmail) {
            const emails = <?php echo json_encode($uniqueEmails); ?>;
            const fortinetEmailAccountField = document.getElementById('fortinet_email_account');
            const fortinetEmailPasswordField = document.getElementById('fortinet_email_password');

            const fortinetEmailData = emails[fortinetEmail];
            if (fortinetEmailData) {
                fortinetEmailAccountField.value = fortinetEmail;
                fortinetEmailPasswordField.value = fortinetEmailData; // Use the decrypted password
            } else {
                fortinetEmailAccountField.value = '';
                fortinetEmailPasswordField.value = '';
            }
        }

        // Function to add a new Allow List field
        function addAllowList() {
            const container = document.getElementById('allowListContainer');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <input type="text" class="form-control allow_list" name="allow_list[]">
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            `;
            container.appendChild(newField);
        }

        // Function to add a new Full Access Group field
        function addFullAccessGroup() {
            const container = document.getElementById('fullAccessGroupContainer');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <input type="text" class="form-control full_access_group" name="full_access_group[]">
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            `;
            container.appendChild(newField);
        }

        // Function to add a new Block Access Group field
        function addBlockAccessGroup() {
            const container = document.getElementById('blockAccessGroupContainer');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <input type="text" class="form-control block_access_group" name="block_access_group[]">
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            `;
            container.appendChild(newField);
        }

        // Function to add a new Limited Access Group field
        function addLimitedAccessGroup() {
            const container = document.getElementById('limitedAccessGroupContainer');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <input type="text" class="form-control limited_access_group" name="limited_access_group[]">
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            `;
            container.appendChild(newField);
        }

        // Function to add a new Guest Group field
        function addGuestGroup() {
            const container = document.getElementById('guestGroupContainer');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <input type="text" class="form-control guest_group" name="guest_group[]">
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            `;
            container.appendChild(newField);
        }

        // Function to add a new Block List field
        function addBlockList() {
            const container = document.getElementById('blockListContainer');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <input type="text" class="form-control block_list" name="block_list[]">
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            `;
            container.appendChild(newField);
        }
    </script>
</body>
</html>

