<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeNetworkGroup = isset($_GET['itemTypeNetworkGroup']) ? $_GET['itemTypeNetworkGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $login = $_POST['login'] ?? null;
    $password = $_POST['password'] ?? null;
    $ddns = $_POST['ddns'] ?? null;
    $accountNumber = $_POST['account_number'] ?? null;
    $orderNumber = $_POST['order_number'] ?? null;
    $packet = $_POST['packet'] ?? null;
    $telephoneNo = $_POST['telephone_no'] ?? [];
    $serviceProvider = $_POST['service_provider'] ?? null;
    $others = $_POST['others'] ?? null;

    // Handle file upload
    $garbledName = null; // Initialize garbledName
    if (isset($_FILES["picture"]) && $_FILES["picture"]["error"] == 0) {
        $targetDir = "../../images/ISP/";
        $fileName = basename($_FILES["picture"]["name"]);
        $fileType = strtolower(pathinfo($fileName, PATHINFO_EXTENSION));
        $garbledName = bin2hex(random_bytes(16)) . "." . $fileType; // Generate a garbled name
        $targetFile = $targetDir . $garbledName;

        // Check if the target directory exists, if not create it
        if (!is_dir($targetDir)) {
            mkdir($targetDir, 0755, true);
        }

        // Check if file is an actual image
        $check = getimagesize($_FILES["picture"]["tmp_name"]);
        if ($check !== false) {
            // Move the uploaded file to the target directory
            if (!move_uploaded_file($_FILES["picture"]["tmp_name"], $targetFile)) {
                echo "<script>alert('Failed to upload file. Please try again.');</script>";
                exit;
            }
        } else {
            echo "<script>alert('File is not an image.');</script>";
            exit;
        }
    }

    // Encrypt the password
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $encryptedPassword = encryptPassword($password, $encryptionKey);
    $telephoneNoString = implode(',', $telephoneNo);

    try {
        // Prepare and execute the insert query for item_type_nw_isp
        $stmt = $pdo->prepare("INSERT INTO item_type_nw_isp (
            item_type_name,
            item_type_nw_group_name,
            company_name,
            debtor_code,
            active,
            login,
            password,
            ddns,
            account_number,
            order_number,
            packet,
            telephone_no,
            service_provider,
            others,
            picture
        ) VALUES (
            :item_type_name,
            :item_type_nw_group_name,
            :company_name,
            :debtor_code,
            :active,
            :login,
            :password,
            :ddns,
            :account_number,
            :order_number,
            :packet,
            :telephone_no,
            :service_provider,
            :others,
            :picture
        )");

        // Execute the statement
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':item_type_nw_group_name' => $itemTypeNetworkGroup,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':active' => $active,
            ':login' => $login,
            ':password' => $encryptedPassword,
            ':ddns' => $ddns,
            ':account_number' => $accountNumber,
            ':order_number' => $orderNumber,
            ':packet' => $packet,
            ':telephone_no' => $telephoneNoString,
            ':service_provider' => $serviceProvider,
            ':others' => $others,
            ':picture' => $garbledName
        ]);

        // Build the log message
        $logMessage = "Item inserted into Internet Service Provider for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Confirm and Save Details</h1>
            </div>
            <div class="card-body">
                <form method="POST" enctype="multipart/form-data">
                    <!-- Display the passed values -->
                    <div class="mb-3">
                        <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                        <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                        <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                        <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeNetworkGroup); ?></strong></p>
                    </div>

                    <!-- Login and Password -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Login and Password</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="login" id="login" placeholder="Login">
                                        <label for="login">Login</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="password" id="password" placeholder="Password">
                                        <label for="password">Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- DDNS and Account Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">DDNS and Account Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="ddns" id="ddns" placeholder="DDNS">
                                        <label for="ddns">DDNS</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="account_number" id="account_number" placeholder="Account Number">
                                        <label for="account_number">Account Number</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="service_provider" id="service_provider" placeholder="Service Provider">
                                        <label for="service_provider">Service Provider</label>
                                    </div>    
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="order_number" id="order_number" placeholder="Order Number">
                                        <label for="order_number">Order Number</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="packet" id="packet" placeholder="Packet">
                                        <label for="packet">Packet</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Telephone Numbers -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Telephone Numbers</h5>
                        </div>
                        <div class="card-body">
                            <div class="mb-3" id="telephoneNoContainer">
                                <label for="telephone_no" class="form-label">Telephone Number:</label>
                                <div id="telephone-container">
                                    <!-- Initial Telephone Number field (no remove button) -->
                                    <div class="input-group mb-2">
                                        <div class="form-floating">
                                            <input type="text" class="form-control" name="telephone_no[]" placeholder="Telephone Number">
                                            <label for="telephone_no">Telephone Number</label>
                                        </div>
                                    </div>
                                </div>
                                <button type="button" class="btn btn-secondary mt-2" onclick="addTelephoneField()">Add Another</button>
                            </div>
                        </div>
                    </div>

                    <!-- Upload Picture -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Upload Picture</h5>
                        </div>
                        <div class="card-body">
                            <div class="mb-3">
                                <label for="picture" class="form-label">Upload Picture:</label>
                                <input type="file" class="form-control" name="picture" id="picture">
                            </div>
                        </div>
                    </div>
                    
                    <!-- Service Provider and Others -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Others Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="form-floating mb-3">
                                        <textarea class="form-control" id="others" name="others" placeholder="Others" rows="3"></textarea>
                                        <label for="others">Others</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>



                    <!-- Save Button -->
                    <div class="text-center">
                        <button type="submit" class="btn btn-primary">Save</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script>
        let telephoneCounter = 1; // Counter for unique IDs

        function addTelephoneField() {
            telephoneCounter++; // Increment the counter for unique IDs
            const container = document.getElementById('telephone-container');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <div class="form-floating">
                    <input type="text" class="form-control" name="telephone_no[]" placeholder="Telephone Number">
                    <label for="telephone_no${telephoneCounter}">Telephone Number</label>
                </div>
                <button type="button" class="btn btn-danger" onclick="removeTelephoneField(this)">Remove</button>
            `;
            container.appendChild(newField);
        }

        function removeTelephoneField(button) {
            const container = document.getElementById('telephone-container');
            if (container.childElementCount > 1) {
                button.parentElement.remove();
            }
        }
    </script>

    <!-- Bootstrap JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

