<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeNetworkGroup = isset($_GET['itemTypeNetworkGroup']) ? $_GET['itemTypeNetworkGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch printer models from item_type_hw
$printerModels = [];
if ($debtorCode) {
    try {
        $stmt = $pdo->prepare("SELECT model FROM item_type_hw WHERE item_type_hw_group_name = 'Printer' AND debtor_code = ?");
        $stmt->execute([$debtorCode]);
        $printerModels = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $login = $_POST['login'] ?? null;
    $password = $_POST['password'] ?? null;
    $brand = $_POST['brand'] ?? null;
    $model = $_POST['model'] ?? null;
    $tcpIp = $_POST['tcp_ip'] ?? null;
    $printerModel = $_POST['printer_model'] ?? null;
    $serialNumber = $_POST['serial_number'] ?? null;
    $purchaseDate = $_POST['purchase_date'] ?? null;
    $warrantyExpireDate = $_POST['warranty_expire_date'] ?? null;
    $others = $_POST['others'] ?? null;
    $printServer = $_POST['print_server'] ?? null; // New field

    // Encrypt the password
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $encryptedPassword = encryptPassword($password, $encryptionKey);

    try {
        // Prepare and execute the insert query for item_type_nw_ps
        $stmt = $pdo->prepare("INSERT INTO item_type_nw_ps (
            item_type_name,
            item_type_nw_group_name,
            company_name,
            debtor_code,
            active,
            login,
            password,
            brand,
            model,
            tcp_ip,
            printer_model,
            serial_number,
            purchase_date,
            warranty_expire_date,
            others
        ) VALUES (
            :item_type_name,
            :item_type_nw_group_name,
            :company_name,
            :debtor_code,
            :active,
            :login,
            :password,
            :brand,
            :model,
            :tcp_ip,
            :printer_model,
            :serial_number,
            :purchase_date,
            :warranty_expire_date,
            :others
        )");

        // Execute the statement
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':item_type_nw_group_name' => $itemTypeNetworkGroup,
            ':debtor_code' => $debtorCode,
            ':active' => $active,
            ':login' => $login,
            ':password' => $encryptedPassword,
            ':brand' => $brand,
            ':model' => $model,
            ':tcp_ip' => $tcpIp,
            ':printer_model' => $printerModel,
            ':serial_number' => $serialNumber,
            ':purchase_date' => $purchaseDate,
            ':warranty_expire_date' => $warrantyExpireDate,
            ':others' => $others
        ]);

        // Build the log message
        $logMessage = "Item inserted into Print Server for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Update the print_server field in item_type_hw
        if ($printerModel) {
            $stmt = $pdo->prepare("UPDATE item_type_hw SET print_server = :print_server WHERE model = :model AND debtor_code = :debtor_code");
            $stmt->execute([
                ':print_server' => $model, // Use the model from item_type_nw_ps
                ':model' => $printerModel,
                ':debtor_code' => $debtorCode
            ]);
        }

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert/update error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Confirm and Save Details</h1>
            </div>
            <div class="card-body">
                <form method="POST">
                    <!-- Display the passed values -->
                    <div class="mb-3">
                        <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                        <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                        <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                        <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeNetworkGroup); ?></strong></p>
                    </div>

                    <!-- Hardware Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Hardware Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="brand" id="brand" placeholder="Brand">
                                        <label for="brand">Brand</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="model" id="model" placeholder="Model">
                                        <label for="model">Model</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="serial_number" id="serial_number" placeholder="Serial Number">
                                        <label for="serial_number">Serial Number</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <select class="form-control" name="printer_model" id="printer_model">
                                            <option value="">Select Printer Model</option>
                                            <?php foreach ($printerModels as $model): ?>
                                                <option value="<?php echo htmlspecialchars($model); ?>"><?php echo htmlspecialchars($model); ?></option>
                                            <?php endforeach; ?>
                                        </select>
                                        <label for="printer_model">Printer Model</label>
                                    </div>

                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Login and Password -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Login and Password</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="login" id="login" placeholder="Login">
                                        <label for="login">Login</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="password" id="password" placeholder="Password">
                                        <label for="password">Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Network Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="tcp_ip" id="tcp_ip" placeholder="TCP/IP">
                                        <label for="tcp_ip">TCP/IP</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Warranty Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Warranty Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" name="purchase_date" id="purchase_date" placeholder="Purchase Date">
                                        <label for="purchase_date">Purchase Date</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" name="warranty_expire_date" id="warranty_expire_date" placeholder="Warranty Expire Date">
                                        <label for="warranty_expire_date">Warranty Expire Date</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Others Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Others Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="others" name="others" placeholder="Others" rows="3"></textarea>
                                <label for="others">Others</label>
                            </div>
                        </div>
                    </div>

                    <!-- Hidden input for print_server -->
                    <input type="hidden" name="print_server" id="print_server" value="">

                    <!-- Save Button -->
                    <div class="text-center">
                        <button type="submit" class="btn btn-primary">Save</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <!-- JavaScript to update print_server field -->
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            const printerModelSelect = document.getElementById('printer_model');
            const printServerInput = document.getElementById('print_server');

            printerModelSelect.addEventListener('change', function() {
                printServerInput.value = printerModelSelect.value;
            });
        });
    </script>
</body>
</html>

