<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeNetworkGroup = isset($_GET['itemTypeNetworkGroup']) ? $_GET['itemTypeNetworkGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $login = $_POST['login'] ?? null;
    $password = $_POST['password'] ?? null;
    $model = $_POST['model'] ?? null;
    $tcpIp = $_POST['tcp_ip'] ?? null;
    $ssid = isset($_POST['ssid']) ? implode(',', $_POST['ssid']) : null; // Implode SSID values
    $ssidPwd = isset($_POST['ssid_pwd']) ? implode(',', $_POST['ssid_pwd']) : null; // Implode SSID values
    $serialNumber = $_POST['serial_number'] ?? null;
    $ddns = $_POST['ddns'] ?? null;
    $fixTcpIp = $_POST['fix_tcp_ip'] ?? null;
    $openPort = $_POST['open_port'] ?? [];
    $openPortFor = $_POST['open_port_for'] ?? [];
    $purchaseDate = $_POST['purchase_date'] ?? null;
    $warrantyExpireDate = $_POST['warranty_expire_date'] ?? null;
    $others = $_POST['others'] ?? null;

    // Encrypt the password and SSID pwd
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $encryptedPassword = encryptPassword($password, $encryptionKey);
    $encryptedSsidPwd = encryptPassword($ssidPwd, $encryptionKey);
    $decryptedPassword = decryptPassword($encryptedPassword, $encryptionKey);    
    $decryptedSsidPassword = decryptPassword($encryptedSsidPwd, $encryptionKey);    

    $openPortString = implode(',', $openPort);
    $openPortForString = implode(',', $openPortFor);
        
    try {
        // Prepare and execute the insert query
        $stmt = $pdo->prepare("INSERT INTO item_type_nw_router (
            item_type_name,
            item_type_nw_group_name,
            company_name,
            debtor_code,
            active,
            login,
            password,
            model,
            tcp_ip,
            ssid,
            ssid_pwd,
            serial_number,
            ddns,
            fix_tcp_ip,
            open_port,
            open_port_for,
            purchase_date,
            warranty_expire_date,
            others
        ) VALUES (
            :item_type_name,
            :item_type_nw_group_name,
            :company_name,
            :debtor_code,
            :active,
            :login,
            :password,
            :model,
            :tcp_ip,
            :ssid,
            :ssid_pwd,
            :serial_number,
            :ddns,
            :fix_tcp_ip,
            :open_port,
            :open_port_for,
            :purchase_date,
            :warranty_expire_date,
            :others
        )");

        // Execute the statement
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':item_type_nw_group_name' => $itemTypeNetworkGroup,
            ':debtor_code' => $debtorCode,
            ':active' => $active,
            ':login' => $login,
            ':password' => $encryptedPassword,
            ':model' => $model,
            ':tcp_ip' => $tcpIp,
            ':ssid' => $ssid,
            ':ssid_pwd' => $encryptedSsidPwd,
            ':serial_number' => $serialNumber,
            ':ddns' => $ddns,
            ':fix_tcp_ip' => $fixTcpIp,
            ':open_port' => $openPortString,
            ':open_port_for' => $openPortForString,
            ':purchase_date' => $purchaseDate,
            ':warranty_expire_date' => $warrantyExpireDate,
            ':others' => $others
        ]);

        // Build the log message
        $logMessage = "Item inserted into Router for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]); 
                
        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-4">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Confirm and Save Details</h1>
            </div>
            <div class="card-body">
                <form method="POST">
                    <div class="mb-3">
                        <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                        <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                        <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                        <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeNetworkGroup); ?></strong></p>
                    </div>

                    <!-- Login and Password -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Login and Password</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="login" name="login" placeholder="Login">
                                        <label for="login">Login</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="password" name="password" placeholder="Password">
                                        <label for="password">Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Network Information Card -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Network Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <!-- TCP/IP Field -->
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="tcp_ip" name="tcp_ip" placeholder="TCP/IP">
                                        <label for="tcp_ip">TCP/IP</label>
                                    </div>
                                </div>

                                <!-- DDNS Field -->
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="ddns" name="ddns" placeholder="DDNS">
                                        <label for="ddns">DDNS</label>
                                    </div>
                                </div>

                                <!-- Fix TCP/IP Field -->
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="fix_tcp_ip" name="fix_tcp_ip" placeholder="Fix TCP/IP">
                                        <label for="fix_tcp_ip">Fix TCP/IP</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Hardware Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Hardware Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="model" name="model" placeholder="Model">
                                        <label for="model">Model</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="serial_number" name="serial_number" placeholder="Serial Number">
                                        <label for="serial_number">Serial Number</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- SSID Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">SSID Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-group mb-3">
                                <label for="ssid-container">SSID and SSID Pwd:</label>
                                <div id="ssid-container">
                                    <!-- Initial Row -->
                                    <div class="input-group mb-2">
                                        <div class="form-floating flex-grow-1">
                                            <input type="text" class="form-control" name="ssid[]" placeholder="SSID">
                                            <label>SSID</label>
                                        </div>
                                        <div class="form-floating flex-grow-1">
                                            <input type="text" class="form-control" name="ssid_pwd[]" placeholder="SSID Pwd">
                                            <label>SSID Pwd</label>
                                        </div>
                                        <button type="button" class="btn btn-danger" onclick="removeSSIDField(this)">Remove</button>
                                    </div>
                                </div>
                                <div class="text-left">
                                    <button type="button" class="btn btn-secondary" onclick="addSSIDField()">Add</button>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Open Port Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Open Port Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-group mb-3">
                                <label for="openPortContainer">Open Port and Description:</label>
                                <div id="openPortContainer">
                                    <!-- Initial Row -->
                                    <div class="input-group mb-2">
                                        <div class="form-floating flex-grow-1">
                                            <input type="text" class="form-control open_port" name="open_port[]" placeholder="Enter Open Port">
                                            <label>Open Port</label>
                                        </div>
                                        <div class="form-floating flex-grow-1">
                                            <input type="text" class="form-control open_port_for" name="open_port_for[]" placeholder="Enter Open Port Description">
                                            <label>Description</label>
                                        </div>
                                        <button type="button" class="btn btn-danger" onclick="removeOpenPortField(this)">Remove</button>
                                    </div>
                                </div>
                                <div class="text-left">
                                    <button type="button" class="btn btn-success" onclick="addOpenPortField()">Add</button>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Warranty Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Warranty Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" id="purchase_date" name="purchase_date">
                                        <label for="purchase_date">Purchase Date</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" id="warranty_expire_date" name="warranty_expire_date">
                                        <label for="warranty_expire_date">Warranty Expire Date</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Others Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Others Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="others" name="others" rows="3" placeholder="Others"></textarea>
                                <label for="others">Others</label>
                            </div>
                        </div>
                    </div>

                    <!-- Save Button -->
                    <div class="text-center">
                        <button type="submit" class="btn btn-primary">Save</button>
                        <a href="add_config_info.php" class="btn btn-secondary">Cancel</a>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.x JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        function addSSIDField() {
            const container = document.getElementById('ssid-container');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <div class="form-floating flex-grow-1">
                    <input type="text" class="form-control" name="ssid[]" placeholder="SSID">
                    <label>SSID</label>
                </div>
                <div class="form-floating flex-grow-1">
                    <input type="text" class="form-control" name="ssid_pwd[]" placeholder="SSID Pwd">
                    <label>SSID Pwd</label>
                </div>
                <button type="button" class="btn btn-danger" onclick="removeSSIDField(this)">Remove</button>
            `;
            // Append the new field to the end of the container
            container.appendChild(newField);
        }

        function removeSSIDField(button) {
            const container = document.getElementById('ssid-container');
            if (container.childElementCount > 1) { // Ensure there's more than one field
                button.parentElement.remove();
            } else {
                alert("The last field cannot be removed.");
            }
        }

        function addOpenPortField() {
        const container = document.getElementById('openPortContainer');
        const newField = document.createElement('div');
        newField.className = 'input-group mb-2';
        newField.innerHTML = `
            <div class="form-floating flex-grow-1">
                <input type="text" class="form-control open_port" name="open_port[]" placeholder="Enter Open Port">
                <label>Open Port</label>
            </div>
            <div class="form-floating flex-grow-1">
                <input type="text" class="form-control open_port_for" name="open_port_for[]" placeholder="Enter Open Port Description">
                <label>Description</label>
            </div>
            <button type="button" class="btn btn-danger" onclick="removeOpenPortField(this)">Remove</button>
        `;
        // Append the new field to the end of the container
        container.appendChild(newField);
    }

        function removeOpenPortField(button) {
            const container = document.getElementById('openPortContainer');
            if (container.childElementCount > 1) { // Ensure there's more than one field
                button.parentElement.remove();
            } else {
                alert("The last field cannot be removed.");
            }
        }
    </script>
</body>
</html>

