<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeNetworkGroup = isset($_GET['itemTypeNetworkGroup']) ? $_GET['itemTypeNetworkGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the list of installed PCs for the selected company based on debtor_code and company_name
$installedPcs = [];
if ($debtorCode && $companyName) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $vpnType = $_POST['vpn_type'] ?? null;
    $forticlientUsername = $_POST['forticlient_username'] ?? null;
    $forticlientLogin = $_POST['forticlient_login'] ?? null;
    $forticlientPassword = $_POST['forticlient_password'] ?? null;
    $ciscoMerakiUsername = $_POST['cisco_meraki_username'] ?? null;
    $ciscoMerakiLogin = $_POST['cisco_meraki_login'] ?? null;
    $ciscoMerakiPassword = $_POST['cisco_meraki_password'] ?? null;
    $radminTcpIp = $_POST['radmin_tcp_ip'] ?? null;
    $radminNetworkGroup = $_POST['radmin_network_group'] ?? null;
    $radminPassword = $_POST['radmin_password'] ?? null;
    $radminMasterHost = $_POST['radmin_master_host'] ?? null;
    $hamachiTcpIp = $_POST['hamachi_tcp_ip'] ?? null;
    $hamachiNetworkGroup = $_POST['hamachi_network_group'] ?? null;
    $hamachiMasterHost = $_POST['hamachi_master_host'] ?? null;
    $installedPc = $_POST['installed_pc'] ?? null;
    $others = $_POST['others'] ?? null;

    // Encrypt the password and SSID key
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

    // Check if the password fields are empty before encrypting
    $encryptedForticlientPassword = !empty($forticlientPassword) ? encryptPassword($forticlientPassword, $encryptionKey) : null;
    $encryptedCiscoMerakiPassword = !empty($ciscoMerakiPassword) ? encryptPassword($ciscoMerakiPassword, $encryptionKey) : null;
    $encryptedRadminPassword = !empty($radminPassword) ? encryptPassword($radminPassword, $encryptionKey) : null;

    try {
        // Prepare and execute the insert query for the new table `item_type_nw_vpn`
        $stmt = $pdo->prepare("INSERT INTO item_type_nw_vpn (
            item_type_name,
            item_type_nw_group_name,
            company_name,
            debtor_code,
            active,
            vpn_type,
            forticlient_username,
            forticlient_login,
            forticlient_password,
            cisco_meraki_username,
            cisco_meraki_login,
            cisco_meraki_password,
            radmin_tcp_ip,
            radmin_network_group,
            radmin_password,
            radmin_master_host,
            hamachi_tcp_ip,
            hamachi_network_group,
            hamachi_master_host,
            installed_pc,
            others
        ) VALUES (
            :item_type_name,
            :item_type_nw_group_name,
            :company_name,
            :debtor_code,
            :active,
            :vpn_type,
            :forticlient_username,
            :forticlient_login,
            :forticlient_password,
            :cisco_meraki_username,
            :cisco_meraki_login,
            :cisco_meraki_password,
            :radmin_tcp_ip,
            :radmin_network_group,
            :radmin_password,
            :radmin_master_host,
            :hamachi_tcp_ip,
            :hamachi_network_group,
            :hamachi_master_host,
            :installed_pc,
            :others
        )");

        // Execute the statement
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':item_type_nw_group_name' => $itemTypeNetworkGroup,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':active' => $active,
            ':vpn_type' => $vpnType,
            ':forticlient_username' => $forticlientUsername,
            ':forticlient_login' => $forticlientLogin,
            ':forticlient_password' => $encryptedForticlientPassword,
            ':cisco_meraki_username' => $ciscoMerakiUsername,
            ':cisco_meraki_login' => $ciscoMerakiLogin,
            ':cisco_meraki_password' => $encryptedCiscoMerakiPassword,
            ':radmin_tcp_ip' => $radminTcpIp,
            ':radmin_network_group' => $radminNetworkGroup,
            ':radmin_password' => $encryptedRadminPassword,
            ':radmin_master_host' => $radminMasterHost,
            ':hamachi_tcp_ip' => $hamachiTcpIp,
            ':hamachi_network_group' => $hamachiNetworkGroup,
            ':hamachi_master_host' => $hamachiMasterHost,
            ':installed_pc' => $installedPc,
            ':others' => $others
        ]);

        // Build the log message
        $logMessage = "Item inserted into VPN for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Confirm and Save Details</h1>
            </div>
            <div class="card-body">
                <form method="POST">
                    <!-- Display the passed values -->
                    <div class="row mb-3">
                        <div class="col-12">
                            <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                            <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                            <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                            <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeNetworkGroup); ?></strong></p>
                        </div>
                    </div>

                    <!-- VPN Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">VPN Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row mb-3">
                                <div class="col-12">
                                    <label for="vpn_type" class="form-label">Select VPN Type:</label>
                                    <select class="form-control" id="vpn_type" name="vpn_type">
                                        <option value="">Select VPN Type</option>
                                        <option value="forticlient">FortiClient</option>
                                        <option value="cisco_meraki">Cisco Meraki</option>
                                        <option value="radmin">Radmin</option>
                                        <option value="hamachi">Hamachi</option>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- FortiClient VPN Configuration -->
                    <div class="card mb-3" id="forticlient_form" style="display: none;">
                        <div class="card-header">
                            FortiClient VPN Configuration
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="forticlient_username" id="forticlient_username" placeholder="FortiClient Username">
                                        <label for="forticlient_username">FortiClient Username</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="forticlient_login" id="forticlient_login" placeholder="FortiClient Login">
                                        <label for="forticlient_login">FortiClient Login</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="forticlient_password" id="forticlient_password" placeholder="FortiClient Password">
                                        <label for="forticlient_password">FortiClient Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Cisco Meraki VPN Configuration -->
                    <div class="card mb-3" id="cisco_meraki_form" style="display: none;">
                        <div class="card-header">
                            Cisco Meraki VPN Configuration
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="cisco_meraki_username" id="cisco_meraki_username" placeholder="Cisco Meraki Username">
                                        <label for="cisco_meraki_username">Cisco Meraki Username</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="cisco_meraki_login" id="cisco_meraki_login" placeholder="Cisco Meraki Login">
                                        <label for="cisco_meraki_login">Cisco Meraki Login</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="cisco_meraki_password" id="cisco_meraki_password" placeholder="Cisco Meraki Password">
                                        <label for="cisco_meraki_password">Cisco Meraki Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Radmin VPN Configuration -->
                    <div class="card mb-3" id="radmin_form" style="display: none;">
                        <div class="card-header">
                            Radmin VPN Configuration
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="radmin_tcp_ip" id="radmin_tcp_ip" placeholder="Radmin TCP/IP">
                                        <label for="radmin_tcp_ip">Radmin TCP/IP</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="radmin_network_group" id="radmin_network_group" placeholder="Radmin Network Group">
                                        <label for="radmin_network_group">Radmin Network Group</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="radmin_password" id="radmin_password" placeholder="Radmin Password">
                                        <label for="radmin_password">Radmin Password</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="radmin_master_host" id="radmin_master_host" placeholder="Radmin Master Host">
                                        <label for="radmin_master_host">Radmin Master Host</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Hamachi VPN Configuration -->
                    <div class="card mb-3" id="hamachi_form" style="display: none;">
                        <div class="card-header">
                            Hamachi VPN Configuration
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="hamachi_tcp_ip" id="hamachi_tcp_ip" placeholder="Hamachi TCP/IP">
                                        <label for="hamachi_tcp_ip">Hamachi TCP/IP</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="hamachi_network_group" id="hamachi_network_group" placeholder="Hamachi Network Group">
                                        <label for="hamachi_network_group">Hamachi Network Group</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="hamachi_master_host" id="hamachi_master_host" placeholder="Hamachi Master Host">
                                        <label for="hamachi_master_host">Hamachi Master Host</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- PC Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">PC Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row mb-3">
                                <div class="col-12">
                                    <label for="installed_pc" class="form-label">Installed PC:</label>
                                    <select class="form-control" id="installed_pc" name="installed_pc">
                                        <option value="">Select Installed PC</option>
                                        <?php foreach ($installedPcs as $pc): ?>
                                            <option value="<?php echo htmlspecialchars($pc); ?>"><?php echo htmlspecialchars($pc); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Others Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Others Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row mb-3">
                                <div class="col-12">
                                    <div class="form-floating mb-3">
                                        <textarea class="form-control" id="others" name="others" placeholder="Others" rows="3"></textarea>
                                        <label for="others">Others</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Save Button -->
                    <div class="row">
                        <div class="col-12">
                            <button type="submit" class="btn btn-primary" id="saveButton" style="float: left;">Save</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        $(document).ready(function() {
            $('#vpn_type').change(function() {
                // Hide all forms
                $('#forticlient_form').hide();
                $('#cisco_meraki_form').hide();
                $('#radmin_form').hide();
                $('#hamachi_form').hide();

                // Show the selected form
                var selectedVpn = $(this).val();
                if (selectedVpn) {
                    $('#' + selectedVpn + '_form').show();
                }

                // Enable or disable the Save button based on VPN type and installed PC
                checkSaveButton();
            }).change(); // Trigger change event to initialize the form visibility

            $('#installed_pc').change(function() {
                checkSaveButton();
            });

            function checkSaveButton() {
                var vpnType = $('#vpn_type').val();
                var installedPc = $('#installed_pc').val();
                if (vpnType && installedPc) {
                    $('#saveButton').prop('disabled', false);
                } else {
                    $('#saveButton').prop('disabled', true);
                }
            }
        });
    </script>
</body>
</html>

