<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypePcGroup = isset($_GET['itemTypePcGroup']) ? $_GET['itemTypePcGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Directly get debtor_code from URL

// Fetch customer usernames based on debtor_code and company_name
$customerUsernames = [];
if (!empty($debtorCode) && !empty($companyName)) {
    $stmt = $pdo->prepare("SELECT customer_username FROM customer_info WHERE debtor_code = :debtor_code AND company_name = :company_name");
    $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
    $customerUsernames = $stmt->fetchAll(PDO::FETCH_COLUMN);
}

// Fetch client_account_id from item_type_sw_o365_client table for 365 Licence dropdown
$clientAccountIds = [];
if (!empty($companyName) && !empty($debtorCode)) {
    $stmt = $pdo->prepare("SELECT client_account_id FROM item_type_sw_o365_client WHERE company_name = :company_name AND debtor_code = :debtor_code AND item_type_sw_group_name = 'Office 365 Client Account'");
    $stmt->execute([':company_name' => $companyName, ':debtor_code' => $debtorCode]);
    $clientAccountIds = $stmt->fetchAll(PDO::FETCH_COLUMN);
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1;
    $processor = $_POST['processor'] ?? '';
    $hardDiskType = $_POST['harddisk_type'] ?? [];
    $hardDiskSpace = $_POST['harddisk_space'] ?? [];
    $hardDiskTotalUnit = $_POST['harddisk_total_unit'] ?? '';
    $ramType = $_POST['ram_type'] ?? '';
    $ramGb = $_POST['ram_gb'] ?? '';
    $ramTotalUnit = $_POST['ram_total_unit'] ?? '';
    $computerName = $_POST['computer_name'] ?? '';
    $domain = $_POST['domain'] ?? '';
    $loginId = $_POST['login_id'] ?? '';
    $loginPassword = $_POST['login_password'] ?? '';
    $customerUsername = $_POST['customer_username'] ?? '';
    $osVersion = $_POST['os_version'] ?? '';
    $tcpIp = $_POST['tcp_ip'] ?? '';
    $subnetMask = $_POST['subnet_mask'] ?? '';
    $gateway = $_POST['gateway'] ?? '';
    $dns = $_POST['dns'] ?? '';
    $installedSoftware = $_POST['installed_software'] ?? '';
    $partNo = $_POST['part_no'] ?? '';
    $serialNumber = $_POST['serial_number'] ?? '';
    $purchaseDate = $_POST['purchase_date'] ?? '';
    $warrantyExpireDate = $_POST['warranty_expire_date'] ?? '';
    $userEmail = $_POST['user_email'] ?? ''; // Ensure user_email is treated as a single string
    $office365 = $_POST['office_365'] ?? '';
    $antivirus = $_POST['antivirus'] ?? '';
    $installedPrinter = $_POST['installed_printer'] ?? '';
    $vpn = $_POST['vpn'] ?? '';
    $others = $_POST['others'] ?? '';
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included
    $pcEmailAccount = htmlspecialchars($_POST['pc_email_account']);
    $pcEmailPassword = htmlspecialchars($_POST['pc_email_password']);
    $pin = htmlspecialchars($_POST['pin']);

    // New fields from the HTML form
    $brand = $_POST['brand'] ?? '';
    $model = $_POST['model'] ?? '';
    $windowsProductKey = $_POST['windows_product_key'] ?? '';

    $hardDiskTypeString = implode(',', $hardDiskType);
    $hardDiskSpaceString = implode(',', $hardDiskSpace);

    $encryptionKey = 'your_secret_key'; // This should be a secure key

    // Encrypt sensitive fields
    $encryptedLoginPassword = encryptPassword($loginPassword, $encryptionKey);
    $encryptedPcEmailPassword = encryptPassword($pcEmailPassword, $encryptionKey);
    $encryptedWindowsProductKey = encryptPassword($windowsProductKey, $encryptionKey);

    try {
        // Prepare and execute the insert query
        $stmt = $pdo->prepare("INSERT INTO item_type_pc (
            item_type_name, 
            company_name,
            debtor_code,
            item_type_pc_group_name, 
            active,
            processor,
            harddisk_type,
            harddisk_space,
            harddisk_total_unit,
            ram_type,
            ram_gb,
            ram_total_unit,
            computer_name,
            domain,
            login_id,
            login_password,
            customer_username,
            os_version,
            tcp_ip,
            subnet_mask,
            gateway,
            dns,
            installed_software,
            part_no,
            serial_number,
            purchase_date,
            warranty_expire_date,
            user_email,
            office_365,
            antivirus,
            installed_printer,
            vpn,
            others,
            pc_email_account,
            pc_email_password,
            pin,
            brand, -- Added field
            model, -- Added field
            windows_product_key -- Added field
        ) VALUES (
            :item_type_name, 
            :company_name,
            :debtor_code,
            :item_type_pc_group_name,
            :active,
            :processor,
            :harddisk_type,
            :harddisk_space,
            :harddisk_total_unit,
            :ram_type,
            :ram_gb,
            :ram_total_unit,
            :computer_name,
            :domain,
            :login_id,
            :login_password,
            :customer_username,
            :os_version,
            :tcp_ip,
            :subnet_mask,
            :gateway,
            :dns,
            :installed_software,
            :part_no,
            :serial_number,
            :purchase_date,
            :warranty_expire_date,
            :user_email,
            :office_365,
            :antivirus,
            :installed_printer,
            :vpn,
            :others,
            :pc_email_account,
            :pc_email_password,
            :pin,
            :brand, -- Added field
            :model, -- Added field
            :windows_product_key -- Added field
        )");

        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':item_type_pc_group_name' => $itemTypePcGroup,
            ':active' => $active,
            ':processor' => $processor,
            ':harddisk_type' => $hardDiskTypeString,
            ':harddisk_space' => $hardDiskSpaceString,
            ':harddisk_total_unit' => $hardDiskTotalUnit,
            ':ram_type' => $ramType,
            ':ram_gb' => $ramGb,
            ':ram_total_unit' => $ramTotalUnit,
            ':computer_name' => $computerName,
            ':domain' => $domain,
            ':login_id' => $loginId,
            ':login_password' => $encryptedLoginPassword,
            ':customer_username' => $customerUsername,
            ':os_version' => $osVersion,
            ':tcp_ip' => $tcpIp,
            ':subnet_mask' => $subnetMask,
            ':gateway' => $gateway,
            ':dns' => $dns,
            ':installed_software' => $installedSoftware,
            ':part_no' => $partNo,
            ':serial_number' => $serialNumber,
            ':purchase_date' => $purchaseDate,
            ':warranty_expire_date' => $warrantyExpireDate,
            ':user_email' => $userEmail,
            ':office_365' => $office365,
            ':antivirus' => $antivirus,
            ':installed_printer' => $installedPrinter,
            ':vpn' => $vpn,
            ':others' => $others,
            ':pc_email_account' => $pcEmailAccount,
            ':pc_email_password' => $encryptedPcEmailPassword,
            ':pin' => $pin,
            ':brand' => $brand, // Added field
            ':model' => $model, // Added field
            ':windows_product_key' => $encryptedWindowsProductKey // Added field
        ]);

        // Get the last inserted ID (item_type_pc_id)
        $itemTypePcId = $pdo->lastInsertId();

        // Insert into installed_pc_for_office365_client table
        if (!empty($office365)) {
            // Fetch item_type_sw_o365_client_id and client_account_id based on the selected Office 365 license
            $stmtSw = $pdo->prepare("SELECT item_type_sw_o365_client_id, client_account_id FROM item_type_sw_o365_client WHERE client_account_id = :o365_license");
            $stmtSw->execute([':o365_license' => $office365]);
            $itemTypeSw = $stmtSw->fetch(PDO::FETCH_ASSOC);

            if ($itemTypeSw) {
                $stmtLink = $pdo->prepare("INSERT INTO installed_pc_for_office365_client (
                    item_type_pc_id, debtor_code, company_name, computer_name, o365_license, item_type_sw_o365_client_id, client_account_id
                ) VALUES (
                    :item_type_pc_id, :debtor_code, :company_name, :computer_name, :o365_license, :item_type_sw_o365_client_id, :client_account_id
                )");
                $stmtLink->execute([
                    ':item_type_pc_id' => $itemTypePcId,
                    ':debtor_code' => $debtorCode,
                    ':company_name' => $companyName,
                    ':computer_name' => $computerName,
                    ':o365_license' => $office365,
                    ':item_type_sw_o365_client_id' => $itemTypeSw['item_type_sw_o365_client_id'],
                    ':client_account_id' => $itemTypeSw['client_account_id']
                ]);
            }
        }

        $logMessage = "Desktop/Laptop inserted into Desktop/Laptop for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Company Name and Item Details -->
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypePcGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                <!-- Customer Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Customer Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select name="customer_username" id="customer_username" class="form-select">
                                        <option value="">Select Customer Username</option>
                                        <?php foreach ($customerUsernames as $username): ?>
                                            <option value="<?php echo htmlspecialchars($username); ?>"><?php echo htmlspecialchars($username); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="customer_username">Customer Username</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Hardware Specifications Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Hardware Specifications</h5>
                    </div>
                    <div class="card-body">
                        <div class="card mb-3">
                            <div class="card-header">
                                <h5 class="mb-0">Brand and Model</h5>
                            </div>
                            <div class="card-body">
                                <div class="row g-3">
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="brand" id="brand" class="form-control" placeholder="Brand">
                                            <label for="brand">Brand</label>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="serial_number" id="serial_number" class="form-control" placeholder="Serial Number">
                                            <label for="serial_number">Serial Number</label>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="model" id="model" class="form-control" placeholder="Model">
                                            <label for="model">Model</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <!-- Processor Card -->
                        <div class="card mb-3">
                            <div class="card-header">
                                <h6 class="mb-0">Processor</h6>
                            </div>
                            <div class="card-body">
                                <div class="row g-3">
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="processor" id="processor" class="form-control" placeholder="Processor">
                                            <label for="processor">Processor</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <!-- Hard Disk Card -->
                        <div class="card mb-3">
                            <div class="card-header">
                                <h6 class="mb-0">Hard Disk</h6>
                            </div>
                            <div class="card-body">
                                <div class="row g-3">
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="harddisk_total_unit" id="harddisk_total_unit" class="form-control" placeholder="Hard Disk Total Unit">
                                            <label for="harddisk_total_unit">Hard Disk Total Unit</label>
                                        </div>
                                    </div>
                                    <div class="col-md-12">
                                        <div class="input-group">
                                            <div class="form-floating">
                                                <input type="text" name="harddisk_type[]" class="form-control" placeholder="Hard Disk Type">
                                                <label for="harddisk_type">Hard Disk Type</label>
                                            </div>
                                            <div class="form-floating">
                                                <input type="text" name="harddisk_space[]" class="form-control" placeholder="Hard Disk Space">
                                                <label for="harddisk_space">Hard Disk Space</label>
                                            </div>
                                            <button type="button" onclick="addHardDisk()" class="btn btn-primary">Add</button>
                                        </div>
                                        <div id="hardDiskContainer" class="mt-3"></div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <!-- RAM Card -->
                        <div class="card mb-3">
                            <div class="card-header">
                                <h6 class="mb-0">RAM</h6>
                            </div>
                            <div class="card-body">
                                <div class="row g-3">
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="ram_type" id="ram_type" class="form-control" placeholder="RAM Type">
                                            <label for="ram_type">RAM Type</label>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="ram_gb" id="ram_gb" class="form-control" placeholder="RAM GB">
                                            <label for="ram_gb">RAM GB</label>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="ram_total_unit" id="ram_total_unit" class="form-control" placeholder="RAM Total Unit">
                                            <label for="ram_total_unit">RAM Total Unit</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- OS and Computer Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Computer Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="computer_name" id="computer_name" class="form-control" placeholder="Computer Name">
                                    <label for="computer_name">Computer Name</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="domain" id="domain" class="form-control" placeholder="Domain">
                                    <label for="domain">Domain</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="os_version" id="os_version" class="form-control" placeholder="OS Version">
                                    <label for="os_version">OS Version</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="windows_product_key" id="windows_product_key" class="form-control" placeholder="Windows Product Key">
                                    <label for="windows_product_key">Windows Product Key</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Network Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Network Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="tcp_ip" id="tcp_ip" class="form-control" placeholder="TCP/IP">
                                    <label for="tcp_ip">TCP/IP</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="subnet_mask" id="subnet_mask" class="form-control" placeholder="Subnet Mask">
                                    <label for="subnet_mask">Subnet Mask</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="gateway" id="gateway" class="form-control" placeholder="Gateway">
                                    <label for="gateway">Gateway</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="dns" id="dns" class="form-control" placeholder="DNS">
                                    <label for="dns">DNS</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Login and Admin Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Login and Admin Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_id" id="login_id" class="form-control" placeholder="Login ID">
                                    <label for="login_id">Login ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_password" id="login_password" class="form-control" placeholder="Login Password">
                                    <label for="login_password">Login Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- 365 Licence Dropdown -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">365 Licence</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select name="office_365" id="office_365" class="form-select">
                                        <option value="">Select 365 Licence</option>
                                        <?php foreach ($clientAccountIds as $clientAccountId): ?>
                                            <option value="<?php echo htmlspecialchars($clientAccountId); ?>"><?php echo htmlspecialchars($clientAccountId); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="office_365">365 Licence</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Purchase and Warranty Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Purchase and Warranty Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="part_no" id="part_no" class="form-control" placeholder="Part No">
                                    <label for="part_no">Part No</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" name="purchase_date" id="purchase_date" class="form-control">
                                    <label for="purchase_date">Purchase Date</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" name="warranty_expire_date" id="warranty_expire_date" class="form-control">
                                    <label for="warranty_expire_date">Warranty Expire Date</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Email Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Email Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="email" name="user_email" id="user_email" class="form-control" placeholder="User Email">
                                    <label for="user_email">User Email</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-floating mb-3">
                                    <textarea id="others" name="others" class="form-control" placeholder="Others"></textarea>
                                    <label for="others">Others</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- PC Email Fields -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Windows Home Configuration</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="pc_email_account" id="pc_email_account" placeholder="PC Email Account">
                                    <label for="pc_email_account">PC Email Account</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="pc_email_password" id="pc_email_password" placeholder="PC Email Password">
                                    <label for="pc_email_password">PC Email Password</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="pin" id="pin" placeholder="PIN">
                                    <label for="pin">PIN</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="row">
                    <div class="col-md-12">
                        <button type="submit" class="btn btn-primary">Save</button>
                    </div>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Script for Adding Hard Disk Fields -->
<script>
function addHardDisk() {
    const container = document.getElementById('hardDiskContainer');

    const rowDiv = document.createElement('div');
    rowDiv.className = 'input-group mb-2';

    const input1 = document.createElement('input');
    input1.type = 'text';
    input1.name = 'harddisk_type[]';
    input1.placeholder = 'Type';
    input1.className = 'form-control';
    input1.id = 'floatingHardDiskType' + container.children.length;

    const label1 = document.createElement('label');
    label1.setAttribute('for', input1.id);
    label1.innerText = 'Type';

    const input2 = document.createElement('input');
    input2.type = 'text';
    input2.name = 'harddisk_space[]';
    input2.placeholder = 'Space';
    input2.className = 'form-control';
    input2.id = 'floatingHardDiskSpace' + container.children.length;

    const label2 = document.createElement('label');
    label2.setAttribute('for', input2.id);
    label2.innerText = 'Space';

    const removeButton = document.createElement('button');
    removeButton.type = 'button';
    removeButton.className = 'btn btn-secondary';
    removeButton.innerText = 'Remove';
    removeButton.onclick = function () {
        container.removeChild(rowDiv);
    };

    const floatingDiv1 = document.createElement('div');
    floatingDiv1.className = 'form-floating';
    floatingDiv1.appendChild(input1);
    floatingDiv1.appendChild(label1);

    const floatingDiv2 = document.createElement('div');
    floatingDiv2.className = 'form-floating';
    floatingDiv2.appendChild(input2);
    floatingDiv2.appendChild(label2);

    rowDiv.appendChild(floatingDiv1);
    rowDiv.appendChild(floatingDiv2);
    rowDiv.appendChild(removeButton);

    container.appendChild(rowDiv);
}
</script>

<!-- Bootstrap 5.3 JS CDN -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
</body>
</html>