<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypePosHardwareGroup = isset($_GET['itemTypePosHardwareGroup']) ? $_GET['itemTypePosHardwareGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Directly get debtor_code from URL

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $processor = $_POST['processor'] ?? [];
    $hardDiskType = $_POST['harddisk_type'] ?? [];
    $hardDiskSpace = $_POST['harddisk_space'] ?? [];
    $hardDiskTotalUnit = $_POST['harddisk_total_unit'] ?? [];
    $ramType = $_POST['ram_type'] ?? [];
    $ramGb = $_POST['ram_gb'] ?? [];
    $ramTotalUnit = $_POST['ram_total_unit'] ?? [];
    $computerName = $_POST['computer_name'] ?? [];
    $loginId = $_POST['login_id'] ?? [];
    $loginPassword = $_POST['login_password'] ?? [];
    $osVersion = $_POST['os_version'] ?? [];
    $tcpIp = $_POST['tcp_ip'] ?? [];
    $subnetMask = $_POST['subnet_mask'] ?? [];
    $gateway = $_POST['gateway'] ?? [];
    $dns = $_POST['dns'] ?? [];
    $installedAcSoftware = $_POST['installed_ac_software'] ?? [];
    $partNo = $_POST['part_no'] ?? [];
    $serialNumber = $_POST['serial_number'] ?? [];
    $purchaseDate = $_POST['purchase_date'] ?? [];
    $warrantyExpireDate = $_POST['warranty_expire_date'] ?? [];
    $others = $_POST['others'] ?? [];
    $brand = $_POST['brand'] ?? [];
    $model = $_POST['model'] ?? [];
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included

    // Encrypt the login password
    $encryptionKey = "your_secret_key"; // Replace with your actual encryption key
    $encryptedPassword = encryptPassword($loginPassword, $encryptionKey);

    $hardDiskTypeString = implode(',', $hardDiskType);
    $hardDiskSpaceString = implode(',', $hardDiskSpace);

    try {
        // Prepare and execute the insert query for item_type_pos_hw_aio_pc
        $stmt = $pdo->prepare("INSERT INTO item_type_pos_hw_aio_pc (
            item_type_name, 
            company_name, 
            debtor_code,
            active,
            brand,
            model,
            item_type_pos_hw_group_name,
            processor,
            harddisk_type,
            harddisk_space,
            harddisk_total_unit,
            ram_type,
            ram_gb,
            ram_total_unit,
            computer_name,
            login_id,
            login_password,
            os_version,
            tcp_ip,
            subnet_mask,
            gateway,
            dns,
            installed_ac_software,
            part_no,
            serial_number,
            purchase_date,
            warranty_expire_date,
            others
        ) VALUES (
            :item_type_name, 
            :company_name, 
            :debtor_code,
            :active,
            :brand,
            :model,
            :item_type_pos_hw_group_name,
            :processor,
            :harddisk_type,
            :harddisk_space,
            :harddisk_total_unit,
            :ram_type,
            :ram_gb,
            :ram_total_unit,
            :computer_name,
            :login_id,
            :login_password,
            :os_version,
            :tcp_ip,
            :subnet_mask,
            :gateway,
            :dns,
            :installed_ac_software,
            :part_no,
            :serial_number,
            :purchase_date,
            :warranty_expire_date,
            :others
        )");
    
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':item_type_pos_hw_group_name' => $itemTypePosHardwareGroup,
            ':active' => $active,
            ':brand' => $brand,
            ':model' => $model,
            ':processor' => $processor,
            ':harddisk_type' => $hardDiskTypeString,
            ':harddisk_space' => $hardDiskSpaceString,
            ':harddisk_total_unit' => $hardDiskTotalUnit,
            ':ram_type' => $ramType,
            ':ram_gb' => $ramGb,
            ':ram_total_unit' => $ramTotalUnit,
            ':computer_name' => $computerName,
            ':login_id' => $loginId,
            ':login_password' => $encryptedPassword, // Use the encrypted password
            ':os_version' => $osVersion,
            ':tcp_ip' => $tcpIp,
            ':subnet_mask' => $subnetMask,
            ':gateway' => $gateway,
            ':dns' => $dns,
            ':installed_ac_software' => $installedAcSoftware,
            ':part_no' => $partNo,
            ':serial_number' => $serialNumber,
            ':purchase_date' => $purchaseDate,
            ':warranty_expire_date' => $warrantyExpireDate,
            ':others' => $others
        ]);
    
        $logMessage = "Item inserted into POS All in one PC for company_name: $companyName";
    
        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]); 
        
        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS with Floating Labels -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display the passed values -->
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypePosHardwareGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                <!-- Login Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="computer_name" id="computer_name" class="form-control" placeholder="Computer Name">
                                    <label for="computer_name">Computer Name</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_id" id="login_id" class="form-control" placeholder="Login ID">
                                    <label for="login_id">Login ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_password" id="login_password" class="form-control" placeholder="Login Password">
                                    <label for="login_password">Login Password</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="os_version" id="os_version" class="form-control" placeholder="OS Version">
                                    <label for="os_version">OS Version</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Network Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Network Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="tcp_ip" id="tcp_ip" class="form-control" placeholder="TCP/IP">
                                    <label for="tcp_ip">TCP/IP</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="subnet_mask" id="subnet_mask" class="form-control" placeholder="Subnet Mask">
                                    <label for="subnet_mask">Subnet Mask</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="gateway" id="gateway" class="form-control" placeholder="Gateway">
                                    <label for="gateway">Gateway</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="dns" id="dns" class="form-control" placeholder="DNS">
                                    <label for="dns">DNS</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Hardware Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Hardware Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="brand" id="brand" class="form-control" placeholder="Brand">
                                    <label for="brand">Brand</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="model" id="model" class="form-control" placeholder="Model">
                                    <label for="model">Model</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="part_no" id="part_no" class="form-control" placeholder="Part No">
                                    <label for="part_no">Part No</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="serial_number" id="serial_number" class="form-control" placeholder="Serial Number">
                                    <label for="serial_number">Serial Number</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Processor and Hard Disk Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Processor and Hard Disk Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="processor" id="processor" class="form-control" placeholder="Processor">
                                    <label for="processor">Processor</label>
                                </div>
                                <div id="hardDiskContainer">
                                    <!-- Initial hard disk fields -->
                                    <div class="input-group mb-2">
                                        <div class="form-floating">
                                            <input type="text" name="harddisk_type[]" class="form-control" placeholder="Type">
                                            <label>Type</label>
                                        </div>
                                        <div class="form-floating">
                                            <input type="text" name="harddisk_space[]" class="form-control" placeholder="Space">
                                            <label>Space</label>
                                        </div>
                                        <button type="button" class="btn btn-secondary" onclick="removeHardDisk(this)">Remove</button>
                                    </div>
                                </div>
                                <button type="button" class="btn btn-primary" onclick="addHardDisk()">Add Hard Disk</button>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="harddisk_total_unit" id="harddisk_total_unit" class="form-control" placeholder="Hard Disk Total Unit">
                                    <label for="harddisk_total_unit">Hard Disk Total Unit</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- RAM Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">RAM Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="ram_type" id="ram_type" class="form-control" placeholder="RAM Type">
                                    <label for="ram_type">RAM Type</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="ram_gb" id="ram_gb" class="form-control" placeholder="RAM GB">
                                    <label for="ram_gb">RAM GB</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="ram_total_unit" id="ram_total_unit" class="form-control" placeholder="RAM Total Unit">
                                    <label for="ram_total_unit">RAM Total Unit</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Installed AC Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Installed Autocount Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="installed_ac_software" id="installed_ac_software" class="form-control" placeholder="Installed AC Software">
                                    <label for="installed_ac_software">Installed AC Software</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Warranty Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Warranty Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" name="purchase_date" id="purchase_date" class="form-control" placeholder="Purchase Date">
                                    <label for="purchase_date">Purchase Date</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" name="warranty_expire_date" id="warranty_expire_date" class="form-control" placeholder="Warranty Expire Date">
                                    <label for="warranty_expire_date">Warranty Expire Date</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea id="others" name="others" class="form-control" placeholder="Others"></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Save</button>
                </div>
            </form>
        </div>
    </div>
</div>

<script>
function addHardDisk() {
    const container = document.getElementById('hardDiskContainer');
    const inputGroup = document.createElement('div');
    inputGroup.className = 'input-group mb-2';
    inputGroup.innerHTML = `
        <div class="form-floating">
            <input type="text" name="harddisk_type[]" class="form-control" placeholder="Type">
            <label>Type</label>
        </div>
        <div class="form-floating">
            <input type="text" name="harddisk_space[]" class="form-control" placeholder="Space">
            <label>Space</label>
        </div>
        <button type="button" class="btn btn-secondary" onclick="removeHardDisk(this)">Remove</button>
    `;
    container.appendChild(inputGroup);
}

function removeHardDisk(button) {
    const container = document.getElementById('hardDiskContainer');
    const remainingFields = container.querySelectorAll('.input-group').length;

    if (remainingFields > 1) {
        button.closest('.input-group').remove();
    } else {
        alert("You must have at least one hard disk field.");
    }
}
</script>

<!-- Bootstrap 5.x JS with Floating Labels -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>