<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypePosHardwareGroup = isset($_GET['itemTypePosHardwareGroup']) ? $_GET['itemTypePosHardwareGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Directly get debtor_code from URL

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1;
    $model = $_POST['model'] ?? [];
    $itemOf = $_POST['item_of'] ?? [];
    $partNo = $_POST['part_no'] ?? [];
    $serialNumber = $_POST['serial_number'] ?? [];
    $purchaseDate = $_POST['purchase_date'] ?? [];
    $warrantyExpireDate = $_POST['warranty_expire_date'] ?? [];
    $others = $_POST['others'] ?? [];
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included

    try {
        // Prepare and execute the insert query
        $stmt = $pdo->prepare("INSERT INTO item_type_pos_hw_others (
            item_type_name, 
            company_name, 
            debtor_code,
            item_type_pos_hw_group_name,
            active,
            model,
            item_of,
            part_no,
            serial_number,
            purchase_date,
            warranty_expire_date,
            others
        ) VALUES (
            :item_type_name, 
            :company_name,
            :debtor_code,
            :item_type_pos_hw_group_name, 
            :active,
            :model,
            :item_of,
            :part_no,
            :serial_number,
            :purchase_date,
            :warranty_expire_date,
            :others
        )");
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':item_type_pos_hw_group_name' => $itemTypePosHardwareGroup,
            ':active' => $active,
            ':model' => $model,
            ':item_of' => $itemOf,
            ':part_no' => $partNo,
            ':serial_number' => $serialNumber,
            ':purchase_date' => $purchaseDate,
            ':warranty_expire_date' => $warrantyExpireDate,
            ':others' => $others
        ]);

        // Build the log message
        $logMessage = "Item inserted into POS other hardware for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);         
    
        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS with Floating Labels -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display the passed values -->
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypePosHardwareGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                <!-- Hardware Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Hardware Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="model" id="model" class="form-control" placeholder="Model">
                                    <label for="model">Model</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="item_of" id="item_of" class="form-control" placeholder="Item Of">
                                    <label for="item_of">Item Of</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="part_no" id="part_no" class="form-control" placeholder="Part No">
                                    <label for="part_no">Part No</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="serial_number" id="serial_number" class="form-control" placeholder="Serial Number">
                                    <label for="serial_number">Serial Number</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Warranty Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Warranty Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" name="purchase_date" id="purchase_date" class="form-control" placeholder="Purchase Date">
                                    <label for="purchase_date">Purchase Date</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" name="warranty_expire_date" id="warranty_expire_date" class="form-control" placeholder="Warranty Expire Date">
                                    <label for="warranty_expire_date">Warranty Expire Date</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea 
                                id="others" 
                                name="others" 
                                class="form-control" 
                                placeholder="Others" 
                                style="height: 200px; resize: vertical; overflow-y: hidden;" 
                                oninput="this.style.height = ''; this.style.height = this.scrollHeight + 'px';"
                            ></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Save</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS with Floating Labels -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

