<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypePcGroup = isset($_GET['itemTypePcGroup']) ? $_GET['itemTypePcGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Directly get debtor_code from URL

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1;
    $processor = $_POST['processor'] ?? '';
    $hardDiskType = $_POST['harddisk_type'] ?? [];
    $hardDiskSpace = $_POST['harddisk_space'] ?? [];
    $hardDiskTotalUnit = $_POST['harddisk_total_unit'] ?? '';
    $ramType = $_POST['ram_type'] ?? '';
    $ramGb = $_POST['ram_gb'] ?? '';
    $ramTotalUnit = $_POST['ram_total_unit'] ?? '';
    $computerName = $_POST['computer_name'] ?? '';
    $domain = $_POST['domain'] ?? '';
    $loginId = $_POST['login_id'] ?? '';
    $loginPassword = $_POST['login_password'] ?? ''; // Login password to be encrypted
    $windowsProductKey = $_POST['windows_product_key'] ?? '';
    $osVersion = $_POST['os_version'] ?? '';
    $tcpIp = $_POST['tcp_ip'] ?? '';
    $subnetMask = $_POST['subnet_mask'] ?? '';
    $gateway = $_POST['gateway'] ?? '';
    $dns = $_POST['dns'] ?? '';
    $partNo = $_POST['part_no'] ?? '';
    $serialNumber = $_POST['serial_number'] ?? '';
    $purchaseDate = $_POST['purchase_date'] ?? '';
    $warrantyExpireDate = $_POST['warranty_expire_date'] ?? '';
    $isAutocountMain = isset($_POST['is_autocount_main']) ? 1 : 0;
    $isRemote = isset($_POST['is_remote']) ? 1 : 0;
    $isHyperV = isset($_POST['is_hyper_v']) ? 1 : 0;
    $folder = $_POST['folder'] ?? [];
    $accessRight = $_POST['access_right'] ?? [];
    $accessUser = $_POST['access_user'] ?? [];
    $networkDrive = $_POST['network_drive'] ?? [];
    $remoteBy = $_POST['remote_by'] ?? '';
    $remoteUser = $_POST['remote_user'] ?? [];
    $remoteUserPassword = $_POST['remote_user_password'] ?? [];
    $others = $_POST['others'] ?? [];
    $iloTcpIp = $_POST['ilo_tcp_ip'] ?? [];
    $iloUsername = $_POST['ilo_username'] ?? [];
    $iloPassword = $_POST['ilo_password'] ?? [];
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included
    $brand = $_POST['brand'] ?? ''; // New field: Brand
    $model = $_POST['model'] ?? ''; // New field: Model

    // Define the encryption key (this should be secure and consistent)
    $encryptionKey = 'your_secret_key'; // Replace 'your_secret_key' with your actual secure key

    // Encrypt sensitive fields
    $encryptedLoginPassword = encryptPassword($loginPassword, $encryptionKey); // Encrypt login password
    $encryptedRemoteUserPassword = encryptPassword(implode(',', $remoteUserPassword), $encryptionKey);
    $encryptedIloPassword = encryptPassword($iloPassword, $encryptionKey); // Encrypt ILO password
    $encryptedWindowsProductKey = encryptPassword($windowsProductKey, $encryptionKey); // Encrypt Windows product key

    // Decrypt for logging (optional, only if needed for debugging or logging)
    $decryptedLoginPassword = decryptPassword($encryptedLoginPassword, $encryptionKey);
    $decryptedRemoteUserPassword = decryptPassword($encryptedRemoteUserPassword, $encryptionKey);
    $decryptedIloPassword = decryptPassword($encryptedIloPassword, $encryptionKey);
    $decryptedWindowsProductKey = decryptPassword($encryptedWindowsProductKey, $encryptionKey);

    // Convert arrays to strings
    $hardDiskTypeString = implode(',', $hardDiskType);
    $hardDiskSpaceString = implode(',', $hardDiskSpace);
    $folderString = implode(',', $folder);
    $accessRightString = implode(',', $accessRight);
    $accessUserString = implode(',', $accessUser);
    $networkDriveString = implode(',', $networkDrive);
    $remoteUserString = implode(',', $remoteUser);

    try {
        // Prepare and execute the insert query
        $stmt = $pdo->prepare("INSERT INTO item_type_pc (
            item_type_name, 
            company_name,
            debtor_code,
            item_type_pc_group_name, 
            active,
            processor,
            harddisk_type,
            harddisk_space,
            harddisk_total_unit,
            ram_type,
            ram_gb,
            ram_total_unit,
            computer_name,
            domain,
            login_id,
            login_password,
            windows_product_key,
            os_version,
            tcp_ip,
            subnet_mask,
            gateway,
            dns,
            part_no,
            serial_number,
            purchase_date,
            warranty_expire_date,
            is_autocount_main,
            is_remote,
            is_hyper_v,
            folder,
            access_right,
            access_user,
            network_drive,
            remote_by,
            remote_user,
            remote_user_password,
            ilo_tcp_ip,
            ilo_username,
            ilo_password,
            others,
            brand, -- New field: Brand
            model -- New field: Model
        ) VALUES (
            :item_type_name, 
            :company_name,
            :debtor_code,
            :item_type_pc_group_name,
            :active,
            :processor,
            :harddisk_type,
            :harddisk_space,
            :harddisk_total_unit,
            :ram_type,
            :ram_gb,
            :ram_total_unit,
            :computer_name,
            :domain,
            :login_id,
            :login_password,
            :windows_product_key,
            :os_version,
            :tcp_ip,
            :subnet_mask,
            :gateway,
            :dns,
            :part_no,
            :serial_number,
            :purchase_date,
            :warranty_expire_date,
            :is_autocount_main,
            :is_remote,
            :is_hyper_v,
            :folder,
            :access_right,
            :access_user,
            :network_drive,
            :remote_by,
            :remote_user,
            :remote_user_password,
            :ilo_tcp_ip,
            :ilo_username,
            :ilo_password,
            :others,
            :brand, -- New field: Brand
            :model -- New field: Model
        )");

        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':item_type_pc_group_name' => $itemTypePcGroup,
            ':active' => $active,
            ':processor' => $processor,
            ':harddisk_type' => $hardDiskTypeString,
            ':harddisk_space' => $hardDiskSpaceString,
            ':harddisk_total_unit' => $hardDiskTotalUnit,
            ':ram_type' => $ramType,
            ':ram_gb' => $ramGb,
            ':ram_total_unit' => $ramTotalUnit,
            ':computer_name' => $computerName,
            ':domain' => $domain,
            ':login_id' => $loginId,
            ':login_password' => $encryptedLoginPassword, // Use encrypted login password
            ':windows_product_key' => $encryptedWindowsProductKey, // Use encrypted Windows product key
            ':os_version' => $osVersion,
            ':tcp_ip' => $tcpIp,
            ':subnet_mask' => $subnetMask,
            ':gateway' => $gateway,
            ':dns' => $dns,
            ':part_no' => $partNo,
            ':serial_number' => $serialNumber,
            ':purchase_date' => $purchaseDate,
            ':warranty_expire_date' => $warrantyExpireDate,
            ':is_autocount_main' => $isAutocountMain,
            ':is_remote' => $isRemote,
            ':is_hyper_v' => $isHyperV,
            ':folder' => $folderString,
            ':access_right' => $accessRightString,
            ':access_user' => $accessUserString,
            ':network_drive' => $networkDriveString,
            ':remote_by' => $remoteBy,
            ':remote_user' => $remoteUserString,
            ':remote_user_password' => $encryptedRemoteUserPassword,
            ':ilo_tcp_ip' => $iloTcpIp,
            ':ilo_username' => $iloUsername,
            ':ilo_password' => $encryptedIloPassword, // Use encrypted ILO password
            ':others' => $others,
            ':brand' => $brand, // New field: Brand
            ':model' => $model // New field: Model
        ]);

        $logMessage = "Item inserted into Server for company_name: $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.3 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypePcGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                <!-- Hardware Specifications Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Hardware Specifications</h5>
                    </div>
                    <div class="card-body">
                        <div class="card mb-3">
                            <div class="card-header">
                                <h5 class="mb-0">Brand and Model</h5>
                            </div>
                            <div class="card-body">
                                <div class="row g-3">
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="brand" id="brand" class="form-control" placeholder="Brand">
                                            <label for="brand">Brand</label>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="serial_number" id="serial_number" class="form-control" placeholder="Serial Number">
                                            <label for="serial_number">Serial Number</label>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="model" id="model" class="form-control" placeholder="Model">
                                            <label for="model">Model</label>
                                        </div>
                                    </div>
                                    
                                </div>
                            </div>
                        </div>
                        
                        <!-- Processor Card -->
                        <div class="card mb-3">
                            <div class="card-header">
                                <h6 class="mb-0">Processor</h6>
                            </div>
                            <div class="card-body">
                                <div class="row g-3">
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="processor" id="processor" class="form-control" placeholder="Processor">
                                            <label for="processor">Processor</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <!-- Hard Disk Card -->
                        <div class="card mb-3">
                            <div class="card-header">
                                <h6 class="mb-0">Hard Disk</h6>
                            </div>
                            <div class="card-body">
                                <div class="row g-3">
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="harddisk_total_unit" id="harddisk_total_unit" class="form-control" placeholder="Hard Disk Total Unit">
                                            <label for="harddisk_total_unit">Hard Disk Total Unit</label>
                                        </div>
                                    </div>
                                    <div class="col-md-12">
                                        <div class="input-group">
                                            <div class="form-floating">
                                                <input type="text" name="harddisk_type[]" class="form-control" placeholder="Hard Disk Type">
                                                <label for="harddisk_type">Hard Disk Type</label>
                                            </div>
                                            <div class="form-floating">
                                                <input type="text" name="harddisk_space[]" class="form-control" placeholder="Hard Disk Space">
                                                <label for="harddisk_space">Hard Disk Space</label>
                                            </div>
                                            <button type="button" onclick="addHardDisk()" class="btn btn-primary">Add</button>
                                        </div>
                                        <div id="hardDiskContainer" class="mt-3"></div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <!-- RAM Card -->
                        <div class="card mb-3">
                            <div class="card-header">
                                <h6 class="mb-0">RAM</h6>
                            </div>
                            <div class="card-body">
                                <div class="row g-3">
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="ram_type" id="ram_type" class="form-control" placeholder="RAM Type">
                                            <label for="ram_type">RAM Type</label>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="ram_gb" id="ram_gb" class="form-control" placeholder="RAM GB">
                                            <label for="ram_gb">RAM GB</label>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="ram_total_unit" id="ram_total_unit" class="form-control" placeholder="RAM Total Unit">
                                            <label for="ram_total_unit">RAM Total Unit</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- OS and Computer Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Computer Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="computer_name" id="computer_name" class="form-control" placeholder="Computer Name">
                                    <label for="computer_name">Computer Name</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="domain" id="domain" class="form-control" placeholder="Domain">
                                    <label for="domain">Domain</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="os_version" id="os_version" class="form-control" placeholder="OS Version">
                                    <label for="os_version">OS Version</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="windows_product_key" id="windows_product_key" class="form-control" placeholder="Windows Product Key">
                                    <label for="windows_product_key">Windows Product Key</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Network Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Network Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="tcp_ip" id="tcp_ip" class="form-control" placeholder="TCP/IP">
                                    <label for="tcp_ip">TCP/IP</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="subnet_mask" id="subnet_mask" class="form-control" placeholder="Subnet Mask">
                                    <label for="subnet_mask">Subnet Mask</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="gateway" id="gateway" class="form-control" placeholder="Gateway">
                                    <label for="gateway">Gateway</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="dns" id="dns" class="form-control" placeholder="DNS">
                                    <label for="dns">DNS</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">ILO Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="ilo_tcp_ip" id="ilo_tcp_ip" class="form-control" placeholder="ILO TCP/IP">
                                    <label for="ilo_tcp_ip">ILO TCP/IP</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="ilo_username" id="ilo_username" class="form-control" placeholder="ILO Username">
                                    <label for="ilo_username">ILO Username</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="ilo_password" id="ilo_password" class="form-control" placeholder="ILO Password">
                                    <label for="ilo_password">ILO Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Login and Admin Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Login and Admin Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="login_id" id="login_id" class="form-control" placeholder="Login ID">
                                    <label for="login_id">Login ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="login_password" id="login_password" class="form-control" placeholder="Login Password">
                                    <label for="login_password">Login Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Purchase and Warranty Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Purchase and Warranty Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="part_no" id="part_no" class="form-control" placeholder="Part No">
                                    <label for="part_no">Part No</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="date" name="purchase_date" id="purchase_date" class="form-control" placeholder="Purchase Date">
                                    <label for="purchase_date">Purchase Date</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="date" name="warranty_expire_date" id="warranty_expire_date" class="form-control" placeholder="Warranty Expire Date">
                                    <label for="warranty_expire_date">Warranty Expire Date</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Remote and Hyper-V Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Remote and Hyper-V Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-6">
                                <div class="form-check">
                                    <input type="checkbox" name="is_autocount_main" id="is_autocount_main" class="form-check-input" value="1">
                                    <label for="is_autocount_main" class="form-check-label">Is Autocount Main</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-check">
                                    <input type="checkbox" name="is_remote" id="is_remote" class="form-check-input" value="1">
                                    <label for="is_remote" class="form-check-label">Is Remote</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-check">
                                    <input type="checkbox" name="is_hyper_v" id="is_hyper_v" class="form-check-input" value="1">
                                    <label for="is_hyper_v" class="form-check-label">Is Hyper-V</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Folder and Access Rights -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Folder and Access Rights</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-12">
                                <div class="input-group">
                                    <div class="form-floating">
                                        <input type="text" name="folder[]" class="form-control" placeholder="Folder">
                                        <label for="folder">Folder</label>
                                    </div>
                                    <div class="form-floating">
                                        <input type="text" name="access_right[]" class="form-control" placeholder="Access Right">
                                        <label for="access_right">Access Right</label>
                                    </div>
                                    <div class="form-floating">
                                        <input type="text" name="access_user[]" class="form-control" placeholder="Access User">
                                        <label for="access_user">Access User</label>
                                    </div>
                                    <div class="form-floating">
                                        <input type="text" name="network_drive[]" class="form-control" placeholder="Network Drive">
                                        <label for="network_drive">Network Drive</label>
                                    </div>
                                    <button type="button" onclick="addFolderAndAccessRights()" class="btn btn-primary">Add</button>
                                </div>
                                <div id="folderAndAccessRightsContainer" class="mt-3"></div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Remote User Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Remote User Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="remote_by" id="remote_by" class="form-control" placeholder="Remote By">
                                    <label for="remote_by">Remote By</label>
                                </div>
                            </div>
                            <div class="col-md-12">
                                <div class="input-group">
                                    <div class="form-floating">
                                        <input type="text" name="remote_user[]" class="form-control" placeholder="Remote User">
                                        <label for="remote_user">Remote User</label>
                                    </div>
                                    <div class="form-floating">
                                        <input type="text" name="remote_user_password[]" class="form-control" placeholder="Remote User Password">
                                        <label for="remote_user_password">Remote User Password</label>
                                    </div>
                                    <button type="button" onclick="addRemoteUser()" class="btn btn-primary">Add</button>
                                </div>
                                <div id="remoteUserContainer" class="mt-3"></div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Additional Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Additional Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-12">
                                <div class="form-floating">
                                    <textarea name="others" id="others" class="form-control" placeholder="Others" style="height: 100px;"></textarea>
                                    <label for="others">Others</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.3 JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>

<!-- Custom Script for Dynamic Fields -->
<script>
function addHardDisk() {
    const container = document.getElementById('hardDiskContainer');
    const rowDiv = document.createElement('div');
    rowDiv.className = 'input-group mb-3';
    rowDiv.innerHTML = `
        <div class="form-floating">
            <input type="text" name="harddisk_type[]" class="form-control" placeholder="Hard Disk Type">
            <label for="harddisk_type">Hard Disk Type</label>
        </div>
        <div class="form-floating">
            <input type="text" name="harddisk_space[]" class="form-control" placeholder="Hard Disk Space">
            <label for="harddisk_space">Hard Disk Space</label>
        </div>
        <button type="button" class="btn btn-danger" onclick="this.parentElement.remove()">Remove</button>
    `;
    container.appendChild(rowDiv);
}

function addFolderAndAccessRights() {
    const container = document.getElementById('folderAndAccessRightsContainer');
    const rowDiv = document.createElement('div');
    rowDiv.className = 'input-group mb-3';
    rowDiv.innerHTML = `
        <div class="form-floating">
            <input type="text" name="folder[]" class="form-control" placeholder="Folder">
            <label for="folder">Folder</label>
        </div>
        <div class="form-floating">
            <input type="text" name="access_right[]" class="form-control" placeholder="Access Right">
            <label for="access_right">Access Right</label>
        </div>
        <div class="form-floating">
            <input type="text" name="access_user[]" class="form-control" placeholder="Access User">
            <label for="access_user">Access User</label>
        </div>
        <div class="form-floating">
            <input type="text" name="network_drive[]" class="form-control" placeholder="Network Drive">
            <label for="network_drive">Network Drive</label>
        </div>
        <button type="button" class="btn btn-danger" onclick="this.parentElement.remove()">Remove</button>
    `;
    container.appendChild(rowDiv);
}

function addRemoteUser() {
    const container = document.getElementById('remoteUserContainer');
    const rowDiv = document.createElement('div');
    rowDiv.className = 'input-group mb-3';
    rowDiv.innerHTML = `
        <div class="form-floating">
            <input type="text" name="remote_user[]" class="form-control" placeholder="Remote User">
            <label for="remote_user">Remote User</label>
        </div>
        <div class="form-floating">
            <input type="text" name="remote_user_password[]" class="form-control" placeholder="Remote User Password">
            <label for="remote_user_password">Remote User Password</label>
        </div>
        <button type="button" class="btn btn-danger" onclick="this.parentElement.remove()">Remove</button>
    `;
    container.appendChild(rowDiv);
}
</script>
</body>
</html>