<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeSoftwareGroup = isset($_GET['itemTypeSoftwareGroup']) ? $_GET['itemTypeSoftwareGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Directly get debtor_code from URL

$installedPc = [];
if ($debtorCode && $companyName) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
        $installedPc = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1;
    $installedPc = $_POST['installed_pc'] ?? ''; // Now a single value
    $softwareName = $_POST['software_name'] ?? '';
    $softwareVersion = $_POST['software_version'] ?? '';
    $installPath = $_POST['install_path'] ?? ''; // New field
    $others = $_POST['others'] ?? '';
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included

    try {
        // Prepare and execute the insert query
        $stmt = $pdo->prepare("INSERT INTO item_type_sw_av_ep_client (
            item_type_name, 
            item_type_sw_group_name,
            company_name, 
            debtor_code,
            active,
            installed_pc,
            software_name,
            software_version,
            install_path,
            others
        ) VALUES (
            :item_type_name, 
            :item_type_sw_group_name,
            :company_name, 
            :debtor_code,
            :active,
            :installed_pc,
            :software_name,
            :software_version,
            :install_path, 
            :others
        )");
    
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':item_type_sw_group_name' => $itemTypeSoftwareGroup,
            ':active' => $active,
            ':installed_pc' => $installedPc,
            ':software_name' => $softwareName,
            ':software_version' => $softwareVersion,
            ':install_path' => $installPath,
            ':others' => $others
        ]);
    
        $logMessage = "Item inserted into Antivirus Endpoint for Client: $companyName";
    
        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]); 
    
        // Success alert
        echo "<script>alert('Data saved successfully!');</script>";
    
        // Check if the "Save and Add New" button was clicked
        if (isset($_POST['save_and_new'])) {
            // Redirect to the same page to clear the "Installed PC" field
            echo "<script>window.location.href = 'sw_antivirus_endpoint_client.php?itemType=$itemType&itemTypeSoftwareGroup=$itemTypeSoftwareGroup&companyName=$companyName&debtorCode=$debtorCode&softwareName=$softwareName&softwareVersion=$softwareVersion&installPath=$installPath&others=$others';</script>";
        } else {
            // Redirect to the same page to clear the form
            echo "<script>window.location.href = 'add_config_info.php';</script>";
        }
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}

// Retrieve form data from the URL if available
$softwareName = isset($_GET['softwareName']) ? $_GET['softwareName'] : '';
$softwareVersion = isset($_GET['softwareVersion']) ? $_GET['softwareVersion'] : '';
$installPath = isset($_GET['installPath']) ? $_GET['installPath'] : '';
$others = isset($_GET['others']) ? $_GET['others'] : '';
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST" onsubmit="return validateForm();">
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeSoftwareGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                <!-- Installed PC Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">PC Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-select" id="installed_pc" name="installed_pc">
                                        <option value="">Please select a PC</option>
                                        <?php foreach ($installedPc as $option): ?>
                                            <option value="<?php echo htmlspecialchars($option); ?>" <?php echo ($option == $installedPc) ? 'selected' : ''; ?>><?php echo htmlspecialchars($option); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Software Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Software Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="software_name" name="software_name" placeholder="Software Name" value="<?php echo htmlspecialchars($softwareName); ?>">
                                    <label for="software_name">Software Name</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="software_version" name="software_version" placeholder="Software Version" value="<?php echo htmlspecialchars($softwareVersion); ?>">
                                    <label for="software_version">Software Version</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="install_path" name="install_path" placeholder="Install Path" value="<?php echo htmlspecialchars($installPath); ?>">
                                    <label for="install_path">Install Path</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea class="form-control" id="others" name="others" placeholder="Others"><?php echo htmlspecialchars($others); ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary" name="save">Save</button>
                <!-- Save and Add New Button -->
                <button type="submit" class="btn btn-success" name="save_and_new">Save and Add New</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        $('#installed_pc').select2({
            theme: "bootstrap-5",
            width: $(this).data('width') ? $(this).data('width') : $(this).hasClass('w-100') ? '100%' : 'style',
            placeholder: $(this).data('placeholder'),
            closeOnSelect: true, // Ensure it closes after selecting an option
        });

        // Clear the "Installed PC" field after form submission
        $('form').on('submit', function() {
            if (document.referrer.includes('save_and_new')) {
                $('#installed_pc').val('').trigger('change');
            }
        });
    });

    // Form validation
    function validateForm() {
        const installedPc = $('#installed_pc').val();
        const softwareName = $('#software_name').val();

        if (installedPc === '' || softwareName === '') {
            alert('Please select an Installed PC and provide a Software Name.');
            return false;
        }
        return true;
    }
</script>
</body>
</html>

