<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');
// Encryption key (must match the key used in encrypt.php)
$encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeSoftwareGroup = isset($_GET['itemTypeSoftwareGroup']) ? $_GET['itemTypeSoftwareGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Directly get debtor_code from URL

$installedPcs = [];
if ($debtorCode && $companyName) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1;
    $contractNumber = $_POST['contract_number'] ?? '';
    $enterpriseSiteId = $_POST['enterprise_site_id'] ?? '';
    $installedPc = $_POST['installed_pc'] ?? '';
    $managementConsoleUrl = $_POST['management_console_url'] ?? '';
    $quantity = $_POST['quantity'] ?? '';
    $license = $_POST['license'] ?? '';
    $login = $_POST['login'] ?? '';
    $password = $_POST['password'] ?? '';
    $softwareName = $_POST['software_name'] ?? '';
    $softwareVersion = $_POST['software_version'] ?? '';
    $others = $_POST['others'] ?? '';
    $licenseEmailLogin = $_POST['license_email_login'] ?? ''; // New field
    $licenseEmailPassword = $_POST['license_email_password'] ?? ''; // New field
    $webConsoleLogin = $_POST['web_console_login'] ?? ''; // New field
    $webConsolePassword = $_POST['web_console_password'] ?? ''; // New field
    $agentPort = $_POST['agent_port'] ?? ''; // New field
    $console = $_POST['console'] ?? ''; // New field
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included

    // Encrypt sensitive fields before storing in the database
    $encryptedPassword = encryptPassword($password, $encryptionKey);
    $encryptedlicense = encryptPassword($license, $encryptionKey); // Encrypt the license key
    $encryptedLicenseEmailPassword = encryptPassword($licenseEmailPassword, $encryptionKey); // Encrypt the license email password
    $encryptedWebConsolePassword = encryptPassword($webConsolePassword, $encryptionKey); // Encrypt the web console password

    // Decrypt the password, license key, license email password, and web console password for logging purposes
    $decryptedPassword = decryptPassword($encryptedPassword, $encryptionKey);
    $decryptedlicense = decryptPassword($encryptedlicense, $encryptionKey);
    $decryptedLicenseEmailPassword = decryptPassword($encryptedLicenseEmailPassword, $encryptionKey);
    $decryptedWebConsolePassword = decryptPassword($encryptedWebConsolePassword, $encryptionKey);

    // Create log data excluding sensitive information and 'debtor_code'
    $logData = array(
        'item_type_name' => $itemType,
        'company_name' => $companyName,
        'debtor_code' => $debtorCode,
        'item_type_sw_group_name' => $itemTypeSoftwareGroup,
        'active' => $active,
        'contract_number' => $contractNumber,
        'enterprise_site_id' => $enterpriseSiteId,
        'installed_pc' => $installedPc,
        'management_console_url' => $managementConsoleUrl,
        'quantity' => $quantity,
        'license' => $decryptedlicense, // Plaintext license key for logging
        'login' => $login,
        'password' => $decryptedPassword, // Plaintext password for logging
        'software_name' => $softwareName,
        'software_version' => $softwareVersion,
        'others' => $others,
        'license_email_login' => $licenseEmailLogin, // Plaintext license email login for logging
        'license_email_password' => $decryptedLicenseEmailPassword, // Plaintext license email password for logging
        'web_console_login' => $webConsoleLogin, // Plaintext web console login for logging
        'web_console_password' => $decryptedWebConsolePassword, // Plaintext web console password for logging
        'agent_port' => $agentPort, // Plaintext agent port for logging
        'console' => $console // Plaintext console for logging
    );

    try {
        // Prepare and execute the insert query for the new table
        $stmt = $pdo->prepare("INSERT INTO item_type_sw_av_ep_master (
            item_type_name, 
            item_type_sw_group_name,
            company_name, 
            debtor_code,
            active,
            contract_number,
            enterprise_site_id,
            installed_pc,
            management_console_url,
            quantity,
            license,
            login,
            password,
            software_name,
            software_version,
            others,
            license_email_login, 
            license_email_password, 
            web_console_login, 
            web_console_password, 
            agent_port, 
            console 
        ) VALUES (
            :item_type_name, 
            :item_type_sw_group_name,
            :company_name, 
            :debtor_code,
            :active,
            :contract_number,
            :enterprise_site_id,
            :installed_pc,
            :management_console_url,
            :quantity,
            :license,
            :login,
            :password,
            :software_name,
            :software_version,
            :others,
            :license_email_login, 
            :license_email_password, 
            :web_console_login, 
            :web_console_password, 
            :agent_port, 
            :console 
        )");
    
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':item_type_sw_group_name' => $itemTypeSoftwareGroup,
            ':active' => $active,
            ':contract_number' => $contractNumber,
            ':enterprise_site_id' => $enterpriseSiteId,
            ':installed_pc' => $installedPc,
            ':management_console_url' => $managementConsoleUrl,
            ':quantity' => $quantity,
            ':license' => $encryptedlicense, // Encrypted license key
            ':login' => $login,
            ':password' => $encryptedPassword, // Encrypted password
            ':software_name' => $softwareName,
            ':software_version' => $softwareVersion,
            ':others' => $others,
            ':license_email_login' => $licenseEmailLogin, // Plaintext license email login
            ':license_email_password' => $encryptedLicenseEmailPassword, // Encrypted license email password
            ':web_console_login' => $webConsoleLogin, // Plaintext web console login
            ':web_console_password' => $encryptedWebConsolePassword, // Encrypted web console password
            ':agent_port' => $agentPort, // Plaintext agent port
            ':console' => $console // Plaintext console
        ]);
    
        $logMessage = "Item inserted into Antivirus Endpoint for Master: $companyName";
    
        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);
    
        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display the passed values -->
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeSoftwareGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">        
                </div>

                <!-- PC Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">PC Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-select" id="installed_pc" name="installed_pc">
                                        <option value="">Select Installed PC</option>
                                        <?php foreach ($installedPcs as $option): ?>
                                            <option value="<?php echo htmlspecialchars($option); ?>"><?php echo htmlspecialchars($option); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- General Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">General Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="contract_number" name="contract_number" placeholder="Contract Number">
                                    <label for="contract_number">Contract Number</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="enterprise_site_id" name="enterprise_site_id" placeholder="Enterprise Site ID">
                                    <label for="enterprise_site_id">Enterprise Site ID</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="license" name="license" placeholder="License">
                                    <label for="license">License</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="management_console_url" name="management_console_url" placeholder="Management Console URL">
                                    <label for="management_console_url">Management Console URL</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="number" class="form-control" id="quantity" name="quantity" placeholder="Quantity">
                                    <label for="quantity">Quantity</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Software Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Software Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="software_name" name="software_name" placeholder="Software Name">
                                    <label for="software_name">Software Name</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="software_version" name="software_version" placeholder="Software Version">
                                    <label for="software_version">Software Version</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Login Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="login" name="login" placeholder="Login">
                                    <label for="login">Login</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="password" name="password" placeholder="Password">
                                    <label for="password">Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- License Email Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">License Email Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="license_email_login" name="license_email_login" placeholder="License Email Login">
                                    <label for="license_email_login">License Email Login</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="license_email_password" name="license_email_password" placeholder="License Email Password">
                                    <label for="license_email_password">License Email Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Web Console Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Web Console</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="web_console_login" name="web_console_login" placeholder="Web Console Login">
                                    <label for="web_console_login">Web Console Login</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="agent_port" name="agent_port" placeholder="Agent Port">
                                    <label for="agent_port">Agent Port</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="web_console_password" name="web_console_password" placeholder="Web Console Password">
                                    <label for="web_console_password">Web Console Password</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="console" name="console" placeholder="Console">
                                    <label for="console">Console</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea class="form-control" id="others" name="others" placeholder="Others"></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        $('#installed_pc').select2({
            theme: "bootstrap-5",
            width: $(this).data('width') ? $(this).data('width') : $(this).hasClass('w-100') ? '100%' : 'style',
            placeholder: "Select Installed PC",
            closeOnSelect: true, // Ensure it closes after selecting one option
        });
    });
</script>
</body>
</html>

