<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeSoftwareGroup = isset($_GET['itemTypeSoftwareGroup']) ? $_GET['itemTypeSoftwareGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Directly get debtor_code from URL

$computerNames = [];
if (!empty($debtorCode) && !empty($companyName)) {
    $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
    $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
    $computerNames = $stmt->fetchAll(PDO::FETCH_COLUMN);
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1;
    $installedPc = $_POST['installed_pc'] ?? ''; // Change to single value
    $login = $_POST['login'] ?? '';
    $password = $_POST['password'] ?? '';
    $softwareName = $_POST['software_name'] ?? '';
    $softwareVersion = $_POST['software_version'] ?? '';
    $publicLicenseId = $_POST['public_license_id'] ?? '';
    $activationKey = $_POST['activation_key'] ?? '';
    $others = $_POST['others'] ?? '';
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included
    $brand = $_POST['brand'] ?? ''; // New antivirus brand field
    $numberOfDevices = $_POST['number_of_device'] ?? ''; // New number of devices field
    $purchaseFrom = $_POST['purchase_from'] ?? ''; // New purchase from field
    $expirationDate = $_POST['expiration_date'] ?? ''; // New expiration date field

    $encryptionKey = 'your_secret_key'; // This should be a secure key

    // Encrypt both password and activation key using the same encryption method
    $encryptedPassword = encryptPassword($password, $encryptionKey);
    $encryptedActivationKey = encryptPassword($activationKey, $encryptionKey);

    // Decrypt for logging purposes (optional, if needed)
    $decryptedPassword = decryptPassword($encryptedPassword, $encryptionKey);
    $decryptedActivationKey = decryptPassword($encryptedActivationKey, $encryptionKey);

    // Create log data excluding sensitive information and 'debtor_code'
    $logData = array(
        ':item_type_name' => $itemType,
        ':company_name' => $companyName,
        ':debtor_code' => $debtorCode,
        ':item_type_sw_group_name' => $itemTypeSoftwareGroup,
        ':active' => $active,
        ':installed_pc' => $installedPc,
        ':login' => $login,
        ':password' => $decryptedPassword,
        ':software_name' => $softwareName,
        ':software_version' => $softwareVersion,
        ':public_license_id' => $publicLicenseId,
        ':activation_key' => $decryptedActivationKey,
        ':others' => $others,
        ':brand' => $brand,  // Add the antivirus brand here
        ':number_of_device' => $numberOfDevices,  // Add the number of devices here
        ':purchase_from' => $purchaseFrom,  // Add the purchase from here
        ':expiration_date' => $expirationDate  // Add the expiration date here
    );

    try {
        // Prepare and execute the insert query for the new table
        $stmt = $pdo->prepare("INSERT INTO item_type_sw_av_is (
            item_type_name, 
            item_type_sw_group_name,
            company_name, 
            debtor_code,
            active,
            installed_pc,
            login,
            password,
            software_name,
            software_version,
            public_license_id,
            activation_key,
            others,
            brand,  -- Saving the antivirus brand
            number_of_device,  -- Saving the number of devices
            purchase_from,  -- Saving the purchase from
            expiration_date  -- Saving the expiration date
        ) VALUES (
            :item_type_name, 
            :item_type_sw_group_name,
            :company_name, 
            :debtor_code,
            :active,
            :installed_pc,
            :login,
            :password,
            :software_name,
            :software_version,
            :public_license_id,
            :activation_key,
            :others,
            :brand,  -- Bind the antivirus brand value
            :number_of_device,  -- Bind the number of devices value
            :purchase_from,  -- Bind the purchase from value
            :expiration_date  -- Bind the expiration date value
        )");
    
        // Execute the insert query
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':item_type_sw_group_name' => $itemTypeSoftwareGroup,
            ':active' => $active,
            ':installed_pc' => $installedPc,
            ':login' => $login,
            ':password' => $encryptedPassword,
            ':software_name' => $softwareName,
            ':software_version' => $softwareVersion,
            ':public_license_id' => $publicLicenseId,
            ':activation_key' => $encryptedActivationKey,
            ':others' => $others,
            ':brand' => $brand,  // Add the antivirus brand here
            ':number_of_device' => $numberOfDevices,  // Add the number of devices here
            ':purchase_from' => $purchaseFrom,  // Add the purchase from here
            ':expiration_date' => $expirationDate  // Add the expiration date here
        ]);
    
        $logMessage = "Item inserted into Antivirus Internet Security for $companyName";
    
        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);
    
        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeSoftwareGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                <!-- PC Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">PC Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-group row">
                            <div class="col-md-6">
                                <label for="installed_pc">Installed PC</label>
                                <select class="form-select" id="installed_pc" name="installed_pc" data-placeholder="Choose anything" required>
                                    <option value="" selected>Please select a PC</option>
                                    <?php foreach ($computerNames as $option): ?>
                                        <option value="<?php echo htmlspecialchars($option); ?>"><?php echo htmlspecialchars($option); ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Antivirus Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Antivirus Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="col-md-6">
                            <div class="form-floating row mb-3">
                                <select class="form-control" name="brand" id="brand">
                                    <option value="" selected>Please select an antivirus</option>
                                    <option value="ESET">ESET</option>
                                    <option value="Bitdefender">Bitdefender</option>
                                    <option value="Kaspersky">Kaspersky</option>
                                    <option value="Trend Micro">Trend Micro</option>
                                    <option value="Norton Antivirus">Norton Antivirus</option>
                                    <option value="AVG">AVG</option>
                                    <option value="Avira">Avira</option>
                                    <option value="Other">Other</option>
                                </select>
                                <label for="brand">Antivirus Brand</label>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Software Installation Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Software Installation Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-group row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login" id="login" class="form-control" placeholder="Login">
                                    <label for="login">Login</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="password" id="password" class="form-control" placeholder="Password">
                                    <label for="password">Password</label>
                                </div>
                            </div>
                        </div>
                        <div class="form-group row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="software_name" id="software_name" class="form-control" placeholder="Software Name">
                                    <label for="software_name">Software Name</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="software_version" id="software_version" class="form-control" placeholder="Software Version">
                                    <label for="software_version">Software Version</label>
                                </div>
                            </div>
                        </div>
                        <div class="form-group row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="public_license_id" id="public_license_id" class="form-control" placeholder="Public License ID">
                                    <label for="public_license_id">Public License ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="activation_key" id="activation_key" class="form-control" placeholder="Activation Key">
                                    <label for="activation_key">Activation Key</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Purchase and Expiration Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Purchase and Expiration Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-group row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="number" name="number_of_device" id="number_of_device" class="form-control" placeholder="Number of Devices">
                                    <label for="number_of_device">Number of Devices</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-control" name="purchase_from" id="purchase_from">
                                        <option value="" selected>Please select a purchase source</option>
                                        <option value="CITSSB">CITSSB</option>
                                        <option value="User Own Purchase">User Own Purchase</option>
                                        <option value="Freeway">Freeway</option>
                                    </select>
                                    <label for="purchase_from">Purchase From</label>
                                </div>
                            </div>
                        </div>
                        <div class="form-group row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" name="expiration_date" id="expiration_date" class="form-control" placeholder="Expiration Date">
                                    <label for="expiration_date">Expiration Date</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Additional Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Additional Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea id="others" name="others" class="form-control" placeholder="Additional Information"></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        $('#installed_pc').select2({
            theme: "bootstrap-5",
            width: $(this).data('width') ? $(this).data('width') : $(this).hasClass('w-100') ? '100%' : 'style',
            placeholder: $(this).data('placeholder'),
            closeOnSelect: true,
        });
    });
</script>
</body>
</html>

