<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeSoftwareGroup = isset($_GET['itemTypeSoftwareGroup']) ? $_GET['itemTypeSoftwareGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Directly get debtor_code from URL

// Fetch the license data
$licenses = [];
if (!empty($debtorCode) && !empty($companyName)) {
    $stmt = $pdo->prepare("SELECT master_account_id FROM item_type_sw_o365_master WHERE item_type_sw_group_name = 'Office 365 Master Account' AND debtor_code = :debtor_code AND company_name = :company_name");
    $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
    $licenses = $stmt->fetchAll(PDO::FETCH_COLUMN);
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1;
    $clientAccountId = $_POST['client_account_id'] ?? '';
    $clientAccountPassword = $_POST['client_account_password'] ?? '';
    $license = $_POST['license'] ?? '';
    $authenticator = $_POST['authenticator'] ?? '';
    $others = $_POST['others'] ?? '';
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included

    $encryptionKey = 'your_secret_key'; // This should be a secure key
    $encryptedClientAccountPassword = encryptPassword($clientAccountPassword, $encryptionKey);
    $decryptedClientAccountPassword = decryptPassword($encryptedClientAccountPassword, $encryptionKey);

    try {
        // Prepare and execute the insert query
        $stmt = $pdo->prepare("INSERT INTO item_type_sw_o365_client (
            item_type_name, 
            item_type_sw_group_name,
            company_name, 
            active,
            debtor_code,
            client_account_id,
            client_account_password,
            license,
            authenticator,
            others
        ) VALUES (
            :item_type_name, 
            :item_type_sw_group_name,
            :company_name, 
            :active,
            :debtor_code,
            :client_account_id,
            :client_account_password,
            :license,
            :authenticator,
            :others
        )");

        // Execute the insert query
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':item_type_sw_group_name' => $itemTypeSoftwareGroup,
            ':debtor_code' => $debtorCode,
            ':active' => $active,
            ':client_account_id' => $clientAccountId,
            ':client_account_password' => $encryptedClientAccountPassword,
            ':license' => $license,
            ':authenticator' => $authenticator,
            ':others' => $others
        ]);

        $logMessage = "Item inserted into Microsoft Office 365 Client Account for $companyName";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Check if the "Save and Add New" button was clicked
        if (isset($_POST['save_and_new'])) {
            // Retain the form values
            $clientAccountId = $_POST['client_account_id'];
            $clientAccountPassword = $_POST['client_account_password'];
            $authenticator = $_POST['authenticator'];
            $license = $_POST['license'];
            $others = $_POST['others'];

            // Success alert
            echo "<script>alert('Data saved successfully!');</script>";
        } else {
            // Success alert and redirect
            echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
        }
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add Configuration Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Add Configuration Details</h1>
        </div>
        <div class="card-body">
            <form method="POST" id="configForm">
                <!-- Display the passed values -->
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeSoftwareGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">License</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="license">License</label>
                                    <select class="form-select" id="license" name="license" data-placeholder="Choose a license">
                                        <option value="">Please select a license</option>
                                        <?php foreach ($licenses as $license): ?>
                                            <option value="<?php echo htmlspecialchars($license); ?>" <?php echo isset($_POST['license']) && $_POST['license'] === $license ? 'selected' : ''; ?>>
                                                <?php echo htmlspecialchars($license); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Account Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <!-- Left column -->
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="client_account_id" id="client_account_id" class="form-control" placeholder="Client Account ID" value="<?php echo htmlspecialchars($_POST['client_account_id'] ?? ''); ?>">
                                    <label for="client_account_id">Client Account ID</label>
                                </div>
                            </div>
                            <!-- Right column -->
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="client_account_password" id="client_account_password" class="form-control" placeholder="Client Account Password" value="<?php echo htmlspecialchars($_POST['client_account_password'] ?? ''); ?>">
                                    <label for="client_account_password">Client Account Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Authenticator</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="authenticator" id="authenticator" class="form-control" placeholder="Authenticator Mobile Name (For Office Use)" value="<?php echo htmlspecialchars($_POST['authenticator'] ?? ''); ?>">
                                    <label for="authenticator">Authenticator Mobile Name (For Office Use)</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-floating mb-3">
                                    <textarea id="others" name="others" class="form-control" placeholder="Others"><?php echo htmlspecialchars($_POST['others'] ?? ''); ?></textarea>
                                    <label for="others">Others</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary" name="save">Save</button>
                <!-- Save and Add New Button -->
                <button type="submit" class="btn btn-success" name="save_and_new">Save and Add New</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        // Initialize Select2 for the license dropdown
        $('#license').select2({
            theme: "bootstrap-5",
            placeholder: "Please select a license"
        });
    });
</script>
</body>
</html>

