<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemType = isset($_GET['itemType']) ? $_GET['itemType'] : '';
$itemTypeSoftwareGroup = isset($_GET['itemTypeSoftwareGroup']) ? $_GET['itemTypeSoftwareGroup'] : '';
$companyName = isset($_GET['companyName']) ? $_GET['companyName'] : '';
$debtorCode = isset($_GET['debtorCode']) ? $_GET['debtorCode'] : ''; // Directly get debtor_code from URL

// Fetch the list of installed PCs from the database
$installedPcs = [];
if ($debtorCode && $companyName) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1;
    $masterAccountId = $_POST['master_account_id'] ?? '';
    $masterAccountPassword = $_POST['master_account_password'] ?? '';
    $license = $_POST['license'] ?? '';
    $login = $_POST['login'] ?? '';
    $password = $_POST['password'] ?? '';
    $authenticator = $_POST['authenticator'] ?? '';
    $others = $_POST['others'] ?? '';
    $installedPc = $_POST['installed_pc'] ?? ''; // Retrieve installed_pc from POST
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included

    // Encrypt the master_account_password and password
    $encryptionKey = 'your_secret_key'; // This should be a secure key
    $encryptedMasterAccountPassword = encryptPassword($masterAccountPassword, $encryptionKey);
    $encryptedPassword = encryptPassword($password, $encryptionKey);

    // Decrypt the passwords for logging (not recommended for production)
    $decryptedMasterAccountPassword = decryptPassword($encryptedMasterAccountPassword, $encryptionKey);
    $decryptedPassword = decryptPassword($encryptedPassword, $encryptionKey);

    try {
        // Prepare and execute the insert query
        $stmt = $pdo->prepare("INSERT INTO item_type_sw_o365_master (
            item_type_name, 
            item_type_sw_group_name,
            company_name, 
            debtor_code,
            active,
            master_account_id,
            master_account_password,
            license,
            login,
            password,
            authenticator,
            others,
            installed_pc
        ) VALUES (
            :item_type_name, 
            :item_type_sw_group_name,
            :company_name, 
            :debtor_code,
            :active,
            :master_account_id,
            :master_account_password,
            :license,
            :login,
            :password,
            :authenticator,
            :others,
            :installed_pc
        )");
    
        $stmt->execute([
            ':item_type_name' => $itemType,
            ':item_type_sw_group_name' => $itemTypeSoftwareGroup,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':active' => $active,
            ':master_account_id' => $masterAccountId,
            ':master_account_password' => $encryptedMasterAccountPassword, // Encrypted password
            ':license' => $license,
            ':login' => $login,
            ':password' => $encryptedPassword, // Encrypted password
            ':authenticator' => $authenticator,
            ':others' => $others,
            ':installed_pc' => $installedPc // Include installed_pc in the execute array
        ]);
    
        $logMessage = "Item inserted into Microsoft Office 365 Master Account for $companyName";
    
        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);
    
        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = 'add_config_info.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display the passed values -->
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeSoftwareGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Account Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="master_account_id" id="master_account_id" class="form-control" placeholder="Master Account ID">
                                    <label for="master_account_id">Master Account ID</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="master_account_password" id="master_account_password" class="form-control" placeholder="Master Account Password">
                                    <label for="master_account_password">Master Account Password</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="license" id="license" class="form-control" placeholder="License">
                                    <label for="license">License</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login" id="login" class="form-control" placeholder="Login">
                                    <label for="login">Login</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="password" id="password" class="form-control" placeholder="Password">
                                    <label for="password">Password</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="authenticator" id="authenticator" class="form-control" placeholder="Authenticator Mobile Name (For Office Use)">
                                    <label for="authenticator">Authenticator Mobile Name (For Office Use)</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Installed PC</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-group">
                            <label for="installed_pc">Installed PC</label>
                            <select class="form-control" name="installed_pc" id="installed_pc">
                                <option value="">Select Installed PC</option>
                                <?php foreach ($installedPcs as $option): ?>
                                    <option value="<?php echo htmlspecialchars($option); ?>"><?php echo htmlspecialchars($option); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea id="others" name="others" class="form-control" placeholder="Others"></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        $('#installed_pc').select2({
            theme: "bootstrap-5",
            width: $(this).data('width') ? $(this).data('width') : $(this).hasClass('w-100') ? '100%' : 'style',
            placeholder: "Select Installed PC",
            closeOnSelect: true, // Ensure it closes after selecting one option
        });
    });
</script>
</body>
</html>

