<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the item_type_ac_main_id from the URL
$itemTypeAcId = isset($_GET['item_type_ac_main_id']) ? $_GET['item_type_ac_main_id'] : '';

// Fetch the existing data from the database
$itemTypeAcData = [];
if ($itemTypeAcId) {
    try {
        $stmt = $pdo->prepare("SELECT * FROM item_type_ac_main WHERE item_type_ac_main_id = ?");
        $stmt->execute([$itemTypeAcId]);
        $itemTypeAcData = $stmt->fetch(PDO::FETCH_ASSOC);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($itemTypeAcData['company_name']) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$itemTypeAcData['company_name']]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

try {
    // Fetch necessary data
    $itemtype = $pdo->query("SELECT item_type_id, item_type_name FROM item_type")->fetchAll(PDO::FETCH_ASSOC);
    $itemtype_ac_group = $pdo->query("SELECT item_type_ac_group_id, item_type_ac_group_name FROM item_type_ac_group")->fetchAll(PDO::FETCH_ASSOC);
    $add_on_module = $pdo->query("SELECT ac_function_module_id, ac_function_module_name FROM ac_function_module")->fetchAll(PDO::FETCH_ASSOC);
    $add_on_pos_module = $pdo->query("SELECT ac_function_pos_module_id, ac_function_pos_module_name FROM ac_function_pos_module")->fetchAll(PDO::FETCH_ASSOC);
    $plug_in = $pdo->query("SELECT ac_function_plug_in_id, ac_function_plug_in_name FROM ac_function_plug_in")->fetchAll(PDO::FETCH_ASSOC);

    // Fetch installed PC options from item_type_pc where debtor_code and company_name match
    $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtorCode AND company_name = :companyName");
    $stmt->execute([':debtorCode' => $debtorCode, ':companyName' => $itemTypeAcData['company_name']]);
    $installedPcOptions = $stmt->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}

// Fetch add-on modules, plug-ins, and add-on POS modules for the given item_type_ac_main_id
$selectedAddOnModules = [];
$selectedPlugIns = [];
$selectedAddOnPosModules = [];

if ($itemTypeAcId) {
    try {
        $stmt = $pdo->prepare("SELECT module_name FROM add_on_modules WHERE item_type_ac_main_id = ?");
        $stmt->execute([$itemTypeAcId]);
        $selectedAddOnModules = $stmt->fetchAll(PDO::FETCH_COLUMN);

        $stmt = $pdo->prepare("SELECT plug_in_name FROM plug_ins WHERE item_type_ac_main_id = ?");
        $stmt->execute([$itemTypeAcId]);
        $selectedPlugIns = $stmt->fetchAll(PDO::FETCH_COLUMN);

        $stmt = $pdo->prepare("SELECT pos_module_name FROM add_on_pos_modules WHERE item_type_ac_main_id = ?");
        $stmt->execute([$itemTypeAcId]);
        $selectedAddOnPosModules = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Handle form submission to update data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Debugging: Print out the POST data
    error_log(print_r($_POST, true));
    $active = isset($_POST['active']) ? 1 : 0;
    $offsiteBackup = isset($_POST['offsite_backup']) ? 1 : 0;
    $tax = isset($_POST['tax']) ? 1 : 0;
    $plugIn = isset($_POST['plug_in']) ? $_POST['plug_in'] : [];
    $implementAndTrainingEInvoice = isset($_POST['implement_and_training_e_invoice']) ? 1 : 0;
    $backupTime = $_POST['backup_time'] ?? null;
    $autocountEdition = $_POST['autocount_edition'] ?? null;
    $autocountVersion = $_POST['autocount_version'] ?? null;
    $autocountRevision = $_POST['autocount_revision'] ?? null;
    $sqlName = $_POST['sql_name'] ?? null;
    $sqlPort = $_POST['sql_port'] ?? null;
    $sqlServerVersion = $_POST['sql_server_version'] ?? null;
    $adminPassword = $_POST['admin_password'] ?? null;
    $installedPc = $_POST['installed_pc'] ?? '';
    $autoEmailAddress = $_POST['auto_email_address'] ?? null;
    $mainPcInstallerComputerTcpIp = $_POST['main_pc_installer_computer_tcpip'] ?? null;
    $numberOfAccountBook = $_POST['number_of_account_book'] ?? null;
    $accountingPid = $_POST['accounting_pid'] ?? null;
    $eInvoiceInstalledCompanyNames = $_POST['einvoice_installed_company_name'] ?? [];
    $eInvoiceInstalledCompanyNamesString = implode(',', $eInvoiceInstalledCompanyNames);
    $addOnModules = $_POST['add_on_module'] ?? [];
    $addOnPosModules = $_POST['add_on_pos_module'] ?? [];
    $others = $_POST['others'] ?? null;

    // Encrypt the admin password
    $encryptionKey = 'your_secret_key'; // This should be a secure key
    $encryptedAdminPassword = encryptPassword($adminPassword, $encryptionKey);

    // Decrypt the old admin password for comparison
    $decryptedOldAdminPassword = decryptPassword($itemTypeAcData['admin_password'], $encryptionKey);

    // Helper function to compare values
    function compareValues($oldValue, $newValue, $fieldName) {
        // Trim whitespace
        $oldValue = trim($oldValue);
        $newValue = trim($newValue);
    
        // Handle time fields specifically
        if ($fieldName === 'backup_time') {
            // Convert both values to the same time format for comparison
            $oldTime = date('H:i:s', strtotime($oldValue));
            $newTime = date('H:i:s', strtotime($newValue));
    
            // Compare the formatted times
            if ($oldTime !== $newTime) {
                return "$oldValue -> $newValue";
            }
            return null;
        }
    
        // Convert to consistent types (e.g., integers for numeric fields)
        if (is_numeric($oldValue) && is_numeric($newValue)) {
            $oldValue = (int)$oldValue;
            $newValue = (int)$newValue;
        }
    
        // Strict comparison for other fields
        if ($oldValue !== $newValue) {
            return "$oldValue -> $newValue";
        }
        return null;
    }

    // Compare old and new data
    $changes = [];

    // Compare 'number_of_account_book'
    if ($change = compareValues($itemTypeAcData['number_of_account_book'], $numberOfAccountBook, 'number_of_account_book')) {
        $changes['number_of_account_book'] = $change;
    }

    // Compare 'accounting_pid'
    if ($change = compareValues($itemTypeAcData['accounting_pid'], $accountingPid, 'accounting_pid')) {
        $changes['accounting_pid'] = $change;
    }

    // Compare 'active'
    if ($change = compareValues($itemTypeAcData['active'], $active, 'active')) {
        $changes['active'] = $change;
    }

    // Compare 'offsite_backup'
    if ($change = compareValues($itemTypeAcData['offsite_backup'], $offsiteBackup, 'offsite_backup')) {
        $changes['offsite_backup'] = $change;
    }

    // Compare 'tax'
    if ($change = compareValues($itemTypeAcData['tax'], $tax, 'tax')) {
        $changes['tax'] = $change;
    }

    // Compare 'backup_time'
    if ($change = compareValues($itemTypeAcData['backup_time'], $backupTime, 'backup_time')) {
        $changes['backup_time'] = $change;
    }

    // Compare 'autocount_edition'
    if ($change = compareValues($itemTypeAcData['autocount_edition'], $autocountEdition, 'autocount_edition')) {
        $changes['autocount_edition'] = $change;
    }

    // Compare 'autocount_version'
    if ($change = compareValues($itemTypeAcData['autocount_version'], $autocountVersion, 'autocount_version')) {
        $changes['autocount_version'] = $change;
    }

    // Compare 'autocount_revision'
    if ($change = compareValues($itemTypeAcData['autocount_revision'], $autocountRevision, 'autocount_revision')) {
        $changes['autocount_revision'] = $change;
    }

    // Compare 'sql_name'
    if ($change = compareValues($itemTypeAcData['sql_name'], $sqlName, 'sql_name')) {
        $changes['sql_name'] = $change;
    }

    // Compare 'sql_port'
    if ($change = compareValues($itemTypeAcData['sql_port'], $sqlPort, 'sql_port')) {
        $changes['sql_port'] = $change;
    }

    // Compare 'sql_server_version'
    if ($change = compareValues($itemTypeAcData['sql_server_version'], $sqlServerVersion, 'sql_server_version')) {
        $changes['sql_server_version'] = $change;
    }

    // Compare 'admin_password'
    if ($change = compareValues($decryptedOldAdminPassword, $adminPassword, 'admin_password')) {
        $changes['admin_password'] = $change;
    }

    // Compare 'installed_pc'
    if ($change = compareValues($itemTypeAcData['installed_pc'], $installedPc, 'installed_pc')) {
        $changes['installed_pc'] = $change;
    }

    // Compare 'auto_email_address'
    if ($change = compareValues($itemTypeAcData['auto_email_address'], $autoEmailAddress, 'auto_email_address')) {
        $changes['auto_email_address'] = $change;
    }

    // Compare 'main_pc_installer_computer_tcpip'
    if ($change = compareValues($itemTypeAcData['main_pc_installer_computer_tcpip'], $mainPcInstallerComputerTcpIp, 'main_pc_installer_computer_tcpip')) {
        $changes['main_pc_installer_computer_tcpip'] = $change;
    }

    // Compare 'implement_and_training_e_invoice'
    if ($change = compareValues($itemTypeAcData['implement_and_training_e_invoice'], $implementAndTrainingEInvoice, 'implement_and_training_e_invoice')) {
        $changes['implement_and_training_e_invoice'] = $change;
    }

    // Compare 'einvoice_installed_company_name'
    if ($change = compareValues($itemTypeAcData['einvoice_installed_company_name'], $eInvoiceInstalledCompanyNamesString, 'einvoice_installed_company_name')) {
        $changes['einvoice_installed_company_name'] = $change;
    }

    // Compare 'others'
    if ($change = compareValues($itemTypeAcData['others'], $others, 'others')) {
        $changes['others'] = $change;
    }

    // Fetch names for add-on modules
    $oldAddOnModuleNames = [];
    foreach ($selectedAddOnModules as $moduleId) {
        $stmt = $pdo->prepare("SELECT ac_function_module_name FROM ac_function_module WHERE ac_function_module_id = ?");
        $stmt->execute([$moduleId]);
        $moduleName = $stmt->fetchColumn();
        if ($moduleName) {
            $oldAddOnModuleNames[] = $moduleName;
        }
    }

    $newAddOnModuleNames = [];
    foreach ($addOnModules as $moduleId) {
        $stmt = $pdo->prepare("SELECT ac_function_module_name FROM ac_function_module WHERE ac_function_module_id = ?");
        $stmt->execute([$moduleId]);
        $moduleName = $stmt->fetchColumn();
        if ($moduleName) {
            $newAddOnModuleNames[] = $moduleName;
        }
    }

    if (array_diff($oldAddOnModuleNames, $newAddOnModuleNames) || array_diff($newAddOnModuleNames, $oldAddOnModuleNames)) {
        $changes['add_on_module'] = implode(', ', $oldAddOnModuleNames) . ' -> ' . implode(', ', $newAddOnModuleNames);
    }

    // Fetch names for plug-ins
    $oldPlugInNames = [];
    foreach ($selectedPlugIns as $plugInId) {
        $stmt = $pdo->prepare("SELECT ac_function_plug_in_name FROM ac_function_plug_in WHERE ac_function_plug_in_id = ?");
        $stmt->execute([$plugInId]);
        $plugInName = $stmt->fetchColumn();
        if ($plugInName) {
            $oldPlugInNames[] = $plugInName;
        }
    }

    $newPlugInNames = [];
    foreach ($plugIn as $plugInId) {
        $stmt = $pdo->prepare("SELECT ac_function_plug_in_name FROM ac_function_plug_in WHERE ac_function_plug_in_id = ?");
        $stmt->execute([$plugInId]);
        $plugInName = $stmt->fetchColumn();
        if ($plugInName) {
            $newPlugInNames[] = $plugInName;
        }
    }

    if (array_diff($oldPlugInNames, $newPlugInNames) || array_diff($newPlugInNames, $oldPlugInNames)) {
        $changes['plug_in'] = implode(', ', $oldPlugInNames) . ' -> ' . implode(', ', $newPlugInNames);
    }

    // Fetch names for add-on POS modules
    $oldAddOnPosModuleNames = [];
    foreach ($selectedAddOnPosModules as $posModuleId) {
        $stmt = $pdo->prepare("SELECT ac_function_pos_module_name FROM ac_function_pos_module WHERE ac_function_pos_module_id = ?");
        $stmt->execute([$posModuleId]);
        $posModuleName = $stmt->fetchColumn();
        if ($posModuleName) {
            $oldAddOnPosModuleNames[] = $posModuleName;
        }
    }

    $newAddOnPosModuleNames = [];
    foreach ($addOnPosModules as $posModuleId) {
        $stmt = $pdo->prepare("SELECT ac_function_pos_module_name FROM ac_function_pos_module WHERE ac_function_pos_module_id = ?");
        $stmt->execute([$posModuleId]);
        $posModuleName = $stmt->fetchColumn();
        if ($posModuleName) {
            $newAddOnPosModuleNames[] = $posModuleName;
        }
    }

    if (array_diff($oldAddOnPosModuleNames, $newAddOnPosModuleNames) || array_diff($newAddOnPosModuleNames, $oldAddOnPosModuleNames)) {
        $changes['add_on_pos_module'] = implode(', ', $oldAddOnPosModuleNames) . ' -> ' . implode(', ', $newAddOnPosModuleNames);
    }

    // Check if there are any changes
    if (!empty($changes)) {
        try {
            $stmt = $pdo->prepare("UPDATE item_type_ac_main SET
                item_type_name = :item_type_name, 
                item_type_ac_group_name = :item_type_ac_group_name,
                company_name = :company_name, 
                debtor_code = :debtor_code, 
                active = :active,
                backup_time = :backup_time,
                autocount_edition = :autocount_edition,
                autocount_version = :autocount_version,
                autocount_revision = :autocount_revision,
                sql_name = :sql_name,
                sql_port = :sql_port,
                sql_server_version = :sql_server_version,
                admin_password = :admin_password,
                offsite_backup = :offsite_backup,
                tax = :tax,
                installed_pc = :installed_pc,
                auto_email_address = :auto_email_address,
                main_pc_installer_computer_tcpip = :main_pc_installer_computer_tcpip, 
                number_of_account_book = :number_of_account_book,
                accounting_pid = :accounting_pid, 
                implement_and_training_e_invoice = :implement_and_training_e_invoice, 
                einvoice_installed_company_name = :einvoice_installed_company_name,
                others = :others,
                updated_time = NOW() 
            WHERE item_type_ac_main_id = :item_type_ac_main_id");

            // Execute the update query
            $stmt->execute([
                ':item_type_name' => $itemTypeAcData['item_type_name'],
                ':item_type_ac_group_name' => $itemTypeAcData['item_type_ac_group_name'],
                ':company_name' => $itemTypeAcData['company_name'],
                ':debtor_code' => $debtorCode, // Include debtor_code in the update
                ':active' => $active,
                ':backup_time' => $backupTime,
                ':autocount_edition' => $autocountEdition,
                ':autocount_version' => $autocountVersion,
                ':autocount_revision' => $autocountRevision,
                ':sql_name' => $sqlName,
                ':sql_port' => $sqlPort,
                ':sql_server_version' => $sqlServerVersion,
                ':admin_password' => $encryptedAdminPassword,
                ':offsite_backup' => $offsiteBackup,
                ':tax' => $tax,
                ':installed_pc' => $installedPc,
                ':auto_email_address' => $autoEmailAddress,
                ':main_pc_installer_computer_tcpip' => $mainPcInstallerComputerTcpIp,
                ':number_of_account_book' => $numberOfAccountBook,
                ':accounting_pid' => $accountingPid,
                ':implement_and_training_e_invoice' => $implementAndTrainingEInvoice,
                ':einvoice_installed_company_name' => $eInvoiceInstalledCompanyNamesString,  // Saving the comma-separated string
                ':others' => $others,
                ':item_type_ac_main_id' => $itemTypeAcId
            ]);

            // Handle add-on modules
            $stmt = $pdo->prepare("DELETE FROM add_on_modules WHERE item_type_ac_main_id = ?");
            $stmt->execute([$itemTypeAcId]);

            foreach ($addOnModules as $moduleId) {
                $stmt = $pdo->prepare("INSERT INTO add_on_modules (module_name, item_type_ac_main_id) VALUES (:module_name, :item_type_ac_main_id)");
                $stmt->execute([
                    ':module_name' => $moduleId,
                    ':item_type_ac_main_id' => $itemTypeAcId
                ]);
            }

            // Handle plug-ins
            $stmt = $pdo->prepare("DELETE FROM plug_ins WHERE item_type_ac_main_id = ?");
            $stmt->execute([$itemTypeAcId]);

            foreach ($plugIn as $plugInId) {
                $stmt = $pdo->prepare("INSERT INTO plug_ins (plug_in_name, item_type_ac_main_id) VALUES (:plug_in_name, :item_type_ac_main_id)");
                $stmt->execute([
                    ':plug_in_name' => $plugInId,
                    ':item_type_ac_main_id' => $itemTypeAcId
                ]);
            }

            // Handle add-on POS modules
            $stmt = $pdo->prepare("DELETE FROM add_on_pos_modules WHERE item_type_ac_main_id = ?");
            $stmt->execute([$itemTypeAcId]);

            foreach ($addOnPosModules as $posModuleId) {
                $stmt = $pdo->prepare("INSERT INTO add_on_pos_modules (pos_module_name, item_type_ac_main_id) VALUES (:pos_module_name, :item_type_ac_main_id)");
                $stmt->execute([
                    ':pos_module_name' => $posModuleId,
                    ':item_type_ac_main_id' => $itemTypeAcId
                ]);
            }

            // Handle POS fields
            $posEditions = $_POST['pos_edition'] ?? [];
            $posRevisions = $_POST['pos_revision'] ?? [];
            $posVersions = $_POST['pos_version'] ?? [];
            $posPids = $_POST['pos_pid'] ?? [];
            $posFieldIds = $_POST['pos_field_id'] ?? [];

            // Fetch POS fields data from the database
            $posFieldsData = [];
            try {
                $stmt = $pdo->prepare("SELECT * FROM ac_pos_fields WHERE item_type_ac_main_id = ?");
                $stmt->execute([$itemTypeAcId]);
                $posFieldsData = $stmt->fetchAll(PDO::FETCH_ASSOC);
            } catch (PDOException $e) {
                error_log('Database query error: ' . $e->getMessage());
            }

            // Track changes in POS fields
            $oldPosFields = [];
            foreach ($posFieldsData as $posField) {
                $oldPosFields[$posField['id']] = [
                    'pos_edition' => $posField['pos_edition'],
                    'pos_revision' => $posField['pos_revision'],
                    'pos_version' => $posField['pos_version'],
                    'pos_pid' => $posField['pos_pid']
                ];
            }

            $newPosFields = [];
            for ($i = 0; $i < count($posEditions); $i++) {
                $newPosFields[$posFieldIds[$i] ?? 'new_' . $i] = [
                    'pos_edition' => $posEditions[$i],
                    'pos_revision' => $posRevisions[$i],
                    'pos_version' => $posVersions[$i],
                    'pos_pid' => $posPids[$i]
                ];
            }

            // Identify added, removed, and edited POS fields
            $addedPosFields = array_diff_key($newPosFields, $oldPosFields);
            $removedPosFields = array_diff_key($oldPosFields, $newPosFields);
            $editedPosFields = [];

            foreach ($newPosFields as $id => $newPosField) {
                if (isset($oldPosFields[$id]) && $oldPosFields[$id] !== $newPosField) {
                    $editedPosFields[$id] = [
                        'old' => $oldPosFields[$id],
                        'new' => $newPosField
                    ];
                }
            }

            // Log added POS fields
            foreach ($addedPosFields as $id => $posField) {
                $changes['pos_field_added'][] = "Edition: {$posField['pos_edition']}, Revision: {$posField['pos_revision']}, Version: {$posField['pos_version']}, PID: {$posField['pos_pid']}";
            }

            // Log removed POS fields
            foreach ($removedPosFields as $id => $posField) {
                $changes['pos_field_removed'][] = "Edition: {$posField['pos_edition']}, Revision: {$posField['pos_revision']}, Version: {$posField['pos_version']}, PID: {$posField['pos_pid']}";
            }

            // Log edited POS fields
            foreach ($editedPosFields as $id => $posField) {
                $changes['pos_field_edited'][] = "ID: $id, Old: Edition: {$posField['old']['pos_edition']}, Revision: {$posField['old']['pos_revision']}, Version: {$posField['old']['pos_version']}, PID: {$posField['old']['pos_pid']} -> New: Edition: {$posField['new']['pos_edition']}, Revision: {$posField['new']['pos_revision']}, Version: {$posField['new']['pos_version']}, PID: {$posField['new']['pos_pid']}";
            }

            // Delete removed POS fields
            if (!empty($posFieldsData)) {
                $removedPosFieldIds = array_diff(array_column($posFieldsData, 'id'), $posFieldIds);
                foreach ($removedPosFieldIds as $posFieldId) {
                    $stmt = $pdo->prepare("DELETE FROM ac_pos_fields WHERE id = ?");
                    $stmt->execute([$posFieldId]);
                }
            }

            // Update or insert POS fields
            for ($i = 0; $i < count($posEditions); $i++) {
                if (isset($posFieldIds[$i]) && !empty($posFieldIds[$i])) {
                    // Update existing POS field
                    $stmt = $pdo->prepare("UPDATE ac_pos_fields SET
                        pos_edition = :pos_edition,
                        pos_revision = :pos_revision,
                        pos_version = :pos_version,
                        pos_pid = :pos_pid
                    WHERE id = :pos_field_id");
                    $stmt->execute([
                        ':pos_edition' => $posEditions[$i],
                        ':pos_revision' => $posRevisions[$i],
                        ':pos_version' => $posVersions[$i],
                        ':pos_pid' => $posPids[$i],
                        ':pos_field_id' => $posFieldIds[$i]
                    ]);
                } else {
                    // Insert new POS field
                    $stmt = $pdo->prepare("INSERT INTO ac_pos_fields (
                        pos_edition,
                        pos_revision,
                        pos_version,
                        pos_pid,
                        item_type_ac_main_id
                    ) VALUES (
                        :pos_edition,
                        :pos_revision,
                        :pos_version,
                        :pos_pid,
                        :item_type_ac_main_id
                    )");
                    $stmt->execute([
                        ':pos_edition' => $posEditions[$i],
                        ':pos_revision' => $posRevisions[$i],
                        ':pos_version' => $posVersions[$i],
                        ':pos_pid' => $posPids[$i],
                        ':item_type_ac_main_id' => $itemTypeAcId
                    ]);
                }
            }

            // Construct log message
            $logMessage = "Updated data in Autocount:\n";
            foreach ($changes as $field => $change) {
                if (is_array($change)) {
                    $logMessage .= "$field:\n";
                    foreach ($change as $item) {
                        $logMessage .= "  $item\n";
                    }
                } else {
                    $logMessage .= "$field: $change\n";
                }
            }

            // Insert log into activity_logs
            $stmtLog = $pdo->prepare("INSERT INTO activity_logs (username, timestamp, role, activity)
                                        VALUES (:username, :timestamp, :role, :activity)");
            $stmtLog->execute([
                ':username' => isset($_SESSION['username']) ? $_SESSION['username'] : 'N/A',
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => isset($_SESSION['role']) ? $_SESSION['role'] : 'N/A',
                ':activity' => $logMessage
            ]);

            // Success alert and redirect
            echo "<script>alert('Data updated successfully!'); window.location.href = '/crm/public/company/view_autocount_table.php?debtor_code=$debtorCode';</script>";
        } catch (PDOException $e) {
            error_log('Database update error: ' . $e->getMessage());
            echo "<script>alert('Failed to update data. Please try again.'); window.location.href = '/crm/public/config_info/edit_ac_autocount.php?item_type_ac_main_id=$itemTypeAcId';</script>";
        }
    } else {
        // No changes were made, display alert only
        echo "<script>alert('No data change.'); window.location.href = '/crm/public/company/view_autocount_table.php?debtor_code=$debtorCode';</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
<meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    
    <!-- Bootstrap 5.x CSS via CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">

    <!-- Include jQuery (necessary for Select2) -->
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    
    <!-- Include Select2 CSS and JS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
    <style>
        .einvoice-field {
            margin-bottom: 10px;
        }
    </style>
</head>
<body>

<div class="container mt-5">
    <form method="POST">
        <input type="hidden" name="item_type_ac_main_id" value="<?php echo htmlspecialchars($itemTypeAcId); ?>">
        <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Edit Configuration Details</h1>
            </div>
            <div class="card-body">
                <p>Company Name: <strong><?php echo htmlspecialchars($itemTypeAcData['company_name']); ?></strong></p>
                <p>Item Type: <strong><?php echo htmlspecialchars($itemTypeAcData['item_type_name']); ?></strong></p>
                <p>Item Type Ac Group: <strong><?php echo htmlspecialchars($itemTypeAcData['item_type_ac_group_name']); ?></strong></p>

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $itemTypeAcData['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Autocount Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select name="autocount_edition" id="autocount_edition" class="form-select">
                                        <option value="">Select an edition</option>
                                        <option value="express_accounting" <?php if ($itemTypeAcData['autocount_edition'] == 'express_accounting') echo 'selected'; ?>>Express Accounting</option>
                                        <option value="express_invoicing" <?php if ($itemTypeAcData['autocount_edition'] == 'express_invoicing') echo 'selected'; ?>>Express Invoicing</option>
                                        <option value="express_complete" <?php if ($itemTypeAcData['autocount_edition'] == 'express_complete') echo 'selected'; ?>>Express Complete</option>
                                        <option value="accountant" <?php if ($itemTypeAcData['autocount_edition'] == 'accountant') echo 'selected'; ?>>Accountant</option>
                                        <option value="account_plus" <?php if ($itemTypeAcData['autocount_edition'] == 'account_plus') echo 'selected'; ?>>Account Plus</option>
                                        <option value="express_plus" <?php if ($itemTypeAcData['autocount_edition'] == 'express_plus') echo 'selected'; ?>>Express Plus</option>
                                        <option value="basic" <?php if ($itemTypeAcData['autocount_edition'] == 'basic') echo 'selected'; ?>>Basic</option>
                                        <option value="pro" <?php if ($itemTypeAcData['autocount_edition'] == 'pro') echo 'selected'; ?>>Pro</option>
                                        <option value="premium" <?php if ($itemTypeAcData['autocount_edition'] == 'premium') echo 'selected'; ?>>Premium</option>
                                        <option value="ultimate" <?php if ($itemTypeAcData['autocount_edition'] == 'ultimate') echo 'selected'; ?>>Ultimate</option>
                                    </select>
                                    <label for="autocount_edition">Autocount Edition:</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <select name="autocount_version" id="autocount_version" class="form-select">
                                        <option value="">Select an Autocount Version</option>
                                        <option value="1.5" <?php if ($itemTypeAcData['autocount_version'] == '1.5') echo 'selected'; ?>>1.5</option>
                                        <option value="1.8" <?php if ($itemTypeAcData['autocount_version'] == '1.8') echo 'selected'; ?>>1.8</option>
                                        <option value="1.9" <?php if ($itemTypeAcData['autocount_version'] == '1.9') echo 'selected'; ?>>1.9</option>
                                        <option value="2.0" <?php if ($itemTypeAcData['autocount_version'] == '2.0') echo 'selected'; ?>>2.0</option>
                                        <option value="2.1" <?php if ($itemTypeAcData['autocount_version'] == '2.1') echo 'selected'; ?>>2.1</option>
                                        <option value="2.2" <?php if ($itemTypeAcData['autocount_version'] == '2.2') echo 'selected'; ?>>2.2</option>
                                        <option value="2.3" <?php if ($itemTypeAcData['autocount_version'] == '2.3') echo 'selected'; ?>>2.3</option>
                                        <option value="2.4" <?php if ($itemTypeAcData['autocount_version'] == '2.4') echo 'selected'; ?>>2.4</option>
                                        <option value="2.5" <?php if ($itemTypeAcData['autocount_version'] == '2.5') echo 'selected'; ?>>2.5</option>
                                    </select>
                                    <label for="autocount_version">Autocount Version:</label>
                                </div>    
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="autocount_revision" id="autocount_revision" class="form-control" value="<?php echo htmlspecialchars($itemTypeAcData['autocount_revision']); ?>">
                                    <label for="autocount_revision">Autocount Revision</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="number" name="number_of_account_book" id="number_of_account_book" class="form-control" value="<?php echo htmlspecialchars($itemTypeAcData['number_of_account_book']); ?>">
                                    <label for="number_of_account_book">Number of Account Book</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Autocount Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="admin_password" id="admin_password" class="form-control" value="<?php echo htmlspecialchars(decryptPassword($itemTypeAcData['admin_password'], 'your_secret_key')); ?>">
                                    <label for="admin_password">Admin Password</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="auto_email_address" id="auto_email_address" class="form-control" value="<?php echo htmlspecialchars($itemTypeAcData['auto_email_address']); ?>">
                                    <label for="auto_email_address">Autocount Email Address</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">SQL Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select name="sql_server_version" id="sql_server_version" class="form-select">
                                        <option value="">Select a SQL Server Version:</option>
                                        <option value="2005" <?php if ($itemTypeAcData['sql_server_version'] == '2005') echo 'selected'; ?>>2005</option>
                                        <option value="2008" <?php if ($itemTypeAcData['sql_server_version'] == '2008') echo 'selected'; ?>>2008</option>
                                        <option value="2012" <?php if ($itemTypeAcData['sql_server_version'] == '2012') echo 'selected'; ?>>2012</option>
                                        <option value="2016" <?php if ($itemTypeAcData['sql_server_version'] == '2016') echo 'selected'; ?>>2016</option>
                                        <option value="2019" <?php if ($itemTypeAcData['sql_server_version'] == '2019') echo 'selected'; ?>>2019</option>
                                    </select>
                                    <label for="sql_server_version">SQL Server Version:</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="sql_name" id="sql_name" class="form-control" value="<?php echo htmlspecialchars($itemTypeAcData['sql_name']); ?>">
                                    <label for="sql_name">SQL Name</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="sql_port" id="sql_port" class="form-control" value="<?php echo htmlspecialchars($itemTypeAcData['sql_port']); ?>">
                                    <label for="sql_port">SQL Port</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>      
                
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Backup Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="time" name="backup_time" id="backup_time" class="form-control" value="<?php echo htmlspecialchars($itemTypeAcData['backup_time']); ?>">
                                    <label for="backup_time">Backup Time:</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-check">
                                    <input type="checkbox" name="offsite_backup" value="1" class="form-check-input" <?php if ($itemTypeAcData['offsite_backup'] == 1) echo 'checked'; ?>>
                                    <label class="form-check-label" for="offsite_backup">Offsite Backup</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Tax Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-check">
                                    <input type="checkbox" name="tax" value="1" class="form-check-input" <?php if ($itemTypeAcData['tax'] == 1) echo 'checked'; ?>>
                                    <label class="form-check-label" for="tax">Tax</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Autocount Main PC Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-select" id="installed_pc" name="installed_pc">
                                        <option value="" disabled selected>Choose a PC</option>
                                        <?php foreach ($installedPcOptions as $option): ?>
                                            <option value="<?php echo htmlspecialchars($option); ?>" <?php if ($itemTypeAcData['installed_pc'] == $option) echo 'selected'; ?>><?php echo htmlspecialchars($option); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="installed_pc">Installed PC</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="main_pc_installer_computer_tcpip" id="main_pc_installer_computer_tcpip" class="form-control" value="<?php echo htmlspecialchars($itemTypeAcData['main_pc_installer_computer_tcpip']); ?>">
                                    <label for="main_pc_installer_computer_tcpip">Main PC Installer Computer TCP/IP</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="accounting_pid" id="accounting_pid" class="form-control" value="<?php echo htmlspecialchars($itemTypeAcData['accounting_pid']); ?>">
                                    <label for="accounting_pid">Accounting PID</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>                

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">E-Invoice Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-check">
                                    <input type="checkbox" name="implement_and_training_e_invoice" value="1" class="form-check-input" <?php if ($itemTypeAcData['implement_and_training_e_invoice'] == 1) echo 'checked'; ?>>
                                    <label class="form-check-label" for="implement_and_training_e_invoice">Implement and Training E Invoice</label>
                                </div>
                            </div>
                        </div>
    
                        <div class="row mt-3">
                            <div class="col-md-12">
                                <label for="einvoice_installed_company_name">E Invoice Installed Company Name</label>
                                <!-- Bootstrap Button and Input Group -->
                                <div id="einvoiceContainer">
                                    <?php
                                    $eInvoiceInstalledCompanyNames = explode(',', $itemTypeAcData['einvoice_installed_company_name']);
                                    foreach ($eInvoiceInstalledCompanyNames as $companyName): ?>
                                        <div class="einvoice-field mb-2">
                                            <div class="input-group">
                                                <input type="text" name="einvoice_installed_company_name[]" class="form-control" placeholder="Enter company name" value="<?php echo htmlspecialchars($companyName); ?>">
                                                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
                                            </div>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                                <button type="button" class="btn btn-primary mb-3" onclick="addField()">Add More</button>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Modules and Plug-Ins</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-12">
                                <!-- Add-On Modules -->
                                <div class="form-group">
                                    <label for="add_on_module">Add-On Module</label>
                                    <select id="add_on_module" name="add_on_module[]" class="form-select select2-multiple" multiple="multiple" data-placeholder="Choose add-on modules" style="width: 100%;">
                                        <?php foreach ($add_on_module as $addOnModule): ?>
                                            <option value="<?php echo htmlspecialchars($addOnModule['ac_function_module_id']); ?>" 
                                                <?php if (in_array($addOnModule['ac_function_module_id'], $selectedAddOnModules)) echo 'selected'; ?>>
                                                <?php echo htmlspecialchars($addOnModule['ac_function_module_name']); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>

                                <!-- Plug-ins -->
                                <div class="form-group">
                                    <label for="plug_in">Select Plug In:</label>
                                    <select id="plug_in" name="plug_in[]" class="form-select select2-multiple" multiple="multiple" data-placeholder="Choose plug-ins" style="width: 100%;">
                                        <?php foreach ($plug_in as $plugInModule): ?>
                                            <option value="<?php echo htmlspecialchars($plugInModule['ac_function_plug_in_id']); ?>" 
                                                <?php if (in_array($plugInModule['ac_function_plug_in_id'], $selectedPlugIns)) echo 'selected'; ?>>
                                                <?php echo htmlspecialchars($plugInModule['ac_function_plug_in_name']); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>

                                <!-- Add-On POS Modules -->
                                <div class="form-group">
                                    <label for="add_on_pos_module">Add On POS Module: </label>
                                    <br>
                                    <select id="add_on_pos_module" name="add_on_pos_module[]" class="form-select select2-multiple" multiple="multiple" data-placeholder="Choose add-on POS modules" style="width: 100%;">
                                        <?php foreach ($add_on_pos_module as $addOnPosModule): ?>
                                            <option value="<?php echo htmlspecialchars($addOnPosModule['ac_function_pos_module_id']); ?>" 
                                                <?php if (in_array($addOnPosModule['ac_function_pos_module_id'], $selectedAddOnPosModules)) echo 'selected'; ?>>
                                                <?php echo htmlspecialchars($addOnPosModule['ac_function_pos_module_name']); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                            <!-- Others Information -->
                <div class="card mb-3">
                <div class="card-header">
                    <h5 class="mb-0">Others Information</h5>
                </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea name="others" id="others" class="form-control"><?php echo htmlspecialchars($itemTypeAcData['others']); ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- POS Fields Card -->
        <div id="posFieldsContainer">
            <?php
            // Fetch POS fields data from the database
            $posFieldsData = [];
            try {
                $stmt = $pdo->prepare("SELECT * FROM ac_pos_fields WHERE item_type_ac_main_id = ?");
                $stmt->execute([$itemTypeAcId]);
                $posFieldsData = $stmt->fetchAll(PDO::FETCH_ASSOC);
            } catch (PDOException $e) {
                error_log('Database query error: ' . $e->getMessage());
            }

            foreach ($posFieldsData as $posField): ?>
                <div class="card mt-4 shadow-lg pos-field-card">
                    <div class="card-header bg-secondary text-white">
                        <h5 class="mb-0">POS Fields</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select name="pos_edition[]" id="pos_edition" class="form-select">
                                        <option value="" disabled selected>Please select a POS edition</option>
                                        <option value="pos_basic" <?php if ($posField['pos_edition'] == 'pos_basic') echo 'selected'; ?>>POS Basic</option>
                                        <option value="pos_standard" <?php if ($posField['pos_edition'] == 'pos_standard') echo 'selected'; ?>>POS Standard</option>
                                        <option value="pos_counter_a" <?php if ($posField['pos_edition'] == 'pos_counter_a') echo 'selected'; ?>>POS Counter A</option>
                                        <option value="pos_counter_b" <?php if ($posField['pos_edition'] == 'pos_counter_b') echo 'selected'; ?>>POS Counter B</option>
                                        <option value="pos_counter_branch" <?php if ($posField['pos_edition'] == 'pos_counter_branch') echo 'selected'; ?>>POS Counter Branch</option>
                                    </select>
                                    <label for="pos_edition">POS Edition:</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <select name="pos_version[]" id="pos_version" class="form-select">
                                        <option value="">Select a Pos Version</option>
                                        <option value="3.0" <?php if ($posField['pos_version'] == '3.0') echo 'selected'; ?>>3.0</option>
                                        <option value="3.1" <?php if ($posField['pos_version'] == '3.1') echo 'selected'; ?>>3.1</option>
                                        <option value="5.0" <?php if ($posField['pos_version'] == '5.0') echo 'selected'; ?>>5.0</option>
                                        <option value="5.1" <?php if ($posField['pos_version'] == '5.1') echo 'selected'; ?>>5.1</option>
                                        <option value="5.2" <?php if ($posField['pos_version'] == '5.2') echo 'selected'; ?>>5.2</option>
                                    </select>
                                    <label for="pos_version">POS Version:</label>
                                </div>

                            </div>

                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="pos_revision[]" id="pos_revision" class="form-control" value="<?php echo htmlspecialchars($posField['pos_revision']); ?>">
                                    <label for="pos_revision">POS Revision</label>
                                </div>
                                
                                <div class="form-floating mb-3">
                                    <input type="text" name="pos_pid[]" id="pos_pid" class="form-control" value="<?php echo htmlspecialchars($posField['pos_pid']); ?>">
                                    <label for="pos_pid">POS PID</label>
                                </div>
                            </div>
                        </div>
                        <input type="hidden" name="pos_field_id[]" value="<?php echo htmlspecialchars($posField['id']); ?>">
                        <button type="button" class="btn btn-danger mt-3" onclick="removePosFieldCard(this)">Remove</button>
                        <button type="button" class="btn btn-primary mt-3" onclick="addPosFieldCard()">Add POS Field Card</button>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
        <br>
        <button type="submit" class="btn btn-primary">Update</button>
    </form>
</div>
</body>
</html>
<!-- Select2 CSS -->
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet">
<link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet">

<!-- jQuery -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>

<!-- Bootstrap 5.x JS via CDN -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script>
    $(document).ready(function() {
        initializeSelect2ForFields();
        
        // Initialize Select2 for the moved Add On POS Module
        $('#add_on_pos_module').select2({
            theme: "bootstrap-5",
            width: '100%',
            placeholder: "Choose add-on POS modules",
            closeOnSelect: false,
        });
    });

    function initializeSelect2ForFields() {
        $('.pos-field-card #add_on_pos_module').each(function() {
            initializeSelect2ForElement($(this));
        });

        if (!$('#plug_in').hasClass("select2-hidden-accessible")) {
            $('#plug_in').select2({
                theme: "bootstrap-5",
                width: '100%',
                placeholder: "Choose plug-ins",
                closeOnSelect: false,
            });
        }

        if (!$('#add_on_module').hasClass("select2-hidden-accessible")) {
            $('#add_on_module').select2({
                theme: "bootstrap-5",
                width: '100%',
                placeholder: "Choose add-on modules",
                closeOnSelect: false,
            });
        }
    }

    function initializeSelect2ForElement(element) {
        if (!element.hasClass("select2-hidden-accessible")) {
            element.select2({
                theme: "bootstrap-5",
                width: '100%',
                placeholder: "Choose add-on POS modules",
                closeOnSelect: false,
            });
        }
    }

    function addPosFieldCard() {
        const container = document.getElementById('posFieldsContainer');
        const cardCount = container.childElementCount;
        
        // Create a new card
        const newCard = document.createElement('div');
        newCard.className = 'card mt-4 shadow-lg pos-field-card';
        newCard.innerHTML = `
            <div class="card-header bg-secondary text-white">
                <h5 class="mb-0">POS Fields</h5>
            </div>
            <div class="card-body">
                <div class="row">
                    <div class="col-md-6">
                        <div class="form-floating mb-3">
                            <select name="pos_edition[]" id="pos_edition_${cardCount}" class="form-select">
                                <option value="" disabled selected>Please select a POS edition</option>
                                <option value="pos_basic">POS Basic</option>
                                <option value="pos_standard">POS Standard</option>
                                <option value="pos_counter_a">POS Counter A</option>
                                <option value="pos_counter_b">POS Counter B</option>
                                <option value="pos_counter_branch">POS Counter Branch</option>
                            </select>
                            <label for="pos_edition_${cardCount}">POS Edition:</label>
                        </div>
                        <div class="form-floating mb-3">
                            <select name="pos_version[]" id="pos_version_${cardCount}" class="form-select">
                                <option value="">Select a Pos Version</option>
                                <option value="3.0">3.0</option>
                                <option value="3.1">3.1</option>
                                <option value="5.0">5.0</option>
                                <option value="5.1">5.1</option>
                                <option value="5.2">5.2</option>
                            </select>
                            <label for="pos_version_${cardCount}">POS Version:</label>
                        </div>
                        
                    </div>
                    <div class="col-md-6">
                        <div class="form-floating mb-3">
                            <input type="text" name="pos_revision[]" id="pos_revision_${cardCount}" class="form-control">
                            <label for="pos_revision_${cardCount}">POS Revision</label>
                        </div>
                        
                        <div class="form-floating mb-3">
                            <input type="text" name="pos_pid[]" id="pos_pid_${cardCount}" class="form-control">
                            <label for="pos_pid_${cardCount}">POS PID</label>
                        </div>
                    </div>
                </div>
                <button type="button" class="btn btn-danger mt-3" onclick="removePosFieldCard(this)">Remove</button>
                <button type="button" class="btn btn-primary mt-3" onclick="addPosFieldCard()">Add POS Field Card</button>
            </div>
        `;

        // Append the new card
        container.appendChild(newCard);

        // Initialize Select2 for the new add_on_pos_module field
        initializeSelect2ForElement($(`#add_on_pos_module_${cardCount}`));
    }

    function getAddOnPosModuleOptions() {
        // This function should return the HTML for the add-on POS module options
        // You may need to adjust this based on how you're getting the data
        return `
            <?php foreach ($add_on_pos_module as $addOnPosModule): ?>
                <option value="<?php echo htmlspecialchars($addOnPosModule['ac_function_pos_module_id']); ?>">
                    <?php echo htmlspecialchars($addOnPosModule['ac_function_pos_module_name']); ?>
                </option>
            <?php endforeach; ?>
        `;
    }

    function removePosFieldCard(button) {
        const container = document.getElementById('posFieldsContainer');
        if (container.childElementCount > 1) {
            button.closest('.pos-field-card').remove();
        } else {
            alert('You must have at least one POS field card.');
        }
    }

    // Function to add E-Invoice field
    function addField() {
        const container = document.getElementById('einvoiceContainer');
        const newField = document.createElement('div');
        newField.className = 'einvoice-field mb-2';
        newField.innerHTML = `
            <div class="input-group">
                <input type="text" name="einvoice_installed_company_name[]" class="form-control" placeholder="Enter company name">
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            </div>
        `;
        container.appendChild(newField);
    }

    // Function to remove E-Invoice field
    function removeField(button) {
        button.closest('.einvoice-field').remove();
    }
</script>

