<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if item_type_cloud_accounting_id is passed via URL
if (!isset($_GET['item_type_cloud_accounting_id'])) {
    echo "<p>No item ID provided.</p>";
    exit;
}

$itemTypeCloudAccountingId = $_GET['item_type_cloud_accounting_id'];

// Fetch the item details based on item_type_cloud_accounting_id
$stmt = $pdo->prepare('SELECT * FROM item_type_cloud_accounting WHERE item_type_cloud_accounting_id = :item_type_cloud_accounting_id LIMIT 1');
$stmt->bindParam(':item_type_cloud_accounting_id', $itemTypeCloudAccountingId);
$stmt->execute();
$item = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$item) {
    echo "<p>No item found with the provided ID.</p>";
    exit;
}

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($item['company_name']) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$item['company_name']]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Handle form submission to update data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $active = isset($_POST['active']) ? 1 : 0;
    $loginAccount = $_POST['login_account'] ?? null;
    $loginPassword = $_POST['login_password'] ?? null;
    $oneSalesPos = isset($_POST['onesales_pos']) ? 1 : 0;
    $oneSalesEcommerce = isset($_POST['onesales_ecommerce']) ? 1 : 0;
    $others = $_POST['others'] ?? null;

    // Encrypt the login password if it has been changed
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $encryptedLoginPassword = $item['login_password']; // Default to the existing encrypted password
    if ($loginPassword !== $item['login_password']) {
        $encryptedLoginPassword = encryptPassword($loginPassword, $encryptionKey);
    }

    // Decrypt the existing password for comparison and logging
    $decryptedExistingPassword = decryptPassword($item['login_password'], $encryptionKey);

    // Compare old and new values
    $logMessage = "Changes made to Cloud Accounting for company: " . $item['company_name'] . "\n";
    $changes = [];

    if ($item['active'] != $active) {
        $changes['active'] = "Old: " . $item['active'] . " -> New: " . $active;
    }
    if ($item['login_account'] != $loginAccount) {
        $changes['login_account'] = "Old: " . $item['login_account'] . " -> New: " . $loginAccount;
    }
    if ($decryptedExistingPassword != $loginPassword) {
        $changes['login_password'] = "Old: " . $decryptedExistingPassword . " -> New: " . $loginPassword;
    }
    if ($item['onesales_pos'] != $oneSalesPos) {
        $changes['onesales_pos'] = "Old: " . $item['onesales_pos'] . " -> New: " . $oneSalesPos;
    }
    if ($item['onesales_ecommerce'] != $oneSalesEcommerce) {
        $changes['onesales_ecommerce'] = "Old: " . $item['onesales_ecommerce'] . " -> New: " . $oneSalesEcommerce;
    }
    if ($item['others'] != $others) {
        $changes['others'] = "Old: " . $item['others'] . " -> New: " . $others;
    }

    // If there are changes, log them
    if (!empty($changes)) {
        foreach ($changes as $field => $change) {
            $logMessage .= "$field: $change\n";
        }

        try {
            $stmt = $pdo->prepare("UPDATE item_type_cloud_accounting SET
                active = :active,
                login_account = :login_account,
                login_password = :login_password,
                onesales_pos = :onesales_pos,
                onesales_ecommerce = :onesales_ecommerce,
                others = :others,
                updated_time = NOW()
            WHERE item_type_cloud_accounting_id = :item_type_cloud_accounting_id");

            // Execute the update query
            $stmt->execute([
                ':active' => $active,
                ':login_account' => $loginAccount,
                ':login_password' => $encryptedLoginPassword,
                ':onesales_pos' => $oneSalesPos,
                ':onesales_ecommerce' => $oneSalesEcommerce,
                ':others' => $others,
                ':item_type_cloud_accounting_id' => $itemTypeCloudAccountingId,
            ]);

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // Success alert and redirect to view_autocount_table.php
            echo "<script>alert('Data updated successfully for Debtor Code: " . htmlspecialchars($debtorCode) . "!'); window.location.href = '/crm/public/company/view_autocount_table.php?debtor_code=" . urlencode($debtorCode) . "';</script>";
        } catch (PDOException $e) {
            error_log('Database update error: ' . $e->getMessage());
            echo "<script>alert('Failed to update data. Please try again.'); window.location.href = '/crm/public/company/view_autocount_table.php?debtor_code=" . urlencode($debtorCode) . "';</script>";
        }
    } else {
        // No changes were made, show alert and redirect to view_autocount_table.php
        echo "<script>alert('No changes were made.'); window.location.href = '/crm/public/company/view_autocount_table.php?debtor_code=" . urlencode($debtorCode) . "';</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Cloud Accounting Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit Cloud Accounting Details</h1>
        </div>
        <div class="card-body">
            <!-- Display Information Section -->
            <div class="mb-3">
                <p>Company Name: <strong><?php echo htmlspecialchars($item['company_name']); ?></strong></p>
                <p>Item Type: <strong><?php echo htmlspecialchars($item['item_type_name']); ?></strong></p>
                <p>Item Type Ac Group: <strong><?php echo htmlspecialchars($item['item_type_ac_group_name']); ?></strong></p>
            </div>

            <form method="POST">
                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" id="active" <?= $item['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- Login Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_account" id="login_account" class="form-control" placeholder="Login Account" value="<?php echo htmlspecialchars($item['login_account']); ?>">
                                    <label for="login_account">Login Account</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_password" id="login_password" class="form-control" placeholder="Login Password" value="<?php echo htmlspecialchars(decryptPassword($item['login_password'], 'your_secret_key')); ?>">
                                    <label for="login_password">Login Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- OneSales Options -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">OneSales Options</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-check mb-3">
                                    <input type="checkbox" name="onesales_pos" id="onesales_pos" class="form-check-input" <?php if ($item['onesales_pos']) echo 'checked'; ?>>
                                    <label class="form-check-label" for="onesales_pos">OneSales POS</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-check mb-3">
                                    <input type="checkbox" name="onesales_ecommerce" id="onesales_ecommerce" class="form-check-input" <?php if ($item['onesales_ecommerce']) echo 'checked'; ?>>
                                    <label class="form-check-label" for="onesales_ecommerce">OneSales E-Commerce</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating">
                            <textarea name="others" id="others" class="form-control" placeholder="Others"><?php echo htmlspecialchars($item['others']); ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Hidden Input for Debtor Code -->
                <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Save</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

