<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if item_type_cloud_payroll_id is passed via URL
if (!isset($_GET['item_type_cloud_payroll_id'])) {
    echo "<p>No item ID provided.</p>";
    exit;
}

$itemTypeCloudPayrollId = $_GET['item_type_cloud_payroll_id'];

// Fetch the item details based on item_type_cloud_payroll_id
$stmt = $pdo->prepare('SELECT * FROM item_type_cloud_payroll WHERE item_type_cloud_payroll_id = :item_type_cloud_payroll_id LIMIT 1');
$stmt->bindParam(':item_type_cloud_payroll_id', $itemTypeCloudPayrollId);
$stmt->execute();
$item = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$item) {
    echo "<p>No item found with the provided ID.</p>";
    exit;
}

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($item['company_name']) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$item['company_name']]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

$add_on_module = [];
try {
    // Fetch necessary data
    $itemtype = $pdo->query("SELECT item_type_id, item_type_name FROM item_type")->fetchAll(PDO::FETCH_ASSOC);
    $itemtype_ac_group = $pdo->query("SELECT item_type_ac_group_id, item_type_ac_group_name FROM item_type_ac_group")->fetchAll(PDO::FETCH_ASSOC);
    $add_on_module = $pdo->query("SELECT ac_function_module_id, ac_function_module_name FROM ac_function_module")->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}

// Handle form submission to update data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Debugging: Print out the POST data
    error_log(print_r($_POST, true));

    $active = isset($_POST['active']) ? 1 : 0;
    $loginAccount = $_POST['login_account'] ?? null;
    $loginPassword = $_POST['login_password'] ?? null;
    $hardwareId = $_POST['hardware_id'] ?? null;
    $linkingHardware = $_POST['linking_hardware'] ?? null;
    $payrollUserLoginId = $_POST['payroll_user_login_id'] ?? null;
    $payrollUserLoginPassword = $_POST['payroll_user_login_password'] ?? null;
    $location = $_POST['location'] ?? null;
    $others = $_POST['others'] ?? null;
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included

    // Debugging: Print out the debtor_code
    error_log('Debtor Code: ' . $debtorCode);

    // Ensure login_password and payroll_user_login_password are strings
    if (is_array($loginPassword)) {
        $loginPassword = implode(',', $loginPassword);
    }

    // Encrypt the login_password
    $encryptedLoginPassword = encryptPassword($loginPassword, 'your_secret_key');

    // Encrypt each payroll_user_login_password individually
    $encryptedPayrollUserLoginPasswords = [];
    if (is_array($payrollUserLoginPassword)) {
        foreach ($payrollUserLoginPassword as $password) {
            $encryptedPayrollUserLoginPasswords[] = encryptPassword($password, 'your_secret_key');
        }
    } else {
        $encryptedPayrollUserLoginPasswords[] = encryptPassword($payrollUserLoginPassword, 'your_secret_key');
    }
    $encryptedPayrollUserLoginPassword = implode(',', $encryptedPayrollUserLoginPasswords);

    // Decrypt the old login password for logging
    $decryptedOldLoginPassword = decryptPassword($item['login_password'], 'your_secret_key');

    // Decrypt the old payroll user login passwords for logging
    $decryptedOldPayrollUserLoginPasswords = [];
    if (!empty($item['payroll_user_login_password'])) {
        $oldPayrollPasswords = explode(',', $item['payroll_user_login_password']);
        foreach ($oldPayrollPasswords as $password) {
            $decryptedOldPayrollUserLoginPasswords[] = decryptPassword($password, 'your_secret_key');
        }
    }
    $decryptedOldPayrollUserLoginPassword = implode(',', $decryptedOldPayrollUserLoginPasswords);

    // Debugging: Print out the decrypted passwords
    error_log('Decrypted Old Login Password: ' . $decryptedOldLoginPassword);
    error_log('Decrypted Old Payroll User Login Password: ' . $decryptedOldPayrollUserLoginPassword);

    // Create log data excluding sensitive information and 'debtor_code'
    $logData = array(
        'active' => $active,
        'login_account' => $loginAccount,
        'login_password' => $loginPassword,
        'hardware_id' => is_array($hardwareId) ? implode(',', $hardwareId) : $hardwareId,
        'linking_hardware' => is_array($linkingHardware) ? implode(',', $linkingHardware) : $linkingHardware,
        'payroll_user_login_id' => is_array($payrollUserLoginId) ? implode(',', $payrollUserLoginId) : $payrollUserLoginId,
        'payroll_user_login_password' => is_array($payrollUserLoginPassword) ? implode(',', $payrollUserLoginPassword) : $payrollUserLoginPassword,
        'location' => is_array($location) ? implode(',', $location) : $location,
        'others' => $others,
    );

    // Compare old and new data to log only changes
    $changes = [];
    foreach ($logData as $key => $value) {
        if ($key === 'login_password' || $key === 'payroll_user_login_password') {
            $oldValue = $key === 'login_password' ? $decryptedOldLoginPassword : $decryptedOldPayrollUserLoginPassword;
            if ($oldValue !== $value) {
                $changes[] = "$key: $oldValue -> $value";
            }
        } else {
            if ($item[$key] !== $value) {
                $changes[] = "$key: " . $item[$key] . " -> $value";
            }
        }
    }

    if (!empty($changes)) {
        $logMessage = "Changes made to item_type_cloud_payroll:\n" . implode("\n", $changes);

        try {
            $stmt = $pdo->prepare("UPDATE item_type_cloud_payroll SET
                active = :active,
                login_account = :login_account,
                login_password = :login_password,
                hardware_id = :hardware_id,
                linking_hardware = :linking_hardware,
                payroll_user_login_id = :payroll_user_login_id,
                payroll_user_login_password = :payroll_user_login_password,
                location = :location,
                others = :others,
                updated_time = NOW(),
                debtor_code = :debtor_code
            WHERE item_type_cloud_payroll_id = :item_type_cloud_payroll_id");

            // Execute the update query
            $stmt->execute([
                ':active' => $active,
                ':login_account' => $loginAccount,
                ':login_password' => $encryptedLoginPassword,
                ':hardware_id' => is_array($hardwareId) ? implode(',', $hardwareId) : $hardwareId,
                ':linking_hardware' => is_array($linkingHardware) ? implode(',', $linkingHardware) : $linkingHardware,
                ':payroll_user_login_id' => is_array($payrollUserLoginId) ? implode(',', $payrollUserLoginId) : $payrollUserLoginId,
                ':payroll_user_login_password' => $encryptedPayrollUserLoginPassword,
                ':location' => is_array($location) ? implode(',', $location) : $location,
                ':others' => $others,
                ':debtor_code' => $debtorCode,
                ':item_type_cloud_payroll_id' => $itemTypeCloudPayrollId,
            ]);

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // Success alert and redirect
            echo "<script>alert('Data updated successfully for Debtor Code: " . htmlspecialchars($debtorCode) . "!'); window.location.href = '/crm/public/company/view_autocount_table.php?debtor_code=" . urlencode($debtorCode) . "';</script>";
        } catch (PDOException $e) {
            error_log('Database update error: ' . $e->getMessage());
            echo "<script>alert('Failed to update data. Please try again.'); window.location.href = '/crm/public/config_info/edit_ac_cloud_payroll.php?item_type_cloud_payroll_id=" . $itemTypeCloudPayrollId . "';</script>";
        }
    } else {
        echo "<script>alert('No changes were made.'); window.location.href = '/crm/public/company/view_autocount_table.php?debtor_code=" . urlencode($debtorCode) . "';</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Cloud Payroll Details</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit Cloud Payroll Details</h1>
        </div>
        <div class="card-body">
            <!-- Display Information Section -->
            <div class="mb-3">
                <p>Company Name: <strong><?php echo htmlspecialchars($item['company_name']); ?></strong></p>
                <p>Item Type: <strong><?php echo htmlspecialchars($item['item_type_name']); ?></strong></p>
                <p>Item Type Ac Group: <strong><?php echo htmlspecialchars($item['item_type_ac_group_name']); ?></strong></p>
            </div>

            <form method="POST">
                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $item['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_account" id="login_account" class="form-control" placeholder="Login Account" value="<?php echo htmlspecialchars($item['login_account']); ?>">
                                    <label for="login_account">Login Account</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_password" id="login_password" class="form-control" placeholder="Login Password" value="<?php echo htmlspecialchars(decryptPassword($item['login_password'], 'your_secret_key')); ?>">
                                    <label for="login_password">Login Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Cloud Payroll Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-group" id="cloudPayrollContainer">
                            <?php
                            $hardwareIds = explode(',', $item['hardware_id']);
                            $linkingHardwares = explode(',', $item['linking_hardware']);
                            $locations = explode(',', $item['location']);
                            foreach ($hardwareIds as $index => $hardwareId) {
                                $linkingHardware = isset($linkingHardwares[$index]) ? $linkingHardwares[$index] : '';
                                $location = isset($locations[$index]) ? $locations[$index] : '';
                                ?>
                                <div class="input-group mb-2">
                                    <div class="form-floating me-2">
                                        <input type="text" class="form-control" name="hardware_id[]" placeholder="Hardware ID" value="<?php echo htmlspecialchars($hardwareId); ?>">
                                        <label>Hardware ID</label>
                                    </div>
                                    <div class="form-floating me-2">
                                        <input type="text" class="form-control" name="linking_hardware[]" placeholder="Linking Hardware" value="<?php echo htmlspecialchars($linkingHardware); ?>">
                                        <label>Linking Hardware</label>
                                    </div>
                                    <div class="form-floating me-2">
                                        <input type="text" class="form-control" name="location[]" placeholder="Location" value="<?php echo htmlspecialchars($location); ?>">
                                        <label>Location</label>
                                    </div>
                                    <button type="button" class="btn btn-danger" onclick="removeContainer(this)">Remove</button>
                                </div>
                                <?php
                            }
                            ?>
                        </div>
                        <button type="button" class="btn btn-secondary" onclick="addContainer('cloudPayroll')">Add Fields</button>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Payroll User Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-group" id="payrollUserLoginContainer">
                            <?php
                            $payrollUserLoginIds = explode(',', $item['payroll_user_login_id']);
                            $payrollUserLoginPasswords = explode(',', $item['payroll_user_login_password']);
                            foreach ($payrollUserLoginIds as $index => $payrollUserLoginId) {
                                $payrollUserLoginPassword = isset($payrollUserLoginPasswords[$index]) ? $payrollUserLoginPasswords[$index] : '';
                                ?>
                                <div class="input-group mb-2">
                                    <div class="form-floating me-2">
                                        <input type="text" class="form-control" name="payroll_user_login_id[]" placeholder="Payroll User Login ID" value="<?php echo htmlspecialchars($payrollUserLoginId); ?>">
                                        <label>Payroll User Login ID</label>
                                    </div>
                                    <div class="form-floating me-2">
                                        <input type="text" class="form-control" name="payroll_user_login_password[]" placeholder="Payroll User Login Password" value="<?php echo htmlspecialchars(decryptPassword($payrollUserLoginPassword, 'your_secret_key')); ?>">
                                        <label>Payroll User Login Password</label>
                                    </div>
                                    <button type="button" class="btn btn-danger" onclick="removeContainer(this)">Remove</button>
                                </div>
                                <?php
                            }
                            ?>
                        </div>
                        <button type="button" class="btn btn-secondary" onclick="addContainer('payrollUserLogin')">Add Fields</button>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea name="others" id="others" class="form-control" placeholder="Others"><?php echo htmlspecialchars($item['others']); ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>
                <!-- Add hidden input for debtor_code -->
                <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Update</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap JS and dependencies -->
<script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.4/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>

<script>
function addContainer(containerId) {
    const container = document.getElementById(containerId + 'Container');

    if (containerId === 'cloudPayroll') {
        const fieldGroup = `
            <div class="input-group mb-2">
                <div class="form-floating me-2">
                    <input type="text" class="form-control" name="hardware_id[]" placeholder="Hardware ID">
                    <label>Hardware ID</label>
                </div>
                <div class="form-floating me-2">
                    <input type="text" class="form-control" name="linking_hardware[]" placeholder="Linking Hardware">
                    <label>Linking Hardware</label>
                </div>
                <div class="form-floating me-2">
                    <input type="text" class="form-control" name="location[]" placeholder="Location">
                    <label>Location</label>
                </div>
                <button type="button" class="btn btn-danger" onclick="removeContainer(this)">Remove</button>
            </div>
        `;
        container.insertAdjacentHTML('beforeend', fieldGroup);
    } else if (containerId === 'payrollUserLogin') {
        const fieldGroup = `
            <div class="input-group mb-2">
                <div class="form-floating me-2">
                    <input type="text" class="form-control" name="payroll_user_login_id[]" placeholder="Payroll User Login ID">
                    <label>Payroll User Login ID</label>
                </div>
                <div class="form-floating me-2">
                    <input type="text" class="form-control" name="payroll_user_login_password[]" placeholder="Payroll User Login Password">
                    <label>Payroll User Login Password</label>
                </div>
                <button type="button" class="btn btn-danger" onclick="removeContainer(this)">Remove</button>
            </div>
        `;
        container.insertAdjacentHTML('beforeend', fieldGroup);
    }
}

function removeContainer(button) {
    const container = button.closest('.input-group').parentElement;
    if (container.childElementCount > 1) {
        button.closest('.input-group').remove();
    } else {
        alert('The last field cannot be removed.');
    }
}
</script>
</body>
</html>

