<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if item_type_million_accounting_id is passed via URL
if (!isset($_GET['item_type_million_accounting_id'])) {
    echo "<p>No item ID provided.</p>";
    exit;
}

$itemTypeMillionAccountingId = $_GET['item_type_million_accounting_id'];

// Fetch the item details based on item_type_million_accounting_id
$stmt = $pdo->prepare('SELECT * FROM item_type_million_accounting WHERE item_type_million_accounting_id = :item_type_million_accounting_id LIMIT 1');
$stmt->bindParam(':item_type_million_accounting_id', $itemTypeMillionAccountingId);
$stmt->execute();
$item = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$item) {
    echo "<p>No item found with the provided ID.</p>";
    exit;
}

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($item['company_name']) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$item['company_name']]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

$add_on_module = [];
$installedPcOptions = [];
try {
    // Fetch necessary data
    $itemtype = $pdo->query("SELECT item_type_id, item_type_name FROM item_type")->fetchAll(PDO::FETCH_ASSOC);
    $itemtype_ac_group = $pdo->query("SELECT item_type_ac_group_id, item_type_ac_group_name FROM item_type_ac_group")->fetchAll(PDO::FETCH_ASSOC);
    $add_on_module = $pdo->query("SELECT ac_function_module_id, ac_function_module_name FROM ac_function_module")->fetchAll(PDO::FETCH_ASSOC);

    // Fetch installed PC options from item_type_pc where debtor_code and company_name match
    $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtorCode AND company_name = :companyName");
    $stmt->execute([':debtorCode' => $debtorCode, ':companyName' => $item['company_name']]);
    $installedPcOptions = $stmt->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}

// Handle form submission to update data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Debugging: Print out the POST data
    error_log(print_r($_POST, true));

    $active = isset($_POST['active']) ? 1 : 0;
    $sqlServerVersion = $_POST['sql_server_version'] ?? null;
    $version = $_POST['version'] ?? null;
    $loginId = $_POST['login_id'] ?? null;
    $password = $_POST['password'] ?? null;
    $installedPc = $_POST['installed_pc'] ?? null; // Change to single value
    $others = $_POST['others'] ?? null;
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included
    // Debugging: Print out the debtor_code
    error_log('Debtor Code: ' . $debtorCode);

    // Encrypt the password if it has been changed
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $encryptedPassword = $item['password']; // Default to the existing encrypted password
    if ($password !== $item['password']) {
        $encryptedPassword = encryptPassword($password, $encryptionKey);
    }
    $decryptedPassword = decryptPassword($encryptedPassword, $encryptionKey);

    // Store the old data
    $oldData = $item;
    $oldData['password'] = decryptPassword($oldData['password'], $encryptionKey);

    // Check if any data has changed
    $hasChanges = false;
    if ($active != $oldData['active']) $hasChanges = true;
    if ($sqlServerVersion != $oldData['sql_server_version']) $hasChanges = true;
    if ($version != $oldData['version']) $hasChanges = true;
    if ($loginId != $oldData['login_id']) $hasChanges = true;
    if ($password != $oldData['password']) $hasChanges = true;
    if ($installedPc != $oldData['installed_pc']) $hasChanges = true;
    if ($others != $oldData['others']) $hasChanges = true;
    if ($debtorCode != $oldData['debtor_code']) $hasChanges = true;

    if (!$hasChanges) {
        echo "<script>alert('No data changed.'); window.location.href = '/crm/public/company/view_autocount_table.php?debtor_code=" . urlencode($debtorCode) . "';</script>";
        exit;
    }

    try {
        $stmt = $pdo->prepare("UPDATE item_type_million_accounting SET
            active = :active,
            sql_server_version = :sql_server_version,
            version = :version,
            login_id = :login_id,
            password = :password,
            installed_pc = :installed_pc,
            others = :others,
            updated_time = NOW(),
            debtor_code = :debtor_code
        WHERE item_type_million_accounting_id = :item_type_million_accounting_id");

        // Execute the update query
        $stmt->execute([
            ':active' => $active,
            ':sql_server_version' => $sqlServerVersion,
            ':version' => $version,
            ':login_id' => $loginId,
            ':password' => $encryptedPassword,
            ':installed_pc' => $installedPc, // Change to single value
            ':others' => $others,
            ':debtor_code' => $debtorCode,
            ':item_type_million_accounting_id' => $itemTypeMillionAccountingId,
        ]);

        // Fetch the new data after the update
        $stmt = $pdo->prepare('SELECT * FROM item_type_million_accounting WHERE item_type_million_accounting_id = :item_type_million_accounting_id LIMIT 1');
        $stmt->bindParam(':item_type_million_accounting_id', $itemTypeMillionAccountingId);
        $stmt->execute();
        $newItem = $stmt->fetch(PDO::FETCH_ASSOC);
        $newItem['password'] = decryptPassword($newItem['password'], $encryptionKey);

        // Build the log message with only the fields that have changed, excluding 'updated_time'
        $logMessage = "Data change in million accounting (Company Name: " . $item['company_name'] . "):\n";
        foreach ($oldData as $key => $value) {
            if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
            }
        }

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data updated successfully for Debtor Code: " . htmlspecialchars($debtorCode) . "!'); window.location.href = '/crm/public/company/view_autocount_table.php?debtor_code=" . urlencode($debtorCode) . "';</script>";
    } catch (PDOException $e) {
        error_log('Database update error: ' . $e->getMessage());
        echo "<script>alert('Failed to update data. Please try again.'); window.location.href = '/crm/public/config_info/edit_ac_million_accounting.php?item_type_million_accounting_id=" . $itemTypeMillionAccountingId . "';</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Million Accounting Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit Million Accounting Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display Information Section -->
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($item['company_name']); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($item['item_type_name']); ?></strong></p>
                    <p>Item Type Ac Group: <strong><?php echo htmlspecialchars($item['item_type_ac_group_name']); ?></strong></p>
                </div>

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $item['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Status and SQL Server Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select name="sql_server_version" id="sql_server_version" class="form-select">
                                        <option value="">Select a SQL Server Version</option>
                                        <option value="2005" <?php if ($item['sql_server_version'] == '2005') echo 'selected'; ?>>2005</option>
                                        <option value="2008" <?php if ($item['sql_server_version'] == '2008') echo 'selected'; ?>>2008</option>
                                        <option value="2012" <?php if ($item['sql_server_version'] == '2012') echo 'selected'; ?>>2012</option>
                                        <option value="2016" <?php if ($item['sql_server_version'] == '2016') echo 'selected'; ?>>2016</option>
                                        <option value="2019" <?php if ($item['sql_server_version'] == '2019') echo 'selected'; ?>>2019</option>
                                        <option value="2024" <?php if ($item['sql_server_version'] == '2024') echo 'selected'; ?>>2024</option>
                                    </select>
                                    <label for="sql_server_version">SQL Server Version</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="version" id="version" class="form-control" value="<?php echo htmlspecialchars($item['version']); ?>">
                                    <label for="version">Version</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_id" id="login_id" class="form-control" value="<?php echo htmlspecialchars($item['login_id']); ?>">
                                    <label for="login_id">Login ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="password" id="password" class="form-control" value="<?php echo htmlspecialchars(decryptPassword($item['password'], 'your_secret_key')); ?>">
                                    <label for="password">Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">PC Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-select" id="installed_pc" name="installed_pc">
                                        <option value="" disabled <?php echo empty($item['installed_pc']) ? 'selected' : ''; ?>>Please select a PC</option>
                                        <?php foreach ($installedPcOptions as $option): ?>
                                            <option value="<?php echo htmlspecialchars($option); ?>" <?php echo $option == $item['installed_pc'] ? 'selected' : ''; ?>>
                                                <?php echo htmlspecialchars($option); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>


                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-floating mb-3">
                                    <textarea name="others" id="others" class="form-control"><?php echo htmlspecialchars($item['others']); ?></textarea>
                                    <label for="others">Others</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Add hidden input for debtor_code -->
                <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Update</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
$(document).ready(function() {
    $('#installed_pc').select2({
        theme: "bootstrap-5",
        width: $(this).data('width') ? $(this).data('width') : $(this).hasClass('w-100') ? '100%' : 'style',
        placeholder: $(this).data('placeholder'),
    });
});
</script>
</body>
</html>

