<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Define the encryption key
$encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

// Check if item_type_ac_offsite_backup_id is passed via URL
if (!isset($_GET['item_type_ac_offsite_backup_id'])) {
    echo "<p>No item ID provided.</p>";
    exit;
}

$itemTypeAcOffsiteBackupId = $_GET['item_type_ac_offsite_backup_id'];

// Fetch the item details based on item_type_ac_offsite_backup_id
$stmt = $pdo->prepare('SELECT * FROM item_type_ac_offsite_backup WHERE item_type_ac_offsite_backup_id = :item_type_ac_offsite_backup_id LIMIT 1');
$stmt->bindParam(':item_type_ac_offsite_backup_id', $itemTypeAcOffsiteBackupId);
$stmt->execute();
$item = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$item) {
    echo "<p>No item found with the provided ID.</p>";
    exit;
}

// Decrypt the password for display
$decryptedPassword = decryptPassword($item['password'], $encryptionKey);

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($item['company_name']) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$item['company_name']]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

try {
    // Fetch necessary data
    $itemtype = $pdo->query("SELECT item_type_id, item_type_name FROM item_type")->fetchAll(PDO::FETCH_ASSOC);
    $itemtype_ac_group = $pdo->query("SELECT item_type_ac_group_id, item_type_ac_group_name FROM item_type_ac_group")->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}

// Handle form submission to update data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Debugging: Print out the POST data
    error_log(print_r($_POST, true));

    $active = isset($_POST['active']) ? 1 : 0;
    $url = $_POST['url'] ?? null;
    $loginId = $_POST['login_id'] ?? null;
    $password = $_POST['password'] ?? null;
    $monitorService = isset($_POST['monitor_service']) ? 1 : 0;
    $others = $_POST['others'] ?? null;
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included

    // Encrypt the password before saving
    $encryptedPassword = encryptPassword($password, $encryptionKey);

    // Store the old data
    $oldData = $item;
    $oldData['password'] = decryptPassword($oldData['password'], $encryptionKey);

    // Check if any data has changed
    $hasChanges = false;
    if ($active != $oldData['active'] ||
        $url != $oldData['url'] ||
        $loginId != $oldData['login_id'] ||
        $password != $oldData['password'] ||
        $monitorService != $oldData['monitor_service'] ||
        $others != $oldData['others'] ||
        $debtorCode != $oldData['debtor_code']) {
        $hasChanges = true;
    }

    if (!$hasChanges) {
        // No data change, display alert and exit
        echo "<script>alert('No data change detected.'); window.location.href = '/crm/public/company/view_autocount_table.php?debtor_code=" . urlencode($debtorCode) . "';</script>";
        exit;
    }

    try {
        $stmt = $pdo->prepare("UPDATE item_type_ac_offsite_backup SET
            active = :active,
            url = :url,
            login_id = :login_id,
            password = :password,
            monitor_service = :monitor_service,
            others = :others,
            updated_time = NOW(),
            debtor_code = :debtor_code
        WHERE item_type_ac_offsite_backup_id = :item_type_ac_offsite_backup_id");

        // Execute the update query
        $stmt->execute([
            ':active' => $active,
            ':url' => $url,
            ':login_id' => $loginId,
            ':password' => $encryptedPassword,
            ':monitor_service' => $monitorService,
            ':others' => $others,
            ':debtor_code' => $debtorCode,
            ':item_type_ac_offsite_backup_id' => $itemTypeAcOffsiteBackupId,
        ]);

        // Fetch the new data after the update
        $stmt = $pdo->prepare('SELECT * FROM item_type_ac_offsite_backup WHERE item_type_ac_offsite_backup_id = :item_type_ac_offsite_backup_id LIMIT 1');
        $stmt->bindParam(':item_type_ac_offsite_backup_id', $itemTypeAcOffsiteBackupId);
        $stmt->execute();
        $newItem = $stmt->fetch(PDO::FETCH_ASSOC);
        $newItem['password'] = decryptPassword($newItem['password'], $encryptionKey);

        // Build the log message with only the fields that have changed, excluding 'updated_time'
        $logMessage = "Data change in ac offsite backup (Company Name: " . $item['company_name'] . "):\n";
        foreach ($oldData as $key => $value) {
            if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
            }
        }

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data updated successfully for Debtor Code: " . htmlspecialchars($debtorCode) . "!'); window.location.href = '/crm/public/company/view_autocount_table.php?debtor_code=" . urlencode($debtorCode) . "';</script>";
    } catch (PDOException $e) {
        error_log('Database update error: ' . $e->getMessage());
        echo "<script>alert('Failed to update data. Please try again.'); window.location.href = '/crm/public/config_info/edit_ac_offsite_backup.php?item_type_ac_offsite_backup_id=" . $itemTypeAcOffsiteBackupId . "';</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Confirm and Save Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Display Information Section -->
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($item['company_name']); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($item['item_type_name']); ?></strong></p>
                    <p>Item Type Ac Group: <strong><?php echo htmlspecialchars($item['item_type_ac_group_name']); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                </div>

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $item['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- Login Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_id" id="login_id" class="form-control" placeholder="Enter Login ID" value="<?php echo htmlspecialchars($item['login_id']); ?>">
                                    <label for="login_id">Login ID</label>
                                </div>    
                                <div class="form-floating mb-3">
                                    <input type="text" name="url" id="url" class="form-control" placeholder="Enter URL" value="<?php echo htmlspecialchars($item['url']); ?>">
                                    <label for="url">URL</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="password" id="password" class="form-control" placeholder="Enter Password" value="<?php echo htmlspecialchars($decryptedPassword); ?>">
                                    <label for="password">Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Destination and Others -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Destination</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select name="destination" id="destination" class="form-select">
                                        <option value="CITSSB" <?= $item['destination'] === 'CITSSB' ? 'selected' : '' ?>>CITSSB</option>
                                        <option value="Google Drive" <?= $item['destination'] === 'Google Drive' ? 'selected' : '' ?>>Google Drive</option>
                                    </select>
                                    <label for="destination">Destination</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Monitor Service -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Monitor Service</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input type="checkbox" name="monitor_service" id="monitor_service" value="1" class="form-check-input" <?php if ($item['monitor_service']) echo 'checked'; ?>>
                            <label class="form-check-label" for="monitor_service">Monitor Service</label>
                        </div>
                    </div>
                </div>

                <!-- Destination and Others -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-12">
                                <div class="form-floating mb-3">
                                    <textarea class="form-control" id="others" name="others" placeholder="Enter Others"><?php echo htmlspecialchars($item['others']); ?></textarea>
                                    <label for="others">Others</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Save</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>

