<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if item_type_email_citssb_id is passed via URL
if (!isset($_GET['item_type_email_citssb_id'])) {
    echo "<p>No item ID provided.</p>";
    exit;
}

$itemTypeEmailCitssbId = $_GET['item_type_email_citssb_id'];

// Fetch the item details based on item_type_email_citssb_id
$stmt = $pdo->prepare('SELECT * FROM item_type_email_citssb WHERE item_type_email_citssb_id = :item_type_email_citssb_id LIMIT 1');
$stmt->bindParam(':item_type_email_citssb_id', $itemTypeEmailCitssbId);
$stmt->execute();
$item = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$item) {
    echo "<p>No item found with the provided ID.</p>";
    exit;
}

// Fetch the debtor_code based on the company_name
$debtorCode = '';
if ($item['company_name']) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$item['company_name']]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

try {
    // Fetch necessary data
    $itemtype = $pdo->query("SELECT item_type_id, item_type_name FROM item_type")->fetchAll(PDO::FETCH_ASSOC);
    $itemtype_email_citssb = $pdo->query("SELECT item_type_email_citssb_id, item_type_email_citssb_name FROM item_type_email_citssb")->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}

// Handle form submission to update data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Debugging: Print out the POST data
    error_log(print_r($_POST, true));

    $active = isset($_POST['active']) ? 1 : 0;
    $email = $_POST['email'] ?? null;
    $password = $_POST['password'] ?? null; // New password (plaintext)
    $usedAt = $_POST['used_at'] ?? null;
    $updateOfficePhoneDate = $_POST['update_office_phone_date'] ?? null;
    $others = $_POST['others'] ?? null;

    // Decrypt the old password for comparison
    $oldPasswordPlaintext = decryptPassword($item['password'], 'your_secret_key');

    // Prepare new data for comparison (excluding updated_time)
    $newData = [
        'active' => $active,
        'email' => $email,
        'password' => $password, // Use plaintext for comparison
        'used_at' => $usedAt,
        'update_office_phone_date' => $updateOfficePhoneDate,
        'others' => $others,
    ];

    // Prepare old data for comparison (excluding updated_time)
    $oldData = [
        'active' => $item['active'],
        'email' => $item['email'],
        'password' => $oldPasswordPlaintext, // Use decrypted password for comparison
        'used_at' => $item['used_at'],
        'update_office_phone_date' => $item['update_office_phone_date'],
        'others' => $item['others'],
    ];

    // Check if any data has changed (excluding updated_time)
    $dataChanged = false;
    foreach ($newData as $key => $value) {
        if ($oldData[$key] != $value) {
            $dataChanged = true;
            break;
        }
    }

    if (!$dataChanged) {
        // No data changed, display a message and exit
        echo "<script>alert('No data changed.'); window.location.href = '/crm/public/company/view_email_citssb_table.php?debtor_code=" . urlencode($debtorCode) . "';</script>";
        exit;
    }

    // Encrypt the new password before saving to the database
    $encryptedPassword = encryptPassword($password, 'your_secret_key');

    try {
        $stmt = $pdo->prepare("UPDATE item_type_email_citssb SET
            active = :active,
            email = :email,
            password = :password,
            used_at = :used_at,
            update_office_phone_date = :update_office_phone_date,
            others = :others,
            updated_time = NOW()
        WHERE item_type_email_citssb_id = :item_type_email_citssb_id");

        // Execute the update query
        $stmt->execute([
            ':active' => $active,
            ':email' => $email,
            ':used_at' => $usedAt,
            ':password' => $encryptedPassword,
            ':update_office_phone_date' => $updateOfficePhoneDate,
            ':others' => $others,
            ':item_type_email_citssb_id' => $itemTypeEmailCitssbId,
        ]);

        // Fetch the new data after the update
        $stmt = $pdo->prepare('SELECT * FROM item_type_email_citssb WHERE item_type_email_citssb_id = :item_type_email_citssb_id LIMIT 1');
        $stmt->bindParam(':item_type_email_citssb_id', $itemTypeEmailCitssbId);
        $stmt->execute();
        $newItem = $stmt->fetch(PDO::FETCH_ASSOC);
        $newItem['password'] = decryptPassword($newItem['password'], 'your_secret_key');

        // Build the log message with only the fields that have changed (excluding updated_time)
        $logMessage = "Data change in item_type_email_citssb (Company Name: " . $item['company_name'] . "):\n";
        foreach ($oldData as $key => $value) {
            if ($newItem[$key] !== $value) {
                $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
            }
        }

        // Insert the log into activity_logs (including timestamp but not comparing it)
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data updated successfully for Debtor Code: " . htmlspecialchars($debtorCode) . "!'); window.location.href = '/crm/public/company/view_email_citssb_table.php?debtor_code=" . urlencode($debtorCode) . "';</script>";
    } catch (PDOException $e) {
        error_log('Database update error: ' . $e->getMessage());
        echo "<script>alert('Failed to update data. Please try again.'); window.location.href = 'edit_email_for_citssb_use.php?item_type_email_citssb_id=" . $itemTypeEmailCitssbId . "';</script>";
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-4">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Confirm and Save Details</h1>
            </div>
            <div class="card-body">
                <form method="POST">
                    <!-- Hidden input for debtor code -->
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">

                    <p>Company Name: <strong><?php echo htmlspecialchars($item['company_name']); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($item['item_type_name']); ?></strong></p>

                    <!-- Active Status Card -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Active Status</h5>
                        </div>
                        <div class="card-body">
                            <!-- Active Checkbox -->
                            <div class="form-check">
                                <input type="checkbox" class="form-check-input" name="active" value="1" id="active" <?php if ($item['active']) echo 'checked'; ?>>
                                <label for="active" class="form-check-label">Active</label>
                            </div>
                        </div>
                    </div>

                    <!-- Hardware Details Card -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Hardware Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <!-- Email Input with Floating Label -->
                                    <div class="form-floating mb-3">
                                        <input type="email" class="form-control" name="email" id="floatingEmail" placeholder="name@example.com" value="<?php echo htmlspecialchars($item['email']); ?>">
                                        <label for="floatingEmail">Email</label>
                                    </div>

                                    <!-- Password Input with Floating Label -->
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="password" id="floatingPassword" placeholder="Password" value="<?php echo htmlspecialchars(decryptPassword($item['password'], 'your_secret_key')); ?>">
                                        <label for="floatingPassword">Password</label>
                                    </div>
                                </div>

                                <div class="col-md-6">
                                    <!-- Update Office Phone Date Input with Floating Label -->
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" name="update_office_phone_date" id="floatingUpdateDate" placeholder="Update Office Phone Date" value="<?php echo htmlspecialchars($item['update_office_phone_date']); ?>">
                                        <label for="floatingUpdateDate">Update Office Phone Date</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <select class="form-select" name="used_at" id="floatingUsedAt" placeholder="Used At">
                                            <option value="">Select an option</option>
                                            <option value="Fortinet" <?php echo ($item['used_at'] == 'Fortinet') ? 'selected' : ''; ?>>Fortinet</option>
                                            <option value="Synology" <?php echo ($item['used_at'] == 'Synology') ? 'selected' : ''; ?>>Synology</option>
                                        </select>
                                        <label for="floatingUsedAt">Used At</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Other Information Card -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Other Information</h5>
                        </div>
                        <div class="card-body">
                            <!-- Others Textarea with Floating Label -->
                            <div class="form-floating">
                                <textarea class="form-control" id="floatingOthers" name="others" placeholder="Others"><?php echo htmlspecialchars($item['others']); ?></textarea>
                                <label for="floatingOthers">Others</label>
                            </div>
                        </div>
                    </div>

                    <!-- Save Button -->
                    <div class="text-center">
                        <button type="submit" class="btn btn-primary">Save</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap JS and dependencies -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
