<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur'); // Corrected timezone setting

// Encryption key (must match the key used in encrypt.php)
$encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

// Check if debtor_code and item_type_hosting_email_id are passed via URL
if (!isset($_GET['debtor_code']) || !isset($_GET['item_type_hosting_email_id'])) {
    echo "<p>No debtor code or email ID provided.</p>";
    exit;
}

$debtorCode = $_GET['debtor_code'];
$emailId = $_GET['item_type_hosting_email_id'];

// Fetch the email details based on debtor_code and item_type_hosting_email_id
$stmt = $pdo->prepare('SELECT * FROM item_type_hosting_email WHERE debtor_code = :debtor_code AND item_type_hosting_email_id = :item_type_hosting_email_id LIMIT 1');
$stmt->execute([':debtor_code' => $debtorCode, ':item_type_hosting_email_id' => $emailId]);
$email = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$email) {
    echo "<p>No email found with the provided ID.</p>";
    exit;
}

// Decrypt sensitive fields for display
$email['login_password'] = decryptPassword($email['login_password'], $encryptionKey);

// Fetch customer usernames based on debtor_code
$customerUsernames = [];
$computerNames = [];
if (!empty($debtorCode)) {
    $stmt = $pdo->prepare("SELECT customer_username FROM customer_info WHERE debtor_code = :debtor_code");
    $stmt->execute([':debtor_code' => $debtorCode]);
    $customerUsernames = $stmt->fetchAll(PDO::FETCH_COLUMN);

    $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code");
    $stmt->execute([':debtor_code' => $debtorCode]);
    $computerNames = $stmt->fetchAll(PDO::FETCH_COLUMN);
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // Validate and sanitize input data
        $active = isset($_POST['active']) ? 1 : 0;
        $email_account = htmlspecialchars($_POST['email_account']);
        $service_provider = htmlspecialchars($_POST['service_provider']);
        $customer_username = htmlspecialchars($_POST['customer_username']);
        $installed_pc = htmlspecialchars($_POST['installed_pc']);
        $login_password = htmlspecialchars($_POST['login_password']);
        $incoming_mail_server = htmlspecialchars($_POST['incoming_mail_server']);
        $outgoing_server = htmlspecialchars($_POST['outgoing_server']);
        $incoming_mail_server_port = htmlspecialchars($_POST['incoming_mail_server_port']);
        $outgoing_mail_server_port = htmlspecialchars($_POST['outgoing_mail_server_port']);
        $others = htmlspecialchars($_POST['others']);

        // Encrypt sensitive fields before storing in the database
        $login_password_encrypted = encryptPassword($login_password, $encryptionKey);

        // Store the old data for logging
        $oldData = $email;

        // Check if any changes were made
        $hasChanges = false;
        if ($active != $oldData['active']) $hasChanges = true;
        if ($email_account != $oldData['email_account']) $hasChanges = true;
        if ($service_provider != $oldData['service_provider']) $hasChanges = true;
        if ($customer_username != $oldData['customer_username']) $hasChanges = true;
        if ($installed_pc != $oldData['installed_pc']) $hasChanges = true;
        if ($login_password != $oldData['login_password']) $hasChanges = true;
        if ($incoming_mail_server != $oldData['incoming_mail_server']) $hasChanges = true;
        if ($outgoing_server != $oldData['outgoing_server']) $hasChanges = true;
        if ($incoming_mail_server_port != $oldData['incoming_mail_server_port']) $hasChanges = true;
        if ($outgoing_mail_server_port != $oldData['outgoing_mail_server_port']) $hasChanges = true;
        if ($others != $oldData['others']) $hasChanges = true;

        if (!$hasChanges) {
            // No changes were made, display alert and redirect back to view_hosting_table.php
            echo '<script type="text/javascript">';
            echo 'alert("No changes made.");';
            echo 'window.location.href="view_hosting_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        } else {
            // Update the email in the database
            $stmt = $pdo->prepare('UPDATE item_type_hosting_email SET active = :active, email_account = :email_account, service_provider = :service_provider, customer_username = :customer_username, installed_pc = :installed_pc, login_password = :login_password, incoming_mail_server = :incoming_mail_server, outgoing_server = :outgoing_server, incoming_mail_server_port = :incoming_mail_server_port, outgoing_mail_server_port = :outgoing_mail_server_port, updated_time = NOW(), others = :others WHERE debtor_code = :debtor_code AND item_type_hosting_email_id = :item_type_hosting_email_id');
            $success = $stmt->execute([
                ':active' => $active,
                ':email_account' => $email_account,
                ':service_provider' => $service_provider,
                ':customer_username' => $customer_username,
                ':installed_pc' => $installed_pc,
                ':login_password' => $login_password_encrypted, // Encrypted password
                ':incoming_mail_server' => $incoming_mail_server,
                ':outgoing_server' => $outgoing_server,
                ':incoming_mail_server_port' => $incoming_mail_server_port,
                ':outgoing_mail_server_port' => $outgoing_mail_server_port,
                ':others' => $others,
                ':debtor_code' => $debtorCode,
                ':item_type_hosting_email_id' => $emailId
            ]);

            if ($success) {
                // Fetch the new data after the update
                $stmt = $pdo->prepare('SELECT * FROM item_type_hosting_email WHERE debtor_code = :debtor_code AND item_type_hosting_email_id = :item_type_hosting_email_id LIMIT 1');
                $stmt->execute([':debtor_code' => $debtorCode, ':item_type_hosting_email_id' => $emailId]);
                $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

                // Decrypt sensitive fields for logging
                $newItem['login_password'] = decryptPassword($newItem['login_password'], $encryptionKey);

                // Build the log message with only the fields that have changed, excluding 'updated_time'
                $logMessage = "Data change in email item (Debtor Code: " . $debtorCode . "):\n";
                foreach ($oldData as $key => $value) {
                    if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                        $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                    }
                }

                // Insert the log into activity_logs
                $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                           VALUES (:username, :timestamp, :role, :activity)";
                $stmtLog = $pdo->prepare($sqlLog);
                $stmtLog->execute([
                    ':username' => $_SESSION['username'],
                    ':timestamp' => date('Y-m-d H:i:s'),
                    ':role' => $_SESSION['role'],
                    ':activity' => $logMessage
                ]);

                // If update was successful, show success message and redirect
                echo '<script type="text/javascript">';
                echo 'alert("Update successful!");';
                echo 'window.location.href="view_hosting_table.php?debtor_code=' . urlencode($debtorCode) . '";';
                echo '</script>';
            } else {
                throw new Exception("Failed to update the email details.");
            }
        }
    } catch (Exception $e) {
        echo '<script type="text/javascript">';
        echo 'alert("' . $e->getMessage() . '");';
        echo '</script>';
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Email Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit Email Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                <input type="hidden" name="item_type_hosting_id" value="<?= htmlspecialchars($emailId) ?>">

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $email['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- Email and Service Provider -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Email and Service Provider</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="email_account" id="email_account" class="form-control" placeholder="Email Account" value="<?= htmlspecialchars($email['email_account'] ?? '') ?>">
                                    <label for="email_account">Email Account</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" name="login_password" id="login_password" class="form-control" placeholder="Login Password" value="<?= htmlspecialchars($email['login_password'] ?? '') ?>">
                                    <label for="login_password">Login Password</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select name="service_provider" id="service_provider" class="form-control">
                                        <option value="">Select a Service Provider</option>
                                        <option value="cPanel" <?= isset($email['service_provider']) && $email['service_provider'] == 'cPanel' ? 'selected' : '' ?>>cPanel</option>
                                        <option value="Dynamail" <?= isset($email['service_provider']) && $email['service_provider'] == 'Dynamail' ? 'selected' : '' ?>>Dynamail</option>
                                        <option value="Microsoft" <?= isset($email['service_provider']) && $email['service_provider'] == 'Microsoft' ? 'selected' : '' ?>>Microsoft</option>
                                        <option value="Google" <?= isset($email['service_provider']) && $email['service_provider'] == 'Google' ? 'selected' : '' ?>>Google</option>
                                        <option value="Other" <?= isset($email['service_provider']) && $email['service_provider'] == 'Other' ? 'selected' : '' ?>>Other</option>
                                    </select>
                                    <label for="service_provider">Service Provider</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Customer Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Customer Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="customer_username">Customer Username</label>
                                    <select name="customer_username" id="customer_username" class="form-control">
                                        <option value="">Select Customer Username</option>
                                        <?php foreach ($customerUsernames as $username): ?>
                                            <option value="<?php echo htmlspecialchars($username); ?>" <?php if ($email['customer_username'] == $username) echo 'selected'; ?>><?php echo htmlspecialchars($username); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="installed_pc">Installed PC</label>
                                    <select class="form-select" id="installed_pc" name="installed_pc">
                                        <option value="">Select Installed PC</option>
                                        <?php foreach ($computerNames as $option): ?>
                                            <option value="<?php echo htmlspecialchars($option); ?>" <?php if ($email['installed_pc'] == $option) echo 'selected'; ?>><?php echo htmlspecialchars($option); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Mail Server Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Mail Server Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Incoming Mail Server</label>
                                    <div class="input-group mb-2">
                                        <div class="form-floating">
                                            <input type="text" class="form-control" name="incoming_mail_server" id="incoming_mail_server" placeholder=" " value="<?= htmlspecialchars($email['incoming_mail_server'] ?? '') ?>">
                                            <label for="incoming_mail_server">Server</label>
                                        </div>
                                        <div class="form-floating">
                                            <input type="text" class="form-control" name="incoming_mail_server_port" id="incoming_mail_server_port" placeholder=" " value="<?= htmlspecialchars($email['incoming_mail_server_port'] ?? '') ?>">
                                            <label for="incoming_mail_server_port">Port</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label>Outgoing Mail Server</label>
                                    <div class="input-group mb-2">
                                        <div class="form-floating">
                                            <input type="text" class="form-control" name="outgoing_server" id="outgoing_server" placeholder=" " value="<?= htmlspecialchars($email['outgoing_server'] ?? '') ?>">
                                            <label for="outgoing_server">Server</label>
                                        </div>
                                        <div class="form-floating">
                                            <input type="text" class="form-control" name="outgoing_mail_server_port" id="outgoing_mail_server_port" placeholder=" " value="<?= htmlspecialchars($email['outgoing_mail_server_port'] ?? '') ?>">
                                            <label for="outgoing_mail_server_port">Port</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating">
                            <textarea id="others" name="others" class="form-control" placeholder="Others"><?= htmlspecialchars($email['others'] ?? '') ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
$(document).ready(function() {
    // Initialize Select2 for customer_username and installed_pc
    $('#customer_username').select2({
        theme: "bootstrap-5",
        width: '100%', // Ensure Select2 takes the full width
        placeholder: "Select Customer Username",
    });

    $('#installed_pc').select2({
        theme: "bootstrap-5",
        width: '100%', // Ensure Select2 takes the full width
        placeholder: "Select Installed PC",
    });
});
</script>
</body>
</html>