<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set(timezoneId: 'Asia/Kuala_Lumpur');

// Encryption key (must match the key used in encrypt.php)
$encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

// Check if debtor_code and item_type_hosting_hosting_id are passed via URL
if (!isset($_GET['debtor_code']) || !isset($_GET['item_type_hosting_hosting_id'])) {
    echo "<p>No debtor code or domain ID provided.</p>";
    exit;
}

$debtorCode = $_GET['debtor_code'];
$domainId = $_GET['item_type_hosting_hosting_id']; // Updated primary key

try {
    // Fetch the domain details based on debtor_code and item_type_hosting_hosting_id
    $stmt = $pdo->prepare('SELECT * FROM item_type_hosting_hosting WHERE debtor_code = :debtor_code AND item_type_hosting_hosting_id = :item_type_hosting_hosting_id LIMIT 1');
    $stmt->execute([':debtor_code' => $debtorCode, ':item_type_hosting_hosting_id' => $domainId]);
    $domain = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$domain) {
        throw new Exception("No domain found with the provided ID.");
    }

    // Decrypt sensitive fields for display
    $domain['login_password'] = decryptPassword($domain['login_password'], $encryptionKey);
    $domain['wordpress_admin_password'] = decryptPassword($domain['wordpress_admin_password'], $encryptionKey);
    $domain['sql_password'] = decryptPassword($domain['sql_password'], $encryptionKey);
} catch (Exception $e) {
    echo "<p>Error: " . $e->getMessage() . "</p>";
    exit;
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // Validate and sanitize input data
        $active = isset($_POST['active']) ? 1 : 0;
        $service_provider = htmlspecialchars($_POST['service_provider']);
        $hosting_software = htmlspecialchars($_POST['hosting_software']);
        $login_url = htmlspecialchars($_POST['login_url']);
        $second_login_url = htmlspecialchars($_POST['second_login_url']); // New field
        $login_id = htmlspecialchars($_POST['login_id']);
        $login_password = htmlspecialchars($_POST['login_password']);
        $ftp_host_name = htmlspecialchars($_POST['ftp_host_name']); // New field
        $second_ftp_host_name = htmlspecialchars($_POST['second_ftp_host_name']); // New field
        $dns = htmlspecialchars($_POST['dns']);
        $mail_sentinel = isset($_POST['mail_sentinel']) ? 1 : 0;
        $mailbox = htmlspecialchars($_POST['mailbox']);
        $mx_record = htmlspecialchars($_POST['mx_record']);
        $wordpress_url = htmlspecialchars($_POST['wordpress_url']);
        $wordpress_admin_login = htmlspecialchars($_POST['wordpress_admin_login']);
        $wordpress_admin_password = htmlspecialchars($_POST['wordpress_admin_password']);
        $sql_id = htmlspecialchars($_POST['sql_id']);
        $sql_database = htmlspecialchars($_POST['sql_database']);
        $sql_password = htmlspecialchars($_POST['sql_password']);
        $nameserver_1 = htmlspecialchars($_POST['nameserver_1']); // New field
        $nameserver_2 = htmlspecialchars($_POST['nameserver_2']); // New field
        $others = htmlspecialchars($_POST['others']);

        // Encrypt sensitive passwords before storing in the database
        $login_password_encrypted = encryptPassword($login_password, $encryptionKey);
        $wordpress_admin_password_encrypted = encryptPassword($wordpress_admin_password, $encryptionKey);
        $sql_password_encrypted = encryptPassword($sql_password, $encryptionKey);

        // Store the old data for logging
        $oldData = $domain;

        // Check if any changes were made
        $hasChanges = false;
        if ($active != $oldData['active']) $hasChanges = true;
        if ($service_provider != $oldData['service_provider']) $hasChanges = true;
        if ($hosting_software != $oldData['hosting_software']) $hasChanges = true;
        if ($login_url != $oldData['login_url']) $hasChanges = true;
        if ($second_login_url != $oldData['second_login_url']) $hasChanges = true; // New field
        if ($login_id != $oldData['login_id']) $hasChanges = true;
        if ($login_password != $oldData['login_password']) $hasChanges = true;
        if ($ftp_host_name != $oldData['ftp_host_name']) $hasChanges = true; // New field
        if ($second_ftp_host_name != $oldData['second_ftp_host_name']) $hasChanges = true; // New field
        if ($dns != $oldData['dns']) $hasChanges = true;
        if ($mail_sentinel != $oldData['mail_sentinel']) $hasChanges = true;
        if ($mailbox != $oldData['mailbox']) $hasChanges = true;
        if ($mx_record != $oldData['mx_record']) $hasChanges = true;
        if ($wordpress_url != $oldData['wordpress_url']) $hasChanges = true;
        if ($wordpress_admin_login != $oldData['wordpress_admin_login']) $hasChanges = true;
        if ($wordpress_admin_password != $oldData['wordpress_admin_password']) $hasChanges = true;
        if ($sql_id != $oldData['sql_id']) $hasChanges = true;
        if ($sql_database != $oldData['sql_database']) $hasChanges = true;
        if ($sql_password != $oldData['sql_password']) $hasChanges = true;
        if ($nameserver_1 != $oldData['nameserver_1']) $hasChanges = true; // New field
        if ($nameserver_2 != $oldData['nameserver_2']) $hasChanges = true; // New field
        if ($others != $oldData['others']) $hasChanges = true;

        if (!$hasChanges) {
            // No changes were made, display alert and redirect back to view_hosting_table.php
            echo '<script type="text/javascript">';
            echo 'alert("No changes made.");';
            echo 'window.location.href="view_hosting_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        } else {
            // Update the domain in the database
            $stmt = $pdo->prepare('UPDATE item_type_hosting_hosting SET active = :active, service_provider = :service_provider, hosting_software = :hosting_software, login_url = :login_url, second_login_url = :second_login_url, login_id = :login_id, login_password = :login_password, ftp_host_name = :ftp_host_name, second_ftp_host_name = :second_ftp_host_name, dns = :dns, mail_sentinel = :mail_sentinel, mailbox = :mailbox, mx_record = :mx_record, wordpress_url = :wordpress_url, wordpress_admin_login = :wordpress_admin_login, wordpress_admin_password = :wordpress_admin_password, sql_id = :sql_id, sql_database = :sql_database, sql_password = :sql_password, nameserver_1 = :nameserver_1, nameserver_2 = :nameserver_2, updated_time = NOW(), others = :others WHERE debtor_code = :debtor_code AND item_type_hosting_hosting_id = :item_type_hosting_hosting_id');
            $success = $stmt->execute([
                ':active' => $active,
                ':service_provider' => $service_provider,
                ':hosting_software' => $hosting_software,
                ':login_url' => $login_url,
                ':second_login_url' => $second_login_url, // New field
                ':login_id' => $login_id,
                ':login_password' => $login_password_encrypted, // Encrypted password
                ':ftp_host_name' => $ftp_host_name, // New field
                ':second_ftp_host_name' => $second_ftp_host_name, // New field
                ':dns' => $dns,
                ':mail_sentinel' => $mail_sentinel,
                ':mailbox' => $mailbox,
                ':mx_record' => $mx_record,
                ':wordpress_url' => $wordpress_url,
                ':wordpress_admin_login' => $wordpress_admin_login,
                ':wordpress_admin_password' => $wordpress_admin_password_encrypted, // Encrypted password
                ':sql_id' => $sql_id,
                ':sql_database' => $sql_database,
                ':sql_password' => $sql_password_encrypted, // Encrypted password
                ':nameserver_1' => $nameserver_1, // New field
                ':nameserver_2' => $nameserver_2, // New field
                ':others' => $others,
                ':debtor_code' => $debtorCode,
                ':item_type_hosting_hosting_id' => $domainId
            ]);

            if ($success) {
                // Fetch the new data after the update
                $stmt = $pdo->prepare('SELECT * FROM item_type_hosting_hosting WHERE debtor_code = :debtor_code AND item_type_hosting_hosting_id = :item_type_hosting_hosting_id LIMIT 1');
                $stmt->execute([':debtor_code' => $debtorCode, ':item_type_hosting_hosting_id' => $domainId]);
                $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

                // Decrypt sensitive fields for logging
                $newItem['login_password'] = decryptPassword($newItem['login_password'], $encryptionKey);
                $newItem['wordpress_admin_password'] = decryptPassword($newItem['wordpress_admin_password'], $encryptionKey);
                $newItem['sql_password'] = decryptPassword($newItem['sql_password'], $encryptionKey);

                // Build the log message with only the fields that have changed, excluding 'updated_time'
                $logMessage = "Data change in domain item (Debtor Code: " . $debtorCode . "):\n";
                foreach ($oldData as $key => $value) {
                    if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                        $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                    }
                }

                // Insert the log into activity_logs
                $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                           VALUES (:username, :timestamp, :role, :activity)";
                $stmtLog = $pdo->prepare($sqlLog);
                $stmtLog->execute([
                    ':username' => $_SESSION['username'],
                    ':timestamp' => date('Y-m-d H:i:s'),
                    ':role' => $_SESSION['role'],
                    ':activity' => $logMessage
                ]);

                // If update was successful, show success message and redirect
                echo '<script type="text/javascript">';
                echo 'alert("Update successful!");';
                echo 'window.location.href="view_hosting_table.php?debtor_code=' . urlencode($debtorCode) . '";';
                echo '</script>';
            } else {
                throw new Exception("Failed to update the domain details.");
            }
        }
    } catch (Exception $e) {
        echo '<script type="text/javascript">';
        echo 'alert("' . $e->getMessage() . '");';
        echo '</script>';
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Domain Details</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit Domain Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                <input type="hidden" name="item_type_hosting_id" value="<?= htmlspecialchars($domainId) ?>">

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $domain['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- Login Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-select" id="service_provider" name="service_provider">
                                        <option value="">Select a Service Provider</option>
                                        <option value="Shinjuru" <?= isset($domain['service_provider']) && $domain['service_provider'] == 'Shinjuru' ? 'selected' : '' ?>>Shinjuru</option>
                                        <option value="ITWIN" <?= isset($domain['service_provider']) && $domain['service_provider'] == 'ITWIN' ? 'selected' : '' ?>>ITWIN</option>
                                        <option value="Other" <?= isset($domain['service_provider']) && $domain['service_provider'] == 'Other' ? 'selected' : '' ?>>Other</option>
                                    </select>
                                    <label for="service_provider">Service Provider</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="login_url" name="login_url" placeholder="Login URL" value="<?= htmlspecialchars($domain['login_url'] ?? '') ?>">
                                    <label for="login_url">Login URL</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="login_id" name="login_id" placeholder="Login ID" value="<?= htmlspecialchars($domain['login_id'] ?? '') ?>">
                                    <label for="login_id">Login ID</label>
                                </div>
                                <div class="form-check mb-3">
                                    <input type="checkbox" class="form-check-input" name="mail_sentinel" id="mail_sentinel" value="1" <?= $domain['mail_sentinel'] ? 'checked' : '' ?>>
                                    <label class="form-check-label" for="mail_sentinel">Mail Sentinel</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="hosting_software" name="hosting_software" placeholder="Hosting Software" value="<?= htmlspecialchars($domain['hosting_software'] ?? '') ?>">
                                    <label for="hosting_software">Hosting Software</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="second_login_url" name="second_login_url" placeholder="Second Login URL" value="<?= htmlspecialchars($domain['second_login_url'] ?? '') ?>">
                                    <label for="second_login_url">Second Login URL</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="login_password" name="login_password" placeholder="Login Password" value="<?= htmlspecialchars($domain['login_password'] ?? '') ?>">
                                    <label for="login_password">Login Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- FTP Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">FTP Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="ftp_host_name" name="ftp_host_name" placeholder="FTP Host Name" value="<?= htmlspecialchars($domain['ftp_host_name'] ?? '') ?>">
                                    <label for="ftp_host_name">FTP Host Name</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="second_ftp_host_name" name="second_ftp_host_name" placeholder="Second FTP Host Name" value="<?= htmlspecialchars($domain['second_ftp_host_name'] ?? '') ?>">
                                    <label for="second_ftp_host_name">Second FTP Host Name</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- DNS Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">DNS Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                            <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="nameserver_1" name="nameserver_1" placeholder="Nameserver 1" value="<?= htmlspecialchars($domain['nameserver_1'] ?? '') ?>">
                                    <label for="nameserver_1">Nameserver 1</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="dns" name="dns" placeholder="DNS" value="<?= htmlspecialchars($domain['dns'] ?? '') ?>">
                                    <label for="dns">DNS</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="nameserver_2" name="nameserver_2" placeholder="Nameserver 2" value="<?= htmlspecialchars($domain['nameserver_2'] ?? '') ?>">
                                    <label for="nameserver_2">Nameserver 2</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Mailbox Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Mailbox Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-select" id="mailbox" name="mailbox">
                                        <option value="">Select a Mailbox</option>
                                        <option value="cPanel" <?= isset($domain['mailbox']) && $domain['mailbox'] == 'cPanel' ? 'selected' : '' ?>>cPanel</option>
                                        <option value="Dynamail" <?= isset($domain['mailbox']) && $domain['mailbox'] == 'Dynamail' ? 'selected' : '' ?>>Dynamail</option>
                                        <option value="Microsoft" <?= isset($domain['mailbox']) && $domain['mailbox'] == 'Microsoft' ? 'selected' : '' ?>>Microsoft</option>
                                        <option value="Google" <?= isset($domain['mailbox']) && $domain['mailbox'] == 'Google' ? 'selected' : '' ?>>Google</option>
                                        <option value="Other" <?= isset($domain['mailbox']) && $domain['mailbox'] == 'Other' ? 'selected' : '' ?>>Other</option>
                                    </select>
                                    <label for="mailbox">Mailbox</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <textarea class="form-control" id="mx_record" name="mx_record" placeholder="MX Record"><?= htmlspecialchars($domain['mx_record'] ?? '') ?></textarea>
                                    <label for="mx_record">MX Record</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- WordPress Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">WordPress Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="wordpress_url" name="wordpress_url" placeholder="Wordpress URL" value="<?= htmlspecialchars($domain['wordpress_url'] ?? '') ?>">
                                    <label for="wordpress_url">Wordpress URL</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="wordpress_admin_login" name="wordpress_admin_login" placeholder="Wordpress Admin Login" value="<?= htmlspecialchars($domain['wordpress_admin_login'] ?? '') ?>">
                                    <label for="wordpress_admin_login">Wordpress Admin Login</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="wordpress_admin_password" name="wordpress_admin_password" placeholder="Wordpress Admin Password" value="<?= htmlspecialchars($domain['wordpress_admin_password'] ?? '') ?>">
                                    <label for="wordpress_admin_password">Wordpress Admin Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- SQL Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">SQL Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="sql_id" name="sql_id" placeholder="SQL ID" value="<?= htmlspecialchars($domain['sql_id'] ?? '') ?>">
                                    <label for="sql_id">SQL ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="sql_database" name="sql_database" placeholder="SQL Database" value="<?= htmlspecialchars($domain['sql_database'] ?? '') ?>">
                                    <label for="sql_database">SQL Database</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="sql_password" name="sql_password" placeholder="SQL Password" value="<?= htmlspecialchars($domain['sql_password'] ?? '') ?>">
                                    <label for="sql_password">SQL Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea class="form-control" id="others" name="others" placeholder="Others"><?= htmlspecialchars($domain['others'] ?? '') ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
</body>
</html>

