<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

$id = isset($_GET['item_type_hw_cctv_id']) ? $_GET['item_type_hw_cctv_id'] : null;

if (!$id) {
    echo "<script>window.location.href = 'add_config_info.php';</script>";
    exit;
}

// Fetch main record
$stmt = $pdo->prepare("SELECT * FROM item_type_hw_cctv WHERE item_type_hw_cctv_id = :item_type_hw_cctv_id");
$stmt->execute([':item_type_hw_cctv_id' => $id]);
$cctv = $stmt->fetch(PDO::FETCH_ASSOC);

// Decrypt the old passwords for logging
$cctv['password'] = decryptPassword($cctv['password'], 'your_secret_key');
$cctv['user_password'] = array_map(function($pwd) {
    return decryptPassword($pwd, 'your_secret_key');
}, explode(',', $cctv['user_password']));

// Fetch installed_pc_for_cctv records
$stmt = $pdo->prepare("SELECT * FROM installed_pc_for_cctv WHERE item_type_hw_cctv_id = :id");
$stmt->execute([':id' => $id]);
$installedPcRecords = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Fetch installed PC options
$installedPcOptions = [];
if (!empty($cctv['debtor_code']) && !empty($cctv['company_name'])) {
    $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtorCode AND company_name = :companyName");
    $stmt->execute([':debtorCode' => $cctv['debtor_code'], ':companyName' => $cctv['company_name']]);
    $installedPcOptions = $stmt->fetchAll(PDO::FETCH_COLUMN);
}

// Explode the user_login and user_password fields
$userLoginArray = explode(',', $cctv['user_login']);
$userPasswordArray = $cctv['user_password']; // Already decrypted

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = isset($_POST['active']) ? 1 : 0;
    $login = $_POST['login'] ?? null;
    $password = $_POST['password'] ?? null;
    $ddns = $_POST['ddns'] ?? null;
    $brand = $_POST['brand'] ?? null;
    $model = $_POST['model'] ?? null;
    $tcpIp = $_POST['tcp_ip'] ?? null;
    $openPort = $_POST['open_port'] ?? null;
    $userLogin = $_POST['user_login'] ?? [];
    $userPassword = $_POST['user_password'] ?? [];
    $installedPc = $_POST['installed_pc'] ?? [];
    $software = $_POST['software'] ?? null;
    $softwareLogin = $_POST['software_login'] ?? [];
    $softwarePassword = $_POST['software_password'] ?? [];

    // Encrypt the passwords for database storage
    $encryptionKey = 'your_secret_key';
    $encryptedPassword = encryptPassword($password, $encryptionKey);
    $encryptedUserPasswords = array_map(function($pwd) use ($encryptionKey) {
        return encryptPassword($pwd, $encryptionKey);
    }, $userPassword);
    $encryptedSoftwarePasswords = array_map(function($pwd) use ($encryptionKey) {
        return encryptPassword($pwd, $encryptionKey);
    }, $softwarePassword);

    // Store the old data for logging
    $oldData = $cctv;

    // Fetch existing installed_pc_for_cctv records for comparison
    $stmt = $pdo->prepare("SELECT computer_name, software_login, software_password FROM installed_pc_for_cctv WHERE item_type_hw_cctv_id = :id");
    $stmt->execute([':id' => $id]);
    $oldInstalledPcRecords = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Decrypt old software passwords for comparison
    foreach ($oldInstalledPcRecords as &$record) {
        $record['software_password'] = decryptPassword($record['software_password'], $encryptionKey);
    }

    try {
        // Update the main record (item_type_hw_cctv)
        $stmt = $pdo->prepare("UPDATE item_type_hw_cctv SET
            item_type_name = :item_type_name, 
            company_name = :company_name, 
            debtor_code = :debtor_code,
            active = :active,
            item_type_hw_group_name = :item_type_hw_group_name,
            login = :login,
            password = :password,
            ddns = :ddns,
            brand = :brand,
            model = :model,
            tcp_ip = :tcp_ip,
            open_port = :open_port,
            user_login = :user_login,
            user_password = :user_password,
            software = :software,
            updated_time = NOW()
        WHERE item_type_hw_cctv_id = :id");

        // Convert arrays to comma-separated strings
        $userLoginString = implode(',', $userLogin);
        $userPasswordString = implode(',', $encryptedUserPasswords);

        $stmt->execute([
            ':item_type_name' => $cctv['item_type_name'],
            ':company_name' => $cctv['company_name'],
            ':debtor_code' => $cctv['debtor_code'],
            ':active' => $active,
            ':item_type_hw_group_name' => $cctv['item_type_hw_group_name'],
            ':login' => $login,
            ':password' => $encryptedPassword,
            ':ddns' => $ddns,
            ':brand' => $brand,
            ':model' => $model,
            ':tcp_ip' => $tcpIp,
            ':open_port' => $openPort,
            ':user_login' => $userLoginString,
            ':user_password' => $userPasswordString,
            ':software' => $software,
            ':id' => $id
        ]);

        // Fetch the updated record for logging
        $stmt = $pdo->prepare("SELECT * FROM item_type_hw_cctv WHERE item_type_hw_cctv_id = :item_type_hw_cctv_id");
        $stmt->execute([':item_type_hw_cctv_id' => $id]);
        $newData = $stmt->fetch(PDO::FETCH_ASSOC);

        // Decrypt the new passwords for logging
        $newData['password'] = $password; // Already in plaintext
        $newData['user_password'] = $userPassword; // Already in plaintext

        // Build the log message and check for changes
        $logMessage = "Data change in CCTV (ID: $id):\n";
        $hasChanges = false;

        // Check for changes in item_type_hw_cctv
        foreach ($oldData as $key => $value) {
            if ($key === 'user_password') {
                if (array_diff($value, $newData[$key]) || array_diff($newData[$key], $value)) {
                    $hasChanges = true;
                    $logMessage .= "$key: " . implode(',', $value) . " -> " . implode(',', $newData[$key]) . "\n";
                }
            } elseif ($key !== 'updated_time' && isset($newData[$key]) && $newData[$key] !== $value) {
                $hasChanges = true;
                $logMessage .= "$key: " . (is_array($value) ? implode(',', $value) : $value) . " -> " . (is_array($newData[$key]) ? implode(',', $newData[$key]) : $newData[$key]) . "\n";
            }
        }

        // Check for changes in installed_pc_for_cctv
        $newInstalledPcRecords = [];
        foreach ($installedPc as $index => $pc) {
            $newInstalledPcRecords[] = [
                'computer_name' => $pc,
                'software_login' => $softwareLogin[$index] ?? null,
                'software_password' => $softwarePassword[$index] ?? null // Plaintext for comparison
            ];
        }

        // Compare old and new installed_pc_for_cctv records
        if ($oldInstalledPcRecords != $newInstalledPcRecords) {
            $hasChanges = true;
            $logMessage .= "installed_pc_for_cctv: " . json_encode($oldInstalledPcRecords) . " -> " . json_encode($newInstalledPcRecords) . "\n";
        }

        if ($hasChanges) {
            // Build the simplified log message
            $logMessage = "Data change in CCTV (ID: $id):\n";
        
            // Compare old and new installed_pc_for_cctv records
            foreach ($oldInstalledPcRecords as $index => $oldRecord) {
                $newRecord = $newInstalledPcRecords[$index] ?? null;
        
                if ($newRecord && ($oldRecord['computer_name'] === $newRecord['computer_name'])) {
                    $logMessage .= "- Computer: " . $oldRecord['computer_name'] . "\n";
        
                    // Check for changes in software_login
                    if ($oldRecord['software_login'] !== $newRecord['software_login']) {
                        $logMessage .= "  - Software Login: " . $oldRecord['software_login'] . " -> " . $newRecord['software_login'] . "\n";
                    }
        
                    // Check for changes in software_password
                    if ($oldRecord['software_password'] !== $newRecord['software_password']) {
                        $logMessage .= "  - Software Password: " . $oldRecord['software_password'] . " -> " . $newRecord['software_password'] . "\n";
                    }
                }
            }
        
            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);
        
            // Update installed_pc_for_cctv records
            // First, delete existing records for this item_type_hw_cctv_id
            $stmt = $pdo->prepare("DELETE FROM installed_pc_for_cctv WHERE item_type_hw_cctv_id = :id");
            $stmt->execute([':id' => $id]);
        
            // Insert new installed_pc_for_cctv records with software login and password
            foreach ($newInstalledPcRecords as $record) {
                $stmt = $pdo->prepare("INSERT INTO installed_pc_for_cctv (
                    item_type_hw_cctv_id, 
                    computer_name, 
                    software_login, 
                    software_password
                ) VALUES (
                    :item_type_hw_cctv_id, 
                    :computer_name, 
                    :software_login, 
                    :software_password
                )");
                $stmt->execute([
                    ':item_type_hw_cctv_id' => $id,
                    ':computer_name' => $record['computer_name'],
                    ':software_login' => $record['software_login'],
                    ':software_password' => encryptPassword($record['software_password'], $encryptionKey) // Encrypt before saving
                ]);
            }
        
            // Success alert and redirect
            $debtorCode = $cctv['debtor_code'];
            $companyName = $cctv['company_name'];
            echo "<script>alert('Data updated successfully!'); window.location.href = 'view_hardware_table.php?debtor_code=$debtorCode&company_name=$companyName';</script>";
        } else {
            // Alert if no changes were detected
            echo "<script>alert('No data changed!'); window.history.back();</script>";
        }
        exit;
    } catch (PDOException $e) {
        error_log('Database update error: ' . $e->getMessage());
        $debtorCode = $cctv['debtor_code'];
        $companyName = $cctv['company_name'];
        echo "<script>alert('Failed to update data. Please try again.'); window.location.href = 'view_hardware_table.php?debtor_code=$debtorCode&company_name=$companyName';</script>";
        exit;
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit CCTV Details</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit CCTV Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $cctv['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- Login Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="brand" name="brand" placeholder="Brand" value="<?php echo htmlspecialchars($cctv['brand']); ?>">
                                    <label for="brand">Brand</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="login" name="login" placeholder="Login" value="<?php echo htmlspecialchars($cctv['login']); ?>">
                                    <label for="login">Login</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="ddns" name="ddns" placeholder="DDNS" value="<?php echo htmlspecialchars($cctv['ddns']); ?>">
                                    <label for="ddns">DDNS</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="tcp_ip" name="tcp_ip" placeholder="TCP/IP" value="<?php echo htmlspecialchars($cctv['tcp_ip']); ?>">
                                    <label for="tcp_ip">TCP/IP</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="model" name="model" placeholder="Model" value="<?php echo htmlspecialchars($cctv['model']); ?>">
                                    <label for="model">Model</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="password" name="password" placeholder="Password" value="<?php echo htmlspecialchars($cctv['password']); ?>">
                                    <label for="password">Password</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="open_port" name="open_port" placeholder="Open Port" value="<?php echo htmlspecialchars($cctv['open_port']); ?>">
                                    <label for="open_port">Open Port</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- User Login Details (CCTV Login ID and Password) -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">User Login Details (CCTV Login ID and Password)</h5>
                    </div>
                    <div class="card-body">
                        <div id="userLoginContainer">
                            <?php foreach ($userLoginArray as $index => $userLogin): ?>
                                <div class="form-group row mb-3">
                                    <div class="col-sm-12">
                                        <div class="input-group">
                                            <div class="form-floating">
                                                <input type="text" name="user_login[]" class="form-control" placeholder="User Login" value="<?php echo htmlspecialchars($userLogin); ?>">
                                                <label>User Login</label>
                                            </div>
                                            <div class="form-floating">
                                                <input type="text" name="user_password[]" class="form-control" placeholder="User Password" value="<?php echo htmlspecialchars($userPasswordArray[$index]); ?>">
                                                <label>User Password</label>
                                            </div>
                                            <button type="button" class="btn btn-secondary" onclick="removeUserLogin(this)">Remove</button>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                        <div class="form-group row mb-3">
                            <div class="col-sm-12">
                                <button type="button" onclick="addUserLogin()" class="btn btn-primary">Add</button>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Installed PC and Software Details</h5>
                    </div>
                    <div class="card-body">
                        <div id="installedPcAndSoftwareContainer">
                            <?php foreach ($installedPcRecords as $index => $pc): ?>
                                <div class="form-group row mb-3">
                                    <div class="col-sm-12">
                                        <div class="input-group">
                                            <div class="form-floating">
                                                <select class="form-select" name="installed_pc[]" id="installed_pc">
                                                    <option value="" disabled selected>Please select a PC</option>
                                                    <?php foreach ($installedPcOptions as $option): ?>
                                                        <option value="<?php echo htmlspecialchars($option); ?>" <?php echo $option == $pc['computer_name'] ? 'selected' : ''; ?>><?php echo htmlspecialchars($option); ?></option>
                                                    <?php endforeach; ?>
                                                </select>
                                                <label for="installed_pc">Installed PC</label>
                                            </div>
                                            <div class="form-floating">
                                                <input type="text" name="software_login[]" class="form-control" placeholder="Software Login ID" value="<?php echo htmlspecialchars($pc['software_login']); ?>">
                                                <label>Software Login ID</label>
                                            </div>
                                            <div class="form-floating">
                                                <input type="text" name="software_password[]" class="form-control" placeholder="Software Login Password" value="<?php echo htmlspecialchars(decryptPassword($pc['software_password'], 'your_secret_key')); ?>">
                                                <label>Software Login Password</label>
                                            </div>
                                            <button type="button" class="btn btn-secondary" onclick="removeInstalledPcAndSoftware(this)">Remove</button>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                        <div class="form-group row mb-3">
                            <div class="col-sm-12">
                                <button type="button" onclick="addInstalledPcAndSoftware()" class="btn btn-primary">Add</button>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Update</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5 JS and dependencies -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
<script>
function addUserLogin() {
    const container = document.getElementById('userLoginContainer');

    const rowDiv = document.createElement('div');
    rowDiv.className = 'form-group row mb-3';

    const inputGroupDiv = document.createElement('div');
    inputGroupDiv.className = 'col-sm-12';

    const inputGroup = document.createElement('div');
    inputGroup.className = 'input-group';

    const input1Div = document.createElement('div');
    input1Div.className = 'form-floating';
    const input1 = document.createElement('input');
    input1.type = 'text';
    input1.name = 'user_login[]';
    input1.placeholder = 'User Login';
    input1.className = 'form-control';
    const input1Label = document.createElement('label');
    input1Label.innerText = 'User Login';
    input1Div.appendChild(input1);
    input1Div.appendChild(input1Label);

    const input2Div = document.createElement('div');
    input2Div.className = 'form-floating';
    const input2 = document.createElement('input');
    input2.type = 'text';
    input2.name = 'user_password[]';
    input2.placeholder = 'User Password';
    input2.className = 'form-control';
    const input2Label = document.createElement('label');
    input2Label.innerText = 'User Password';
    input2Div.appendChild(input2);
    input2Div.appendChild(input2Label);

    const removeButton = document.createElement('button');
    removeButton.type = 'button';
    removeButton.className = 'btn btn-secondary';
    removeButton.innerText = 'Remove';
    removeButton.onclick = function () {
        removeUserLogin(this);
    };

    inputGroup.appendChild(input1Div);
    inputGroup.appendChild(input2Div);
    inputGroup.appendChild(removeButton);

    inputGroupDiv.appendChild(inputGroup);

    rowDiv.appendChild(inputGroupDiv);

    container.appendChild(rowDiv);
}

function removeUserLogin(button) {
    const rowDiv = button.closest('.form-group.row');
    const container = document.getElementById('userLoginContainer');
    if (container.children.length > 1) {
        rowDiv.remove();
    } else {
        alert('You cannot remove the last field.');
    }
}

function addInstalledPcAndSoftware() {
    const container = document.getElementById('installedPcAndSoftwareContainer');

    const rowDiv = document.createElement('div');
    rowDiv.className = 'form-group row mb-3';

    const inputGroupDiv = document.createElement('div');
    inputGroupDiv.className = 'col-sm-12';

    const inputGroup = document.createElement('div');
    inputGroup.className = 'input-group';

    const selectDiv = document.createElement('div');
    selectDiv.className = 'form-floating';
    const select = document.createElement('select');
    select.className = 'form-select';
    select.name = 'installed_pc[]';
    select.innerHTML = `
        <option value="" disabled selected>Please select a PC</option>
        <?php foreach ($installedPcOptions as $option): ?>
            <option value="<?php echo htmlspecialchars($option); ?>"><?php echo htmlspecialchars($option); ?></option>
        <?php endforeach; ?>
    `;
    const selectLabel = document.createElement('label');
    selectLabel.innerText = 'Installed PC';
    selectDiv.appendChild(select);
    selectDiv.appendChild(selectLabel);

    const input1Div = document.createElement('div');
    input1Div.className = 'form-floating';
    const input1 = document.createElement('input');
    input1.type = 'text';
    input1.name = 'software_login[]';
    input1.placeholder = 'Software Login ID';
    input1.className = 'form-control';
    const input1Label = document.createElement('label');
    input1Label.innerText = 'Software Login ID';
    input1Div.appendChild(input1);
    input1Div.appendChild(input1Label);

    const input2Div = document.createElement('div');
    input2Div.className = 'form-floating';
    const input2 = document.createElement('input');
    input2.type = 'text';
    input2.name = 'software_password[]';
    input2.placeholder = 'Software Login Password';
    input2.className = 'form-control';
    const input2Label = document.createElement('label');
    input2Label.innerText = 'Software Login Password';
    input2Div.appendChild(input2);
    input2Div.appendChild(input2Label);

    const removeButton = document.createElement('button');
    removeButton.type = 'button';
    removeButton.className = 'btn btn-secondary';
    removeButton.innerText = 'Remove';
    removeButton.onclick = function () {
        removeInstalledPcAndSoftware(this);
    };

    inputGroup.appendChild(selectDiv);
    inputGroup.appendChild(input1Div);
    inputGroup.appendChild(input2Div);
    inputGroup.appendChild(removeButton);

    inputGroupDiv.appendChild(inputGroup);

    rowDiv.appendChild(inputGroupDiv);

    container.appendChild(rowDiv);
}

function removeInstalledPcAndSoftware(button) {
    const rowDiv = button.closest('.form-group.row');
    const container = document.getElementById('installedPcAndSoftwareContainer');
    if (container.children.length > 1) {
        rowDiv.remove();
    } else {
        alert('You cannot remove the last field.');
    }
}
</script>

