<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$itemTypeHwOthersId = isset($_GET['item_type_hw_others_id']) ? $_GET['item_type_hw_others_id'] : null; // Unique identifier for the record
$debtorCode = isset($_GET['debtor_code']) ? $_GET['debtor_code'] : ''; // Debtor code
$companyName = isset($_GET['company_name']) ? $_GET['company_name'] : ''; // Company name

// Fetch the existing data from the database
$existingData = [];
if ($itemTypeHwOthersId) {
    try {
        $stmt = $pdo->prepare("SELECT * FROM item_type_hw_others WHERE item_type_hw_others_id = ?");
        $stmt->execute([$itemTypeHwOthersId]);
        $existingData = $stmt->fetch(PDO::FETCH_ASSOC);
        if (!$existingData) {
            echo "<script>alert('Record not found!'); window.location.href = 'view_hardware_table.php?debtor_code=$debtorCode&company_name=$companyName';</script>";
            exit;
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Extract necessary values from the fetched data
$companyName = $existingData['company_name'] ?? $companyName;
$itemType = $existingData['item_type_name'] ?? '';
$itemTypeHardwareGroup = $existingData['item_type_hw_group_name'] ?? '';

// Fetch the debtor_code based on the company_name
if (!$debtorCode && $companyName) {
    try {
        $stmt = $pdo->prepare("SELECT debtor_code FROM company_info WHERE company_name = ?");
        $stmt->execute([$companyName]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $debtorCode = $company['debtor_code'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the list of installed PCs from the database
$installedPcs = [];
if ($debtorCode && $companyName) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = 1; // Always set active to 1
    $installedPc = $_POST['installed_pc'] ?? null;
    $brand = $_POST['brand'] ?? null;
    $model = $_POST['model'] ?? null;
    $partNo = $_POST['part_no'] ?? null;
    $serialNumber = $_POST['serial_number'] ?? null;
    $others = $_POST['others'] ?? null;

    // Store the old data for comparison
    $oldData = $existingData;

    // Check if any data has changed
    $dataChanged = false;
    foreach ($oldData as $key => $value) {
        // Skip fields that are not in the form or are not user-editable
        if ($key === 'created_at' || !isset($_POST[$key])) {
            continue;
        }

        // Compare the POST value with the existing value
        if (trim($_POST[$key]) !== trim($value)) {
            $dataChanged = true;
            break;
        }
    }

    if (!$dataChanged) {
        // No data changed, show alert and redirect
        echo "<script>alert('No data changed!'); window.location.href = 'view_hardware_table.php?debtor_code=$debtorCode&company_name=$companyName';</script>";
        exit;
    }

    try {
        // Prepare and execute the update query
        $stmt = $pdo->prepare("UPDATE item_type_hw_others SET
            item_type_name = :item_type_name, 
            company_name = :company_name, 
            debtor_code = :debtor_code,
            active = :active,
            item_type_hw_group_name = :item_type_hw_group_name,
            installed_pc = :installed_pc,
            brand = :brand,
            model = :model,
            part_no = :part_no,
            serial_number = :serial_number,
            others = :others,
            updated_time = NOW()
        WHERE item_type_hw_others_id = :item_type_hw_others_id");

        $stmt->execute([
            ':item_type_name' => $itemType,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':item_type_hw_group_name' => $itemTypeHardwareGroup,
            ':active' => $active,
            ':installed_pc' => $installedPc,
            ':brand' => $brand,
            ':model' => $model,
            ':part_no' => $partNo,
            ':serial_number' => $serialNumber,
            ':others' => $others,
            ':item_type_hw_others_id' => $itemTypeHwOthersId
        ]);

        // Fetch the updated record for logging
        $stmt = $pdo->prepare("SELECT * FROM item_type_hw_others WHERE item_type_hw_others_id = :item_type_hw_others_id");
        $stmt->execute([':item_type_hw_others_id' => $itemTypeHwOthersId]);
        $newData = $stmt->fetch(PDO::FETCH_ASSOC);

        // Build the log message
        $logMessage = "Data change in Hardware(Others) (ID: $itemTypeHwOthersId):\n";
        foreach ($oldData as $key => $value) {
            // Skip fields that are not user-editable
            if ($key === 'created_at' || !isset($_POST[$key])) {
                continue;
            }

            // Compare the POST value with the existing value
            if (trim($_POST[$key]) !== trim($value)) {
                $logMessage .= "$key: $value -> " . $_POST[$key] . "\n";
            }
        }

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // Success alert and redirect
        echo "<script>alert('Data updated successfully!'); window.location.href = 'view_hardware_table.php?debtor_code=$debtorCode&company_name=$companyName';</script>";
    } catch (PDOException $e) {
        error_log('Database update error: ' . $e->getMessage());
        echo "<script>alert('Failed to update data. Please try again.'); window.location.href = 'view_hardware_table.php?debtor_code=$debtorCode&company_name=$companyName';</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Hardware Others Details</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-4">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h2 class="mb-0">Edit Hardware Others Details</h2>
        </div>
        <div class="card-body">
            <form method="POST">
                <!-- Hidden input for item_type_hw_id -->
                <input type="hidden" name="item_type_hw_id" value="<?php echo htmlspecialchars($itemTypeHwId); ?>">

                <!-- Display the passed values -->
                <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $existingData['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- Installed PC Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Installed PC</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <select class="form-select" name="installed_pc" id="installed_pc">
                                <option value="">Select Installed PC</option>
                                <?php foreach ($installedPcs as $pc): ?>
                                    <option value="<?php echo htmlspecialchars($pc); ?>" <?php echo ($existingData['installed_pc'] == $pc) ? 'selected' : ''; ?>><?php echo htmlspecialchars($pc); ?></option>
                                <?php endforeach; ?>
                            </select>
                            <label for="installed_pc">Installed PC</label>
                        </div>
                    </div>
                </div>

                <!-- General Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">General Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="brand" id="brand" placeholder="Brand" value="<?php echo htmlspecialchars($existingData['brand'] ?? ''); ?>">
                                    <label for="brand">Brand</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="model" id="model" placeholder="Model" value="<?php echo htmlspecialchars($existingData['model'] ?? ''); ?>">
                                    <label for="model">Model</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="part_no" id="part_no" placeholder="Part No" value="<?php echo htmlspecialchars($existingData['part_no'] ?? ''); ?>">
                                    <label for="part_no">Part No</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="serial_number" id="serial_number" placeholder="Serial Number" value="<?php echo htmlspecialchars($existingData['serial_number'] ?? ''); ?>">
                                    <label for="serial_number">Serial Number</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea class="form-control" id="others" name="others" placeholder="Others"><?php echo htmlspecialchars($existingData['others'] ?? ''); ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Update</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5 JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>

