<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if debtor_code and item_type_hw_ups_id are passed via URL
if (isset($_GET['debtor_code']) && isset($_GET['item_type_hw_ups_id'])) {
    $debtorCode = $_GET['debtor_code'];
    $upsId = $_GET['item_type_hw_ups_id'];

    // Fetch the UPS details based on debtor_code and item_type_hw_ups_id
    $stmt = $pdo->prepare('SELECT * FROM item_type_hw_ups WHERE debtor_code = :debtor_code AND item_type_hw_ups_id = :item_type_hw_ups_id LIMIT 1');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_type_hw_ups_id', $upsId);
    $stmt->execute();
    $ups = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$ups) {
        echo "<p>No UPS found with the provided ID.</p>";
        exit;
    }

    // Decrypt the password
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $ups['password'] = decryptPassword($ups['password'], $encryptionKey);

    // Fetch the company name based on debtor_code
    $companyName = '';
    if ($debtorCode) {
        try {
            $stmt = $pdo->prepare("SELECT company_name FROM company_info WHERE debtor_code = ?");
            $stmt->execute([$debtorCode]);
            $company = $stmt->fetch(PDO::FETCH_ASSOC);
            if ($company) {
                $companyName = $company['company_name'];
            }
        } catch (PDOException $e) {
            error_log('Database query error: ' . $e->getMessage());
        }
    }

    // Fetch the list of installed PCs for the selected company based on debtor_code and company_name
    $installedPcs = [];
    if ($debtorCode && $companyName) {
        try {
            $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
            $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
            $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
        } catch (PDOException $e) {
            error_log('Database query error: ' . $e->getMessage());
        }
    }
} else {
    echo "<p>No debtor code or UPS ID provided.</p>";
    exit;
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $active = isset($_POST['active']) ? 1 : 0;
    $login = htmlspecialchars($_POST['login']);
    $password = htmlspecialchars($_POST['password']);
    $brand = htmlspecialchars($_POST['brand']);
    $model = htmlspecialchars($_POST['model']);
    $software_name = htmlspecialchars($_POST['software_name']);
    $software_version = htmlspecialchars($_POST['software_version']);
    $part_no = htmlspecialchars($_POST['part_no']);
    $serial_number = htmlspecialchars($_POST['serial_number']);
    $tcp_ip = htmlspecialchars($_POST['tcp_ip']);
    $installedPc = htmlspecialchars($_POST['installed_pc']);
    $others = htmlspecialchars($_POST['others']);

    // Encrypt the password
    $encryptedPassword = encryptPassword($password, $encryptionKey);

    // Store the old data for comparison
    $oldData = $ups;

    // Check if any data has changed
    $dataChanged = false;
    if ($active != $oldData['active'] ||
        $login != $oldData['login'] ||
        $password != $oldData['password'] ||
        $brand != $oldData['brand'] ||
        $model != $oldData['model'] ||
        $software_name != $oldData['software_name'] ||
        $software_version != $oldData['software_version'] ||
        $part_no != $oldData['part_no'] ||
        $serial_number != $oldData['serial_number'] ||
        $tcp_ip != $oldData['tcp_ip'] ||
        $others != $oldData['others'] ||
        $installedPc != $oldData['installed_pc']) {
        $dataChanged = true;
    }

    if (!$dataChanged) {
        // If no data changed, show alert and redirect back to view_hardware_table.php
        echo '<script type="text/javascript">';
        echo 'alert("No data changed.");';
        echo 'window.location.href="view_hardware_table.php?debtor_code=' . urlencode($debtorCode) . '";';
        echo '</script>';
    } else {
        // Update the UPS in the database
        $stmt = $pdo->prepare('UPDATE item_type_hw_ups SET active = :active, login = :login, password = :password, brand = :brand, model = :model, software_name = :software_name, software_version = :software_version, part_no = :part_no, serial_number = :serial_number, tcp_ip = :tcp_ip, installed_pc = :installed_pc, others = :others, updated_time = NOW() WHERE debtor_code = :debtor_code AND item_type_hw_ups_id = :item_type_hw_ups_id');
        $stmt->bindParam(':active', $active);
        $stmt->bindParam(':login', $login);
        $stmt->bindParam(':password', $encryptedPassword);
        $stmt->bindParam(':brand', $brand);
        $stmt->bindParam(':model', $model);
        $stmt->bindParam(':software_name', $software_name);
        $stmt->bindParam(':software_version', $software_version);
        $stmt->bindParam(':part_no', $part_no);
        $stmt->bindParam(':serial_number', $serial_number);
        $stmt->bindParam(':tcp_ip', $tcp_ip);
        $stmt->bindParam(':installed_pc', $installedPc);
        $stmt->bindParam(':others', $others);
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->bindParam(':item_type_hw_ups_id', $upsId);

        if ($stmt->execute()) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_hw_ups WHERE debtor_code = :debtor_code AND item_type_hw_ups_id = :item_type_hw_ups_id LIMIT 1');
            $stmt->bindParam(':debtor_code', $debtorCode);
            $stmt->bindParam(':item_type_hw_ups_id', $upsId);
            $stmt->execute();
            $newItem = $stmt->fetch(PDO::FETCH_ASSOC);
            $newItem['password'] = decryptPassword($newItem['password'], $encryptionKey); // Decrypt for logging

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in UPS (Company Name: " . $companyName . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="view_hardware_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        } else {
            // If update failed, show error message
            echo '<script type="text/javascript">';
            echo 'alert("Failed to update. Please try again.");';
            echo '</script>';
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit UPS Details</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit UPS Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                <input type="hidden" name="item_type_hw_id" value="<?= htmlspecialchars($upsId) ?>">
                
                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $ups['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- Hardware Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Hardware Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="brand" name="brand" placeholder="Brand" value="<?= htmlspecialchars($ups['brand'] ?? '') ?>">
                                    <label for="brand">Brand</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="model" name="model" placeholder="Model" value="<?= htmlspecialchars($ups['model'] ?? '') ?>">
                                    <label for="model">Model</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="part_no" name="part_no" placeholder="Part No" value="<?= htmlspecialchars($ups['part_no'] ?? '') ?>">
                                    <label for="part_no">Part No</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="serial_number" name="serial_number" placeholder="Serial Number" value="<?= htmlspecialchars($ups['serial_number'] ?? '') ?>">
                                    <label for="serial_number">Serial Number</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <select class="form-select" id="installed_pc" name="installed_pc">
                                        <option value="">Select Installed PC</option>
                                        <?php foreach ($installedPcs as $pc): ?>
                                            <option value="<?= htmlspecialchars($pc) ?>" <?= $pc == $ups['installed_pc'] ? 'selected' : '' ?>><?= htmlspecialchars($pc) ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="installed_pc">UPS Installed PC</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Software Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Software Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="software_name" name="software_name" placeholder="Software Name" value="<?= htmlspecialchars($ups['software_name'] ?? '') ?>">
                                    <label for="software_name">Software Name</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="software_version" name="software_version" placeholder="Software Version" value="<?= htmlspecialchars($ups['software_version'] ?? '') ?>">
                                    <label for="software_version">Software Version</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="login" name="login" placeholder="Login" value="<?= htmlspecialchars($ups['login'] ?? '') ?>">
                                    <label for="login">Login</label>
                                </div>

                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="password" name="password" placeholder="Password" value="<?= htmlspecialchars($ups['password'] ?? '') ?>">
                                    <label for="password">Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Network Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Network Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="tcp_ip" name="tcp_ip" placeholder="TCP/IP" value="<?= htmlspecialchars($ups['tcp_ip'] ?? '') ?>">
                                    <label for="tcp_ip">TCP/IP</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea 
                                id="others" 
                                name="others" 
                                class="form-control" 
                                placeholder="Others" 
                                style="height: 200px; resize: vertical; overflow-y: hidden;"
                                oninput="this.style.height = ''; this.style.height = this.scrollHeight + 'px';"
                            ><?= htmlspecialchars($ups['others'] ?? '') ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Update</button>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5 JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>

