<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the NAS ID from the URL
$nasId = isset($_GET['item_type_nas_id']) ? intval($_GET['item_type_nas_id']) : 0;

// Fetch the NAS details from the database
$nasDetails = [];
if ($nasId) {
    try {
        $stmt = $pdo->prepare("SELECT * FROM item_type_nas_nas WHERE item_type_nas_id = ?");
        $stmt->execute([$nasId]);
        $nasDetails = $stmt->fetch(PDO::FETCH_ASSOC);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Decrypt the passwords for display
$encryptionKey = 'your_secret_key'; // This should be a secure key
$decryptedPassword = decryptPassword($nasDetails['password'], $encryptionKey);
$decryptedBackupUserPassword = decryptPassword($nasDetails['backup_user_password'], $encryptionKey);

// Explode the hard disk values
$hardDiskUnits = explode(',', $nasDetails['harddisk_unit']);
$hardDiskSizes = explode(',', $nasDetails['harddisk_size']);
$hardDiskSns = explode(',', $nasDetails['harddisk_sn']);

// Fetch unique emails and decrypt passwords
$uniqueEmails = [];
if ($nasDetails['debtor_code']) {
    try {
        // Fetch emails from item_type_email_citssb where used_at is 'Synology'
        $stmt = $pdo->prepare("
            SELECT email, password 
            FROM item_type_email_citssb 
            WHERE debtor_code = ? 
              AND used_at = 'Synology'
        ");
        $stmt->execute([$nasDetails['debtor_code']]);
        $emails = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Decrypt passwords and store unique emails
        foreach ($emails as $emailData) {
            $email = $emailData['email'];
            $password = decryptPassword($emailData['password'], $encryptionKey); // Replace with your actual encryption key
            $uniqueEmails[$email] = $password; // Associative array to handle duplicates
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Fetch the company name based on debtor_code
$companyName = 'Unknown Company'; // Default fallback
if ($nasDetails['debtor_code']) {
    try {
        $stmt = $pdo->prepare("SELECT company_name FROM company_info WHERE debtor_code = ?");
        $stmt->execute([$nasDetails['debtor_code']]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $companyName = $company['company_name'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = isset($_POST['active']) ? 1 : 0;
    $login = htmlspecialchars(trim($_POST['login']));
    $password = htmlspecialchars(trim($_POST['password']));
    $backupUserId = htmlspecialchars(trim($_POST['backup_user_id']));
    $backupUserPassword = htmlspecialchars(trim($_POST['backup_user_password']));
    $deviceName = htmlspecialchars(trim($_POST['device_name']));
    $model = htmlspecialchars(trim($_POST['model']));
    $hardDiskUnit = isset($_POST['harddisk_unit']) && is_array($_POST['harddisk_unit']) ? array_map('trim', $_POST['harddisk_unit']) : [];
    $hardDiskSize = isset($_POST['harddisk_size']) && is_array($_POST['harddisk_size']) ? array_map('trim', $_POST['harddisk_size']) : [];
    $hardDiskSn = isset($_POST['harddisk_sn']) && is_array($_POST['harddisk_sn']) ? array_map('trim', $_POST['harddisk_sn']) : [];
    $hardDiskRaid = htmlspecialchars(trim($_POST['harddisk_raid']));
    $tcpIp = htmlspecialchars(trim($_POST['tcp_ip']));
    $dmsVersion = htmlspecialchars(trim($_POST['dms_version']));
    $quickconnectId = htmlspecialchars(trim($_POST['quickconnect_id']));
    $serialNumber = htmlspecialchars(trim($_POST['serial_number']));
    $purchaseDate = htmlspecialchars(trim($_POST['purchase_date']));
    $warrantyExpireDate = htmlspecialchars(trim($_POST['warranty_expire_date']));
    $extendWarranty = htmlspecialchars(trim($_POST['extend_warranty']));
    $physicalBackup = isset($_POST['physical_backup']) ? 1 : 0;
    $fileServer = isset($_POST['file_server']) ? 1 : 0;
    $hyperBackup = isset($_POST['hyper_backup']) ? 1 : 0;
    $synologyDrive = isset($_POST['synology_drive']) ? 1 : 0;
    $activeBackupForGoogle = isset($_POST['active_backup_for_google']) ? 1 : 0;
    $activeBackupForO365 = isset($_POST['active_backup_for_o365']) ? 1 : 0;
    $others = htmlspecialchars(trim($_POST['others']));

    // Retrieve the selected email
    $synologyEmail = htmlspecialchars(trim($_POST['synology_email']));

    // Filter out empty values from hard disk arrays
    $hardDiskUnit = array_filter($hardDiskUnit, 'strlen');
    $hardDiskSize = array_filter($hardDiskSize, 'strlen');
    $hardDiskSn = array_filter($hardDiskSn, 'strlen');

    // Implode the hard disk arrays
    $hardDiskUnit = implode(',', $hardDiskUnit);
    $hardDiskSize = implode(',', $hardDiskSize);
    $hardDiskSn = implode(',', $hardDiskSn);

    // Store the old data for comparison
    $oldData = $nasDetails;
    $oldData['password'] = $decryptedPassword; // Decrypted password for comparison
    $oldData['backup_user_password'] = $decryptedBackupUserPassword; // Decrypted backup user password for comparison

    // Prepare the new data for comparison
    $newData = [
        'active' => $active,
        'login' => $login,
        'password' => $password,
        'backup_user_id' => $backupUserId,
        'backup_user_password' => $backupUserPassword,
        'device_name' => $deviceName,
        'model' => $model,
        'harddisk_unit' => $hardDiskUnit,
        'harddisk_size' => $hardDiskSize,
        'harddisk_raid' => $hardDiskRaid,
        'tcp_ip' => $tcpIp,
        'dms_version' => $dmsVersion,
        'quickconnect_id' => $quickconnectId,
        'serial_number' => $serialNumber,
        'harddisk_sn' => $hardDiskSn,
        'purchase_date' => $purchaseDate,
        'warranty_expire_date' => $warrantyExpireDate,
        'extend_warranty' => $extendWarranty,
        'physical_backup' => $physicalBackup,
        'file_server' => $fileServer,
        'hyper_backup' => $hyperBackup,
        'synology_drive' => $synologyDrive,
        'active_backup_for_google' => $activeBackupForGoogle,
        'active_backup_for_o365' => $activeBackupForO365,
        'others' => $others,
        'synology_email' => $synologyEmail,
    ];

    // Normalize empty dates
    $normalizedOldPurchaseDate = ($oldData['purchase_date'] === null || $oldData['purchase_date'] === '0000-00-00') ? '' : $oldData['purchase_date'];
    $normalizedNewPurchaseDate = ($newData['purchase_date'] === null || $newData['purchase_date'] === '0000-00-00') ? '' : $newData['purchase_date'];

    $normalizedOldWarrantyExpireDate = ($oldData['warranty_expire_date'] === null || $oldData['warranty_expire_date'] === '0000-00-00') ? '' : $oldData['warranty_expire_date'];
    $normalizedNewWarrantyExpireDate = ($newData['warranty_expire_date'] === null || $newData['warranty_expire_date'] === '0000-00-00') ? '' : $newData['warranty_expire_date'];

    // Compare old and new data to check for changes
    $hasChanges = false;
    foreach ($newData as $key => $value) {
        // For password fields, compare plaintext values
        if (in_array($key, ['password', 'backup_user_password'])) {
            if ($oldData[$key] !== $value) {
                $hasChanges = true;
                break;
            }
        } else {
            // For date fields, compare normalized values
            if ($key === 'purchase_date') {
                if ($normalizedOldPurchaseDate !== $normalizedNewPurchaseDate) {
                    $hasChanges = true;
                    break;
                }
            } elseif ($key === 'warranty_expire_date') {
                if ($normalizedOldWarrantyExpireDate !== $normalizedNewWarrantyExpireDate) {
                    $hasChanges = true;
                    break;
                }
            } else {
                if ($oldData[$key] !== $value) {
                    $hasChanges = true;
                    break;
                }
            }
        }
    }

    if (!$hasChanges) {
        // No data change, display alert and redirect to the previous page
        echo "<script>
            alert('No data change detected.');
            window.location.href = 'view_nas_table.php?debtor_code=" . urlencode($nasDetails['debtor_code']) . "&company_name=" . urlencode($nasDetails['company_name']) . "';
        </script>";
        exit; // Stop further execution
    }

    try {
        // Encrypt the passwords only if they have changed
        $encryptedPassword = ($oldData['password'] !== $password) ? encryptPassword($password, $encryptionKey) : $nasDetails['password'];
        $encryptedBackupUserPassword = ($oldData['backup_user_password'] !== $backupUserPassword) ? encryptPassword($backupUserPassword, $encryptionKey) : $nasDetails['backup_user_password'];

        // Prepare and execute the update query
        $stmt = $pdo->prepare("UPDATE item_type_nas_nas SET
            active = :active,
            login = :login,
            password = :password,
            backup_user_id = :backup_user_id,
            backup_user_password = :backup_user_password,
            device_name = :device_name,
            model = :model,
            harddisk_unit = :harddisk_unit,
            harddisk_size = :harddisk_size,
            harddisk_raid = :harddisk_raid,
            tcp_ip = :tcp_ip,
            dms_version = :dms_version,
            quickconnect_id = :quickconnect_id,
            serial_number = :serial_number,
            harddisk_sn = :harddisk_sn,
            purchase_date = :purchase_date,
            warranty_expire_date = :warranty_expire_date,
            extend_warranty = :extend_warranty,
            physical_backup = :physical_backup,
            file_server = :file_server,
            hyper_backup = :hyper_backup,
            synology_drive = :synology_drive,
            active_backup_for_google = :active_backup_for_google,
            active_backup_for_o365 = :active_backup_for_o365,
            others = :others,
            synology_email = :synology_email,
            updated_time = NOW() -- Update the updated_time field to the current timestamp
        WHERE item_type_nas_id = :item_type_nas_id");

        // Execute the statement
        $stmt->execute([
            ':active' => $active,
            ':login' => $login,
            ':password' => $encryptedPassword,
            ':backup_user_id' => $backupUserId,
            ':backup_user_password' => $encryptedBackupUserPassword,
            ':device_name' => $deviceName,
            ':model' => $model,
            ':harddisk_unit' => $hardDiskUnit,
            ':harddisk_size' => $hardDiskSize,
            ':harddisk_raid' => $hardDiskRaid,
            ':tcp_ip' => $tcpIp,
            ':dms_version' => $dmsVersion,
            ':quickconnect_id' => $quickconnectId,
            ':serial_number' => $serialNumber,
            ':harddisk_sn' => $hardDiskSn,
            ':purchase_date' => $purchaseDate,
            ':warranty_expire_date' => $warrantyExpireDate,
            ':extend_warranty' => $extendWarranty,
            ':physical_backup' => $physicalBackup,
            ':file_server' => $fileServer,
            ':hyper_backup' => $hyperBackup,
            ':synology_drive' => $synologyDrive,
            ':active_backup_for_google' => $activeBackupForGoogle,
            ':active_backup_for_o365' => $activeBackupForO365,
            ':others' => $others,
            ':synology_email' => $synologyEmail,
            ':item_type_nas_id' => $nasId
        ]);

        // Success alert and redirect to the previous page
        echo "<script>
            alert('Data updated successfully!');
            window.location.href = 'view_nas_table.php?debtor_code=" . urlencode($nasDetails['debtor_code']) . "&company_name=" . urlencode($nasDetails['company_name']) . "';
        </script>";
    } catch (PDOException $e) {
        error_log('Database update error: ' . $e->getMessage());
        echo "<script>alert('Failed to update data. Please try again.');</script>";
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit NAS Details</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Edit NAS Details</h1>
            </div>
            <div class="card-body">
                <form method="POST" onsubmit="return validateForm()">
                    <!-- Display the passed values -->
                    <div class="mb-3">
                        <p>Debtor Code: <strong><?php echo htmlspecialchars($nasDetails['debtor_code']); ?></strong></p>
                        <p>Company Name: <strong><?php echo htmlspecialchars($nasDetails['company_name']); ?></strong></p>
                        <p>Item Type: <strong><?php echo htmlspecialchars($nasDetails['item_type_name']); ?></strong></p>
                        <p>Item Type Group: <strong><?php echo htmlspecialchars($nasDetails['item_type_nas_group_name']); ?></strong></p>
                    </div>

                    <!-- Active Status -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Active Status</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $nasDetails['active'] ? 'checked' : '' ?>>
                                <label class="form-check-label" for="active">Active</label>
                            </div>
                        </div>
                    </div>

                    <!-- Login and Password -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Login and Password</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="login" id="login" value="<?php echo htmlspecialchars($nasDetails['login']); ?>" placeholder="Login">
                                        <label for="login">Login</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="password" id="password" value="<?php echo htmlspecialchars($decryptedPassword); ?>" placeholder="Password">
                                        <label for="password">Password</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="backup_user_id" id="backup_user_id" value="<?php echo htmlspecialchars($nasDetails['backup_user_id']); ?>" placeholder="Backup User ID">
                                        <label for="backup_user_id">Backup User ID</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="backup_user_password" id="backup_user_password" value="<?php echo htmlspecialchars($decryptedBackupUserPassword); ?>" placeholder="Backup User Password">
                                        <label for="backup_user_password">Backup User Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Device and Model -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Device and Model</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="device_name" id="device_name" value="<?php echo htmlspecialchars($nasDetails['device_name']); ?>" placeholder="Device Name">
                                        <label for="device_name">Device Name</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="serial_number" id="serial_number" value="<?php echo htmlspecialchars($nasDetails['serial_number']); ?>" placeholder="Synology Serial Number">
                                        <label for="serial_number">Synology Serial Number</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="model" id="model" value="<?php echo htmlspecialchars($nasDetails['model']); ?>" placeholder="Model">
                                        <label for="model">Model</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="dms_version" id="dms_version" value="<?php echo htmlspecialchars($nasDetails['dms_version']); ?>" placeholder="DMS Version">
                                        <label for="dms_version">DMS Version</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Serial Number and Hard Disks -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Hard Disk Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="harddisk_raid" id="harddisk_raid" value="<?php echo htmlspecialchars($nasDetails['harddisk_raid']); ?>" placeholder="Hard Disk Raid">
                                        <label for="harddisk_raid">Hard Disk Raid</label>
                                    </div>
                                </div>
                                <div class="col-md-12">
                                    <div id="hardDiskContainer">
                                        <!-- Existing hard disk rows -->
                                        <?php
                                        for ($i = 0; $i < count($hardDiskUnits); $i++) {
                                            echo '<div class="input-group mb-2">'; // Use input-group for sticking fields together

                                            // Unit Field
                                            echo '<div class="form-floating">';
                                            echo '<input type="text" class="form-control" name="harddisk_unit[]" placeholder="Unit" value="' . htmlspecialchars($hardDiskUnits[$i]) . '">';
                                            echo '<label>Unit</label>';
                                            echo '</div>';

                                            // Size Field
                                            echo '<div class="form-floating">';
                                            echo '<input type="text" class="form-control" name="harddisk_size[]" placeholder="Size" value="' . htmlspecialchars($hardDiskSizes[$i]) . '">';
                                            echo '<label>Size</label>';
                                            echo '</div>';

                                            // S/N Field
                                            echo '<div class="form-floating">';
                                            echo '<input type="text" class="form-control" name="harddisk_sn[]" placeholder="S/N" value="' . htmlspecialchars($hardDiskSns[$i]) . '">';
                                            echo '<label>S/N</label>';
                                            echo '</div>';

                                            // Remove Button
                                            echo '<button type="button" class="btn btn-danger" onclick="removeHardDisk(this)">Remove</button>';

                                            echo '</div>'; // Close input-group
                                        }
                                        ?>
                                    </div>
                                    <button type="button" class="btn btn-secondary" onclick="addHardDisk()">Add Hard Disk</button>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Network Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Network Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="tcp_ip" id="tcp_ip" value="<?php echo htmlspecialchars($nasDetails['tcp_ip']); ?>" placeholder="TCP/IP">
                                        <label for="tcp_ip">TCP/IP</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="quickconnect_id" id="quickconnect_id" value="<?php echo htmlspecialchars($nasDetails['quickconnect_id']); ?>" placeholder="QuickConnect ID">
                                        <label for="quickconnect_id">QuickConnect ID</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- DMS Version and Warranty Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Warranty Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" name="purchase_date" id="purchase_date" value="<?php echo htmlspecialchars($nasDetails['purchase_date']); ?>" placeholder="Purchase Date">
                                        <label for="purchase_date">Purchase Date</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="extend_warranty" id="extend_warranty" value="<?php echo htmlspecialchars($nasDetails['extend_warranty']); ?>" placeholder="Extend Warranty">
                                        <label for="extend_warranty">Extend Warranty</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" name="warranty_expire_date" id="warranty_expire_date" value="<?php echo htmlspecialchars($nasDetails['warranty_expire_date']); ?>" placeholder="Warranty Expire Date">
                                        <label for="warranty_expire_date">Warranty Expire Date</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Synology Account -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Synology Account</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <select class="form-control" id="synology_email" name="synology_email">
                                            <option value="">Select an Email</option>
                                            <?php foreach ($uniqueEmails as $email => $password): ?>
                                                <option value="<?php echo htmlspecialchars($email); ?>" <?php if ($nasDetails['synology_email'] == $email) echo 'selected'; ?>><?php echo htmlspecialchars($email); ?></option>
                                            <?php endforeach; ?>
                                        </select>
                                        <label for="synology_email">Select Email</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Synology Services -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Synology Services</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-check mb-3">
                                        <input type="checkbox" class="form-check-input" name="physical_backup" id="physical_backup" value="1" <?php if ($nasDetails['physical_backup']) echo 'checked'; ?>>
                                        <label class="form-check-label" for="physical_backup">Physical Backup</label>
                                    </div>
                                    <div class="form-check mb-3">
                                        <input type="checkbox" class="form-check-input" name="file_server" id="file_server" value="1" <?php if ($nasDetails['file_server']) echo 'checked'; ?>>
                                        <label class="form-check-label" for="file_server">File Server</label>
                                    </div>
                                    <div class="form-check mb-3">
                                        <input type="checkbox" class="form-check-input" name="hyper_backup" id="hyper_backup" value="1" <?php if ($nasDetails['hyper_backup']) echo 'checked'; ?>>
                                        <label class="form-check-label" for="hyper_backup">Hyper Backup</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-check mb-3">
                                        <input type="checkbox" class="form-check-input" name="synology_drive" id="synology_drive" value="1" <?php if ($nasDetails['synology_drive']) echo 'checked'; ?>>
                                        <label class="form-check-label" for="synology_drive">Synology Drive</label>
                                    </div>
                                    <div class="form-check mb-3">
                                        <input type="checkbox" class="form-check-input" name="active_backup_for_google" id="active_backup_for_google" value="1" <?php if ($nasDetails['active_backup_for_google']) echo 'checked'; ?>>
                                        <label class="form-check-label" for="active_backup_for_google">Active Backup For Google</label>
                                    </div>
                                    <div class="form-check mb-3">
                                        <input type="checkbox" class="form-check-input" name="active_backup_for_o365" id="active_backup_for_o365" value="1" <?php if ($nasDetails['active_backup_for_o365']) echo 'checked'; ?>>
                                        <label class="form-check-label" for="active_backup_for_o365">Active Backup For Office 365</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Others Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Others Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="others" name="others" rows="3" placeholder="Others"><?php echo htmlspecialchars($nasDetails['others']); ?></textarea>
                                <label for="others">Others</label>
                            </div>
                        </div>
                    </div>

                    <!-- Save Button -->
                    <div class="text-center">
                        <button type="submit" class="btn btn-primary">Update</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap JS and dependencies -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
    <script>
    function addHardDisk() {
        const container = document.getElementById('hardDiskContainer');
        const newRow = document.createElement('div');
        newRow.className = 'input-group mb-2'; // Use input-group for sticking fields together
        newRow.innerHTML = `
            <div class="form-floating">
                <input type="text" class="form-control" name="harddisk_unit[]" placeholder="Unit">
                <label>Unit</label>
            </div>
            <div class="form-floating">
                <input type="text" class="form-control" name="harddisk_size[]" placeholder="Size">
                <label>Size</label>
            </div>
            <div class="form-floating">
                <input type="text" class="form-control" name="harddisk_sn[]" placeholder="S/N">
                <label>S/N</label>
            </div>
            <button type="button" class="btn btn-danger" onclick="removeHardDisk(this)">Remove</button>
        `;
        container.appendChild(newRow);
    }

    function removeHardDisk(button) {
        const row = button.closest('.input-group');
        if (document.querySelectorAll('.input-group').length === 1) {
            alert('The last field cannot be removed.');
        } else {
            row.remove();
        }
    }

    // Validate Form Function
    function validateForm() {
        const hardDiskRows = document.querySelectorAll('.input-group');
        let isValid = true;

        hardDiskRows.forEach(row => {
            const unit = row.querySelector('input[name="harddisk_unit[]"]').value.trim();
            const size = row.querySelector('input[name="harddisk_size[]"]').value.trim();
            const sn = row.querySelector('input[name="harddisk_sn[]"]').value.trim();

            if (unit === '' || size === '' || sn === '') {
                isValid = false;
                alert('Please fill in all fields for each hard disk.');
            }
        });

        return isValid;
    }
    </script>
</body>
</html>

