<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if item_type_nas_ab_o365_id is passed via URL
if (!isset($_GET['item_type_nas_ab_o365_id'])) {
    echo "<p>No NAS ID provided.</p>";
    exit;
}

$itemTypeNasAbO365Id = $_GET['item_type_nas_ab_o365_id'];

// Fetch the NAS details based on item_type_nas_ab_o365_id
$stmt = $pdo->prepare('SELECT * FROM item_type_nas_ab_o365 WHERE item_type_nas_ab_o365_id = :item_type_nas_ab_o365_id LIMIT 1');
$stmt->execute([':item_type_nas_ab_o365_id' => $itemTypeNasAbO365Id]);
$nasDetails = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$nasDetails) {
    echo "<p>No NAS details found with the provided ID.</p>";
    exit;
}

// Fetch the company name based on debtor_code
$companyName = 'Unknown Company'; // Default fallback
if ($nasDetails['debtor_code']) {
    try {
        $stmt = $pdo->prepare("SELECT company_name FROM company_info WHERE debtor_code = :debtor_code LIMIT 1");
        $stmt->execute([':debtor_code' => $nasDetails['debtor_code']]);
        $company = $stmt->fetch(PDO::FETCH_ASSOC);
        if ($company) {
            $companyName = $company['company_name'];
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $active = isset($_POST['active']) ? 1 : 0;
    $abO365ServiceName = htmlspecialchars($_POST['ab_o365_service_name']);
    $abO365ServiceToFolder = htmlspecialchars($_POST['ab_o365_service_to_folder']);
    $abO365ServiceSchedule = htmlspecialchars($_POST['ab_o365_service_schedule']);
    $abO365ServiceTime = htmlspecialchars($_POST['ab_o365_service_time']);
    $abO365PreviousVersionDays = htmlspecialchars($_POST['ab_o365_previous_version_days']);
    $abO365Acc = htmlspecialchars($_POST['ab_o365_acc']);
    $abO365TenantId = htmlspecialchars($_POST['ab_o365_tenant_id']);
    $abO365AppId = htmlspecialchars($_POST['ab_o365_app_id']);
    $abO365DomainAdminEmailAddress = htmlspecialchars($_POST['ab_o365_domain_admin_email_address']);

    // Handle image upload
    $abO365Picture = $nasDetails['ab_o365_picture']; // Default to the current picture
    if (isset($_FILES['ab_o365_picture']) && $_FILES['ab_o365_picture']['error'] == 0) {
        $uploadDir = '/crm/images/NAS/Active Backup for Office 365/';
        $absoluteUploadDir = $_SERVER['DOCUMENT_ROOT'] . $uploadDir;

        // Ensure the directory exists
        if (!is_dir($absoluteUploadDir)) {
            if (!mkdir($absoluteUploadDir, 0777, true)) {
                echo "<script>alert('Failed to create directory. Please check permissions.');</script>";
                exit;
            }
        }

        $uploadFile = $absoluteUploadDir . basename($_FILES['ab_o365_picture']['name']);
        $imageFileType = strtolower(pathinfo($uploadFile, PATHINFO_EXTENSION));

        // Check if the file is an image
        $check = getimagesize($_FILES['ab_o365_picture']['tmp_name']);
        if ($check === false) {
            echo "<script>alert('File is not an image.');</script>";
            exit;
        }

        // Check file size (e.g., limit to 5MB)
        if ($_FILES['ab_o365_picture']['size'] > 5000000) {
            echo "<script>alert('File size exceeds the limit of 5MB.');</script>";
            exit;
        }

        // Allow certain file formats
        if ($imageFileType != "jpg" && $imageFileType != "png" && $imageFileType != "jpeg" && $imageFileType != "gif") {
            echo "<script>alert('Only JPG, JPEG, PNG & GIF files are allowed.');</script>";
            exit;
        }

        // Generate a garbled name for the image
        $garbledName = substr(md5(uniqid(rand(), true)), 0, 20) . '.' . $imageFileType;
        $uploadFile = $absoluteUploadDir . $garbledName;

        // Move the uploaded file to the desired directory
        if (move_uploaded_file($_FILES['ab_o365_picture']['tmp_name'], $uploadFile)) {
            // Delete the old picture if it exists
            if (!empty($nasDetails['ab_o365_picture'])) {
                $oldPicturePath = $_SERVER['DOCUMENT_ROOT'] . $nasDetails['ab_o365_picture'];
                if (file_exists($oldPicturePath)) {
                    unlink($oldPicturePath);
                }
            }
            $abO365Picture = $uploadDir . $garbledName; // Save the relative path in the database
        } else {
            echo "<script>alert('Failed to upload image. Please try again.');</script>";
        }
    }

    // Handle certificate file upload
    $abO365CertificateFile = $nasDetails['ab_o365_certificate_file']; // Default to the current certificate file
    if (isset($_FILES['ab_o365_certificate_file']) && $_FILES['ab_o365_certificate_file']['error'] == 0) {
        $uploadDir = '/crm/images/NAS/Active Backup for Office 365/';
        $absoluteUploadDir = $_SERVER['DOCUMENT_ROOT'] . $uploadDir;

        // Ensure the directory exists
        if (!is_dir($absoluteUploadDir)) {
            if (!mkdir($absoluteUploadDir, 0777, true)) {
                echo "<script>alert('Failed to create directory. Please check permissions.');</script>";
                exit;
            }
        }

        $uploadFile = $absoluteUploadDir . basename($_FILES['ab_o365_certificate_file']['name']);
        $fileType = strtolower(pathinfo($uploadFile, PATHINFO_EXTENSION));

        // Generate a garbled name for the file
        $garbledName = substr(md5(uniqid(rand(), true)), 0, 20) . '.' . $fileType;
        $uploadFile = $absoluteUploadDir . $garbledName;

        // Move the uploaded file to the desired directory
        if (move_uploaded_file($_FILES['ab_o365_certificate_file']['tmp_name'], $uploadFile)) {
            // Delete the old certificate file if it exists
            if (!empty($nasDetails['ab_o365_certificate_file'])) {
                $oldCertificatePath = $_SERVER['DOCUMENT_ROOT'] . $nasDetails['ab_o365_certificate_file'];
                if (file_exists($oldCertificatePath)) {
                    unlink($oldCertificatePath);
                }
            }
            $abO365CertificateFile = $uploadDir . $garbledName; // Save the relative path in the database
        } else {
            echo "<script>alert('Failed to upload certificate file. Please try again.');</script>";
        }
    }

    // Store the old data for comparison
    $oldData = $nasDetails;

    // Check if any data has changed
    $dataChanged = false;
    if ($active != $oldData['active'] ||
        $abO365ServiceName != $oldData['ab_o365_service_name'] ||
        $abO365ServiceToFolder != $oldData['ab_o365_service_to_folder'] ||
        $abO365ServiceSchedule != $oldData['ab_o365_service_schedule'] ||
        $abO365ServiceTime != $oldData['ab_o365_service_time'] ||
        $abO365PreviousVersionDays != $oldData['ab_o365_previous_version_days'] ||
        $abO365Acc != $oldData['ab_o365_acc'] ||
        $abO365TenantId != $oldData['ab_o365_tenant_id'] ||
        $abO365AppId != $oldData['ab_o365_app_id'] ||
        $abO365DomainAdminEmailAddress != $oldData['ab_o365_domain_admin_email_address'] ||
        $abO365Picture != $oldData['ab_o365_picture'] ||
        $abO365CertificateFile != $oldData['ab_o365_certificate_file']) {
        $dataChanged = true;
    }

    if (!$dataChanged) {
        // If no data changed, show alert and redirect back to view_nas_table.php
        echo '<script type="text/javascript">';
        echo 'alert("No data changed.");';
        echo 'window.location.href="view_nas_table.php?debtor_code=' . urlencode($nasDetails['debtor_code']) . '&company_name=' . urlencode($nasDetails['company_name']) . '";';
        echo '</script>';
    } else {
        // Update the NAS details in the database
        $stmt = $pdo->prepare('UPDATE item_type_nas_ab_o365 SET 
            active = :active,
            ab_o365_service_name = :ab_o365_service_name,
            ab_o365_service_to_folder = :ab_o365_service_to_folder,
            ab_o365_service_schedule = :ab_o365_service_schedule,
            ab_o365_service_time = :ab_o365_service_time,
            ab_o365_previous_version_days = :ab_o365_previous_version_days,
            ab_o365_acc = :ab_o365_acc,
            ab_o365_tenant_id = :ab_o365_tenant_id,
            ab_o365_app_id = :ab_o365_app_id,
            ab_o365_domain_admin_email_address = :ab_o365_domain_admin_email_address,
            ab_o365_picture = :ab_o365_picture,
            ab_o365_certificate_file = :ab_o365_certificate_file,
            updated_time = NOW()
            WHERE item_type_nas_ab_o365_id = :item_type_nas_ab_o365_id');

        $success = $stmt->execute([
            ':active' => $active,
            ':ab_o365_service_name' => $abO365ServiceName,
            ':ab_o365_service_to_folder' => $abO365ServiceToFolder,
            ':ab_o365_service_schedule' => $abO365ServiceSchedule,
            ':ab_o365_service_time' => $abO365ServiceTime,
            ':ab_o365_previous_version_days' => $abO365PreviousVersionDays,
            ':ab_o365_acc' => $abO365Acc,
            ':ab_o365_tenant_id' => $abO365TenantId,
            ':ab_o365_app_id' => $abO365AppId,
            ':ab_o365_domain_admin_email_address' => $abO365DomainAdminEmailAddress,
            ':ab_o365_picture' => $abO365Picture,
            ':ab_o365_certificate_file' => $abO365CertificateFile,
            ':item_type_nas_ab_o365_id' => $itemTypeNasAbO365Id
        ]);

        if ($success) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_nas_ab_o365 WHERE item_type_nas_ab_o365_id = :item_type_nas_ab_o365_id LIMIT 1');
            $stmt->execute([':item_type_nas_ab_o365_id' => $itemTypeNasAbO365Id]);
            $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in Active Backup for Office 365 (Company Name: " . $companyName . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="view_nas_table.php?debtor_code=' . urlencode($nasDetails['debtor_code']) . '&company_name=' . urlencode($nasDetails['company_name']) . '";';
            echo '</script>';
        } else {
            // If update failed, show error message
            echo '<script type="text/javascript">';
            echo 'alert("Failed to update. Please try again.");';
            echo '</script>';
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit NAS Active Backup for Office 365 Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit NAS Active Backup for Office 365 Details</h1>
        </div>
        <div class="card-body">
            <form method="POST" enctype="multipart/form-data">
                <input type="hidden" name="item_type_nas_id" value="<?= htmlspecialchars($itemTypeNasId) ?>">
                
                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $nasDetails['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Active Backup for Office 365</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_service_name" id="ab_o365_service_name" placeholder="Active Backup for Office 365 Service Name" value="<?= htmlspecialchars($nasDetails['ab_o365_service_name'] ?? '') ?>">
                                    <label for="ab_o365_service_name">Active Backup for Office 365 Service Name</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_domain_admin_email_address" id="ab_o365_domain_admin_email_address" placeholder="Domain Admin Email Address" value="<?= htmlspecialchars($nasDetails['ab_o365_domain_admin_email_address'] ?? '') ?>">
                                    <label for="ab_o365_domain_admin_email_address">Domain Admin Email Address</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_service_to_folder" id="ab_o365_service_to_folder" placeholder="Active Backup for Office 365 Service To Folder" value="<?= htmlspecialchars($nasDetails['ab_o365_service_to_folder'] ?? '') ?>">
                                    <label for="ab_o365_service_to_folder">Active Backup for Office 365 Service To Folder</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_service_schedule" id="ab_o365_service_schedule" placeholder="Active Backup for Office 365 Service Schedule" value="<?= htmlspecialchars($nasDetails['ab_o365_service_schedule'] ?? '') ?>">
                                    <label for="ab_o365_service_schedule">Active Backup for Office 365 Service Schedule</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="time" class="form-control" name="ab_o365_service_time" id="ab_o365_service_time" placeholder="Active Backup for Office 365 Service Time" value="<?= htmlspecialchars($nasDetails['ab_o365_service_time'] ?? '') ?>">
                                    <label for="ab_o365_service_time">Active Backup for Office 365 Service Time</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_previous_version_days" id="ab_o365_previous_version_days" placeholder="Active Backup for Office 365 Keep Previous Version of Days" value="<?= htmlspecialchars($nasDetails['ab_o365_previous_version_days'] ?? '') ?>">
                                    <label for="ab_o365_previous_version_days">Active Backup for Office 365 Keep Previous Version of Days</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_acc" id="ab_o365_acc" placeholder="Active Backup for Office 365 Account" value="<?= htmlspecialchars($nasDetails['ab_o365_acc'] ?? '') ?>">
                                    <label for="ab_o365_acc">Active Backup for Office 365 Account</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_tenant_id" id="ab_o365_tenant_id" placeholder="Active Backup for Office 365 Tenant ID" value="<?= htmlspecialchars($nasDetails['ab_o365_tenant_id'] ?? '') ?>">
                                    <label for="ab_o365_tenant_id">Active Backup for Office 365 Tenant ID</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" name="ab_o365_app_id" id="ab_o365_app_id" placeholder="Active Backup for Office 365 Application ID" value="<?= htmlspecialchars($nasDetails['ab_o365_app_id'] ?? '') ?>">
                                    <label for="ab_o365_app_id">Active Backup for Office 365 Application ID</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Certificate File for Office 365 Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Certificate File for Office 365</h5>
                    </div>
                    <div class="card-body">
                        <div class="mb-3">
                            <label for="ab_o365_certificate_file" class="form-label">Upload Certificate File for Office 365</label>
                            <input type="file" class="form-control" name="ab_o365_certificate_file" id="ab_o365_certificate_file">
                        </div>

                        <!-- Display the current certificate file -->
                        <?php if (!empty($nasDetails['ab_o365_certificate_file'])): ?>
                            <div class="form-group">
                                <label>Current Certificate File</label>
                                <div class="d-flex align-items-center">
                                    <p class="ml-3"><?= htmlspecialchars(basename($nasDetails['ab_o365_certificate_file'])) ?></p>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>

                <!-- Picture Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Picture</h5>
                    </div>
                    <div class="card-body">
                        <div class="mb-3">
                            <label for="ab_o365_picture" class="form-label">Upload Picture</label>
                            <input type="file" class="form-control" name="ab_o365_picture" id="ab_o365_picture">
                        </div>

                        <!-- Display the current picture and picture name -->
                        <?php if (!empty($nasDetails['ab_o365_picture'])): ?>
                            <div class="form-group">
                                <label>Current Picture</label>
                                <div class="d-flex align-items-center">
                                    <img src="<?= htmlspecialchars($nasDetails['ab_o365_picture']) ?>" alt="Current Picture" style="max-width: 100px; max-height: 100px;" data-bs-toggle="modal" data-bs-target="#pictureModal">
                                    <p class="ml-3"><?= htmlspecialchars(basename($nasDetails['ab_o365_picture'])) ?></p>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Modal for displaying the picture larger -->
<div class="modal fade" id="pictureModal" tabindex="-1" role="dialog" aria-labelledby="pictureModalLabel" aria-hidden="true">
    <div class="modal-dialog modal-lg" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="pictureModalLabel">Current Picture</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body text-center">
                <img src="<?= htmlspecialchars($nasDetails['ab_o365_picture']) ?>" alt="Current Picture" style="max-width: 100%; max-height: 100%;">
            </div>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
</body>
</html>

