<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if debtor_code and item_type_nw_ap_id are passed via URL
if (isset($_GET['debtor_code']) && isset($_GET['item_type_nw_ap_id'])) {
    $debtorCode = $_GET['debtor_code'];
    $itemTypeId = $_GET['item_type_nw_ap_id'];

    // Fetch the item details based on debtor_code and item_type_nw_ap_id
    $stmt = $pdo->prepare('SELECT * FROM item_type_nw_ap WHERE debtor_code = :debtor_code AND item_type_nw_ap_id = :item_type_nw_ap_id LIMIT 1');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_type_nw_ap_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$item) {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }

    // Decrypt the password and SSID key for logging purposes
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $item['password'] = decryptPassword($item['password'], $encryptionKey);
    $item['ssid_key'] = decryptPassword($item['ssid_key'], $encryptionKey);
} else {
    echo "<p>No debtor code or item ID provided.</p>";
    exit;
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $active = isset($_POST['active']) ? 1 : 0;
    $login = htmlspecialchars(trim($_POST['login']));
    $password = htmlspecialchars(trim($_POST['password']));
    $brand = htmlspecialchars(trim($_POST['brand']));
    $model = htmlspecialchars(trim($_POST['model']));
    $ssid = isset($_POST['ssid']) ? $_POST['ssid'] : [];
    $ssid_key = isset($_POST['ssid_key']) ? $_POST['ssid_key'] : [];
    $tcp_ip = htmlspecialchars(trim($_POST['tcp_ip']));
    $serial_number = htmlspecialchars(trim($_POST['serial_number']));
    $purchase_date = htmlspecialchars(trim($_POST['purchase_date']));
    $warranty_expire_date = htmlspecialchars(trim($_POST['warranty_expire_date']));
    $others = htmlspecialchars(trim($_POST['others']));

    // Combine SSID and SSID Key into a single string
    $ssidCombined = implode(',', $ssid);
    $ssidKeyCombined = implode(',', $ssid_key);

    // Encrypt the password and SSID key for database storage
    $encryptedPassword = encryptPassword($password, $encryptionKey);
    $encryptedSsidKey = encryptPassword($ssidKeyCombined, $encryptionKey);

    // Store the old data in plaintext
    $oldData = $item;

    try {
        // Prepare the UPDATE query with updated_time
        $stmt = $pdo->prepare('
            UPDATE item_type_nw_ap 
            SET 
                active = :active, 
                login = :login, 
                password = :password, 
                brand = :brand,
                model = :model, 
                ssid = :ssid, 
                ssid_key = :ssid_key, 
                tcp_ip = :tcp_ip, 
                serial_number = :serial_number, 
                purchase_date = :purchase_date, 
                warranty_expire_date = :warranty_expire_date, 
                others = :others, 
                updated_time = NOW()
            WHERE 
                debtor_code = :debtor_code AND item_type_nw_ap_id = :item_type_nw_ap_id
        ');

        // Bind parameters
        $stmt->bindParam(':active', $active);
        $stmt->bindParam(':login', $login);
        $stmt->bindParam(':password', $encryptedPassword);
        $stmt->bindParam(':brand', $brand);
        $stmt->bindParam(':model', $model);
        $stmt->bindParam(':ssid', $ssidCombined);
        $stmt->bindParam(':ssid_key', $encryptedSsidKey);
        $stmt->bindParam(':tcp_ip', $tcp_ip);
        $stmt->bindParam(':serial_number', $serial_number);
        $stmt->bindParam(':purchase_date', $purchase_date);
        $stmt->bindParam(':warranty_expire_date', $warrantyExpireDate);
        $stmt->bindParam(':others', $others);
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->bindParam(':item_type_nw_ap_id', $itemTypeId);

        // Execute the update
        if ($stmt->execute()) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_nw_ap WHERE debtor_code = :debtor_code AND item_type_nw_ap_id = :item_type_nw_ap_id LIMIT 1');
            $stmt->bindParam(':debtor_code', $debtorCode);
            $stmt->bindParam(':item_type_nw_ap_id', $itemTypeId);
            $stmt->execute();
            $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

            // Decrypt the password and SSID key for logging purposes
            $newItem['password'] = decryptPassword($newItem['password'], $encryptionKey);
            $newItem['ssid_key'] = decryptPassword($newItem['ssid_key'], $encryptionKey);

            // Check if any data has changed
            $dataChanged = false;
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                    $dataChanged = true;
                    break;
                }
            }

            if ($dataChanged) {
                // Build the log message with only the fields that have changed, excluding 'updated_time'
                $logMessage = "Data change in item_type_nw_ap (Debtor Code: " . $debtorCode . "):\n";
                foreach ($oldData as $key => $value) {
                    if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                        $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                    }
                }

                // Insert the log into activity_logs
                $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                           VALUES (:username, :timestamp, :role, :activity)";
                $stmtLog = $pdo->prepare($sqlLog);
                $stmtLog->execute([
                    ':username' => $_SESSION['username'],
                    ':timestamp' => date('Y-m-d H:i:s'),
                    ':role' => $_SESSION['role'],
                    ':activity' => $logMessage
                ]);

                // If update was successful, show success message and redirect
                echo '<script type="text/javascript">';
                echo 'alert("Update successful!");';
                echo 'window.location.href="view_network_table.php?debtor_code=' . urlencode($debtorCode) . '";';
                echo '</script>';
            } else {
                // If no data changed, show no change message
                echo '<script type="text/javascript">';
                echo 'alert("No data changed.");';
                echo 'window.location.href="view_network_table.php?debtor_code=' . urlencode($debtorCode) . '";';
                echo '</script>';
            }
        } else {
            // If update failed, show error message
            throw new Exception("Failed to update the record.");
        }
    } catch (PDOException $e) {
        // Log the exception and show a generic error message
        error_log('Database update error: ' . $e->getMessage());
        echo '<script type="text/javascript">';
        echo 'alert("An error occurred. Please try again later.");';
        echo '</script>';
    } catch (Exception $e) {
        // Log the exception and show a generic error message
        error_log('Update failed: ' . $e->getMessage());
        echo '<script type="text/javascript">';
        echo 'alert("An error occurred. Please try again later.");';
        echo '</script>';
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Access Point</title>
    <!-- Bootstrap CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .form-control-custom {
            max-width: 100%; /* Adjust as needed */
        }
    </style>
</head>
<body>
    <div class="container mt-4">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Edit Access Point</h1>
            </div>
            <div class="card-body">
                <form method="POST">
                    <!-- Hidden Fields -->
                    <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                    <input type="hidden" name="item_type_nw_id" value="<?= htmlspecialchars($itemTypeId) ?>">

                    <!-- Active Status -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Active Status</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $item['active'] ? 'checked' : '' ?>>
                                <label class="form-check-label" for="active">Active</label>
                            </div>
                        </div>
                    </div>

                    <!-- Hardware Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Hardware Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control form-control-custom" name="model" id="model" placeholder="Model" value="<?= htmlspecialchars($item['model'] ?? '') ?>">
                                        <label for="model">Model</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control form-control-custom" name="brand" id="brand" placeholder="Brand" value="<?= htmlspecialchars($item['brand'] ?? '') ?>">
                                        <label for="brand">Brand</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control form-control-custom" name="serial_number" id="serial_number" placeholder="Serial Number" value="<?= htmlspecialchars($item['serial_number'] ?? '') ?>">
                                        <label for="serial_number">Serial Number</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Login Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control form-control-custom" name="login" id="login" placeholder="Login" value="<?= htmlspecialchars($item['login'] ?? '') ?>">
                                        <label for="login">Login</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control form-control-custom" name="password" id="password" placeholder="Password" value="<?= htmlspecialchars($item['password'] ?? '') ?>">
                                        <label for="password">Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Network Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Network Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control form-control-custom" name="tcp_ip" id="tcp_ip" placeholder="TCP/IP" value="<?= htmlspecialchars($item['tcp_ip'] ?? '') ?>">
                                        <label for="tcp_ip">TCP/IP</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="mb-3">
                                        <div id="ssid-container">
                                            <?php
                                            $ssids = explode(',', $item['ssid']);
                                            $ssidKeys = explode(',', $item['ssid_key']);
                                            foreach ($ssids as $index => $ssid) {
                                                $ssidKey = isset($ssidKeys[$index]) ? $ssidKeys[$index] : '';
                                                echo '<div class="input-group mb-2">
                                                        <div class="form-floating me-2">
                                                            <input type="text" class="form-control form-control-custom" name="ssid[]" id="ssid' . $index . '" placeholder="SSID" value="' . htmlspecialchars($ssid) . '">
                                                            <label for="ssid' . $index . '">SSID</label>
                                                        </div>
                                                        <div class="form-floating me-2">
                                                            <input type="text" class="form-control form-control-custom" name="ssid_key[]" id="ssid_key' . $index . '" placeholder="SSID Key" value="' . htmlspecialchars($ssidKey) . '">
                                                            <label for="ssid_key' . $index . '">SSID Key</label>
                                                        </div>
                                                        <button type="button" class="btn btn-danger" onclick="removeSSIDField(this)">Remove</button>
                                                      </div>';
                                            }
                                            ?>
                                        </div>
                                        <div class="mb-3">
                                            <button type="button" class="btn btn-secondary" onclick="addSSIDField()">Add</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Warranty Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Warranty Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control form-control-custom" name="purchase_date" id="purchase_date" placeholder="Purchase Date" value="<?= htmlspecialchars($item['purchase_date'] ?? '') ?>">
                                        <label for="purchase_date">Purchase Date</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control form-control-custom" name="warranty_expire_date" id="warranty_expire_date" placeholder="Warranty Expire Date" value="<?= htmlspecialchars($item['warranty_expire_date'] ?? '') ?>">
                                        <label for="warranty_expire_date">Warranty Expire Date</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Others Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Others Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="form-floating mb-3">
                                        <textarea class="form-control form-control-custom" id="others" name="others" placeholder="Others"><?= htmlspecialchars($item['others'] ?? '') ?></textarea>
                                        <label for="others">Others</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Save Button -->
                    <div class="text-center">
                        <button type="submit" class="btn btn-primary">Save</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        let ssidCounter = <?= count($ssids) ?>; // Counter for unique IDs

        function addSSIDField() {
            ssidCounter++; // Increment the counter for unique IDs
            const container = document.getElementById('ssid-container');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <div class="form-floating me-2">
                    <input type="text" class="form-control form-control-custom" name="ssid[]" id="ssid${ssidCounter}" placeholder="SSID">
                    <label for="ssid${ssidCounter}">SSID</label>
                </div>
                <div class="form-floating me-2">
                    <input type="text" class="form-control form-control-custom" name="ssid_key[]" id="ssid_key${ssidCounter}" placeholder="SSID Key">
                    <label for="ssid_key${ssidCounter}">SSID Key</label>
                </div>
                <button type="button" class="btn btn-danger" onclick="removeSSIDField(this)">Remove</button>
            `;
            container.appendChild(newField);
        }

        function removeSSIDField(button) {
            const container = document.getElementById('ssid-container');
            if (container.childElementCount > 1) {
                button.parentElement.remove();
            } else {
                alert("You must have at least one SSID and SSID key.");
            }
        }
    </script>
</body>
</html>