<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if debtor_code and item_type_nw_fw_id are passed via URL
if (isset($_GET['debtor_code']) && isset($_GET['item_type_nw_fw_id'])) {
    $debtorCode = $_GET['debtor_code'];
    $itemTypeId = $_GET['item_type_nw_fw_id'];

    // Fetch the item details based on debtor_code and item_type_nw_fw_id
    $stmt = $pdo->prepare('SELECT * FROM item_type_nw_fw WHERE debtor_code = :debtor_code AND item_type_nw_fw_id = :item_type_nw_fw_id LIMIT 1');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_type_nw_fw_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$item) {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }

    // Decrypt the password
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $item['password'] = decryptPassword($item['password'], $encryptionKey);
    $item['forticare_password'] = decryptPassword($item['forticare_password'], $encryptionKey);

    // Convert comma-separated strings to arrays
    $item['allow_list'] = explode(',', $item['allow_list']);
    $item['full_access_group'] = explode(',', $item['full_access_group']);
    $item['block_access_group'] = explode(',', $item['block_access_group']);
    $item['limited_access_group'] = explode(',', $item['limited_access_group']);
    $item['guest_group'] = explode(',', $item['guest_group']);
    $item['block_list'] = explode(',', $item['block_list']);
    $item['open_port'] = explode(',', $item['open_port']);
    $item['open_port_for'] = explode(',', $item['open_port_for']);
} else {
    echo "<p>No debtor code or item ID provided.</p>";
    exit;
}

// Fetch unique emails and decrypt passwords
$uniqueEmails = [];
if ($debtorCode) {
    try {
        // Fetch emails from item_type_email_citssb where used_at is 'Fortinet'
        $stmt = $pdo->prepare("
            SELECT email, password 
            FROM item_type_email_citssb 
            WHERE debtor_code = ? 
              AND used_at = 'Fortinet'
        ");
        $stmt->execute([$debtorCode]);
        $emails = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Decrypt passwords and store unique emails
        foreach ($emails as $emailData) {
            $email = $emailData['email'];
            $password = decryptPassword($emailData['password'], $encryptionKey); // Decrypt the password
            $uniqueEmails[$email] = $password; // Associative array to handle duplicates
        }
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $active = isset($_POST['active']) ? 1 : 0;
    $login = htmlspecialchars($_POST['login']);
    $password = htmlspecialchars($_POST['password']);
    $model = htmlspecialchars($_POST['model']);
    $brand = htmlspecialchars($_POST['brand']);
    $tcp_ip = htmlspecialchars($_POST['tcp_ip']);
    $serial_number = htmlspecialchars($_POST['serial_number']);
    $allow_list = isset($_POST['allow_list']) ? implode(',', $_POST['allow_list']) : '';
    $full_access_group = isset($_POST['full_access_group']) ? implode(',', $_POST['full_access_group']) : '';
    $block_access_group = isset($_POST['block_access_group']) ? implode(',', $_POST['block_access_group']) : '';
    $limited_access_group = isset($_POST['limited_access_group']) ? implode(',', $_POST['limited_access_group']) : '';
    $guest_group = isset($_POST['guest_group']) ? implode(',', $_POST['guest_group']) : '';
    $block_list = isset($_POST['block_list']) ? implode(',', $_POST['block_list']) : '';
    $external_access_url = htmlspecialchars($_POST['external_access_url']);
    $ddns = htmlspecialchars($_POST['ddns']);
    $fix_tcp_ip = htmlspecialchars($_POST['fix_tcp_ip']);
    $network_group = htmlspecialchars($_POST['network_group']);
    $open_port = isset($_POST['open_port']) ? implode(',', $_POST['open_port']) : '';
    $open_port_for = isset($_POST['open_port_for']) ? implode(',', $_POST['open_port_for']) : '';
    $forticare_id = htmlspecialchars($_POST['forticare_id']);
    $forticare_password = htmlspecialchars($_POST['forticare_password']);
    $forticare_url = htmlspecialchars($_POST['forticare_url']);
    $hardware_id = htmlspecialchars($_POST['hardware_id']);
    $forticlient_port = htmlspecialchars($_POST['forticlient_port']);
    $purchase_date = htmlspecialchars($_POST['purchase_date']);
    $warranty_expire_date = htmlspecialchars($_POST['warranty_expire_date']);
    $others = htmlspecialchars($_POST['others']);
    $fortinet_email = htmlspecialchars($_POST['fortinet_email']); // Add Fortinet Email

    $encryptedPassword = encryptPassword($password, $encryptionKey);
    $encryptedForticarePassword = encryptPassword($forticare_password, $encryptionKey);

    // Store the old data in plaintext
    $oldData = $item;

    // Convert arrays back to comma-separated strings for comparison
    $oldData['allow_list'] = implode(',', $oldData['allow_list']);
    $oldData['full_access_group'] = implode(',', $oldData['full_access_group']);
    $oldData['block_access_group'] = implode(',', $oldData['block_access_group']);
    $oldData['limited_access_group'] = implode(',', $oldData['limited_access_group']);
    $oldData['guest_group'] = implode(',', $oldData['guest_group']);
    $oldData['block_list'] = implode(',', $oldData['block_list']);
    $oldData['open_port'] = implode(',', $oldData['open_port']);
    $oldData['open_port_for'] = implode(',', $oldData['open_port_for']);

    // Update the item in the database
    $stmt = $pdo->prepare('UPDATE item_type_nw_fw SET active = :active, login = :login, password = :password, model = :model, brand = :brand, tcp_ip = :tcp_ip, serial_number = :serial_number, allow_list = :allow_list, full_access_group = :full_access_group, block_access_group = :block_access_group, limited_access_group = :limited_access_group, guest_group = :guest_group, block_list = :block_list, external_access_url = :external_access_url, ddns = :ddns, fix_tcp_ip = :fix_tcp_ip, network_group = :network_group, open_port = :open_port, open_port_for = :open_port_for, forticare_id = :forticare_id, forticare_password = :forticare_password, hardware_id = :hardware_id, forticlient_port = :forticlient_port, forticare_url = :forticare_url, purchase_date = :purchase_date, warranty_expire_date = :warranty_expire_date, updated_time = NOW(), others = :others, fortinet_email = :fortinet_email WHERE debtor_code = :debtor_code AND item_type_nw_fw_id = :item_type_nw_fw_id');
    $stmt->bindParam(':active', $active);
    $stmt->bindParam(':login', $login);
    $stmt->bindParam(':password', $encryptedPassword);
    $stmt->bindParam(':model', $model);
    $stmt->bindParam(':brand', $brand);
    $stmt->bindParam(':tcp_ip', $tcp_ip);
    $stmt->bindParam(':serial_number', $serial_number);
    $stmt->bindParam(':allow_list', $allow_list);
    $stmt->bindParam(':full_access_group', $full_access_group);
    $stmt->bindParam(':block_access_group', $block_access_group);
    $stmt->bindParam(':limited_access_group', $limited_access_group);
    $stmt->bindParam(':guest_group', $guest_group);
    $stmt->bindParam(':block_list', $block_list);
    $stmt->bindParam(':external_access_url', $external_access_url);
    $stmt->bindParam(':ddns', $ddns);
    $stmt->bindParam(':fix_tcp_ip', $fix_tcp_ip);
    $stmt->bindParam(':network_group', $network_group);
    $stmt->bindParam(':open_port', $open_port);
    $stmt->bindParam(':open_port_for', $open_port_for);
    $stmt->bindParam(':forticare_id', $forticare_id);
    $stmt->bindParam(':forticare_url', $forticare_url);
    $stmt->bindParam(':forticare_password', $encryptedForticarePassword);
    $stmt->bindParam(':hardware_id', $hardware_id);
    $stmt->bindParam(':forticlient_port', $forticlient_port);
    $stmt->bindParam(':purchase_date', $purchase_date);
    $stmt->bindParam(':warranty_expire_date', $warranty_expire_date);
    $stmt->bindParam(':others', $others);
    $stmt->bindParam(':fortinet_email', $fortinet_email); // Bind Fortinet Email
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_type_nw_fw_id', $itemTypeId);

    if ($stmt->execute()) {
        // Fetch the new data after the update
        $stmt = $pdo->prepare('SELECT * FROM item_type_nw_fw WHERE debtor_code = :debtor_code AND item_type_nw_fw_id = :item_type_nw_fw_id LIMIT 1');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->bindParam(':item_type_nw_fw_id', $itemTypeId);
        $stmt->execute();
        $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

        // Decrypt the password for logging purposes
        $newItem['password'] = decryptPassword($newItem['password'], $encryptionKey);
        $newItem['forticare_password'] = decryptPassword($newItem['forticare_password'], $encryptionKey);

        // Check if any data has changed
        $dataChanged = false;
        foreach ($oldData as $key => $value) {
            if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                $dataChanged = true;
                break;
            }
        }

        if ($dataChanged) {
            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in firewall (Debtor Code: " . $debtorCode . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // Check if the log entry was inserted successfully
            if ($stmtLog->rowCount() > 0) {
                // If update was successful, show success message and redirect
                echo '<script type="text/javascript">';
                echo 'alert("Update successful!");';
                echo 'window.location.href="/crm/public/company/view_network_table.php?debtor_code=' . urlencode($debtorCode) . '";';
                echo '</script>';
            } else {
                echo '<script type="text/javascript">';
                echo 'alert("Failed to insert log entry.");';
                echo '</script>';
            }
        } else {
            // If no data changed, show no change message
            echo '<script type="text/javascript">';
            echo 'alert("No data changed.");';
            echo 'window.location.href="/crm/public/company/view_network_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        }
    } else {
        // If update failed, show error message
        echo '<script type="text/javascript">';
        echo 'alert("Failed to update. Please try again.");';
        echo '</script>';
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Firewall Details</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .form-control-custom {
            max-width: 100%; /* Adjust as needed */
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Edit Firewall Details</h1>
            </div>
            <div class="card-body">
                <form method="POST" action="">
                    <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                    <input type="hidden" name="item_type_nw_id" value="<?= htmlspecialchars($itemTypeId) ?>">

                    <!-- Active Status -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Active Status</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $item['active'] ? 'checked' : '' ?>>
                                <label class="form-check-label" for="active">Active</label>
                            </div>
                        </div>
                    </div>

                    <!-- Hardware Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Hardware Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="brand" id="brand" placeholder="Brand" value="<?= htmlspecialchars($item['brand'] ?? '') ?>">
                                        <label for="brand">Brand</label>
                                    </div>    
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="serial_number" id="serial_number" placeholder="Serial Number" value="<?= htmlspecialchars($item['serial_number'] ?? '') ?>">
                                        <label for="serial_number">Serial Number</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="model" id="model" placeholder="Model" value="<?= htmlspecialchars($item['model'] ?? '') ?>">
                                        <label for="model">Model</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="hardware_id" id="hardware_id" placeholder="Hardware ID" value="<?= htmlspecialchars($item['hardware_id'] ?? '') ?>">
                                        <label for="hardware_id">Hardware ID</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Hardware Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Login Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="login" id="login" placeholder="Login" value="<?= htmlspecialchars($item['login'] ?? '') ?>">
                                        <label for="login">Login</label>
                                    </div> 
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="password" id="password" placeholder="Password" value="<?= htmlspecialchars($item['password'] ?? '') ?>">
                                        <label for="password">Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <!-- Network Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Network Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="tcp_ip" id="tcp_ip" placeholder="TCP/IP with Port Number" value="<?= htmlspecialchars($item['tcp_ip'] ?? '') ?>">
                                        <label for="tcp_ip">TCP/IP with Port Number</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="external_access_url" id="external_access_url" placeholder="External Access URL" value="<?= htmlspecialchars($item['external_access_url'] ?? '') ?>">
                                        <label for="external_access_url">External Acess URL</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="ddns" id="ddns" placeholder="DDNS" value="<?= htmlspecialchars($item['ddns'] ?? '') ?>">
                                        <label for="ddns">DDNS</label>
                                    </div>
                                </div>

                                <!-- Right Column -->
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="fix_tcp_ip" id="fix_tcp_ip" placeholder="Fix TCP/IP" value="<?= htmlspecialchars($item['fix_tcp_ip'] ?? '') ?>">
                                        <label for="fix_tcp_ip">Fix TCP/IP</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="forticlient_port" id="forticlient_port" placeholder="Forticlient Port" value="<?= htmlspecialchars($item['forticlient_port'] ?? '') ?>">
                                        <label for="forticlient_port">Forticlient Port</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="network_group" id="network_group" placeholder="Network Group" value="<?= htmlspecialchars($item['network_group'] ?? '') ?>">
                                        <label for="network_group">Network Group</label>
                                    </div>    
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Open Port and Description</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="mb-3" id="openPortContainer">
                                        <?php foreach ($item['open_port'] as $index => $open_port_item): ?>
                                            <div class="input-group mb-2">
                                                <input type="text" class="form-control open_port" name="open_port[]" placeholder="Open Port" value="<?= htmlspecialchars($open_port_item) ?>">
                                                <input type="text" class="form-control open_port_for" name="open_port_for[]" placeholder="Description" value="<?= htmlspecialchars($item['open_port_for'][$index] ?? '') ?>">
                                                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
                                            </div>
                                        <?php endforeach; ?>
                                        <div class="d-flex justify-content-between">
                                            <button type="button" class="btn btn-secondary" onclick="openPort()">Add</button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Allow List -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Allow List</h5>
                        </div>
                        <div class="card-body" id="allowListContainer">
                            <?php foreach ($item['allow_list'] as $allow_list_item): ?>
                                <div class="input-group mb-2">
                                    <input type="text" class="form-control allow_list" name="allow_list[]" value="<?= htmlspecialchars($allow_list_item) ?>">
                                    <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
                                </div>
                            <?php endforeach; ?>
                            <div class="d-flex justify-content-between">
                                <button type="button" class="btn btn-secondary" onclick="addAllowList()">Add</button>
                            </div>
                        </div>
                    </div>

                    <!-- Full Access Group -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Full Access Group</h5>
                        </div>
                        <div class="card-body" id="fullAccessGroupContainer">
                            <?php foreach ($item['full_access_group'] as $full_access_group_item): ?>
                                <div class="input-group mb-2">
                                    <input type="text" class="form-control full_access_group" name="full_access_group[]" value="<?= htmlspecialchars($full_access_group_item) ?>">
                                    <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
                                </div>
                            <?php endforeach; ?>
                            <div class="d-flex justify-content-between">
                                <button type="button" class="btn btn-secondary" onclick="fullAccessGroup()">Add</button>
                            </div>
                        </div>
                    </div>

                    <!-- Block Access Group -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Block Access Group</h5>
                        </div>
                        <div class="card-body" id="blockAccessGroupContainer">
                            <?php foreach ($item['block_access_group'] as $block_access_group_item): ?>
                                <div class="input-group mb-2">
                                    <input type="text" class="form-control block_access_group" name="block_access_group[]" value="<?= htmlspecialchars($block_access_group_item) ?>">
                                    <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
                                </div>
                            <?php endforeach; ?>
                            <div class="d-flex justify-content-between">
                                <button type="button" class="btn btn-secondary" onclick="blockAccessGroup()">Add</button>
                            </div>
                        </div>
                    </div>

                    <!-- Limited Access Group -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Limited Access Group</h5>
                        </div>
                        <div class="card-body" id="limitedAccessGroupContainer">
                            <?php foreach ($item['limited_access_group'] as $limited_access_group_item): ?>
                                <div class="input-group mb-2">
                                    <input type="text" class="form-control limited_access_group" name="limited_access_group[]" value="<?= htmlspecialchars($limited_access_group_item) ?>">
                                    <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
                                </div>
                            <?php endforeach; ?>
                            <div class="d-flex justify-content-between">
                                <button type="button" class="btn btn-secondary" onclick="limitedAccessGroup()">Add</button>
                            </div>
                        </div>
                    </div>

                    <!-- Guest Group -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Guest Group</h5>
                        </div>
                        <div class="card-body" id="guestGroupContainer">
                            <?php foreach ($item['guest_group'] as $guest_group_item): ?>
                                <div class="input-group mb-2">
                                    <input type="text" class="form-control guest_group" name="guest_group[]" value="<?= htmlspecialchars($guest_group_item) ?>">
                                    <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
                                </div>
                            <?php endforeach; ?>
                            <div class="d-flex justify-content-between">
                                <button type="button" class="btn btn-secondary" onclick="guestGroup()">Add</button>
                            </div>
                        </div>
                    </div>

                    <!-- Block List -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Block List</h5>
                        </div>
                        <div class="card-body" id="blockListContainer">
                            <?php foreach ($item['block_list'] as $block_list_item): ?>
                                <div class="input-group mb-2">
                                    <input type="text" class="form-control block_list" name="block_list[]" value="<?= htmlspecialchars($block_list_item) ?>">
                                    <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
                                </div>
                            <?php endforeach; ?>
                            <div class="d-flex justify-content-between">
                                <button type="button" class="btn btn-secondary" onclick="blockList()">Add</button>
                            </div>
                        </div>
                    </div>

                    <!-- Warranty Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Warranty Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" name="purchase_date" id="purchase_date" placeholder="Purchase Date" value="<?= htmlspecialchars($item['purchase_date'] ?? '') ?>">
                                        <label for="purchase_date">Purchase Date</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" name="warranty_expire_date" id="warranty_expire_date" placeholder="Warranty Expire Date" value="<?= htmlspecialchars($item['warranty_expire_date'] ?? '') ?>">
                                        <label for="warranty_expire_date">Warranty Expire Date</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Fortinet Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="forticare_id" id="forticare_id" placeholder="Forticare ID" value="<?= htmlspecialchars($item['forticare_id'] ?? '') ?>">
                                        <label for="forticare_id">Forticare ID</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="forticare_url" id="forticare_url" placeholder="Forticare URL" value="<?= htmlspecialchars($item['forticare_url'] ?? '') ?>">
                                        <label for="forticare_url">Forticare URL</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="forticare_password" id="forticare_password" placeholder="Forticare Password" value="<?= htmlspecialchars($item['forticare_password'] ?? '') ?>">
                                        <label for="forticare_password">Forticare Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Fortinet Email Fields</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <select class="form-control" id="fortinet_email" name="fortinet_email" onchange="fillFortinetCredentials(this.value)">
                                            <option value="">Select an Email</option>
                                            <?php foreach ($uniqueEmails as $email => $password): ?>
                                                <option value="<?= htmlspecialchars($email) ?>" <?= ($email === $item['fortinet_email']) ? 'selected' : '' ?>>
                                                    <?= htmlspecialchars($email) ?>
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                        <label for="fortinet_email">Select Email</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="fortinet_email_account" id="fortinet_email_account" placeholder="Fortinet Email Account" value="<?= htmlspecialchars($item['fortinet_email'] ?? '') ?>">
                                        <label for="fortinet_email_account">Fortinet Email Account</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="fortinet_email_password" id="fortinet_email_password" placeholder="Fortinet Email Password" value="<?= htmlspecialchars($item['fortinet_email_password'] ?? '') ?>">
                                        <label for="fortinet_email_password">Fortinet Email Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Others Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="form-floating mb-3">
                                        <textarea class="form-control form-control-custom" id="others" name="others" placeholder="Others" rows="3"><?= htmlspecialchars($item['others'] ?? '') ?></textarea>
                                        <label for="others">Others</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <!-- Save Button -->
                    <div class="text-center">
                        <button type="submit" class="btn btn-primary">Save</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap JS and dependencies -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Function to fill Fortinet credentials based on selected email
        function fillFortinetCredentials(fortinetEmail) {
            const emails = <?= json_encode($uniqueEmails) ?>;
            const fortinetEmailAccountField = document.getElementById('fortinet_email_account');
            const fortinetEmailPasswordField = document.getElementById('fortinet_email_password');

            const fortinetEmailData = emails[fortinetEmail];
            if (fortinetEmailData) {
                fortinetEmailAccountField.value = fortinetEmail;
                fortinetEmailPasswordField.value = fortinetEmailData; // Use the decrypted password
            } else {
                fortinetEmailAccountField.value = '';
                fortinetEmailPasswordField.value = '';
            }
        }

        // Pre-fill the Fortinet credentials when the page loads
        document.addEventListener('DOMContentLoaded', () => {
            const selectedEmail = document.getElementById('fortinet_email').value;
            fillFortinetCredentials(selectedEmail);
        });

        // Function to add a new Allow List field
        function addAllowList() {
            const container = document.getElementById('allowListContainer');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <input type="text" class="form-control allow_list" name="allow_list[]">
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            `;
            container.insertBefore(newField, container.lastElementChild);
        }

        // Function to add a new Full Access Group field
        function fullAccessGroup() {
            const container = document.getElementById('fullAccessGroupContainer');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <input type="text" class="form-control full_access_group" name="full_access_group[]">
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            `;
            container.insertBefore(newField, container.lastElementChild);
        }

        // Function to add a new Block Access Group field
        function blockAccessGroup() {
            const container = document.getElementById('blockAccessGroupContainer');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <input type="text" class="form-control block_access_group" name="block_access_group[]">
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            `;
            container.insertBefore(newField, container.lastElementChild);
        }

        // Function to add a new Limited Access Group field
        function limitedAccessGroup() {
            const container = document.getElementById('limitedAccessGroupContainer');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <input type="text" class="form-control limited_access_group" name="limited_access_group[]">
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            `;
            container.insertBefore(newField, container.lastElementChild);
        }

        // Function to add a new Guest Group field
        function guestGroup() {
            const container = document.getElementById('guestGroupContainer');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <input type="text" class="form-control guest_group" name="guest_group[]">
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            `;
            container.insertBefore(newField, container.lastElementChild);
        }

        // Function to add a new Block List field
        function blockList() {
            const container = document.getElementById('blockListContainer');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <input type="text" class="form-control block_list" name="block_list[]">
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            `;
            container.insertBefore(newField, container.lastElementChild);
        }

        // Function to add a new Open Port field
        function openPort() {
            const container = document.getElementById('openPortContainer');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <input type="text" class="form-control open_port" name="open_port[]">
                <input type="text" class="form-control open_port_for" name="open_port_for[]">
                <button type="button" class="btn btn-danger" onclick="removeField(this)">Remove</button>
            `;
            container.insertBefore(newField, container.lastElementChild);
        }

        // Function to remove a field while ensuring at least one field remains
        function removeField(button) {
            const container = button.parentElement.parentElement;
            const fields = container.querySelectorAll('.input-group');
            if (fields.length > 1) {
                button.parentElement.remove();
            } else {
                alert('You must have at least one field.');
            }
        }
    </script>
</body>
</html>

