<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if debtor_code and item_type_nw_isp_id are passed via URL
if (isset($_GET['debtor_code']) && isset($_GET['item_type_nw_isp_id'])) {
    $debtorCode = $_GET['debtor_code'];
    $itemTypeId = $_GET['item_type_nw_isp_id'];

    // Fetch the item details based on debtor_code and item_type_nw_isp_id
    $stmt = $pdo->prepare('SELECT * FROM item_type_nw_isp WHERE debtor_code = :debtor_code AND item_type_nw_isp_id = :item_type_nw_isp_id LIMIT 1');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_type_nw_isp_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$item) {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }

    // Decrypt the password
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $decryptedPassword = decryptPassword($item['password'], $encryptionKey);
    $item['password'] = $decryptedPassword; // Store the plaintext password for logging

    // Convert comma-separated telephone_no string to an array
    $item['telephone_no'] = !empty($item['telephone_no']) ? explode(',', $item['telephone_no']) : [];

    // Fetch the company name based on debtor_code
    $stmt = $pdo->prepare('SELECT company_name FROM company_info WHERE debtor_code = :debtor_code LIMIT 1');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->execute();
    $company = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($company) {
        $companyName = $company['company_name'];
    } else {
        $companyName = 'Unknown Company'; // Fallback if company name is not found
    }
} else {
    echo "<p>No debtor code or item ID provided.</p>";
    exit;
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $active = isset($_POST['active']) ? 1 : 0;
    $login = htmlspecialchars($_POST['login']);
    $password = htmlspecialchars($_POST['password']);
    $ddns = htmlspecialchars($_POST['ddns']);
    $account_number = htmlspecialchars($_POST['account_number']);
    $order_number = htmlspecialchars($_POST['order_number']);
    $packet = htmlspecialchars($_POST['packet']);
    $telephone_no = isset($_POST['telephone_no']) ? $_POST['telephone_no'] : []; // Array of telephone numbers
    $service_provider = htmlspecialchars($_POST['service_provider']);
    $others = htmlspecialchars($_POST['others']);

    // Handle file upload
    $garbledName = $item['picture']; // Default to the current picture
    if (isset($_FILES["picture"]) && $_FILES["picture"]["error"] == 0) {
        $targetDir = "../../images/ISP/";
        $fileName = basename($_FILES["picture"]["name"]);
        $fileType = strtolower(pathinfo($fileName, PATHINFO_EXTENSION));
        $garbledName = bin2hex(random_bytes(16)) . "." . $fileType; // Generate a garbled name
        $targetFile = $targetDir . $garbledName;

        // Check if the target directory exists, if not create it
        if (!is_dir($targetDir)) {
            mkdir($targetDir, 0755, true);
        }

        // Check if file is an actual image
        $check = getimagesize($_FILES["picture"]["tmp_name"]);
        if ($check !== false) {
            // Move the uploaded file to the target directory
            if (move_uploaded_file($_FILES["picture"]["tmp_name"], $targetFile)) {
                // File uploaded successfully
            } else {
                echo "<script>alert('Failed to upload file. Please try again.');</script>";
                exit;
            }
        } else {
            echo "<script>alert('File is not an image.');</script>";
            exit;
        }
    }

    // Convert telephone_no array to a comma-separated string for comparison
    $telephone_no_str = !empty($telephone_no) ? implode(',', $telephone_no) : '';

    // Prepare the new data for comparison (raw form, before encryption)
    $newData = [
        'active' => $active,
        'login' => $login,
        'password' => $password, // Compare raw password (not encrypted)
        'ddns' => $ddns,
        'account_number' => $account_number,
        'order_number' => $order_number,
        'packet' => $packet,
        'telephone_no' => $telephone_no_str, // Use the string version for comparison
        'service_provider' => $service_provider,
        'others' => $others,
        'picture' => $garbledName
    ];

    // Prepare the old data for comparison (raw form, decrypted password)
    $oldData = [
        'active' => $item['active'],
        'login' => $item['login'],
        'password' => $item['password'], // Use decrypted password for comparison
        'ddns' => $item['ddns'],
        'account_number' => $item['account_number'],
        'order_number' => $item['order_number'],
        'packet' => $item['packet'],
        'telephone_no' => !empty($item['telephone_no']) ? implode(',', $item['telephone_no']) : '', // Convert array to string
        'service_provider' => $item['service_provider'],
        'others' => $item['others'],
        'picture' => $item['picture']
    ];

    // Compare old data with new data
    $hasChanges = false;
    foreach ($newData as $key => $value) {
        if ($oldData[$key] != $value) {
            $hasChanges = true;
            break;
        }
    }

    // If no changes, display message and redirect
    if (!$hasChanges) {
        echo '<script type="text/javascript">';
        echo 'alert("No data changed.");';
        echo 'window.location.href="/crm/public/company/view_network_table.php?debtor_code=' . urlencode($debtorCode) . '";';
        echo '</script>';
        exit;
    }

    // If there are changes, proceed with the update
    // Encrypt the password before saving to the database
    $encryptedPassword = encryptPassword($password, $encryptionKey);

    // Update the item in the database
    $sql = 'UPDATE item_type_nw_isp SET active = :active, login = :login, password = :password, ddns = :ddns, account_number = :account_number, order_number = :order_number, packet = :packet, telephone_no = :telephone_no, service_provider = :service_provider, updated_time = NOW(), others = :others';
    if ($garbledName !== $item['picture']) {
        $sql .= ', picture = :picture';
    }
    $sql .= ' WHERE debtor_code = :debtor_code AND item_type_nw_isp_id = :item_type_nw_isp_id';

    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':active', $active);
    $stmt->bindParam(':login', $login);
    $stmt->bindParam(':password', $encryptedPassword);
    $stmt->bindParam(':ddns', $ddns);
    $stmt->bindParam(':account_number', $account_number);
    $stmt->bindParam(':order_number', $order_number);
    $stmt->bindParam(':packet', $packet);
    $stmt->bindParam(':telephone_no', $telephone_no_str); // Use the string version for database
    $stmt->bindParam(':service_provider', $service_provider);
    $stmt->bindParam(':others', $others);
    if ($garbledName !== $item['picture']) {
        $stmt->bindParam(':picture', $garbledName);
    }
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_type_nw_isp_id', $itemTypeId);

    if ($stmt->execute()) {
        // If update was successful, show success message and redirect
        echo '<script type="text/javascript">';
        echo 'alert("Update successful!");';
        echo 'window.location.href="/crm/public/company/view_network_table.php?debtor_code=' . urlencode($debtorCode) . '";';
        echo '</script>';
    } else {
        // If update failed, show error message
        echo '<script type="text/javascript">';
        echo 'alert("Failed to update. Please try again.");';
        echo '</script>';
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Confirm and Save Details</title>
    <!-- Bootstrap CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Confirm and Save Details</h1>
            </div>
            <div class="card-body">
                <form method="POST" enctype="multipart/form-data">
                    <!-- Hidden Field -->
                    <div class="mb-3">
                        <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                    </div>

                    <!-- Active Status -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Active Status</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $item['active'] ? 'checked' : '' ?>>
                                <label class="form-check-label" for="active">Active</label>
                            </div>
                        </div>
                    </div>

                    <!-- Login and Password -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Login and Password</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="login" id="login" placeholder="Login" value="<?= htmlspecialchars($item['login'] ?? '') ?>">
                                        <label for="login">Login</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="password" id="password" placeholder="Password" value="<?= htmlspecialchars($item['password'] ?? '') ?>">
                                        <label for="password">Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- DDNS and Account Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">DDNS and Account Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="ddns" id="ddns" placeholder="DDNS" value="<?= htmlspecialchars($item['ddns'] ?? '') ?>">
                                        <label for="ddns">DDNS</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="account_number" id="account_number" placeholder="Account Number" value="<?= htmlspecialchars($item['account_number'] ?? '') ?>">
                                        <label for="account_number">Account Number</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="service_provider" id="service_provider" placeholder="Service Provider" value="<?= htmlspecialchars($item['service_provider'] ?? '') ?>">
                                        <label for="service_provider">Service Provider</label>
                                    </div>    
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="order_number" id="order_number" placeholder="Order Number" value="<?= htmlspecialchars($item['order_number'] ?? '') ?>">
                                        <label for="order_number">Order Number</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="packet" id="packet" placeholder="Packet" value="<?= htmlspecialchars($item['packet'] ?? '') ?>">
                                        <label for="packet">Packet</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Telephone Numbers -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Telephone Numbers</h5>
                        </div>
                        <div class="card-body">
                            <div id="telephoneNoContainer">
                                <?php foreach ($item['telephone_no'] as $telephone_no_item): ?>
                                    <div class="telephone-no-row mb-2">
                                        <div class="input-group">
                                            <div class="form-floating">
                                                <input type="text" name="telephone_no[]" class="form-control" placeholder="Telephone Number" value="<?= htmlspecialchars($telephone_no_item) ?>">
                                                <label for="telephone_no">Telephone Number</label>
                                            </div>
                                            <button type="button" class="btn btn-danger" onclick="removeTelephoneNo(this)">Remove</button>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                            <button type="button" class="btn btn-primary mt-3" onclick="addTelephoneNo()">Add More</button>
                        </div>
                    </div>

                    <!-- Upload Picture -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Upload Picture</h5>
                        </div>
                        <div class="card-body">
                            <div class="mb-3">
                                <label for="picture" class="form-label">Current Picture</label>
                                <?php if (!empty($item['picture'])): ?>
                                    <div class="mb-3">
                                        <img src="../../images/ISP/<?= htmlspecialchars($item['picture']) ?>" alt="Current Picture" style="max-width: 400px;">
                                    </div>
                                <?php endif; ?>
                                <input type="file" class="form-control" name="picture" id="picture">
                            </div>
                        </div>
                    </div>

                    <!-- Others -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Others</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-12">
                                    <div class="form-floating mb-3">
                                        <textarea class="form-control" id="others" name="others" placeholder="Others" rows="3"><?= htmlspecialchars($item['others'] ?? '') ?></textarea>
                                        <label for="others">Others</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <!-- Save Button -->
                    <div class="text-center">
                        <button type="submit" class="btn btn-primary">Save</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script>
        let telephoneCounter = <?= count($item['telephone_no']) ?>; // Counter for unique IDs

        function addTelephoneNo() {
            telephoneCounter++; // Increment the counter for unique IDs
            const container = document.getElementById('telephoneNoContainer');
            
            const rowDiv = document.createElement('div');
            rowDiv.className = 'telephone-no-row mb-2';
            
            const inputGroup = document.createElement('div');
            inputGroup.className = 'input-group';
            
            const input = document.createElement('input');
            input.type = 'text';
            input.name = 'telephone_no[]';
            input.className = 'form-control';
            input.placeholder = 'Telephone Number';
            input.id = `telephone_no_${telephoneCounter}`; // Unique ID for the input
            
            const label = document.createElement('label');
            label.htmlFor = `telephone_no_${telephoneCounter}`; // Match the label to the input ID
            label.innerText = 'Telephone Number';
            label.className = 'form-label';
            
            const removeButton = document.createElement('button');
            removeButton.type = 'button';
            removeButton.innerText = 'Remove';
            removeButton.className = 'btn btn-danger';
            removeButton.onclick = function() {
                removeTelephoneNo(this);
            };
            
            // Wrap the input in a form-floating div
            const floatingDiv = document.createElement('div');
            floatingDiv.className = 'form-floating';
            floatingDiv.appendChild(input);
            floatingDiv.appendChild(label);
            
            inputGroup.appendChild(floatingDiv);
            inputGroup.appendChild(removeButton);
            rowDiv.appendChild(inputGroup);
            
            container.appendChild(rowDiv);
        }

        function removeTelephoneNo(button) {
            const container = document.getElementById('telephoneNoContainer');
            const rowDiv = button.closest('.telephone-no-row');
            
            // Filter out the add button and count only the telephone number rows
            const telephoneRows = Array.from(container.children).filter(child => child.classList.contains('telephone-no-row'));
            
            // Check if there is more than one telephone number field
            if (telephoneRows.length > 1) {
                container.removeChild(rowDiv);
            } else {
                alert('You must have at least one telephone number field.');
            }
        }
    </script>

    <!-- Bootstrap JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

