<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password decryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if debtor_code and item_type_nw_ns_id are passed via URL
if (isset($_GET['debtor_code']) && isset($_GET['item_type_nw_ns_id'])) {
    $debtorCode = $_GET['debtor_code'];
    $itemTypeId = $_GET['item_type_nw_ns_id'];

    try {
        // Fetch the item details based on debtor_code and item_type_nw_ns_id
        $stmt = $pdo->prepare('SELECT * FROM item_type_nw_ns WHERE debtor_code = :debtor_code AND item_type_nw_ns_id = :item_type_nw_ns_id LIMIT 1');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->bindParam(':item_type_nw_ns_id', $itemTypeId);
        $stmt->execute();
        $item = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$item) {
            throw new Exception("No item found with the provided ID.");
        }

        // Decrypt the password for logging purposes
        $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
        $item['password'] = decryptPassword($item['password'], $encryptionKey);
    } catch (Exception $e) {
        echo "<p>Error: " . $e->getMessage() . "</p>";
        exit;
    }
} else {
    echo "<p>No debtor code or item ID provided.</p>";
    exit;
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // Validate and sanitize input data
        $active = isset($_POST['active']) ? 1 : 0;
        $login = htmlspecialchars($_POST['login']);
        $password = htmlspecialchars($_POST['password']);
        $model = htmlspecialchars($_POST['model']);
        $tcp_ip = htmlspecialchars($_POST['tcp_ip']);
        $serial_number = htmlspecialchars($_POST['serial_number']);
        $purchase_date = htmlspecialchars($_POST['purchase_date']);
        $warranty_expire_date = htmlspecialchars($_POST['warranty_expire_date']);
        $others = htmlspecialchars($_POST['others']);

        // Encrypt the password for database storage
        $encryptedPassword = encryptPassword($password, $encryptionKey);

        // Store the old data in plaintext
        $oldData = $item;

        // Update the item in the database
        $stmt = $pdo->prepare('UPDATE item_type_nw_ns SET 
            active = :active, 
            login = :login, 
            password = :password, 
            model = :model, 
            tcp_ip = :tcp_ip, 
            serial_number = :serial_number, 
            purchase_date = :purchase_date, 
            warranty_expire_date = :warranty_expire_date, 
            others = :others, 
            updated_time = NOW() 
            WHERE debtor_code = :debtor_code AND item_type_nw_ns_id = :item_type_nw_ns_id');

        $stmt->bindParam(':active', $active);
        $stmt->bindParam(':login', $login);
        $stmt->bindParam(':password', $encryptedPassword);
        $stmt->bindParam(':model', $model);
        $stmt->bindParam(':tcp_ip', $tcp_ip);
        $stmt->bindParam(':serial_number', $serial_number);
        $stmt->bindParam(':purchase_date', $purchase_date);
        $stmt->bindParam(':warranty_expire_date', $warranty_expire_date);
        $stmt->bindParam(':others', $others);
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->bindParam(':item_type_nw_ns_id', $itemTypeId);

        if ($stmt->execute()) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_nw_ns WHERE debtor_code = :debtor_code AND item_type_nw_ns_id = :item_type_nw_ns_id LIMIT 1');
            $stmt->bindParam(':debtor_code', $debtorCode);
            $stmt->bindParam(':item_type_nw_ns_id', $itemTypeId);
            $stmt->execute();
            $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

            // Decrypt the password for logging purposes
            $newItem['password'] = decryptPassword($newItem['password'], $encryptionKey);

            // Check if any data has changed
            $dataChanged = false;
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                    $dataChanged = true;
                    break;
                }
            }

            if ($dataChanged) {
                // Build the log message with only the fields that have changed, excluding 'updated_time'
                $logMessage = "Data change in network switch (Debtor Code: " . $debtorCode . "):\n";
                foreach ($oldData as $key => $value) {
                    if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                        $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                    }
                }

                // Insert the log into activity_logs
                $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                           VALUES (:username, :timestamp, :role, :activity)";
                $stmtLog = $pdo->prepare($sqlLog);
                $stmtLog->execute([
                    ':username' => $_SESSION['username'],
                    ':timestamp' => date('Y-m-d H:i:s'),
                    ':role' => $_SESSION['role'],
                    ':activity' => $logMessage
                ]);

                // Check if the log entry was inserted successfully
                if ($stmtLog->rowCount() > 0) {
                    // If update was successful, show success message and redirect
                    echo '<script type="text/javascript">';
                    echo 'alert("Update successful!");';
                    echo 'window.location.href="view_network_table.php?debtor_code=' . urlencode($debtorCode) . '";';
                    echo '</script>';
                } else {
                    throw new Exception("Failed to insert log entry.");
                }
            } else {
                // If no data changed, show no change message
                echo '<script type="text/javascript">';
                echo 'alert("No data changed.");';
                echo 'window.location.href="/crm/public/company/view_network_table.php?debtor_code=' . urlencode($debtorCode) . '";';
                echo '</script>';
            }
        } else {
            throw new Exception("Failed to update the item details.");
        }
    } catch (Exception $e) {
        echo '<script type="text/javascript">';
        echo 'alert("' . $e->getMessage() . '");';
        echo '</script>';
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Network Switch</title>
    <!-- Bootstrap CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-4">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Edit Network Switch</h1>
            </div>
            <div class="card-body">
                <form method="POST">
                    <!-- Hidden Fields -->
                    <div class="mb-3">
                        <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                        <input type="hidden" name="item_type_nw_id" value="<?= htmlspecialchars($itemTypeId) ?>">
                    </div>
                    
                    <!-- Active Status -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Active Status</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $item['active'] ? 'checked' : '' ?>>
                                <label class="form-check-label" for="active">Active</label>
                            </div>
                        </div>
                    </div>

                    <!-- Hardware Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Hardware Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="model" id="model" placeholder="Model" value="<?= htmlspecialchars($item['model'] ?? '') ?>">
                                        <label for="model">Model</label>
                                    </div>
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="serial_number" id="serial_number" placeholder="Serial Number" value="<?= htmlspecialchars($item['serial_number'] ?? '') ?>">
                                        <label for="serial_number">Serial Number</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="tcp_ip" id="tcp_ip" placeholder="TCP/IP" value="<?= htmlspecialchars($item['tcp_ip'] ?? '') ?>">
                                        <label for="tcp_ip">TCP/IP</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Login and Password -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Login and Password</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="login" id="login" placeholder="Login" value="<?= htmlspecialchars($item['login'] ?? '') ?>">
                                        <label for="login">Login</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="password" id="password" placeholder="Password" value="<?= htmlspecialchars($item['password'] ?? '') ?>">
                                        <label for="password">Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Warranty Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Warranty Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" name="purchase_date" id="purchase_date" placeholder="Purchase Date" value="<?= htmlspecialchars($item['purchase_date'] ?? '') ?>">
                                        <label for="purchase_date">Purchase Date</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" name="warranty_expire_date" id="warranty_expire_date" placeholder="Warranty Expire Date" value="<?= htmlspecialchars($item['warranty_expire_date'] ?? '') ?>">
                                        <label for="warranty_expire_date">Warranty Expire Date</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Others Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Others Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="others" name="others" placeholder="Others" rows="3"><?= htmlspecialchars($item['others'] ?? '') ?></textarea>
                                <label for="others">Others</label>
                            </div>
                        </div>
                    </div>

                    <!-- Save Button -->
                    <div class="text-center">
                        <button type="submit" class="btn btn-primary">Save</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

