<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password decryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if debtor_code and item_type_nw_router_id are passed via URL
if (isset($_GET['debtor_code']) && isset($_GET['item_type_nw_router_id'])) {
    $debtorCode = $_GET['debtor_code'];
    $itemTypeId = $_GET['item_type_nw_router_id'];

    // Fetch the item details based on debtor_code and item_type_nw_router_id
    $stmt = $pdo->prepare('SELECT * FROM item_type_nw_router WHERE debtor_code = :debtor_code AND item_type_nw_router_id = :item_type_nw_router_id LIMIT 1');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_type_nw_router_id', $itemTypeId);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$item) {
        echo "<p>No item found with the provided ID.</p>";
        exit;
    }

    // Decrypt the password and SSID pwd for comparison
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $item['password'] = decryptPassword($item['password'], $encryptionKey);
    $item['ssid_pwd'] = decryptPassword($item['ssid_pwd'], $encryptionKey);

    // Convert comma-separated strings to arrays
    $item['open_port'] = explode(',', $item['open_port']);
    $item['open_port_for'] = explode(',', $item['open_port_for']);
    $item['ssid'] = explode(',', $item['ssid']);
    $item['ssid_pwd'] = explode(',', $item['ssid_pwd']);

    // Fetch the company name based on debtor_code
    $stmt = $pdo->prepare('SELECT company_name FROM company_info WHERE debtor_code = :debtor_code LIMIT 1');
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->execute();
    $company = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($company) {
        $companyName = $company['company_name'];
    } else {
        $companyName = 'Unknown Company'; // Fallback if company name is not found
    }
} else {
    echo "<p>No debtor code or item ID provided.</p>";
    exit;
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $active = isset($_POST['active']) ? 1 : 0;
    $login = htmlspecialchars(trim($_POST['login']));
    $password = htmlspecialchars(trim($_POST['password'])); // Plaintext password from form
    $model = htmlspecialchars(trim($_POST['model']));
    $tcp_ip = htmlspecialchars(trim($_POST['tcp_ip']));
    $ssid = isset($_POST['ssid']) ? array_filter($_POST['ssid']) : [];
    $ssid_pwd = isset($_POST['ssid_pwd']) ? array_filter($_POST['ssid_pwd']) : [];
    $serial_number = htmlspecialchars(trim($_POST['serial_number']));
    $ddns = htmlspecialchars(trim($_POST['ddns']));
    $fix_tcp_ip = htmlspecialchars(trim($_POST['fix_tcp_ip']));
    $open_port = isset($_POST['open_port']) ? array_filter($_POST['open_port']) : [];
    $open_port_for = isset($_POST['open_port_for']) ? array_filter($_POST['open_port_for']) : [];
    $purchase_date = htmlspecialchars(trim($_POST['purchase_date']));
    $warranty_expire_date = htmlspecialchars(trim($_POST['warranty_expire_date']));
    $others = htmlspecialchars(trim($_POST['others']));

    // Prepare the new data for comparison
    $newData = [
        'active' => $active,
        'login' => $login,
        'password' => $password, // Plaintext password for comparison
        'model' => $model,
        'tcp_ip' => $tcp_ip,
        'ssid' => implode(',', $ssid),
        'ssid_pwd' => implode(',', $ssid_pwd),
        'serial_number' => $serial_number,
        'ddns' => $ddns,
        'fix_tcp_ip' => $fix_tcp_ip,
        'open_port' => implode(',', $open_port),
        'open_port_for' => implode(',', $open_port_for),
        'purchase_date' => $purchase_date,
        'warranty_expire_date' => $warranty_expire_date,
        'others' => $others,
    ];

    // Store the old data for comparison
    $oldData = $item;
    $oldData['ssid'] = implode(',', $oldData['ssid']); // Convert array to string for comparison
    $oldData['ssid_pwd'] = implode(',', $oldData['ssid_pwd']); // Convert array to string for comparison
    $oldData['open_port'] = implode(',', $oldData['open_port']);
    $oldData['open_port_for'] = implode(',', $oldData['open_port_for']);

    // Compare old and new data
    $changesDetected = false;
    foreach ($newData as $key => $value) {
        if ($oldData[$key] !== $value) {
            $changesDetected = true;
            break;
        }
    }

    if (!$changesDetected) {
        // No changes detected
        echo '<script type="text/javascript">';
        echo 'alert("No changes made.");';
        echo 'window.location.href="/crm/public/company/view_network_table.php?debtor_code=' . urlencode($debtorCode) . '";';
        echo '</script>';
        exit;
    }

    // Encrypt the password and SSID pwd for storage
    $encryptedPassword = encryptPassword($password, $encryptionKey);
    $encryptedSsidPwd = encryptPassword(implode(',', $ssid_pwd), $encryptionKey);

    // Update the item in the database
    $stmt = $pdo->prepare('UPDATE item_type_nw_router SET active = :active, login = :login, password = :password, model = :model, tcp_ip = :tcp_ip, ssid = :ssid, ssid_pwd = :ssid_pwd, serial_number = :serial_number, ddns = :ddns, fix_tcp_ip = :fix_tcp_ip, open_port = :open_port, open_port_for = :open_port_for, purchase_date = :purchase_date, warranty_expire_date = :warranty_expire_date, others = :others WHERE debtor_code = :debtor_code AND item_type_nw_router_id = :item_type_nw_router_id');
    $stmt->bindParam(':active', $active);
    $stmt->bindParam(':login', $login);
    $stmt->bindParam(':password', $encryptedPassword);
    $stmt->bindParam(':model', $model);
    $stmt->bindParam(':tcp_ip', $tcp_ip);
    $stmt->bindParam(':ssid', $newData['ssid']);
    $stmt->bindParam(':ssid_pwd', $encryptedSsidPwd);
    $stmt->bindParam(':serial_number', $serial_number);
    $stmt->bindParam(':ddns', $ddns);
    $stmt->bindParam(':fix_tcp_ip', $fix_tcp_ip);
    $stmt->bindParam(':open_port', $newData['open_port']);
    $stmt->bindParam(':open_port_for', $newData['open_port_for']);
    $stmt->bindParam(':purchase_date', $purchase_date);
    $stmt->bindParam(':warranty_expire_date', $warranty_expire_date);
    $stmt->bindParam(':others', $others);
    $stmt->bindParam(':debtor_code', $debtorCode);
    $stmt->bindParam(':item_type_nw_router_id', $itemTypeId);

    if ($stmt->execute()) {
        // Fetch the new data after the update
        $stmt = $pdo->prepare('SELECT * FROM item_type_nw_router WHERE debtor_code = :debtor_code AND item_type_nw_router_id = :item_type_nw_router_id LIMIT 1');
        $stmt->bindParam(':debtor_code', $debtorCode);
        $stmt->bindParam(':item_type_nw_router_id', $itemTypeId);
        $stmt->execute();
        $newItem = $stmt->fetch(PDO::FETCH_ASSOC);
        $newItem['password'] = decryptPassword($newItem['password'], $encryptionKey); // Decrypt for logging
        $newItem['ssid_pwd'] = decryptPassword($newItem['ssid_pwd'], $encryptionKey); // Decrypt for logging
        $newItem['ssid'] = explode(',', $newItem['ssid']); // Convert to array for comparison
        $newItem['ssid'] = implode(',', $newItem['ssid']); // Convert back to string for logging
        $newItem['ssid_pwd'] = explode(',', $newItem['ssid_pwd']); // Convert to array for comparison
        $newItem['ssid_pwd'] = implode(',', $newItem['ssid_pwd']); // Convert back to string for logging
        $newItem['open_port'] = explode(',', $newItem['open_port']); // Convert to array for comparison
        $newItem['open_port'] = implode(',', $newItem['open_port']); // Convert back to string for logging
        $newItem['open_port_for'] = explode(',', $newItem['open_port_for']); // Convert to array for comparison
        $newItem['open_port_for'] = implode(',', $newItem['open_port_for']); // Convert back to string for logging

        // Build the log message with only the fields that have changed, excluding 'updated_time'
        $logMessage = "Data change in router (Company Name: " . $companyName . "):\n";
        foreach ($oldData as $key => $value) {
            if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
            }
        }

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        // If update was successful, show success message and redirect
        echo '<script type="text/javascript">';
        echo 'alert("Update successful!");';
        echo 'window.location.href="/crm/public/company/view_network_table.php?debtor_code=' . urlencode($debtorCode) . '";';
        echo '</script>';
    } else {
        // If update failed, show error message
        echo '<script type="text/javascript">';
        echo 'alert("Failed to update. Please try again.");';
        echo '</script>';
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Details</title>
    <!-- Bootstrap 5.x CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Edit Details</h1>
            </div>
            <div class="card-body">
                <form method="POST" action="">
                    <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                    <input type="hidden" name="item_type_nw_id" value="<?= htmlspecialchars($itemTypeId) ?>">

                    <!-- Active Status -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Active Status</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $item['active'] ? 'checked' : '' ?>>
                                <label class="form-check-label" for="active">Active</label>
                            </div>
                        </div>
                    </div>
                    
                    <!-- Network Information Card -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Network Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <!-- TCP/IP Field -->
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="tcp_ip" name="tcp_ip" placeholder="TCP/IP" value="<?= htmlspecialchars($item['tcp_ip'] ?? '') ?>">
                                        <label for="tcp_ip">TCP/IP</label>
                                    </div>
                                </div>

                                <!-- DDNS Field -->
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="ddns" name="ddns" placeholder="DDNS" value="<?= htmlspecialchars($item['ddns'] ?? '') ?>">
                                        <label for="ddns">DDNS</label>
                                    </div>
                                </div>

                                <!-- Fix TCP/IP Field -->
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="fix_tcp_ip" name="fix_tcp_ip" placeholder="Fix TCP/IP" value="<?= htmlspecialchars($item['fix_tcp_ip'] ?? '') ?>">
                                        <label for="fix_tcp_ip">Fix TCP/IP</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <!-- Hardware Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Hardware Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="model" id="model" value="<?= htmlspecialchars($item['model'] ?? '') ?>">
                                        <label for="model">Model</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="serial_number" id="serial_number" value="<?= htmlspecialchars($item['serial_number'] ?? '') ?>">
                                        <label for="serial_number">Serial Number</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Login and Password -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Login and Password</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="login" id="login" value="<?= htmlspecialchars($item['login'] ?? '') ?>">
                                        <label for="login">Login</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" name="password" id="password" value="<?= htmlspecialchars($item['password'] ?? '') ?>">
                                        <label for="password">Password</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- SSID Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">SSID Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-group mb-3">
                                <label for="ssid-container">SSID and SSID Pwd:</label>
                                <div id="ssid-container">
                                    <?php
                                    foreach ($item['ssid'] as $index => $ssid) {
                                        $ssidPwd = isset($item['ssid_pwd'][$index]) ? $item['ssid_pwd'][$index] : '';
                                        echo '<div class="input-group mb-2">
                                                <div class="form-floating">
                                                    <input type="text" class="form-control" name="ssid[]" value="' . htmlspecialchars($ssid) . '">
                                                    <label>SSID</label>
                                                </div>
                                                <div class="form-floating">
                                                    <input type="text" class="form-control" name="ssid_pwd[]" value="' . htmlspecialchars($ssidPwd) . '">
                                                    <label>SSID Pwd</label>
                                                </div>
                                                <button type="button" class="btn btn-danger" onclick="removeSSIDField(this)">Remove</button>
                                              </div>';
                                    }
                                    ?>
                                </div>
                                <div class="text-left">
                                    <button type="button" class="btn btn-secondary" onclick="addSSIDField()">Add</button>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Open Port Details -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Open Port Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-group mb-3">
                                <label for="openPortContainer">Open Port and Description:</label>
                                <div id="openPortContainer">
                                    <?php foreach ($item['open_port'] as $index => $open_port_item): ?>
                                        <div class="input-group mb-2">
                                            <div class="form-floating">
                                                <input type="text" name="open_port[]" class="form-control open_port" value="<?= htmlspecialchars($open_port_item) ?>">
                                                <label>Open Port</label>
                                            </div>
                                            <div class="form-floating">
                                                <input type="text" name="open_port_for[]" class="form-control open_port_for" value="<?= htmlspecialchars($item['open_port_for'][$index] ?? '') ?>">
                                                <label>Description</label>
                                            </div>
                                            <button type="button" class="btn btn-danger" onclick="removeOpenPortField(this)">Remove</button>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                                <div class="text-left">
                                    <button type="button" class="btn btn-success" onclick="addOpenPortField()">Add</button>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Warranty Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Warranty Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" name="purchase_date" id="purchase_date" value="<?= htmlspecialchars($item['purchase_date'] ?? '') ?>">
                                        <label for="purchase_date">Purchase Date</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="date" class="form-control" name="warranty_expire_date" id="warranty_expire_date" value="<?= htmlspecialchars($item['warranty_expire_date'] ?? '') ?>">
                                        <label for="warranty_expire_date">Warranty Expire Date</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Others Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Others Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="others" name="others" rows="3"><?= htmlspecialchars($item['others'] ?? '') ?></textarea>
                                <label for="others">Others</label>
                            </div>
                        </div>
                    </div>

                    <!-- Save Button -->
                    <button type="submit" class="btn btn-primary">Save</button>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.x JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        function addSSIDField() {
            const container = document.getElementById('ssid-container');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <div class="form-floating">
                    <input type="text" class="form-control" name="ssid[]" placeholder="SSID">
                    <label>SSID</label>
                </div>
                <div class="form-floating">
                    <input type="text" class="form-control" name="ssid_pwd[]" placeholder="SSID Pwd">
                    <label>SSID Pwd</label>
                </div>
                <button type="button" class="btn btn-danger" onclick="removeSSIDField(this)">Remove</button>
            `;
            // Append the new field to the end of the container
            container.appendChild(newField);
        }

        function removeSSIDField(button) {
            const container = document.getElementById('ssid-container');
            if (container.childElementCount > 1) { // Ensure there's more than one field
                button.parentElement.remove();
            } else {
                alert("The last field cannot be removed.");
            }
        }

        function addOpenPortField() {
            const container = document.getElementById('openPortContainer');
            const newField = document.createElement('div');
            newField.className = 'input-group mb-2';
            newField.innerHTML = `
                <div class="form-floating">
                    <input type="text" class="form-control open_port" name="open_port[]" placeholder="Enter Open Port">
                    <label>Open Port</label>
                </div>
                <div class="form-floating">
                    <input type="text" class="form-control open_port_for" name="open_port_for[]" placeholder="Enter Open Port Description">
                    <label>Description</label>
                </div>
                <button type="button" class="btn btn-danger" onclick="removeOpenPortField(this)">Remove</button>
            `;
            // Append the new field to the end of the container
            container.appendChild(newField);
        }

        function removeOpenPortField(button) {
            const container = document.getElementById('openPortContainer');
            if (container.childElementCount > 1) { // Ensure there's more than one field
                button.parentElement.remove();
            } else {
                alert("The last field cannot be removed.");
            }
        }
    </script>
</body>
</html>

