<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Retrieve the passed values from the URL
$id = isset($_GET['item_type_nw_vpn_id']) ? intval($_GET['item_type_nw_vpn_id']) : null;

if (!$id) {
    die("Invalid ID provided.");
}

// Fetch the existing data from the database
$vpnData = [];
try {
    $stmt = $pdo->prepare("SELECT * FROM item_type_nw_vpn WHERE item_type_nw_vpn_id = ?");
    $stmt->execute([$id]);
    $vpnData = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$vpnData) {
        die("No data found for the provided ID.");
    }
    // Decrypt the password
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key
    $vpnData['forticlient_password'] = decryptPassword($vpnData['forticlient_password'], $encryptionKey);
    $vpnData['cisco_meraki_password'] = decryptPassword($vpnData['cisco_meraki_password'], $encryptionKey);
    $vpnData['radmin_password'] = decryptPassword($vpnData['radmin_password'], $encryptionKey);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
    die("Database error occurred.");
}

// Fetch the list of installed PCs from the database based on debtor_code and company_name
$installedPcOptions = [];
try {
    $debtorCode = $vpnData['debtor_code'];
    $companyName = $vpnData['company_name'];
    $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtorCode AND company_name = :companyName");
    $stmt->execute([':debtorCode' => $debtorCode, ':companyName' => $companyName]);
    $installedPcOptions = $stmt->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    error_log('Database query error: ' . $e->getMessage());
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = isset($_POST['active']) ? 1 : 0;
    $selectedCard = $_POST['selectedCard'] ?? 'forticlientCard'; // Default to forticlientCard if not selected
    $vpnType = $_POST['vpn_type'] ?? null; // Retrieve the vpn_type from the form

    $forticlientUsername = $selectedCard === 'forticlientCard' ? $_POST['forticlient_username'] ?? null : null;
    $forticlientLogin = $selectedCard === 'forticlientCard' ? $_POST['forticlient_login'] ?? null : null;
    $forticlientPassword = $selectedCard === 'forticlientCard' ? $_POST['forticlient_password'] ?? null : null;

    $ciscoMerakiUsername = $selectedCard === 'ciscoMerakiCard' ? $_POST['cisco_meraki_username'] ?? null : null;
    $ciscoMerakiLogin = $selectedCard === 'ciscoMerakiCard' ? $_POST['cisco_meraki_login'] ?? null : null;
    $ciscoMerakiPassword = $selectedCard === 'ciscoMerakiCard' ? $_POST['cisco_meraki_password'] ?? null : null;

    $radminTcpIp = $selectedCard === 'radminCard' ? $_POST['radmin_tcp_ip'] ?? null : null;
    $radminNetworkGroup = $selectedCard === 'radminCard' ? $_POST['radmin_network_group'] ?? null : null;
    $radminPassword = $selectedCard === 'radminCard' ? $_POST['radmin_password'] ?? null : null;
    $radminMasterHost = $selectedCard === 'radminCard' ? $_POST['radmin_master_host'] ?? null : null;

    $hamachiTcpIp = $selectedCard === 'hamachiCard' ? $_POST['hamachi_tcp_ip'] ?? null : null;
    $hamachiNetworkGroup = $selectedCard === 'hamachiCard' ? $_POST['hamachi_network_group'] ?? null : null;
    $hamachiMasterHost = $selectedCard === 'hamachiCard' ? $_POST['hamachi_master_host'] ?? null : null;

    $installedPc = $_POST['installed_pc'] ?? null;
    $others = $_POST['others'] ?? null;

    // Encrypt the password and SSID key
    $encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

    // Check if the password fields are empty before encrypting
    $encryptedForticlientPassword = !empty($forticlientPassword) ? encryptPassword($forticlientPassword, $encryptionKey) : null;
    $encryptedCiscoMerakiPassword = !empty($ciscoMerakiPassword) ? encryptPassword($ciscoMerakiPassword, $encryptionKey) : null;
    $encryptedRadminPassword = !empty($radminPassword) ? encryptPassword($radminPassword, $encryptionKey) : null;

    // Store the old data in plaintext
    $oldData = $vpnData;

    try {
        // Prepare and execute the update query for the new table `item_type_nw_vpn`
        $stmt = $pdo->prepare("UPDATE item_type_nw_vpn SET
            active = :active,
            forticlient_username = :forticlient_username,
            forticlient_login = :forticlient_login,
            forticlient_password = :forticlient_password,
            cisco_meraki_username = :cisco_meraki_username,
            cisco_meraki_login = :cisco_meraki_login,
            cisco_meraki_password = :cisco_meraki_password,
            radmin_tcp_ip = :radmin_tcp_ip,
            radmin_network_group = :radmin_network_group,
            radmin_password = :radmin_password,
            radmin_master_host = :radmin_master_host,
            hamachi_tcp_ip = :hamachi_tcp_ip,
            hamachi_network_group = :hamachi_network_group,
            hamachi_master_host = :hamachi_master_host,
            installed_pc = :installed_pc,
            others = :others,
            vpn_type = :vpn_type
            WHERE item_type_nw_vpn_id = :item_type_nw_vpn_id");

        // Execute the statement
        if ($stmt->execute([
            ':active' => $active,
            ':forticlient_username' => $forticlientUsername,
            ':forticlient_login' => $forticlientLogin,
            ':forticlient_password' => $encryptedForticlientPassword,
            ':cisco_meraki_username' => $ciscoMerakiUsername,
            ':cisco_meraki_login' => $ciscoMerakiLogin,
            ':cisco_meraki_password' => $encryptedCiscoMerakiPassword,
            ':radmin_tcp_ip' => $radminTcpIp,
            ':radmin_network_group' => $radminNetworkGroup,
            ':radmin_password' => $encryptedRadminPassword,
            ':radmin_master_host' => $radminMasterHost,
            ':hamachi_tcp_ip' => $hamachiTcpIp,
            ':hamachi_network_group' => $hamachiNetworkGroup,
            ':hamachi_master_host' => $hamachiMasterHost,
            ':installed_pc' => $installedPc,
            ':others' => $others,
            ':vpn_type' => $vpnType, // Include vpn_type in the update
            ':item_type_nw_vpn_id' => $id
        ])) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare("SELECT * FROM item_type_nw_vpn WHERE item_type_nw_vpn_id = ?");
            $stmt->execute([$id]);
            $newData = $stmt->fetch(PDO::FETCH_ASSOC);

            // Decrypt the password for logging purposes
            $newData['forticlient_password'] = decryptPassword($newData['forticlient_password'], $encryptionKey);
            $newData['cisco_meraki_password'] = decryptPassword($newData['cisco_meraki_password'], $encryptionKey);
            $newData['radmin_password'] = decryptPassword($newData['radmin_password'], $encryptionKey);

            // Check if any data has changed
            $dataChanged = false;
            $vpnTypeChanged = false; // Track if vpn_type has changed
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newData[$key] !== $value) {
                    $dataChanged = true;
                    if ($key === 'vpn_type') {
                        $vpnTypeChanged = true; // Mark vpn_type as changed
                    }
                    break;
                }
            }

            if ($dataChanged) {
                // Build the log message with vpn_type first, followed by changes related to the new vpn_type, old vpn_type, and then the remaining changes
                $logMessage = "Data change in VPN (ID: " . $id . "):\n";

                // Log vpn_type first if it has changed
                if ($vpnTypeChanged) {
                    $logMessage .= "vpn_type: " . $oldData['vpn_type'] . " -> " . $newData['vpn_type'] . "\n";
                }

                // Log changes related to the new vpn_type
                if ($newData['vpn_type'] === 'Hamachi') {
                    foreach (['hamachi_tcp_ip', 'hamachi_network_group', 'hamachi_master_host'] as $field) {
                        if ($oldData[$field] !== $newData[$field]) {
                            $logMessage .= "$field: " . ($oldData[$field] ?? 'NULL') . " -> " . ($newData[$field] ?? 'NULL') . "\n";
                        }
                    }
                }

                // Log changes related to the old vpn_type
                if ($oldData['vpn_type'] === 'FortiClient') {
                    foreach (['forticlient_username', 'forticlient_login', 'forticlient_password'] as $field) {
                        if ($oldData[$field] !== $newData[$field]) {
                            $logMessage .= "$field: " . ($oldData[$field] ?? 'NULL') . " -> " . ($newData[$field] ?? 'NULL') . "\n";
                        }
                    }
                }

                // Log other changes
                foreach ($oldData as $key => $value) {
                    if ($key !== 'updated_time' && $key !== 'vpn_type' && !in_array($key, ['hamachi_tcp_ip', 'hamachi_network_group', 'hamachi_master_host', 'forticlient_username', 'forticlient_login', 'forticlient_password']) && $newData[$key] !== $value) {
                        $logMessage .= "$key: $value -> " . $newData[$key] . "\n";
                    }
                }

                // Insert the log into activity_logs
                $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                           VALUES (:username, :timestamp, :role, :activity)";
                $stmtLog = $pdo->prepare($sqlLog);
                $stmtLog->execute([
                    ':username' => $_SESSION['username'],
                    ':timestamp' => date('Y-m-d H:i:s'),
                    ':role' => $_SESSION['role'],
                    ':activity' => $logMessage
                ]);

                // Check if the log entry was inserted successfully
                if ($stmtLog->rowCount() > 0) {
                    // If update was successful, show success message and redirect
                    echo '<script type="text/javascript">';
                    echo 'alert("Update successful!");';
                    echo 'window.location.href="/crm/public/company/view_network_table.php?debtor_code=' . urlencode($vpnData['debtor_code']) . '";';
                    echo '</script>';
                } else {
                    echo '<script type="text/javascript">';
                    echo 'alert("Failed to insert log entry.");';
                    echo '</script>';
                }
            } else {
                // If no data changed, show no change message
                echo '<script type="text/javascript">';
                echo 'alert("No data changed.");';
                echo 'window.location.href="/crm/public/company/view_network_table.php?debtor_code=' . urlencode($vpnData['debtor_code']) . '";';
                echo '</script>';
            }
        } else {
            // If update failed, show error message
            echo '<script type="text/javascript">';
            echo 'alert("Failed to update. Please try again.");';
            echo '</script>';
        }
    } catch (PDOException $e) {
        error_log('Database update error: ' . $e->getMessage());
        echo "<script>alert('Failed to update data. Please try again.');</script>";
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit VPN Details</title>
    <!-- Bootstrap CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h1 class="mb-0">Edit VPN Details</h1>
            </div>
            <div class="card-body">
                <form method="POST">
                    <!-- Active Status -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Active Status</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $vpnData['active'] ? 'checked' : '' ?>>
                                <label class="form-check-label" for="active">Active</label>
                            </div>
                        </div>
                    </div>

                    <!-- VPN Selection Dropdown -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">VPN Selection</h5>
                        </div>
                        <div class="card-body">
                            <div class="row mb-3">
                                <div class="col-12">
                                    <label for="vpnSelection" class="form-label">Select VPN Configuration:</label>
                                    <select class="form-control" id="vpnSelection" name="vpnSelection">
                                        <option value="forticlientCard" <?php if ($vpnData['forticlient_username'] || $vpnData['forticlient_login'] || $vpnData['forticlient_password']) echo 'selected'; ?>>FortiClient VPN</option>
                                        <option value="ciscoMerakiCard" <?php if ($vpnData['cisco_meraki_username'] || $vpnData['cisco_meraki_login'] || $vpnData['cisco_meraki_password']) echo 'selected'; ?>>Cisco Meraki VPN</option>
                                        <option value="radminCard" <?php if ($vpnData['radmin_tcp_ip'] || $vpnData['radmin_network_group'] || $vpnData['radmin_password'] || $vpnData['radmin_master_host']) echo 'selected'; ?>>Radmin VPN</option>
                                        <option value="hamachiCard" <?php if ($vpnData['hamachi_tcp_ip'] || $vpnData['hamachi_network_group'] || $vpnData['hamachi_master_host']) echo 'selected'; ?>>Hamachi VPN</option>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Hidden input to store the selected card's ID -->
                    <input type="hidden" id="selectedCard" name="selectedCard" value="">
                    <!-- Hidden input to store the vpn_type -->
                    <input type="hidden" id="vpn_type" name="vpn_type" value="<?php echo htmlspecialchars($vpnData['vpn_type']); ?>">

                    <!-- FortiClient VPN Configuration -->
                    <div class="card mb-3 vpn-card" id="forticlientCard">
                        <div class="card-header">
                            FortiClient VPN Configuration
                        </div>
                        <div class="card-body">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" name="forticlient_username" id="forticlient_username" placeholder="FortiClient Username" value="<?php echo htmlspecialchars($vpnData['forticlient_username']); ?>">
                                <label for="forticlient_username">FortiClient Username</label>
                            </div>
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" name="forticlient_login" id="forticlient_login" placeholder="FortiClient Login" value="<?php echo htmlspecialchars($vpnData['forticlient_login']); ?>">
                                <label for="forticlient_login">FortiClient Login</label>
                            </div>
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" name="forticlient_password" id="forticlient_password" placeholder="FortiClient Password" value="<?php echo htmlspecialchars($vpnData['forticlient_password']); ?>">
                                <label for="forticlient_password">FortiClient Password</label>
                            </div>
                        </div>
                    </div>

                    <!-- Cisco Meraki VPN Configuration -->
                    <div class="card mb-3 vpn-card" id="ciscoMerakiCard">
                        <div class="card-header">
                            Cisco Meraki VPN Configuration
                        </div>
                        <div class="card-body">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" name="cisco_meraki_username" id="cisco_meraki_username" placeholder="Cisco Meraki Username" value="<?php echo htmlspecialchars($vpnData['cisco_meraki_username']); ?>">
                                <label for="cisco_meraki_username">Cisco Meraki Username</label>
                            </div>
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" name="cisco_meraki_login" id="cisco_meraki_login" placeholder="Cisco Meraki Login" value="<?php echo htmlspecialchars($vpnData['cisco_meraki_login']); ?>">
                                <label for="cisco_meraki_login">Cisco Meraki Login</label>
                            </div>
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" name="cisco_meraki_password" id="cisco_meraki_password" placeholder="Cisco Meraki Password" value="<?php echo htmlspecialchars($vpnData['cisco_meraki_password']); ?>">
                                <label for="cisco_meraki_password">Cisco Meraki Password</label>
                            </div>
                        </div>
                    </div>

                    <!-- Radmin VPN Configuration -->
                    <div class="card mb-3 vpn-card" id="radminCard">
                        <div class="card-header">
                            Radmin VPN Configuration
                        </div>
                        <div class="card-body">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" name="radmin_tcp_ip" id="radmin_tcp_ip" placeholder="Radmin TCP/IP" value="<?php echo htmlspecialchars($vpnData['radmin_tcp_ip']); ?>">
                                <label for="radmin_tcp_ip">Radmin TCP/IP</label>
                            </div>
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" name="radmin_network_group" id="radmin_network_group" placeholder="Radmin Network Group" value="<?php echo htmlspecialchars($vpnData['radmin_network_group']); ?>">
                                <label for="radmin_network_group">Radmin Network Group</label>
                            </div>
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" name="radmin_password" id="radmin_password" placeholder="Radmin Password" value="<?php echo htmlspecialchars($vpnData['radmin_password']); ?>">
                                <label for="radmin_password">Radmin Password</label>
                            </div>
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" name="radmin_master_host" id="radmin_master_host" placeholder="Radmin Master Host" value="<?php echo htmlspecialchars($vpnData['radmin_master_host']); ?>">
                                <label for="radmin_master_host">Radmin Master Host</label>
                            </div>
                        </div>
                    </div>

                    <!-- Hamachi VPN Configuration -->
                    <div class="card mb-3 vpn-card" id="hamachiCard">
                        <div class="card-header">
                            Hamachi VPN Configuration
                        </div>
                        <div class="card-body">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" name="hamachi_tcp_ip" id="hamachi_tcp_ip" placeholder="Hamachi TCP/IP" value="<?php echo htmlspecialchars($vpnData['hamachi_tcp_ip']); ?>">
                                <label for="hamachi_tcp_ip">Hamachi TCP/IP</label>
                            </div>
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" name="hamachi_network_group" id="hamachi_network_group" placeholder="Hamachi Network Group" value="<?php echo htmlspecialchars($vpnData['hamachi_network_group']); ?>">
                                <label for="hamachi_network_group">Hamachi Network Group</label>
                            </div>
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" name="hamachi_master_host" id="hamachi_master_host" placeholder="Hamachi Master Host" value="<?php echo htmlspecialchars($vpnData['hamachi_master_host']); ?>">
                                <label for="hamachi_master_host">Hamachi Master Host</label>
                            </div>
                        </div>
                    </div>

                    <!-- PC Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">PC Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row mb-3">
                                <div class="col-12">
                                    <label for="installed_pc" class="form-label">Installed PC:</label>
                                    <select class="form-control" id="installed_pc" name="installed_pc">
                                        <option value="">Select Installed PC</option>
                                        <?php foreach ($installedPcOptions as $pc): ?>
                                            <option value="<?php echo htmlspecialchars($pc); ?>" <?php if ($vpnData['installed_pc'] == $pc) echo 'selected'; ?>><?php echo htmlspecialchars($pc); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Others Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Others Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="others" name="others" placeholder="Others" rows="3"><?php echo htmlspecialchars($vpnData['others']); ?></textarea>
                                <label for="others">Others</label>
                            </div>
                        </div>
                    </div>

                    <!-- Save Button -->
                    <div class="row">
                        <div class="col-12 text-center">
                            <button type="submit" class="btn btn-primary">Update</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        $(document).ready(function() {
            function showCard(cardId) {
                console.log('Showing card: ' + cardId);
                var cards = ['forticlientCard', 'ciscoMerakiCard', 'radminCard', 'hamachiCard'];
                cards.forEach(function(id) {
                    if (id === cardId) {
                        $('#' + id).show();
                    } else {
                        $('#' + id).hide();
                        // Clear input fields of other cards
                        $('#' + id + ' input').val('');
                        $('#' + id + ' textarea').val('');
                    }
                });
                // Store the selected card's ID in the hidden input
                $('#selectedCard').val(cardId);

                // Set the vpn_type based on the selected card
                var vpnTypeMap = {
                    'forticlientCard': 'FortiClient',
                    'ciscoMerakiCard': 'Cisco Meraki',
                    'radminCard': 'Radmin',
                    'hamachiCard': 'Hamachi'
                };
                $('#vpn_type').val(vpnTypeMap[cardId]);
            }

            // Initial check on page load
            var initialCard = $('#vpnSelection').val(); // Get the initial selected card from the dropdown
            showCard(initialCard);

            // Handle dropdown change
            $('#vpnSelection').on('change', function() {
                var selectedCard = $(this).val();
                showCard(selectedCard);
            });

            // Check cards on input change, only for VPN cards
            $('.vpn-card input, .vpn-card textarea').on('input', function() {
                var cardId = $(this).closest('.card').attr('id');
                showCard(cardId);
            });

            // Ensure "Active" checkbox does not affect VPN card visibility
            $('#active').on('change', function() {
                // Do nothing here
            });
        });
    </script>
</body>
</html>

