<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if debtor_code and item_type_pc_id are passed via URL
if (!isset($_GET['debtor_code']) || !isset($_GET['item_type_pc_id'])) {
    echo "<p>No debtor code or PC ID provided.</p>";
    exit;
}

$debtorCode = $_GET['debtor_code'];
$pcId = $_GET['item_type_pc_id'];

// Fetch the PC details based on debtor_code and item_type_pc_id
$stmt = $pdo->prepare('SELECT * FROM item_type_pc WHERE debtor_code = :debtor_code AND item_type_pc_id = :item_type_pc_id LIMIT 1');
$stmt->execute([':debtor_code' => $debtorCode, ':item_type_pc_id' => $pcId]);
$pc = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$pc) {
    echo "<p>No PC found with the provided ID.</p>";
    exit;
}

// Decrypt the sensitive fields
$encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

if (!empty($pc['login_password'])) {
    $pc['login_password'] = decryptPassword($pc['login_password'], $encryptionKey);
}

if (!empty($pc['pc_email_password'])) {
    $pc['pc_email_password'] = decryptPassword($pc['pc_email_password'], $encryptionKey);
}

if (!empty($pc['windows_product_key'])) {
    $pc['windows_product_key'] = decryptPassword($pc['windows_product_key'], $encryptionKey);
}

// Fetch customer usernames based on debtor_code
$customerUsernames = [];
if (!empty($debtorCode)) {
    $stmt = $pdo->prepare("SELECT customer_username FROM customer_info WHERE debtor_code = :debtor_code");
    $stmt->execute([':debtor_code' => $debtorCode]);
    $customerUsernames = $stmt->fetchAll(PDO::FETCH_COLUMN);
}

// Fetch client_account_id from item_type_sw table for 365 Licence dropdown
$clientAccountIds = [];
if (!empty($debtorCode)) {
    $stmt = $pdo->prepare("SELECT client_account_id FROM item_type_sw WHERE debtor_code = :debtor_code AND item_type_sw_group_name = 'Office 365 Client Account'");
    $stmt->execute([':debtor_code' => $debtorCode]);
    $clientAccountIds = $stmt->fetchAll(PDO::FETCH_COLUMN);
}

// Fetch the current Office 365 license and client_account_id linked to this PC
$stmt = $pdo->prepare('SELECT o365_license, client_account_id FROM installed_pc_for_office365_client WHERE item_type_pc_id = :item_type_pc_id LIMIT 1');
$stmt->execute([':item_type_pc_id' => $pcId]);
$currentO365License = $stmt->fetch(PDO::FETCH_ASSOC);

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $active = isset($_POST['active']) ? 1 : 0;
    $processor = htmlspecialchars($_POST['processor']);
    $harddisk_type = htmlspecialchars(implode(',', $_POST['harddisk_type']));
    $harddisk_space = htmlspecialchars(implode(',', $_POST['harddisk_space']));
    $harddisk_total_unit = htmlspecialchars($_POST['harddisk_total_unit']);
    $ram_type = htmlspecialchars($_POST['ram_type']);
    $ram_gb = htmlspecialchars($_POST['ram_gb']);
    $ram_total_unit = htmlspecialchars($_POST['ram_total_unit']);
    $computer_name = htmlspecialchars($_POST['computer_name']);
    $os_version = htmlspecialchars($_POST['os_version']);
    $domain = htmlspecialchars($_POST['domain']);
    $login_id = htmlspecialchars($_POST['login_id']);
    $login_password = htmlspecialchars($_POST['login_password']); // Plaintext from form
    $customer_username = htmlspecialchars($_POST['customer_username']);
    $tcp_ip = htmlspecialchars($_POST['tcp_ip']);
    $subnet_mask = htmlspecialchars($_POST['subnet_mask']);
    $gateway = htmlspecialchars($_POST['gateway']);
    $dns = htmlspecialchars($_POST['dns']);
    $part_no = htmlspecialchars($_POST['part_no']);
    $serial_number = htmlspecialchars($_POST['serial_number']);
    $purchase_date = htmlspecialchars($_POST['purchase_date']);
    $warranty_expire_date = htmlspecialchars($_POST['warranty_expire_date']);
    $user_email = htmlspecialchars($_POST['user_email']);
    $others = htmlspecialchars($_POST['others']);
    $pc_email_account = htmlspecialchars($_POST['pc_email_account']);
    $pc_email_password = htmlspecialchars($_POST['pc_email_password']);
    $pin = htmlspecialchars($_POST['pin']);
    $brand = htmlspecialchars($_POST['brand']);
    $model = htmlspecialchars($_POST['model']);
    $windows_product_key = htmlspecialchars($_POST['windows_product_key']);
    $office365 = htmlspecialchars($_POST['office_365'] ?? ''); // Added field

    // Fetch company_name from customer_info table based on debtor_code
    $stmt = $pdo->prepare('SELECT company_name FROM customer_info WHERE debtor_code = :debtor_code LIMIT 1');
    $stmt->execute([':debtor_code' => $debtorCode]);
    $companyName = $stmt->fetchColumn();

    // Encrypt the sensitive fields before saving
    if (!empty($login_password)) {
        $login_password = encryptPassword($login_password, $encryptionKey);
    }

    if (!empty($pc_email_password)) {
        $pc_email_password = encryptPassword($pc_email_password, $encryptionKey);
    }

    if (!empty($windows_product_key)) {
        $windows_product_key = encryptPassword($windows_product_key, $encryptionKey);
    }

    // Store the old data for logging
    $oldData = $pc;
    $oldO365License = $currentO365License['o365_license'] ?? null;
    $oldClientAccountId = $currentO365License['client_account_id'] ?? null;

    // Update the PC in the database
    $stmt = $pdo->prepare('UPDATE item_type_pc SET 
        active = :active, 
        processor = :processor, 
        harddisk_type = :harddisk_type, 
        harddisk_space = :harddisk_space, 
        harddisk_total_unit = :harddisk_total_unit, 
        ram_type = :ram_type, 
        ram_gb = :ram_gb, 
        ram_total_unit = :ram_total_unit, 
        computer_name = :computer_name, 
        os_version = :os_version,
        domain = :domain, 
        login_id = :login_id, 
        login_password = :login_password, 
        customer_username = :customer_username, 
        tcp_ip = :tcp_ip, 
        subnet_mask = :subnet_mask, 
        gateway = :gateway, 
        dns = :dns, 
        part_no = :part_no, 
        serial_number = :serial_number, 
        purchase_date = :purchase_date, 
        warranty_expire_date = :warranty_expire_date, 
        user_email = :user_email, 
        others = :others, 
        pc_email_account = :pc_email_account, 
        pc_email_password = :pc_email_password, 
        pin = :pin,
        brand = :brand,
        model = :model,
        windows_product_key = :windows_product_key,
        office_365 = :office_365
        WHERE debtor_code = :debtor_code AND item_type_pc_id = :item_type_pc_id');

    $success = $stmt->execute([
        ':active' => $active,
        ':processor' => $processor,
        ':harddisk_type' => $harddisk_type,
        ':harddisk_space' => $harddisk_space,
        ':harddisk_total_unit' => $harddisk_total_unit,
        ':ram_type' => $ram_type,
        ':ram_gb' => $ram_gb,
        ':ram_total_unit' => $ram_total_unit,
        ':computer_name' => $computer_name,
        ':os_version' => $os_version,
        ':domain' => $domain,
        ':login_id' => $login_id,
        ':login_password' => $login_password,
        ':customer_username' => $customer_username,
        ':tcp_ip' => $tcp_ip,
        ':subnet_mask' => $subnet_mask,
        ':gateway' => $gateway,
        ':dns' => $dns,
        ':part_no' => $part_no,
        ':serial_number' => $serial_number,
        ':purchase_date' => $purchase_date,
        ':warranty_expire_date' => $warranty_expire_date,
        ':user_email' => $user_email,
        ':others' => $others,
        ':pc_email_account' => $pc_email_account,
        ':pc_email_password' => $pc_email_password,
        ':pin' => $pin,
        ':brand' => $brand,
        ':model' => $model,
        ':windows_product_key' => $windows_product_key,
        ':office_365' => $office365,
        ':debtor_code' => $debtorCode,
        ':item_type_pc_id' => $pcId
    ]);

    if ($success) {
        // Handle Office 365 license removal or update
        $o365LicenseChanged = false;
        if (empty($office365)) {
            // If "Remove License" is selected, delete the Office 365 license record
            if ($currentO365License) {
                $stmt = $pdo->prepare('DELETE FROM installed_pc_for_office365_client WHERE item_type_pc_id = :item_type_pc_id');
                $stmt->execute([':item_type_pc_id' => $pcId]);
                $o365LicenseChanged = true;
            }
        } else {
            // If a license is selected, fetch the item_type_sw_id for the selected client_account_id
            $stmt = $pdo->prepare('SELECT item_type_sw_id FROM item_type_sw WHERE client_account_id = :client_account_id LIMIT 1');
            $stmt->execute([':client_account_id' => $office365]);
            $itemTypeSwId = $stmt->fetchColumn();

            if ($itemTypeSwId) {
                if ($currentO365License) {
                    // Update the existing record
                    $stmt = $pdo->prepare('UPDATE installed_pc_for_office365_client SET o365_license = :o365_license, client_account_id = :client_account_id, item_type_sw_id = :item_type_sw_id, debtor_code = :debtor_code, computer_name = :computer_name, company_name = :company_name WHERE item_type_pc_id = :item_type_pc_id');
                    $stmt->execute([
                        ':o365_license' => $office365,
                        ':client_account_id' => $office365,
                        ':item_type_sw_id' => $itemTypeSwId,
                        ':debtor_code' => $debtorCode,
                        ':computer_name' => $computer_name,
                        ':company_name' => $companyName,
                        ':item_type_pc_id' => $pcId
                    ]);
                } else {
                    // Insert a new record
                    $stmt = $pdo->prepare('INSERT INTO installed_pc_for_office365_client (item_type_pc_id, o365_license, client_account_id, item_type_sw_id, debtor_code, computer_name, company_name) VALUES (:item_type_pc_id, :o365_license, :client_account_id, :item_type_sw_id, :debtor_code, :computer_name, :company_name)');
                    $stmt->execute([
                        ':item_type_pc_id' => $pcId,
                        ':o365_license' => $office365,
                        ':client_account_id' => $office365,
                        ':item_type_sw_id' => $itemTypeSwId,
                        ':debtor_code' => $debtorCode,
                        ':computer_name' => $computer_name,
                        ':company_name' => $companyName
                    ]);
                }
                $o365LicenseChanged = true;
            } else {
                // If no item_type_sw_id is found, show an error
                echo '<script type="text/javascript">';
                echo 'alert("Invalid Office 365 license selected. Please try again.");';
                echo '</script>';
                exit;
            }
        }

        // Fetch the new data after the update
        $stmt = $pdo->prepare('SELECT * FROM item_type_pc WHERE debtor_code = :debtor_code AND item_type_pc_id = :item_type_pc_id LIMIT 1');
        $stmt->execute([':debtor_code' => $debtorCode, ':item_type_pc_id' => $pcId]);
        $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

        // Decrypt the new data for comparison
        if (!empty($newItem['login_password'])) {
            $newItem['login_password'] = decryptPassword($newItem['login_password'], $encryptionKey);
        }

        if (!empty($newItem['pc_email_password'])) {
            $newItem['pc_email_password'] = decryptPassword($newItem['pc_email_password'], $encryptionKey);
        }

        if (!empty($newItem['windows_product_key'])) {
            $newItem['windows_product_key'] = decryptPassword($newItem['windows_product_key'], $encryptionKey);
        }

        // Check if any data has changed
        $hasChanges = false;
        foreach ($oldData as $key => $value) {
            if (in_array($key, ['login_password', 'pc_email_password', 'windows_product_key'])) {
                // Only compare if the form field is not empty
                if (!empty($_POST[$key]) && $newItem[$key] !== $value) {
                    $hasChanges = true;
                    break;
                }
            } else {
                // Compare other fields normally
                if ($newItem[$key] !== $value) {
                    $hasChanges = true;
                    break;
                }
            }
        }

        // Include Office 365 license and client_account_id change in the check
        if ($o365LicenseChanged || $office365 !== $oldO365License || ($office365 !== $oldClientAccountId)) {
            $hasChanges = true;
        }

        if ($hasChanges) {
            // Build the log message with only the fields that have changed, including plaintext passwords
            $logMessage = "Data change in PC item (Debtor Code: $debtorCode):\n";
            foreach ($oldData as $key => $value) {
                if (in_array($key, ['login_password', 'pc_email_password', 'windows_product_key'])) {
                    // Only compare if the form field is not empty
                    if (!empty($_POST[$key]) && $newItem[$key] !== $value) {
                        $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                    }
                } else {
                    // Compare other fields normally
                    if ($newItem[$key] !== $value) {
                        $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                    }
                }
            }

            // Log Office 365 license and client_account_id change
            if ($o365LicenseChanged || $office365 !== $oldO365License || ($office365 !== $oldClientAccountId)) {
                $logMessage .= "Office 365 License: $oldO365License -> $office365\n";
                $logMessage .= "Client Account ID: $oldClientAccountId -> $office365\n";
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="view_pc_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        } else {
            // No data changed, show alert
            echo '<script type="text/javascript">';
            echo 'alert("No data changed.");';
            echo 'window.location.href="view_pc_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        }
    } else {
        // If update failed, show error message
        echo '<script type="text/javascript">';
        echo 'alert("Failed to update. Please try again.");';
        echo '</script>';
    }
}

// Split hard disk type and space into arrays
$harddisk_types = explode(',', $pc['harddisk_type']);
$harddisk_spaces = explode(',', $pc['harddisk_space']);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit PC Details</title>
    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit PC Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                <input type="hidden" name="item_type_pc_id" value="<?= htmlspecialchars($pcId) ?>">

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $pc['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- Customer Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Customer Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select name="customer_username" id="customer_username" class="form-select">
                                        <option value="">Select Customer Username</option>
                                        <?php foreach ($customerUsernames as $username): ?>
                                            <option value="<?php echo htmlspecialchars($username); ?>" <?php if ($pc['customer_username'] == $username) echo 'selected'; ?>><?php echo htmlspecialchars($username); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="customer_username">Customer Username</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

             <!-- 365 Licence Dropdown -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">365 Licence</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                <select name="office_365" id="office_365" class="form-select">
                                        <option value="">No License</option>
                                        <?php foreach ($clientAccountIds as $clientAccountId): ?>
                                            <option value="<?php echo htmlspecialchars($clientAccountId); ?>" <?php if (($currentO365License['o365_license'] ?? '') == $clientAccountId) echo 'selected'; ?>>
                                                <?php echo htmlspecialchars($clientAccountId); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                    <label for="office_365">365 Licence</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Hardware Specifications -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Hardware Specifications</h5>
                    </div>
                    <div class="card-body">
                        <div class="card mb-3">
                            <div class="card-header">
                                <h5 class="mb-0">Brand and Model</h5>
                            </div>
                            <div class="card-body">
                                <div class="row g-3">
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="brand" id="brand" class="form-control" placeholder="Brand" value="<?= htmlspecialchars($pc['brand'] ?? '') ?>">
                                            <label for="brand">Brand</label>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="model" id="model" class="form-control" placeholder="Model" value="<?= htmlspecialchars($pc['model'] ?? '') ?>">
                                            <label for="model">Model</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <!-- Processor Card -->
                        <div class="card mb-3">
                            <div class="card-header">
                                <h6 class="mb-0">Processor</h6>
                            </div>
                            <div class="card-body">
                                <div class="row g-3">
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="processor" id="processor" class="form-control" placeholder="Processor" value="<?= htmlspecialchars($pc['processor'] ?? '') ?>">
                                            <label for="processor">Processor</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <!-- Hard Disk Card -->
                        <div class="card mb-3">
                            <div class="card-header">
                                <h6 class="mb-0">Hard Disk</h6>
                            </div>
                            <div class="card-body">
                                <div class="row g-3">
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="harddisk_total_unit" id="harddisk_total_unit" class="form-control" placeholder="Hard Disk Total Unit" value="<?= htmlspecialchars($pc['harddisk_total_unit'] ?? '') ?>">
                                            <label for="harddisk_total_unit">Hard Disk Total Unit</label>
                                        </div>
                                    </div>
                                    <div id="hardDiskContainer">
                                        <?php foreach ($harddisk_types as $index => $type) : ?>
                                            <div class="input-group mb-3">
                                                <!-- Hard Disk Type -->
                                                <div class="form-floating">
                                                    <input type="text" name="harddisk_type[]" class="form-control" id="harddisk_type<?= $index ?>" placeholder="Type" value="<?= htmlspecialchars($type) ?>">
                                                    <label for="harddisk_type<?= $index ?>">Type</label>
                                                </div>
                                                <!-- Hard Disk Space -->
                                                <div class="form-floating">
                                                    <input type="text" name="harddisk_space[]" class="form-control" id="harddisk_space<?= $index ?>" placeholder="Space" value="<?= htmlspecialchars($harddisk_spaces[$index] ?? '') ?>">
                                                    <label for="harddisk_space<?= $index ?>">Space</label>
                                                </div>
                                                <!-- Remove Button -->
                                                <button type="button" class="btn btn-secondary" onclick="removeHardDisk(this)">Remove</button>
                                            </div>
                                        <?php endforeach; ?>
                                    </div>
                                </div>
                                <button type="button" class="btn btn-primary" onclick="hardDisk()">Add</button>
                            </div>
                        </div>

                        <!-- RAM Card -->
                        <div class="card mb-3">
                            <div class="card-header">
                                <h6 class="mb-0">RAM</h6>
                            </div>
                            <div class="card-body">
                                <div class="row g-3">
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="ram_type" id="ram_type" class="form-control" placeholder="RAM Type" value="<?= htmlspecialchars($pc['ram_type'] ?? '') ?>">
                                            <label for="ram_type">RAM Type</label>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="ram_gb" id="ram_gb" class="form-control" placeholder="RAM GB" value="<?= htmlspecialchars($pc['ram_gb'] ?? '') ?>">
                                            <label for="ram_gb">RAM GB</label>
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-floating">
                                            <input type="text" name="ram_total_unit" id="ram_total_unit" class="form-control" placeholder="RAM Total Unit" value="<?= htmlspecialchars($pc['ram_total_unit'] ?? '') ?>">
                                            <label for="ram_total_unit">RAM Total Unit</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                 <!-- OS Information -->
                 <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Computer Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="computer_name" id="computer_name" class="form-control" placeholder="Computer Name" value="<?= htmlspecialchars($pc['computer_name'] ?? '') ?>">
                                    <label for="computer_name">Computer Name</label>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="domain" id="domain" class="form-control" placeholder="Domain" value="<?= htmlspecialchars($pc['domain'] ?? '') ?>">
                                    <label for="domain">Domain</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="os_version" id="os_version" class="form-control" placeholder="OS Version" value="<?= htmlspecialchars($pc['os_version'] ?? '') ?>">
                                    <label for="os_version">OS Version</label>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="windows_product_key" id="windows_product_key" class="form-control" placeholder="OS PID" value="<?= htmlspecialchars($pc['windows_product_key'] ?? '') ?>">
                                    <label for="windows_product_key">Windows Product Key</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Network Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Network Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="tcp_ip" id="tcp_ip" class="form-control" placeholder="TCP/IP" value="<?= htmlspecialchars($pc['tcp_ip'] ?? '') ?>">
                                    <label for="tcp_ip">TCP/IP</label>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="subnet_mask" id="subnet_mask" class="form-control" placeholder="Subnet Mask" value="<?= htmlspecialchars($pc['subnet_mask'] ?? '') ?>">
                                    <label for="subnet_mask">Subnet Mask</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="gateway" id="gateway" class="form-control" placeholder="Gateway" value="<?= htmlspecialchars($pc['gateway'] ?? '') ?>">
                                    <label for="gateway">Gateway</label>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="dns" id="dns" class="form-control" placeholder="DNS" value="<?= htmlspecialchars($pc['dns'] ?? '') ?>">
                                    <label for="dns">DNS</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Login and Admin Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Login and Admin Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="login_id" id="login_id" class="form-control" placeholder="Login ID" value="<?= htmlspecialchars($pc['login_id'] ?? '') ?>">
                                    <label for="login_id">Login ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="login_password" id="login_password" class="form-control" placeholder="Login Password" value="<?= htmlspecialchars($pc['login_password'] ?? '') ?>">
                                    <label for="login_password">Login Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Purchase and Warranty Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Purchase and Warranty Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="part_no" id="part_no" class="form-control" placeholder="Part No" value="<?= htmlspecialchars($pc['part_no'] ?? '') ?>">
                                    <label for="part_no">Part No</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="serial_number" id="serial_number" class="form-control" placeholder="Serial Number" value="<?= htmlspecialchars($pc['serial_number'] ?? '') ?>">
                                    <label for="serial_number">Serial Number</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="date" name="purchase_date" id="purchase_date" class="form-control" value="<?= htmlspecialchars($pc['purchase_date'] ?? '') ?>">
                                    <label for="purchase_date">Purchase Date</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="date" name="warranty_expire_date" id="warranty_expire_date" class="form-control" value="<?= htmlspecialchars($pc['warranty_expire_date'] ?? '') ?>">
                                    <label for="warranty_expire_date">Warranty Expire Date</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Email Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Email Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="email" name="user_email" id="user_email" class="form-control" placeholder="User Email" value="<?= htmlspecialchars($pc['user_email'] ?? '') ?>">
                                    <label for="user_email">User Email</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating">
                            <textarea id="others" name="others" class="form-control" placeholder="Others"><?= htmlspecialchars($pc['others'] ?? '') ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- PC Email Fields -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Windows Home Configuration</h5>
                    </div>
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="pc_email_account" id="pc_email_account" class="form-control" placeholder="PC Email Account" value="<?= htmlspecialchars($pc['pc_email_account'] ?? '') ?>">
                                    <label for="pc_email_account">PC Email Account</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="pc_email_password" id="pc_email_password" class="form-control" placeholder="PC Email Password" value="<?= htmlspecialchars($pc['pc_email_password'] ?? '') ?>">
                                    <label for="pc_email_password">PC Email Password</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="pin" id="pin" class="form-control" placeholder="PIN" value="<?= htmlspecialchars($pc['pin'] ?? '') ?>">
                                    <label for="pin">PIN</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <div class="row">
                    <div class="col-md-12">
                        <button type="submit" class="btn btn-primary">Save</button>
                    </div>
                </div>
            </form>
        </div>
    </div>
</div>

<!-- Script for Adding Hard Disk Fields -->
<script>
function hardDisk() {
    const container = document.getElementById('hardDiskContainer');

    const rowDiv = document.createElement('div');
    rowDiv.className = 'input-group mb-2';

    const input1 = document.createElement('div');
    input1.className = 'form-floating';
    input1.innerHTML = `
        <input type="text" name="harddisk_type[]" class="form-control" placeholder="Type">
        <label>Type</label>
    `;

    const input2 = document.createElement('div');
    input2.className = 'form-floating';
    input2.innerHTML = `
        <input type="text" name="harddisk_space[]" class="form-control" placeholder="Space">
        <label>Space</label>
    `;

    const removeButton = document.createElement('button');
    removeButton.type = 'button';
    removeButton.className = 'btn btn-secondary';
    removeButton.innerText = 'Remove';
    removeButton.onclick = function () {
        removeHardDisk(removeButton);
    };

    rowDiv.appendChild(input1);
    rowDiv.appendChild(input2);
    rowDiv.appendChild(removeButton);

    container.appendChild(rowDiv);
}

function removeHardDisk(button) {
    const container = document.getElementById('hardDiskContainer');
    const hardDiskFields = container.querySelectorAll('.input-group');

    // Check if there's only one hard disk field left
    if (hardDiskFields.length === 1) {
        alert('The last hard disk field cannot be removed.');
        return; // Prevent removal
    }

    // Remove the field
    const rowDiv = button.parentElement;
    rowDiv.remove();
}
</script>

<!-- Bootstrap 5 JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>

