<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Encryption key (must match the key used in encrypt.php)
$encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

// Check if debtor_code and item_type_pos_hw_aio_pc_id are passed via URL
if (!isset($_GET['debtor_code']) || !isset($_GET['item_type_pos_hw_aio_pc_id'])) {
    echo "<p>No debtor code or AIO PC ID provided.</p>";
    exit;
}

$debtorCode = $_GET['debtor_code'];
$aioPcId = $_GET['item_type_pos_hw_aio_pc_id'];

// Fetch the AIO PC details based on debtor_code and item_type_pos_hw_aio_pc_id
$stmt = $pdo->prepare('SELECT * FROM item_type_pos_hw_aio_pc WHERE debtor_code = :debtor_code AND item_type_pos_hw_aio_pc_id = :item_type_pos_hw_aio_pc_id LIMIT 1');
$stmt->execute([':debtor_code' => $debtorCode, ':item_type_pos_hw_aio_pc_id' => $aioPcId]);
$aioPc = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$aioPc) {
    echo "<p>No AIO PC found with the provided ID.</p>";
    exit;
}

// Decrypt the login_password
if (!empty($aioPc['login_password'])) {
    $decryptedPassword = decryptPassword($aioPc['login_password'], $encryptionKey);
    if ($decryptedPassword !== null) {
        $aioPc['login_password'] = $decryptedPassword; // Replace encrypted password with plaintext for display
    } else {
        echo "<p>Failed to decrypt the password. Please check the decryption key or the encrypted data.</p>";
        exit;
    }
} else {
    $aioPc['login_password'] = '';
}

// Split hard disk type and space into arrays
$harddisk_types = explode(',', $aioPc['harddisk_type']);
$harddisk_spaces = explode(',', $aioPc['harddisk_space']);

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // Validate and sanitize input data
        $active = isset($_POST['active']) ? 1 : 0; // Handle checkbox properly
        $processor = htmlspecialchars($_POST['processor']);
        $harddisk_type = htmlspecialchars(implode(',', $_POST['harddisk_type'])); // Convert array to string
        $harddisk_space = htmlspecialchars(implode(',', $_POST['harddisk_space'])); // Convert array to string
        $harddisk_total_unit = htmlspecialchars($_POST['harddisk_total_unit']);
        $ram_type = htmlspecialchars($_POST['ram_type']);
        $ram_gb = htmlspecialchars($_POST['ram_gb']);
        $ram_total_unit = htmlspecialchars($_POST['ram_total_unit']);
        $computer_name = htmlspecialchars($_POST['computer_name']);
        $login_id = htmlspecialchars($_POST['login_id']);
        $login_password = htmlspecialchars($_POST['login_password']);
        $os_version = htmlspecialchars($_POST['os_version']);
        $tcp_ip = htmlspecialchars($_POST['tcp_ip']);
        $subnet_mask = htmlspecialchars($_POST['subnet_mask']);
        $gateway = htmlspecialchars($_POST['gateway']);
        $dns = htmlspecialchars($_POST['dns']);
        $installed_ac_software = htmlspecialchars($_POST['installed_ac_software']);
        $part_no = htmlspecialchars($_POST['part_no']);
        $brand = htmlspecialchars($_POST['brand']);
        $model = htmlspecialchars($_POST['model']);
        $serial_number = htmlspecialchars($_POST['serial_number']);
        $purchase_date = htmlspecialchars($_POST['purchase_date']);
        $warranty_expire_date = htmlspecialchars($_POST['warranty_expire_date']);
        $others = htmlspecialchars($_POST['others']);

        // Encrypt the login_password before saving to the database
        $encryptedPassword = encryptPassword($login_password, $encryptionKey);

        // Compare old and new values to detect changes
        $hasChanges = false;
        $changedFields = [];

        // Compare all fields including decrypted login_password
        foreach ($aioPc as $key => $value) {
            if ($key === 'login_password') {
                if ($value !== $login_password) {
                    $hasChanges = true;
                    $changedFields[$key] = [$value, $login_password];
                }
            } elseif (isset($_POST[$key])) {
                // Handle harddisk_type and harddisk_space as strings
                if ($key === 'harddisk_type' || $key === 'harddisk_space') {
                    $newValue = implode(',', $_POST[$key]); // Convert array to string
                    if ($value !== $newValue) {
                        $hasChanges = true;
                        $changedFields[$key] = [$value, $newValue];
                    }
                } else {
                    // For other fields, compare directly
                    if ($_POST[$key] != $value) {
                        $hasChanges = true;
                        $changedFields[$key] = [$value, $_POST[$key]];
                    }
                }
            } else {
                // Handle fields not present in $_POST (e.g., active field)
                if ($key === 'active' && $value != $active) {
                    $hasChanges = true;
                    $changedFields[$key] = [$value, $active];
                }
            }
        }

        if (!$hasChanges) {
            // No changes were made, display alert and redirect back
            echo '<script type="text/javascript">';
            echo 'alert("No changes made.");';
            echo 'window.location.href="view_pos_hardware_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
            exit;
        }

        // Update the AIO PC in the database
        $stmt = $pdo->prepare('UPDATE item_type_pos_hw_aio_pc SET active = :active, processor = :processor, harddisk_type = :harddisk_type, harddisk_space = :harddisk_space, harddisk_total_unit = :harddisk_total_unit, ram_type = :ram_type, ram_gb = :ram_gb, ram_total_unit = :ram_total_unit, computer_name = :computer_name, login_id = :login_id, login_password = :login_password, os_version = :os_version, tcp_ip = :tcp_ip, subnet_mask = :subnet_mask, gateway = :gateway, dns = :dns, installed_ac_software = :installed_ac_software, part_no = :part_no, brand = :brand, model = :model, serial_number = :serial_number, purchase_date = :purchase_date, warranty_expire_date = :warranty_expire_date, others = :others WHERE debtor_code = :debtor_code AND item_type_pos_hw_aio_pc_id = :item_type_pos_hw_aio_pc_id');
        $success = $stmt->execute([
            ':active' => $active,
            ':processor' => $processor,
            ':harddisk_type' => $harddisk_type,
            ':harddisk_space' => $harddisk_space,
            ':harddisk_total_unit' => $harddisk_total_unit,
            ':ram_type' => $ram_type,
            ':ram_gb' => $ram_gb,
            ':ram_total_unit' => $ram_total_unit,
            ':computer_name' => $computer_name,
            ':login_id' => $login_id,
            ':login_password' => $encryptedPassword, // Encrypted password
            ':os_version' => $os_version,
            ':tcp_ip' => $tcp_ip,
            ':subnet_mask' => $subnet_mask,
            ':gateway' => $gateway,
            ':dns' => $dns,
            ':installed_ac_software' => $installed_ac_software,
            ':part_no' => $part_no,
            ':brand' => $brand,
            ':model' => $model,
            ':serial_number' => $serial_number,
            ':purchase_date' => $purchase_date,
            ':warranty_expire_date' => $warranty_expire_date,
            ':others' => $others,
            ':debtor_code' => $debtorCode,
            ':item_type_pos_hw_aio_pc_id' => $aioPcId
        ]);

        if ($success) {
            // Log the changes
            $logMessage = "Data change in AIO PC (Debtor Code: $debtorCode):\n";
            foreach ($changedFields as $key => [$oldValue, $newValue]) {
                $logMessage .= "$key: $oldValue -> $newValue\n";
            }

            $stmtLog = $pdo->prepare("INSERT INTO activity_logs (username, timestamp, role, activity) VALUES (:username, :timestamp, :role, :activity)");
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="view_pos_hardware_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        } else {
            throw new Exception("Failed to update the AIO PC details.");
        }
    } catch (Exception $e) {
        echo '<script type="text/javascript">';
        echo 'alert("' . $e->getMessage() . '");';
        echo '</script>';
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit AIO PC Details</title>
    <!-- Bootstrap 5.x CSS with Floating Labels -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit AIO PC Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                <input type="hidden" name="item_type_pos_hw_id" value="<?= htmlspecialchars($aioPcId) ?>">

                <!-- Display the passed values -->
                <div class="mb-3">
                    <p>Company Name: <strong><?= htmlspecialchars($aioPc['company_name']) ?></strong></p>
                    <p>Item Type: <strong><?= htmlspecialchars($aioPc['item_type_name']) ?></strong></p>
                    <p>Item Type Group: <strong><?= htmlspecialchars($aioPc['item_type_pos_hw_group_name']) ?></strong></p>
                </div>
                
                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $aioPc['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- Login Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="computer_name" id="computer_name" class="form-control" value="<?= htmlspecialchars($aioPc['computer_name'] ?? '') ?>">
                                    <label for="computer_name">Computer Name</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_id" id="login_id" class="form-control" value="<?= htmlspecialchars($aioPc['login_id'] ?? '') ?>">
                                    <label for="login_id">Login ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login_password" id="login_password" class="form-control" value="<?= htmlspecialchars($aioPc['login_password'] ?? '') ?>">
                                    <label for="login_password">Login Password</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="os_version" id="os_version" class="form-control" value="<?= htmlspecialchars($aioPc['os_version'] ?? '') ?>">
                                    <label for="os_version">OS Version</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Network Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Network Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="tcp_ip" id="tcp_ip" class="form-control" value="<?= htmlspecialchars($aioPc['tcp_ip'] ?? '') ?>">
                                    <label for="tcp_ip">TCP/IP</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="subnet_mask" id="subnet_mask" class="form-control" value="<?= htmlspecialchars($aioPc['subnet_mask'] ?? '') ?>">
                                    <label for="subnet_mask">Subnet Mask</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="gateway" id="gateway" class="form-control" value="<?= htmlspecialchars($aioPc['gateway'] ?? '') ?>">
                                    <label for="gateway">Gateway</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="dns" id="dns" class="form-control" value="<?= htmlspecialchars($aioPc['dns'] ?? '') ?>">
                                    <label for="dns">DNS</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Hardware Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Hardware Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="brand" id="brand" class="form-control" value="<?= htmlspecialchars($aioPc['brand'] ?? '') ?>">
                                    <label for="brand">Brand</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="model" id="model" class="form-control" value="<?= htmlspecialchars($aioPc['model'] ?? '') ?>">
                                    <label for="model">Model</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="part_no" id="part_no" class="form-control" value="<?= htmlspecialchars($aioPc['part_no'] ?? '') ?>">
                                    <label for="part_no">Part No</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="serial_number" id="serial_number" class="form-control" value="<?= htmlspecialchars($aioPc['serial_number'] ?? '') ?>">
                                    <label for="serial_number">Serial Number</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Processor and Hard Disk Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Processor and Hard Disk Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="processor" id="processor" class="form-control" value="<?= htmlspecialchars($aioPc['processor'] ?? '') ?>">
                                    <label for="processor">Processor</label>
                                </div>
                                <div class="form-group">
                                    <label for="hardDisk">Hard Disk</label>
                                    <div class="input-group" id="hardDiskContainer">
                                        <?php foreach ($harddisk_types as $index => $type) : ?>
                                            <div class="input-group mb-2">
                                                <div class="form-floating">
                                                    <input type="text" name="harddisk_type[]" class="form-control" placeholder="Type" value="<?= htmlspecialchars($type) ?>">
                                                    <label for="harddisk_type_<?= $index ?>">Type</label>
                                                </div>
                                                <div class="form-floating">
                                                    <input type="text" name="harddisk_space[]" class="form-control" placeholder="Space" value="<?= htmlspecialchars($harddisk_spaces[$index] ?? '') ?>">
                                                    <label for="harddisk_space_<?= $index ?>">Space</label>
                                                </div>
                                                <button type="button" class="btn btn-secondary" onclick="removeHardDisk(this)">Remove</button>
                                            </div>
                                        <?php endforeach; ?>
                                    </div>
                                    <button type="button" class="btn btn-primary" onclick="addHardDisk()">Add Hard Disk</button>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="harddisk_total_unit" id="harddisk_total_unit" class="form-control" value="<?= htmlspecialchars($aioPc['harddisk_total_unit'] ?? '') ?>">
                                    <label for="harddisk_total_unit">Hard Disk Total Unit</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- RAM Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">RAM Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="ram_type" id="ram_type" class="form-control" value="<?= htmlspecialchars($aioPc['ram_type'] ?? '') ?>">
                                    <label for="ram_type">RAM Type</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="ram_gb" id="ram_gb" class="form-control" value="<?= htmlspecialchars($aioPc['ram_gb'] ?? '') ?>">
                                    <label for="ram_gb">RAM GB</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="ram_total_unit" id="ram_total_unit" class="form-control" value="<?= htmlspecialchars($aioPc['ram_total_unit'] ?? '') ?>">
                                    <label for="ram_total_unit">RAM Total Unit</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Installed AC Details -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Installed Autocount Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="installed_ac_software" id="installed_ac_software" class="form-control" value="<?= htmlspecialchars($aioPc['installed_ac_software'] ?? '') ?>">
                                    <label for="installed_ac_software">Installed AC Software</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Warranty Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Warranty Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" name="purchase_date" id="purchase_date" class="form-control" value="<?= htmlspecialchars($aioPc['purchase_date'] ?? '') ?>">
                                    <label for="purchase_date">Purchase Date</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" name="warranty_expire_date" id="warranty_expire_date" class="form-control" value="<?= htmlspecialchars($aioPc['warranty_expire_date'] ?? '') ?>">
                                    <label for="warranty_expire_date">Warranty Expire Date</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                    <!-- Others Information -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Others Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="others" name="others" placeholder="Others" rows="3"><?= htmlspecialchars($aioPc['others'] ?? '') ?></textarea>
                                <label for="others">Others</label>
                            </div>
                        </div>
                    </div>

                <!-- Save Button -->
                <div class="text-center">
                    <button type="submit" class="btn btn-primary">Save</button>
                </div>
            </form>
        </div>
    </div>
</div>

<script>
function addHardDisk() {
    const container = document.getElementById('hardDiskContainer');
    const index = container.querySelectorAll('.input-group').length;

    const inputGroup = document.createElement('div');
    inputGroup.className = 'input-group mb-2';
    inputGroup.innerHTML = `
        <div class="form-floating">
            <input type="text" name="harddisk_type[]" class="form-control" placeholder="Type">
            <label for="harddisk_type_${index}">Type</label>
        </div>
        <div class="form-floating">
            <input type="text" name="harddisk_space[]" class="form-control" placeholder="Space">
            <label for="harddisk_space_${index}">Space</label>
        </div>
        <button type="button" class="btn btn-secondary" onclick="removeHardDisk(this)">Remove</button>
    `;

    container.appendChild(inputGroup);
}

function removeHardDisk(button) {
    const container = document.getElementById('hardDiskContainer');
    const remainingFields = container.querySelectorAll('.input-group').length;

    if (remainingFields > 1) {
        button.closest('.input-group').remove();
    } else {
        alert("You must have at least one hard disk field.");
    }
}
</script>

<!-- Bootstrap 5.x JS with Floating Labels -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>