<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if debtor_code and item_type_pc_id are passed via URL
if (!isset($_GET['debtor_code']) || !isset($_GET['item_type_pc_id'])) {
    echo "<p>No debtor code or server ID provided.</p>";
    exit;
}

$debtorCode = $_GET['debtor_code'];
$serverId = $_GET['item_type_pc_id'];

// Fetch the server details based on debtor_code and item_type_pc_id
$stmt = $pdo->prepare('SELECT * FROM item_type_pc WHERE debtor_code = :debtor_code AND item_type_pc_id = :item_type_pc_id LIMIT 1');
$stmt->execute([':debtor_code' => $debtorCode, ':item_type_pc_id' => $serverId]);
$server = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$server) {
    echo "<p>No server found with the provided ID.</p>";
    exit;
}

// Decrypt the login_password, remote_user_password, ilo_password, and windows_product_key fields
$encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

if (!empty($server['login_password'])) {
    $server['login_password'] = decryptPassword($server['login_password'], $encryptionKey);
}

if (!empty($server['remote_user_password'])) {
    $server['remote_user_password'] = decryptPassword($server['remote_user_password'], $encryptionKey);
}

if (!empty($server['ilo_password'])) {
    $server['ilo_password'] = decryptPassword($server['ilo_password'], $encryptionKey);
}

if (!empty($server['windows_product_key'])) {
    $server['windows_product_key'] = decryptPassword($server['windows_product_key'], $encryptionKey);
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Validate and sanitize input data
    $active = isset($_POST['active']) ? 1 : 0;
    $processor = htmlspecialchars($_POST['processor']);
    $harddisk_type = htmlspecialchars(implode(',', $_POST['harddisk_type']));
    $harddisk_space = htmlspecialchars(implode(',', $_POST['harddisk_space']));
    $harddisk_total_unit = htmlspecialchars($_POST['harddisk_total_unit']);
    $ram_type = htmlspecialchars($_POST['ram_type']);
    $ram_gb = htmlspecialchars($_POST['ram_gb']);
    $ram_total_unit = htmlspecialchars($_POST['ram_total_unit']);
    $computer_name = htmlspecialchars($_POST['computer_name']);
    $domain = htmlspecialchars($_POST['domain']);
    $login_id = htmlspecialchars($_POST['login_id']);
    $login_password = htmlspecialchars($_POST['login_password']); // Plaintext from form
    $windowsProductKey = htmlspecialchars($_POST['windows_product_key']); // Plaintext from form
    $os_version = htmlspecialchars($_POST['os_version']);
    $tcp_ip = htmlspecialchars($_POST['tcp_ip']);
    $subnet_mask = htmlspecialchars($_POST['subnet_mask']);
    $gateway = htmlspecialchars($_POST['gateway']);
    $dns = htmlspecialchars($_POST['dns']);
    $is_autocount_main = isset($_POST['is_autocount_main']) ? 1 : 0;
    $is_remote = isset($_POST['is_remote']) ? 1 : 0;
    $is_hyper_v = isset($_POST['is_hyper_v']) ? 1 : 0;
    $folder = htmlspecialchars(implode(',', $_POST['folder']));
    $access_right = htmlspecialchars(implode(',', $_POST['access_right']));
    $access_user = htmlspecialchars(implode(',', $_POST['access_user']));
    $network_drive = htmlspecialchars(implode(',', $_POST['network_drive']));
    $remote_user = htmlspecialchars(implode(',', $_POST['remote_user']));
    $remote_user_password = htmlspecialchars(implode(',', $_POST['remote_user_password'])); // Plaintext from form
    $part_no = htmlspecialchars($_POST['part_no']);
    $serial_number = htmlspecialchars($_POST['serial_number']);
    $purchase_date = htmlspecialchars($_POST['purchase_date']);
    $warranty_expire_date = htmlspecialchars($_POST['warranty_expire_date']);
    $iloTcpIp = htmlspecialchars($_POST['ilo_tcp_ip']);
    $iloUsername = htmlspecialchars($_POST['ilo_username']);
    $iloPassword = htmlspecialchars($_POST['ilo_password']); // Plaintext from form
    $others = htmlspecialchars($_POST['others']);
    $brand = htmlspecialchars($_POST['brand']); // New field: Brand
    $model = htmlspecialchars($_POST['model']); // New field: Model

    // Encrypt sensitive fields before saving
    if (!empty($login_password)) {
        $login_password = encryptPassword($login_password, $encryptionKey);
    } else {
        // If password is not changed, use the old encrypted password
        $login_password = $server['login_password'];
    }

    if (!empty($remote_user_password)) {
        $remote_user_password = encryptPassword($remote_user_password, $encryptionKey);
    } else {
        // If password is not changed, use the old encrypted password
        $remote_user_password = $server['remote_user_password'];
    }

    if (!empty($iloPassword)) {
        $iloPassword = encryptPassword($iloPassword, $encryptionKey);
    } else {
        // If password is not changed, use the old encrypted password
        $iloPassword = $server['ilo_password'];
    }

    if (!empty($windowsProductKey)) {
        $windowsProductKey = encryptPassword($windowsProductKey, $encryptionKey);
    } else {
        // If product key is not changed, use the old encrypted key
        $windowsProductKey = $server['windows_product_key'];
    }

    // Store the old data for logging
    $oldData = $server;

    // Update the server in the database
    $stmt = $pdo->prepare('UPDATE item_type_pc SET 
        active = :active,
        processor = :processor,
        harddisk_type = :harddisk_type,
        harddisk_space = :harddisk_space,
        harddisk_total_unit = :harddisk_total_unit,
        ram_type = :ram_type,
        ram_gb = :ram_gb,
        ram_total_unit = :ram_total_unit,
        computer_name = :computer_name,
        domain = :domain,
        login_id = :login_id,
        login_password = :login_password,
        windows_product_key = :windows_product_key,
        os_version = :os_version,
        tcp_ip = :tcp_ip,
        subnet_mask = :subnet_mask,
        gateway = :gateway,
        dns = :dns,
        is_autocount_main = :is_autocount_main,
        is_remote = :is_remote,
        is_hyper_v = :is_hyper_v,
        folder = :folder,
        access_right = :access_right,
        access_user = :access_user,
        network_drive = :network_drive,
        remote_user = :remote_user,
        remote_user_password = :remote_user_password,
        part_no = :part_no,
        serial_number = :serial_number,
        purchase_date = :purchase_date,
        warranty_expire_date = :warranty_expire_date,
        ilo_tcp_ip = :ilo_tcp_ip,
        ilo_username = :ilo_username,
        ilo_password = :ilo_password,
        others = :others,
        brand = :brand, -- New field: Brand
        model = :model -- New field: Model
        WHERE debtor_code = :debtor_code AND item_type_pc_id = :item_type_pc_id');

    $success = $stmt->execute([
        ':active' => $active,
        ':processor' => $processor,
        ':harddisk_type' => $harddisk_type,
        ':harddisk_space' => $harddisk_space,
        ':harddisk_total_unit' => $harddisk_total_unit,
        ':ram_type' => $ram_type,
        ':ram_gb' => $ram_gb,
        ':ram_total_unit' => $ram_total_unit,
        ':computer_name' => $computer_name,
        ':domain' => $domain,
        ':login_id' => $login_id,
        ':login_password' => $login_password,
        ':windows_product_key' => $windowsProductKey,
        ':os_version' => $os_version,
        ':tcp_ip' => $tcp_ip,
        ':subnet_mask' => $subnet_mask,
        ':gateway' => $gateway,
        ':dns' => $dns,
        ':is_autocount_main' => $is_autocount_main,
        ':is_remote' => $is_remote,
        ':is_hyper_v' => $is_hyper_v,
        ':folder' => $folder,
        ':access_right' => $access_right,
        ':access_user' => $access_user,
        ':network_drive' => $network_drive,
        ':remote_user' => $remote_user,
        ':remote_user_password' => $remote_user_password,
        ':part_no' => $part_no,
        ':serial_number' => $serial_number,
        ':purchase_date' => $purchase_date,
        ':warranty_expire_date' => $warranty_expire_date,
        ':ilo_tcp_ip' => $iloTcpIp,
        ':ilo_username' => $iloUsername,
        ':ilo_password' => $iloPassword,
        ':others' => $others,
        ':brand' => $brand, // New field: Brand
        ':model' => $model, // New field: Model
        ':debtor_code' => $debtorCode,
        ':item_type_pc_id' => $serverId
    ]);

    if ($success) {
        // Fetch the new data after the update
        $stmt = $pdo->prepare('SELECT * FROM item_type_pc WHERE debtor_code = :debtor_code AND item_type_pc_id = :item_type_pc_id LIMIT 1');
        $stmt->execute([':debtor_code' => $debtorCode, ':item_type_pc_id' => $serverId]);
        $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

        // Decrypt the new data for comparison
        if (!empty($newItem['login_password'])) {
            $newItem['login_password'] = decryptPassword($newItem['login_password'], $encryptionKey);
        }

        if (!empty($newItem['remote_user_password'])) {
            $newItem['remote_user_password'] = decryptPassword($newItem['remote_user_password'], $encryptionKey);
        }

        if (!empty($newItem['ilo_password'])) {
            $newItem['ilo_password'] = decryptPassword($newItem['ilo_password'], $encryptionKey);
        }

        if (!empty($newItem['windows_product_key'])) {
            $newItem['windows_product_key'] = decryptPassword($newItem['windows_product_key'], $encryptionKey);
        }

        // Initialize variables
        $changesMade = false;
        $logMessage = "Data change in server item (Debtor Code: $debtorCode):\n";

        // Build the log message with only the fields that have changed, including plaintext passwords
        foreach ($oldData as $key => $value) {
            if ($key === 'login_password' || $key === 'remote_user_password' || $key === 'ilo_password' || $key === 'windows_product_key') {
                // Compare plaintext passwords and keys
                if ($newItem[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                    $changesMade = true;
                }
            } else {
                // Compare other fields normally
                if ($newItem[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                    $changesMade = true;
                }
            }
        }

        // Set alert message based on changes
        if ($changesMade) {
            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            $alertMessage = "Update successful!";
        } else {
            $alertMessage = "No changes made.";
        }

        // Show the alert message
        echo '<script type="text/javascript">';
        echo 'alert(' . json_encode($alertMessage) . ');';
        echo 'window.location.href="view_pc_table.php?debtor_code=' . urlencode($debtorCode) . '";';
        echo '</script>';
    } else {
        // If update failed, show error message
        echo '<script type="text/javascript">';
        echo 'alert("Failed to update. Please try again.");';
        echo '</script>';
    }
}

// Split hard disk type and space into arrays
$harddisk_types = explode(',', $server['harddisk_type']);
$harddisk_spaces = explode(',', $server['harddisk_space']);

// Split folder, access right, access user, network drive, remote user, and remote user password into arrays
$folders = explode(',', $server['folder']);
$access_rights = explode(',', $server['access_right']);
$access_users = explode(',', $server['access_user']);
$network_drives = explode(',', $server['network_drive']);
$remote_users = explode(',', $server['remote_user']);
$remote_user_passwords = explode(',', $server['remote_user_password']);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Server Details</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit Server Details</h1>
        </div>
        <div class="card-body">
            <form method="POST" action="">
                <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                <input type="hidden" name="item_type_pc_id" value="<?= htmlspecialchars($serverId) ?>">

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $server['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

               <!-- Hardware Specifications -->
            <div class="card mb-3">
                <div class="card-header">
                    <h5 class="mb-0">Hardware Specifications</h5>
                </div>
                <div class="card-body">
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="mb-0">Brand and Model</h5>
                        </div>
                        <div class="card-body">
                            <div class="row g-3">
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" name="brand" id="brand" class="form-control" placeholder="Brand" value="<?php echo htmlspecialchars($server['brand'] ?? ''); ?>">
                                        <label for="brand">Brand</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                <div class="form-floating">
                                    <input type="text" name="serial_number" id="serial_number" class="form-control" placeholder="Serial Number" value="<?= htmlspecialchars($server['serial_number'] ?? '') ?>">
                                    <label for="serial_number">Serial Number</label>
                                </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" name="model" id="model" class="form-control" placeholder="Model" value="<?php echo htmlspecialchars($server['model'] ?? ''); ?>">
                                        <label for="model">Model</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <!-- Processor Card -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h6 class="mb-0">Processor</h6>
                        </div>
                        <div class="card-body">
                            <div class="row g-3">
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" name="processor" id="processor" class="form-control" placeholder="Processor" value="<?= htmlspecialchars($server['processor'] ?? '') ?>">
                                        <label for="processor">Processor</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Hard Disk Card -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h6 class="mb-0">Hard Disk</h6>
                        </div>
                        <div class="card-body">
                            <div class="row g-3">
                            <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" name="harddisk_total_unit" id="harddisk_total_unit" class="form-control" placeholder="Hard Disk Total Unit" value="<?= htmlspecialchars($server['harddisk_total_unit'] ?? '') ?>">
                                        <label for="harddisk_total_unit">Hard Disk Total Unit</label>
                                    </div>
                                </div>
                                <div id="hardDiskContainer">
                                <?php foreach ($harddisk_types as $index => $type) : ?>
                                    <div class="input-group mb-3">
                                        <!-- Hard Disk Type -->
                                        <div class="form-floating">
                                            <input type="text" name="harddisk_type[]" class="form-control" id="harddisk_type<?= $index ?>" placeholder="Type" value="<?= htmlspecialchars($type) ?>">
                                            <label for="harddisk_type<?= $index ?>">Type</label>
                                        </div>
                                        <!-- Hard Disk Space -->
                                        <div class="form-floating">
                                            <input type="text" name="harddisk_space[]" class="form-control" id="harddisk_space<?= $index ?>" placeholder="Space" value="<?= htmlspecialchars($harddisk_spaces[$index] ?? '') ?>">
                                            <label for="harddisk_space<?= $index ?>">Space</label>
                                        </div>
                                        <!-- Remove Button -->
                                        <button type="button" class="btn btn-secondary" onclick="removeHardDisk(this)">Remove</button>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                        <button type="button" class="btn btn-primary" onclick="hardDisk()">Add</button>

                    </div>
                </div>

                    <!-- RAM Card -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h6 class="mb-0">RAM</h6>
                        </div>
                        <div class="card-body">
                            <div class="row g-3">
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" name="ram_type" id="ram_type" class="form-control" placeholder="RAM Type" value="<?= htmlspecialchars($server['ram_type'] ?? '') ?>">
                                        <label for="ram_type">RAM Type</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" name="ram_gb" id="ram_gb" class="form-control" placeholder="RAM GB" value="<?= htmlspecialchars($server['ram_gb'] ?? '') ?>">
                                        <label for="ram_gb">RAM GB</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" name="ram_total_unit" id="ram_total_unit" class="form-control" placeholder="RAM Total Unit" value="<?= htmlspecialchars($server['ram_total_unit'] ?? '') ?>">
                                        <label for="ram_total_unit">RAM Total Unit</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
              

                <!-- OS Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Computer Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="computer_name" id="computer_name" class="form-control" placeholder="Computer Name" value="<?= htmlspecialchars($server['computer_name'] ?? '') ?>">
                                    <label for="computer_name">Computer Name</label>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="domain" id="domain" class="form-control" placeholder="Domain" value="<?= htmlspecialchars($server['domain'] ?? '') ?>">
                                    <label for="domain">Domain</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="os_version" id="os_version" class="form-control" placeholder="OS Version" value="<?= htmlspecialchars($server['os_version'] ?? '') ?>">
                                    <label for="os_version">OS Version</label>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="windows_product_key" id="windows_product_key" class="form-control" placeholder="OS PID" value="<?= htmlspecialchars($server['windows_product_key'] ?? '') ?>">
                                    <label for="windows_product_key">Windows Product Key</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Network Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Network Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="tcp_ip" id="tcp_ip" class="form-control" placeholder="TCP/IP" value="<?= htmlspecialchars($server['tcp_ip'] ?? '') ?>">
                                    <label for="tcp_ip">TCP/IP</label>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="subnet_mask" id="subnet_mask" class="form-control" placeholder="Subnet Mask" value="<?= htmlspecialchars($server['subnet_mask'] ?? '') ?>">
                                    <label for="subnet_mask">Subnet Mask</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="gateway" id="gateway" class="form-control" placeholder="Gateway" value="<?= htmlspecialchars($server['gateway'] ?? '') ?>">
                                    <label for="gateway">Gateway</label>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="dns" id="dns" class="form-control" placeholder="DNS" value="<?= htmlspecialchars($server['dns'] ?? '') ?>">
                                    <label for="dns">DNS</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Network Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">ILO Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="ilo_tcp_ip" id="ilo_tcp_ip" class="form-control" placeholder="ILO TCP/IP" value="<?= htmlspecialchars($server['ilo_tcp_ip'] ?? '') ?>">
                                    <label for="ilo_tcp_ip">ILO TCP/IP</label>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="ilo_username" id="ilo_username" class="form-control" placeholder="ILO Username" value="<?= htmlspecialchars($server['ilo_username'] ?? '') ?>">
                                    <label for="ilo_username">ILO Username</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="ilo_password" id="gateway" class="form-control" placeholder="ILO Password" value="<?= htmlspecialchars($server['ilo_password'] ?? '') ?>">
                                    <label for="ilo_password">ILO Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Login and Admin Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Login and Admin Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="login_id" id="login_id" class="form-control" placeholder="Login ID" value="<?= htmlspecialchars($server['login_id'] ?? '') ?>">
                                    <label for="login_id">Login ID</label>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="login_password" id="login_password" class="form-control" placeholder="Login Password" value="<?= htmlspecialchars($server['login_password'] ?? '') ?>">
                                    <label for="login_password">Login Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Purchase and Warranty Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Purchase and Warranty Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="text" name="part_no" id="part_no" class="form-control" placeholder="Part No" value="<?= htmlspecialchars($server['part_no'] ?? '') ?>">
                                    <label for="part_no">Part No</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="date" name="purchase_date" id="purchase_date" class="form-control" placeholder="Purchase Date" value="<?= htmlspecialchars($server['purchase_date'] ?? '') ?>">
                                    <label for="purchase_date">Purchase Date</label>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <div class="form-floating">
                                    <input type="date" name="warranty_expire_date" id="warranty_expire_date" class="form-control" placeholder="Warranty Expire Date" value="<?= htmlspecialchars($server['warranty_expire_date'] ?? '') ?>">
                                    <label for="warranty_expire_date">Warranty Expire Date</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Remote and Hyper-V Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Remote and Hyper-V Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" name="is_autocount_main" id="is_autocount_main" value="1" <?= $server['is_autocount_main'] ? 'checked' : '' ?>>
                                    <label class="form-check-label" for="is_autocount_main">Is Autocount Main</label>
                                </div>
                            </div>
                        </div>
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" name="is_remote" id="is_remote" value="1" <?= $server['is_remote'] ? 'checked' : '' ?>>
                                    <label class="form-check-label" for="is_remote">Is Remote</label>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" name="is_hyper_v" id="is_hyper_v" value="1" <?= $server['is_hyper_v'] ? 'checked' : '' ?>>
                                    <label class="form-check-label" for="is_hyper_v">Is Hyper-V</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Folder and Access Rights -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Folder and Access Rights</h5>
                    </div>
                    <div class="card-body">
                        <div id="folderAndAccessRightsContainer">
                            <?php foreach ($folders as $index => $folder) : ?>
                                <div class="input-group mb-3">
                                    <div class="form-floating">
                                        <input type="text" name="folder[]" class="form-control" id="folder<?= $index ?>" placeholder="Folder" value="<?= htmlspecialchars($folder) ?>">
                                        <label for="folder<?= $index ?>">Folder</label>
                                    </div>
                                    <div class="form-floating">
                                        <input type="text" name="access_right[]" class="form-control" id="access_right<?= $index ?>" placeholder="Access Right" value="<?= htmlspecialchars($access_rights[$index] ?? '') ?>">
                                        <label for="access_right<?= $index ?>">Access Right</label>
                                    </div>
                                    <div class="form-floating">
                                        <input type="text" name="access_user[]" class="form-control" id="access_user<?= $index ?>" placeholder="Access User" value="<?= htmlspecialchars($access_users[$index] ?? '') ?>">
                                        <label for="access_user<?= $index ?>">Access User</label>
                                    </div>
                                    <div class="form-floating">
                                        <input type="text" name="network_drive[]" class="form-control" id="network_drive<?= $index ?>" placeholder="Network Drive" value="<?= htmlspecialchars($network_drives[$index] ?? '') ?>">
                                        <label for="network_drive<?= $index ?>">Network Drive</label>
                                    </div>
                                    <button type="button" class="btn btn-secondary" onclick="removeFolderAndAccessRights(this)">Remove</button>
                                </div>
                            <?php endforeach; ?>
                        </div>
                        <button type="button" onclick="folderAndAccessRights()" class="btn btn-primary">Add</button>
                    </div>
                </div>

                <!-- Remote User Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Remote User Information</h5>
                    </div>
                    <div class="card-body">
                        <div id="remoteUserContainer">
                            <?php foreach ($remote_users as $index => $remote_user) : ?>
                                <div class="input-group mb-3">
                                    <div class="form-floating">
                                        <input type="text" name="remote_user[]" class="form-control" id="remote_user<?= $index ?>" placeholder="Remote User" value="<?= htmlspecialchars($remote_user) ?>">
                                        <label for="remote_user<?= $index ?>">Remote User</label>
                                    </div>
                                    <div class="form-floating">
                                        <input type="text" name="remote_user_password[]" class="form-control" id="remote_user_password<?= $index ?>" placeholder="Remote User Password" value="<?= htmlspecialchars($remote_user_passwords[$index] ?? '') ?>">
                                        <label for="remote_user_password<?= $index ?>">Remote User Password</label>
                                    </div>
                                    <button type="button" class="btn btn-secondary" onclick="removeRemoteUser(this)">Remove</button>
                                </div>
                            <?php endforeach; ?>
                        </div>
                        <button type="button" onclick="remoteUser()" class="btn btn-primary">Add</button>
                    </div>
                </div>

                <!-- Additional Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Additional Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea id="others" name="others" class="form-control" placeholder="Others"><?= htmlspecialchars($server['others'] ?? '') ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<script>
function hardDisk() {
    const container = document.getElementById('hardDiskContainer');

    const rowDiv = document.createElement('div');
    rowDiv.className = 'input-group mb-3';

    // Input for Hard Disk Type
    const input1 = document.createElement('div');
    input1.className = 'form-floating';
    const typeInput = document.createElement('input');
    typeInput.type = 'text';
    typeInput.name = 'harddisk_type[]';
    typeInput.placeholder = 'Type';
    typeInput.className = 'form-control';
    typeInput.id = 'harddisk_type' + container.children.length;
    const typeLabel = document.createElement('label');
    typeLabel.htmlFor = typeInput.id;
    typeLabel.innerText = 'Type';
    input1.appendChild(typeInput);
    input1.appendChild(typeLabel);

    // Input for Hard Disk Space
    const input2 = document.createElement('div');
    input2.className = 'form-floating';
    const spaceInput = document.createElement('input');
    spaceInput.type = 'text';
    spaceInput.name = 'harddisk_space[]';
    spaceInput.placeholder = 'Space';
    spaceInput.className = 'form-control';
    spaceInput.id = 'harddisk_space' + container.children.length;
    const spaceLabel = document.createElement('label');
    spaceLabel.htmlFor = spaceInput.id;
    spaceLabel.innerText = 'Space';
    input2.appendChild(spaceInput);
    input2.appendChild(spaceLabel);

    // Remove Button
    const removeButton = document.createElement('button');
    removeButton.type = 'button';
    removeButton.className = 'btn btn-secondary';
    removeButton.innerText = 'Remove';
    removeButton.onclick = function () {
        removeHardDisk(this);
    };

    rowDiv.appendChild(input1);
    rowDiv.appendChild(input2);
    rowDiv.appendChild(removeButton);

    container.appendChild(rowDiv);
}

function folderAndAccessRights() {
    const container = document.getElementById('folderAndAccessRightsContainer');

    const rowDiv = document.createElement('div');
    rowDiv.className = 'input-group mb-3';

    // Input for Folder
    const input1 = document.createElement('div');
    input1.className = 'form-floating';
    const folderInput = document.createElement('input');
    folderInput.type = 'text';
    folderInput.name = 'folder[]';
    folderInput.placeholder = 'Folder';
    folderInput.className = 'form-control';
    folderInput.id = 'folder' + container.children.length;
    const folderLabel = document.createElement('label');
    folderLabel.htmlFor = folderInput.id;
    folderLabel.innerText = 'Folder';
    input1.appendChild(folderInput);
    input1.appendChild(folderLabel);

    // Input for Access Right
    const input2 = document.createElement('div');
    input2.className = 'form-floating';
    const accessRightInput = document.createElement('input');
    accessRightInput.type = 'text';
    accessRightInput.name = 'access_right[]';
    accessRightInput.placeholder = 'Access Right';
    accessRightInput.className = 'form-control';
    accessRightInput.id = 'access_right' + container.children.length;
    const accessRightLabel = document.createElement('label');
    accessRightLabel.htmlFor = accessRightInput.id;
    accessRightLabel.innerText = 'Access Right';
    input2.appendChild(accessRightInput);
    input2.appendChild(accessRightLabel);

    // Input for Access User
    const input3 = document.createElement('div');
    input3.className = 'form-floating';
    const accessUserInput = document.createElement('input');
    accessUserInput.type = 'text';
    accessUserInput.name = 'access_user[]';
    accessUserInput.placeholder = 'Access User';
    accessUserInput.className = 'form-control';
    accessUserInput.id = 'access_user' + container.children.length;
    const accessUserLabel = document.createElement('label');
    accessUserLabel.htmlFor = accessUserInput.id;
    accessUserLabel.innerText = 'Access User';
    input3.appendChild(accessUserInput);
    input3.appendChild(accessUserLabel);

    // Input for Network Drive
    const input4 = document.createElement('div');
    input4.className = 'form-floating';
    const networkDriveInput = document.createElement('input');
    networkDriveInput.type = 'text';
    networkDriveInput.name = 'network_drive[]';
    networkDriveInput.placeholder = 'Network Drive';
    networkDriveInput.className = 'form-control';
    networkDriveInput.id = 'network_drive' + container.children.length;
    const networkDriveLabel = document.createElement('label');
    networkDriveLabel.htmlFor = networkDriveInput.id;
    networkDriveLabel.innerText = 'Network Drive';
    input4.appendChild(networkDriveInput);
    input4.appendChild(networkDriveLabel);

    // Remove Button
    const removeButton = document.createElement('button');
    removeButton.type = 'button';
    removeButton.className = 'btn btn-secondary';
    removeButton.innerText = 'Remove';
    removeButton.onclick = function () {
        removeFolderAndAccessRights(this);
    };

    rowDiv.appendChild(input1);
    rowDiv.appendChild(input2);
    rowDiv.appendChild(input3);
    rowDiv.appendChild(input4);
    rowDiv.appendChild(removeButton);

    container.appendChild(rowDiv);
}

function remoteUser() {
    const container = document.getElementById('remoteUserContainer');

    const rowDiv = document.createElement('div');
    rowDiv.className = 'input-group mb-3';

    // Input for Remote User
    const input1 = document.createElement('div');
    input1.className = 'form-floating';
    const remoteUserInput = document.createElement('input');
    remoteUserInput.type = 'text';
    remoteUserInput.name = 'remote_user[]';
    remoteUserInput.placeholder = 'Remote User';
    remoteUserInput.className = 'form-control';
    remoteUserInput.id = 'remote_user' + container.children.length;
    const remoteUserLabel = document.createElement('label');
    remoteUserLabel.htmlFor = remoteUserInput.id;
    remoteUserLabel.innerText = 'Remote User';
    input1.appendChild(remoteUserInput);
    input1.appendChild(remoteUserLabel);

    // Input for Remote User Password
    const input2 = document.createElement('div');
    input2.className = 'form-floating';
    const remoteUserPasswordInput = document.createElement('input');
    remoteUserPasswordInput.type = 'text';
    remoteUserPasswordInput.name = 'remote_user_password[]';
    remoteUserPasswordInput.placeholder = 'Remote User Password';
    remoteUserPasswordInput.className = 'form-control';
    remoteUserPasswordInput.id = 'remote_user_password' + container.children.length;
    const remoteUserPasswordLabel = document.createElement('label');
    remoteUserPasswordLabel.htmlFor = remoteUserPasswordInput.id;
    remoteUserPasswordLabel.innerText = 'Remote User Password';
    input2.appendChild(remoteUserPasswordInput);
    input2.appendChild(remoteUserPasswordLabel);

    // Remove Button
    const removeButton = document.createElement('button');
    removeButton.type = 'button';
    removeButton.className = 'btn btn-secondary';
    removeButton.innerText = 'Remove';
    removeButton.onclick = function () {
        removeRemoteUser(this);
    };

    rowDiv.appendChild(input1);
    rowDiv.appendChild(input2);
    rowDiv.appendChild(removeButton);

    container.appendChild(rowDiv);
}

function removeHardDisk(button) {
    const container = document.getElementById('hardDiskContainer');
    if (container.children.length > 1) {
        const rowDiv = button.closest('.input-group');
        if (rowDiv) {
            rowDiv.remove();
        }
    } else {
        alert("The last field cannot be removed.");
    }
}

function removeFolderAndAccessRights(button) {
    const container = document.getElementById('folderAndAccessRightsContainer');
    if (container.children.length > 1) {
        const rowDiv = button.closest('.input-group');
        if (rowDiv) {
            rowDiv.remove();
        }
    } else {
        alert("The last field cannot be removed.");
    }
}

function removeRemoteUser(button) {
    const container = document.getElementById('remoteUserContainer');
    if (container.children.length > 1) {
        const rowDiv = button.closest('.input-group');
        if (rowDiv) {
            rowDiv.remove();
        }
    } else {
        alert("The last field cannot be removed.");
    }
}
</script>

<!-- Bootstrap JS and dependencies -->
<script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.4/dist/umd/popper.min.js"></script>
<script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>
</html>

