<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur'); // Corrected timezone setting

// Retrieve the passed values from the URL
$itemTypeSwAvEpClientId = isset($_GET['item_type_sw_av_ep_client_id']) ? $_GET['item_type_sw_av_ep_client_id'] : null; // ID for editing
$debtorCode = isset($_GET['debtor_code']) ? $_GET['debtor_code'] : ''; // Directly get debtor_code from URL
$companyName = isset($_GET['company_name']) ? $_GET['company_name'] : ''; // Directly get company_name from URL

// If editing, retrieve the existing record
if ($itemTypeSwAvEpClientId) {
    $stmt = $pdo->prepare("SELECT * FROM item_type_sw_av_ep_client WHERE item_type_sw_av_ep_client_id = :item_type_sw_av_ep_client_id");
    $stmt->execute([':item_type_sw_av_ep_client_id' => $itemTypeSwAvEpClientId]);
    $record = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($record) {
        $companyName = $record['company_name'];
        $itemType = $record['item_type_name'];
        $itemTypeSoftwareGroup = $record['item_type_sw_group_name'];
        $softwareName = $record['software_name'];
        $softwareVersion = $record['software_version'];
        $installPath = $record['install_path'];
        $others = $record['others'];
        $installedPc = $record['installed_pc'];
        $debtorCode = $record['debtor_code'];
        $active = $record['active']; // Fetch the active status
    }
}

// Fetch the list of installed PCs from the database
$installedPcs = [];
if ($debtorCode && $companyName) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve the values from POST request
    $active = isset($_POST['active']) ? 1 : 0; // Check if the active checkbox is checked
    $installedPc = $_POST['installed_pc'] ?? ''; // Now a single value
    $softwareName = $_POST['software_name'] ?? '';
    $softwareVersion = $_POST['software_version'] ?? '';
    $installPath = $_POST['install_path'] ?? ''; // New field
    $others = $_POST['others'] ?? '';
    $debtorCode = $_POST['debtor_code'] ?? null; // Ensure debtor_code is included
    $itemType = $_POST['item_type_name'] ?? ''; // Add this line
    $itemTypeSoftwareGroup = $_POST['item_type_sw_group_name'] ?? ''; // Add this line

    try {
        // Fetch the old data for comparison
        $stmt = $pdo->prepare("SELECT * FROM item_type_sw_av_ep_client WHERE item_type_sw_av_ep_client_id = :item_type_sw_av_ep_client_id");
        $stmt->execute([':item_type_sw_av_ep_client_id' => $itemTypeSwAvEpClientId]);
        $oldData = $stmt->fetch(PDO::FETCH_ASSOC);

        // Update existing record
        $stmt = $pdo->prepare("UPDATE item_type_sw_av_ep_client SET
            item_type_name = :item_type_name, 
            item_type_sw_group_name = :item_type_sw_group_name,
            company_name = :company_name, 
            debtor_code = :debtor_code,
            active = :active,
            installed_pc = :installed_pc,
            software_name = :software_name,
            software_version = :software_version,
            install_path = :install_path, 
            others = :others,
            updated_time = NOW()
            WHERE item_type_sw_av_ep_client_id = :item_type_sw_av_ep_client_id");

        $stmt->execute([
            ':item_type_name' => $itemType,
            ':item_type_sw_group_name' => $itemTypeSoftwareGroup,
            ':company_name' => $companyName,
            ':debtor_code' => $debtorCode,
            ':active' => $active,
            ':installed_pc' => $installedPc,
            ':software_name' => $softwareName,
            ':software_version' => $softwareVersion,
            ':install_path' => $installPath, // New field
            ':others' => $others,
            ':item_type_sw_av_ep_client_id' => $itemTypeSwAvEpClientId
        ]);

        // Fetch the new data after the update
        $stmt = $pdo->prepare("SELECT * FROM item_type_sw_av_ep_client WHERE item_type_sw_av_ep_client_id = :item_type_sw_av_ep_client_id");
        $stmt->execute([':item_type_sw_av_ep_client_id' => $itemTypeSwAvEpClientId]);
        $newData = $stmt->fetch(PDO::FETCH_ASSOC);

        // Check if any data has changed
        $changesDetected = false;
        $logMessage = "Data change in Antivirus Endpoint Client (ID: $itemTypeSwAvEpClientId):\n";
        foreach ($oldData as $key => $value) {
            if ($key !== 'updated_time' && $newData[$key] !== $value) {
                $changesDetected = true;
                $logMessage .= "$key: $value -> " . $newData[$key] . "\n";
            }
        }

        if ($changesDetected) {
            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // Success alert
            echo "<script>alert('Data updated successfully!');</script>";
        } else {
            // No changes detected
            echo "<script>alert('No data change detected.');</script>";
        }

        // Redirect back to view_software_table.php with debtor_code and company_name
        echo "<script>window.location.href = '/crm/public/company/view_software_table.php?debtor_code=$debtorCode&company_name=$companyName';</script>";
    } catch (PDOException $e) {
        error_log('Database update error: ' . $e->getMessage());
        echo "<script>alert('Failed to update data. Please try again.');</script>";

        // Redirect back to view_software_table.php with debtor_code and company_name
        echo "<script>window.location.href = '/crm/public/company/view_software_table.php.php?debtor_code=$debtorCode&company_name=$companyName';</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <div class="mb-3">
                    <p>Company Name: <strong><?php echo htmlspecialchars($companyName); ?></strong></p>
                    <p>Item Type: <strong><?php echo htmlspecialchars($itemType); ?></strong></p>
                    <p>Item Type Group: <strong><?php echo htmlspecialchars($itemTypeSoftwareGroup); ?></strong></p>
                    <input type="hidden" name="debtor_code" value="<?php echo htmlspecialchars($debtorCode); ?>">
                    <input type="hidden" name="item_type_sw_av_ep_client_id" value="<?php echo htmlspecialchars($itemTypeSwAvEpClientId); ?>">
                    <input type="hidden" name="item_type_name" value="<?php echo htmlspecialchars($itemType); ?>">
                    <input type="hidden" name="item_type_sw_group_name" value="<?php echo htmlspecialchars($itemTypeSoftwareGroup); ?>">
                </div>

                <!-- Active Field -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Active</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="active" name="active" <?php echo ($active == 1) ? 'checked' : ''; ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- Installed PC Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">PC Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-select" id="installed_pc" name="installed_pc">
                                        <option value="">Please select a PC</option>
                                        <?php foreach ($installedPcs as $option): ?>
                                            <option value="<?php echo htmlspecialchars($option); ?>" <?php echo ($option == $installedPc) ? 'selected' : ''; ?>><?php echo htmlspecialchars($option); ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Software Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Software Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="software_name" name="software_name" placeholder="Software Name" value="<?php echo htmlspecialchars($softwareName); ?>">
                                    <label for="software_name">Software Name</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="software_version" name="software_version" placeholder="Software Version" value="<?php echo htmlspecialchars($softwareVersion); ?>">
                                    <label for="software_version">Software Version</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="install_path" name="install_path" placeholder="Install Path" value="<?php echo htmlspecialchars($installPath); ?>">
                                    <label for="install_path">Install Path</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea class="form-control" id="others" name="others" placeholder="Others"><?php echo htmlspecialchars($others); ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary" name="save">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        $('#installed_pc').select2({
            theme: "bootstrap-5",
            width: $(this).data('width') ? $(this).data('width') : $(this).hasClass('w-100') ? '100%' : 'style',
            placeholder: $(this).data('placeholder'),
            closeOnSelect: true, // Ensure it closes after selecting an option
        });
    });
</script>
</body>
</html>

