<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password decryption
date_default_timezone_set('Asia/Kuala_Lumpur'); // Corrected timezone setting

// Encryption key (must match the key used in encrypt.php)
$encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

// Check if debtor_code, company_name, and item_type_sw_av_ep_master_id are passed via URL
if (!isset($_GET['debtor_code']) || !isset($_GET['company_name']) || !isset($_GET['item_type_sw_av_ep_master_id'])) {
    echo "<p>No debtor code, company name, or antivirus endpoint ID provided.</p>";
    exit;
}

// Retrieve values from the URL
$debtorCode = $_GET['debtor_code'];
$companyName = $_GET['company_name']; // Retrieve company_name from the URL
$antivirusEndpointId = $_GET['item_type_sw_av_ep_master_id'];

// Fetch the antivirus endpoint details based on debtor_code and item_type_sw_av_ep_master_id
$stmt = $pdo->prepare('SELECT * FROM item_type_sw_av_ep_master WHERE debtor_code = :debtor_code AND item_type_sw_av_ep_master_id = :item_type_sw_av_ep_master_id LIMIT 1');
$stmt->execute([':debtor_code' => $debtorCode, ':item_type_sw_av_ep_master_id' => $antivirusEndpointId]);
$antivirusEndpoint = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$antivirusEndpoint) {
    echo "<p>No antivirus endpoint found with the provided ID.</p>";
    exit;
}

// Decrypt sensitive fields for display
$antivirusEndpoint['password'] = decryptPassword($antivirusEndpoint['password'], $encryptionKey);
$antivirusEndpoint['license_email_password'] = decryptPassword($antivirusEndpoint['license_email_password'], $encryptionKey);
$antivirusEndpoint['web_console_password'] = decryptPassword($antivirusEndpoint['web_console_password'], $encryptionKey);

// Fetch the list of installed PCs from the database
$installedPcs = [];
if ($debtorCode && $companyName) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // Validate and sanitize input data
        $active = isset($_POST['active']) ? 1 : 0;
        $contract_number = htmlspecialchars($_POST['contract_number']);
        $enterprise_site_id = htmlspecialchars($_POST['enterprise_site_id']);
        $installed_pc = htmlspecialchars($_POST['installed_pc']);
        $management_console_url = htmlspecialchars($_POST['management_console_url']);
        $quantity = htmlspecialchars($_POST['quantity']);
        $login = htmlspecialchars($_POST['login']);
        $password = htmlspecialchars($_POST['password']);
        $software_name = htmlspecialchars($_POST['software_name']);
        $software_version = htmlspecialchars($_POST['software_version']);
        $others = htmlspecialchars($_POST['others']);
        $license_email_login = htmlspecialchars($_POST['license_email_login']);
        $license_email_password = htmlspecialchars($_POST['license_email_password']);
        $web_console_login = htmlspecialchars($_POST['web_console_login']);
        $web_console_password = htmlspecialchars($_POST['web_console_password']);
        $agent_port = htmlspecialchars($_POST['agent_port']);
        $console = htmlspecialchars($_POST['console']);

        // Encrypt sensitive fields before storing in the database
        $encryptedPassword = encryptPassword($password, $encryptionKey);
        $encryptedLicenseEmailPassword = encryptPassword($license_email_password, $encryptionKey);
        $encryptedWebConsolePassword = encryptPassword($web_console_password, $encryptionKey);

        // Store the old data for logging
        $oldData = $antivirusEndpoint;

        // Check if any changes were made
        $hasChanges = false;
        if ($active != $oldData['active']) $hasChanges = true;
        if ($contract_number != $oldData['contract_number']) $hasChanges = true;
        if ($enterprise_site_id != $oldData['enterprise_site_id']) $hasChanges = true;
        if ($installed_pc != $oldData['installed_pc']) $hasChanges = true;
        if ($management_console_url != $oldData['management_console_url']) $hasChanges = true;
        if ($quantity != $oldData['quantity']) $hasChanges = true;
        if ($login != $oldData['login']) $hasChanges = true;
        if ($password != $oldData['password']) $hasChanges = true;
        if ($software_name != $oldData['software_name']) $hasChanges = true;
        if ($software_version != $oldData['software_version']) $hasChanges = true;
        if ($others != $oldData['others']) $hasChanges = true;
        if ($license_email_login != $oldData['license_email_login']) $hasChanges = true;
        if ($license_email_password != $oldData['license_email_password']) $hasChanges = true;
        if ($web_console_login != $oldData['web_console_login']) $hasChanges = true;
        if ($web_console_password != $oldData['web_console_password']) $hasChanges = true;
        if ($agent_port != $oldData['agent_port']) $hasChanges = true;
        if ($console != $oldData['console']) $hasChanges = true;

        if (!$hasChanges) {
            // No changes were made, display alert and redirect back to view_software_table.php
            echo '<script type="text/javascript">';
            echo 'alert("No changes made.");';
            echo 'window.location.href="/crm/public/company/view_software_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        } else {
            // Update the antivirus endpoint in the database
            $stmt = $pdo->prepare('
                UPDATE item_type_sw_av_ep_master 
                SET 
                    active = :active, 
                    contract_number = :contract_number, 
                    enterprise_site_id = :enterprise_site_id, 
                    installed_pc = :installed_pc, 
                    management_console_url = :management_console_url, 
                    quantity = :quantity, 
                    login = :login, 
                    password = :password, 
                    software_name = :software_name, 
                    software_version = :software_version, 
                    others = :others, 
                    license_email_login = :license_email_login, 
                    license_email_password = :license_email_password, 
                    web_console_login = :web_console_login, 
                    web_console_password = :web_console_password, 
                    agent_port = :agent_port, 
                    console = :console, 
                    updated_time = NOW() 
                WHERE 
                    debtor_code = :debtor_code AND item_type_sw_av_ep_master_id = :item_type_sw_av_ep_master_id
            ');
            $stmt->execute([
                ':active' => $active,
                ':contract_number' => $contract_number,
                ':enterprise_site_id' => $enterprise_site_id,
                ':installed_pc' => $installed_pc,
                ':management_console_url' => $management_console_url,
                ':quantity' => $quantity,
                ':login' => $login,
                ':password' => $encryptedPassword, // Encrypted password
                ':software_name' => $software_name,
                ':software_version' => $software_version,
                ':others' => $others,
                ':license_email_login' => $license_email_login,
                ':license_email_password' => $encryptedLicenseEmailPassword,
                ':web_console_login' => $web_console_login,
                ':web_console_password' => $encryptedWebConsolePassword,
                ':agent_port' => $agent_port,
                ':console' => $console,
                ':debtor_code' => $debtorCode,
                ':item_type_sw_av_ep_master_id' => $antivirusEndpointId
            ]);

            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_sw_av_ep_master WHERE debtor_code = :debtor_code AND item_type_sw_av_ep_master_id = :item_type_sw_av_ep_master_id LIMIT 1');
            $stmt->execute([':debtor_code' => $debtorCode, ':item_type_sw_av_ep_master_id' => $antivirusEndpointId]);
            $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

            // Decrypt sensitive fields for logging
            $newItem['password'] = decryptPassword($newItem['password'], $encryptionKey);
            $newItem['license_email_password'] = decryptPassword($newItem['license_email_password'], $encryptionKey);
            $newItem['web_console_password'] = decryptPassword($newItem['web_console_password'], $encryptionKey);

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in antivirus endpoint (Debtor Code: " . $debtorCode . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // Success alert and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="/crm/public/company/view_software_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        }
    } catch (PDOException $e) {
        // Log the exception and show error alert
        error_log('Database update error: ' . $e->getMessage());
        echo '<script type="text/javascript">';
        echo 'alert("Failed to update. Please try again.");';
        echo '</script>';
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Antivirus Endpoint Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit Antivirus Endpoint Details</h1>
        </div>
        <div class="card-body">
            <form method="POST" action="">
                <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                <input type="hidden" name="item_type_sw_id" value="<?= htmlspecialchars($antivirusEndpointId) ?>">

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $antivirusEndpoint['active'] ? 'checked' : '' ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- PC Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">PC Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-select" id="installed_pc" name="installed_pc">
                                        <option value="">Select Installed PC</option>
                                        <?php foreach ($installedPcs as $option): ?>
                                            <option value="<?= htmlspecialchars($option) ?>" <?= $option == $antivirusEndpoint['installed_pc'] ? 'selected' : '' ?>><?= htmlspecialchars($option) ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- General Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">General Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="contract_number" name="contract_number" placeholder="Contract Number" value="<?= htmlspecialchars($antivirusEndpoint['contract_number'] ?? '') ?>">
                                    <label for="contract_number">Contract Number</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="enterprise_site_id" name="enterprise_site_id" placeholder="Enterprise Site ID" value="<?= htmlspecialchars($antivirusEndpoint['enterprise_site_id'] ?? '') ?>">
                                    <label for="enterprise_site_id">Enterprise Site ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="management_console_url" name="management_console_url" placeholder="Management Console URL" value="<?= htmlspecialchars($antivirusEndpoint['management_console_url'] ?? '') ?>">
                                    <label for="management_console_url">Management Console URL</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="number" class="form-control" id="quantity" name="quantity" placeholder="Quantity" value="<?= htmlspecialchars($antivirusEndpoint['quantity'] ?? '') ?>">
                                    <label for="quantity">Quantity</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Software Information Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Software Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="software_name" name="software_name" placeholder="Software Name" value="<?= htmlspecialchars($antivirusEndpoint['software_name'] ?? '') ?>">
                                    <label for="software_name">Software Name</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="software_version" name="software_version" placeholder="Software Version" value="<?= htmlspecialchars($antivirusEndpoint['software_version'] ?? '') ?>">
                                    <label for="software_version">Software Version</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Login Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="login" name="login" placeholder="Login" value="<?= htmlspecialchars($antivirusEndpoint['login'] ?? '') ?>">
                                    <label for="login">Login</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="password" name="password" placeholder="Password" value="<?= htmlspecialchars($antivirusEndpoint['password'] ?? '') ?>">
                                    <label for="password">Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- License Email Details Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">License Email Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="license_email_login" name="license_email_login" placeholder="License Email Login" value="<?= htmlspecialchars($antivirusEndpoint['license_email_login'] ?? '') ?>">
                                    <label for="license_email_login">License Email Login</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="license_email_password" name="license_email_password" placeholder="License Email Password" value="<?= htmlspecialchars($antivirusEndpoint['license_email_password'] ?? '') ?>">
                                    <label for="license_email_password">License Email Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Web Console Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Web Console</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="web_console_login" name="web_console_login" placeholder="Web Console Login" value="<?= htmlspecialchars($antivirusEndpoint['web_console_login'] ?? '') ?>">
                                    <label for="web_console_login">Web Console Login</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="agent_port" name="agent_port" placeholder="Agent Port" value="<?= htmlspecialchars($antivirusEndpoint['agent_port'] ?? '') ?>">
                                    <label for="agent_port">Agent Port</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="web_console_password" name="web_console_password" placeholder="Web Console Password" value="<?= htmlspecialchars($antivirusEndpoint['web_console_password'] ?? '') ?>">
                                    <label for="web_console_password">Web Console Password</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" class="form-control" id="console" name="console" placeholder="Console" value="<?= htmlspecialchars($antivirusEndpoint['console'] ?? '') ?>">
                                    <label for="console">Console</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Others Card -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea class="form-control" id="others" name="others" placeholder="Others"><?= htmlspecialchars($antivirusEndpoint['others'] ?? '') ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        $('#installed_pc').select2({
            theme: "bootstrap-5",
            width: $(this).data('width') ? $(this).data('width') : $(this).hasClass('w-100') ? '100%' : 'style',
            placeholder: "Select Installed PC",
            closeOnSelect: true, // Ensure it closes after selecting one option
        });
    });
</script>
</body>
</html>