<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password decryption
date_default_timezone_set('Asia/Kuala_Lumpur'); // Corrected timezone setting

// Encryption key (must match the key used in encrypt.php)
$encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

// Check if debtor_code and item_type_sw_av_is_id are passed via URL
if (!isset($_GET['debtor_code']) || !isset($_GET['item_type_sw_av_is_id'])) {
    echo "<p>No debtor code or antivirus IS ID provided.</p>";
    exit;
}

$debtorCode = $_GET['debtor_code'];
$antivirusIsId = $_GET['item_type_sw_av_is_id'];

// Fetch the antivirus IS details based on debtor_code and item_type_sw_av_is_id
$stmt = $pdo->prepare('SELECT * FROM item_type_sw_av_is WHERE debtor_code = :debtor_code AND item_type_sw_av_is_id = :item_type_sw_av_is_id LIMIT 1');
$stmt->execute([':debtor_code' => $debtorCode, ':item_type_sw_av_is_id' => $antivirusIsId]);
$antivirusIs = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$antivirusIs) {
    echo "<p>No antivirus IS found with the provided ID.</p>";
    exit;
}

// Fetch the company name from the antivirus data or session
$companyName = $antivirusIs['company_name'] ?? ($_SESSION['company_name'] ?? ''); // Define $companyName

// Decrypt sensitive fields for display
$antivirusIs['password'] = decryptPassword($antivirusIs['password'], $encryptionKey);
$antivirusIs['activation_key'] = decryptPassword($antivirusIs['activation_key'], $encryptionKey);

// Fetch the list of installed PCs from the database
$installedPcs = [];
if ($debtorCode && $companyName) {
    try {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code AND company_name = :company_name");
        $stmt->execute([':debtor_code' => $debtorCode, ':company_name' => $companyName]);
        $installedPcs = $stmt->fetchAll(PDO::FETCH_COLUMN);
    } catch (PDOException $e) {
        error_log('Database query error: ' . $e->getMessage());
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // Retrieve and sanitize input data
        $active = isset($_POST['active']) ? 1 : 0;
        $installed_pc = $_POST['installed_pc'] ?? '';
        $login = htmlspecialchars($_POST['login'] ?? '');
        $password = htmlspecialchars($_POST['password'] ?? '');
        $software_name = htmlspecialchars($_POST['software_name'] ?? '');
        $software_version = htmlspecialchars($_POST['software_version'] ?? '');
        $publicLicenseId = htmlspecialchars($_POST['public_license_id'] ?? '');
        $activationKey = htmlspecialchars($_POST['activation_key'] ?? '');
        $others = htmlspecialchars($_POST['others'] ?? '');
        $brand = htmlspecialchars($_POST['brand'] ?? '');
        $numberOfDevices = htmlspecialchars($_POST['number_of_device'] ?? '');
        $purchaseFrom = htmlspecialchars($_POST['purchase_from'] ?? '');
        $expirationDate = htmlspecialchars($_POST['expiration_date'] ?? '');

        // Encrypt sensitive fields before storing in the database
        $encryptedPassword = encryptPassword($password, $encryptionKey);
        $encryptedActivationKey = encryptPassword($activationKey, $encryptionKey);

        // Store the old data for logging
        $oldData = $antivirusIs;

        // Check if any changes were made
        $hasChanges = false;
        if ($active != $oldData['active']) $hasChanges = true;
        if ($installed_pc != $oldData['installed_pc']) $hasChanges = true;
        if ($login != $oldData['login']) $hasChanges = true;
        if ($password != $oldData['password']) $hasChanges = true;
        if ($software_name != $oldData['software_name']) $hasChanges = true;
        if ($software_version != $oldData['software_version']) $hasChanges = true;
        if ($publicLicenseId != $oldData['public_license_id']) $hasChanges = true;
        if ($activationKey != $oldData['activation_key']) $hasChanges = true;
        if ($others != $oldData['others']) $hasChanges = true;
        if ($brand != $oldData['brand']) $hasChanges = true;
        if ($numberOfDevices != $oldData['number_of_device']) $hasChanges = true;
        if ($purchaseFrom != $oldData['purchase_from']) $hasChanges = true;
        if ($expirationDate != $oldData['expiration_date']) $hasChanges = true;

        if (!$hasChanges) {
            // No changes were made, display alert and redirect back to view_software_table.php
            echo '<script type="text/javascript">';
            echo 'alert("No changes made.");';
            echo 'window.location.href="/crm/public/company/view_software_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        } else {
            // Update the antivirus IS in the database
            $stmt = $pdo->prepare('UPDATE item_type_sw_av_is SET active = :active, installed_pc = :installed_pc, login = :login, password = :password, software_name = :software_name, software_version = :software_version, public_license_id = :public_license_id, activation_key = :activation_key, others = :others, brand = :brand, number_of_device = :number_of_device, purchase_from = :purchase_from, expiration_date = :expiration_date, updated_time = NOW() WHERE debtor_code = :debtor_code AND item_type_sw_av_is_id = :item_type_sw_av_is_id');
            $stmt->execute([
                ':active' => $active,
                ':installed_pc' => $installed_pc,
                ':login' => $login,
                ':password' => $encryptedPassword, // Encrypted password
                ':software_name' => $software_name,
                ':software_version' => $software_version,
                ':public_license_id' => $publicLicenseId,
                ':activation_key' => $encryptedActivationKey, // Encrypted activation key
                ':others' => $others,
                ':brand' => $brand,
                ':number_of_device' => $numberOfDevices,
                ':purchase_from' => $purchaseFrom,
                ':expiration_date' => $expirationDate,
                ':debtor_code' => $debtorCode,
                ':item_type_sw_av_is_id' => $antivirusIsId
            ]);

            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_sw_av_is WHERE debtor_code = :debtor_code AND item_type_sw_av_is_id = :item_type_sw_av_is_id LIMIT 1');
            $stmt->execute([':debtor_code' => $debtorCode, ':item_type_sw_av_is_id' => $antivirusIsId]);
            $newItem = $stmt->fetch(PDO::FETCH_ASSOC);

            // Decrypt sensitive fields for logging
            $newItem['password'] = decryptPassword($newItem['password'], $encryptionKey);
            $newItem['activation_key'] = decryptPassword($newItem['activation_key'], $encryptionKey);

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in antivirus IS (Debtor Code: " . $debtorCode . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newItem[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newItem[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // Success message
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="/crm/public/company/view_software_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        }
    } catch (PDOException $e) {
        // Log the error and display a user-friendly message
        error_log('Database update error: ' . $e->getMessage());
        echo '<script type="text/javascript">';
        echo 'alert("Failed to update. Please try again.");';
        echo '</script>';
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Antivirus Internet Security Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit Antivirus Internet Security Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                <input type="hidden" name="item_type_sw_id" value="<?= htmlspecialchars($antivirusIsId) ?>">

                <!-- Active Field -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Active</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="active" name="active" <?php echo ($antivirusIs['active'] == 1) ? 'checked' : ''; ?>>
                            <label class="form-check-label" for="active">Active</label>
                        </div>
                    </div>
                </div>

                <!-- PC Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">PC Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-group row">
                            <div class="col-md-6">
                                <label for="installed_pc">Installed PC</label>
                                <select class="form-select" id="installed_pc" name="installed_pc" data-placeholder="Choose anything" required>
                                    <option value="" selected>Please select a PC</option> <!-- Default option -->
                                    <?php foreach ($installedPcs as $option): ?>
                                        <option value="<?php echo htmlspecialchars($option); ?>" <?= $option == $antivirusIs['installed_pc'] ? 'selected' : '' ?>><?php echo htmlspecialchars($option); ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Antivirus Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Antivirus Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-group row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-control" name="brand" id="brand">
                                        <option value="" selected>Please select an antivirus</option> <!-- Default option -->
                                        <option value="ESET" <?= $antivirusIs['brand'] == 'ESET' ? 'selected' : '' ?>>ESET</option>
                                        <option value="Bitdefender" <?= $antivirusIs['brand'] == 'Bitdefender' ? 'selected' : '' ?>>Bitdefender</option>
                                        <option value="Kaspersky" <?= $antivirusIs['brand'] == 'Kaspersky' ? 'selected' : '' ?>>Kaspersky</option>
                                        <option value="Trend Micro" <?= $antivirusIs['brand'] == 'Trend Micro' ? 'selected' : '' ?>>Trend Micro</option>
                                        <option value="Norton Antivirus" <?= $antivirusIs['brand'] == 'Norton Antivirus' ? 'selected' : '' ?>>Norton Antivirus</option>
                                        <option value="AVG" <?= $antivirusIs['brand'] == 'AVG' ? 'selected' : '' ?>>AVG</option>
                                        <option value="Avira" <?= $antivirusIs['brand'] == 'Avira' ? 'selected' : '' ?>>Avira</option>
                                        <option value="Other" <?= $antivirusIs['brand'] == 'Other' ? 'selected' : '' ?>>Other</option>
                                    </select>
                                    <label for="brand">Antivirus Brand</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Software Installation Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Software Installation Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-group row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login" id="login" class="form-control" placeholder="Login" value="<?= htmlspecialchars($antivirusIs['login'] ?? '') ?>">
                                    <label for="login">Login</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="password" id="password" class="form-control" placeholder="Password" value="<?= htmlspecialchars($antivirusIs['password'] ?? '') ?>">
                                    <label for="password">Password</label>
                                </div>
                            </div>
                        </div>
                        <div class="form-group row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="software_name" id="software_name" class="form-control" placeholder="Software Name" value="<?= htmlspecialchars($antivirusIs['software_name'] ?? '') ?>">
                                    <label for="software_name">Software Name</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="software_version" id="software_version" class="form-control" placeholder="Software Version" value="<?= htmlspecialchars($antivirusIs['software_version'] ?? '') ?>">
                                    <label for="software_version">Software Version</label>
                                </div>
                            </div>
                        </div>
                        <div class="form-group row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="public_license_id" id="public_license_id" class="form-control" placeholder="Public License ID" value="<?= htmlspecialchars($antivirusIs['public_license_id'] ?? '') ?>">
                                    <label for="public_license_id">Public License ID</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="activation_key" id="activation_key" class="form-control" placeholder="Activation Key" value="<?= htmlspecialchars($antivirusIs['activation_key'] ?? '') ?>">
                                    <label for="activation_key">Activation Key</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Purchase and Expiration Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Purchase and Expiration Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-group row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="number" name="number_of_device" id="number_of_device" class="form-control" placeholder="Number of Devices" value="<?= htmlspecialchars($antivirusIs['number_of_device'] ?? '') ?>">
                                    <label for="number_of_device">Number of Devices</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <select class="form-control" name="purchase_from" id="purchase_from">
                                        <option value="" selected>Please select a purchase source</option> <!-- Default option -->
                                        <option value="CITSSB" <?= $antivirusIs['purchase_from'] == 'CITSSB' ? 'selected' : '' ?>>CITSSB</option>
                                        <option value="User Own Purchase" <?= $antivirusIs['purchase_from'] == 'User Own Purchase' ? 'selected' : '' ?>>User Own Purchase</option>
                                        <option value="Freeway" <?= $antivirusIs['purchase_from'] == 'Freeway' ? 'selected' : '' ?>>Freeway</option>
                                    </select>
                                    <label for="purchase_from">Purchase From</label>
                                </div>
                            </div>
                        </div>
                        <div class="form-group row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="date" name="expiration_date" id="expiration_date" class="form-control" value="<?= htmlspecialchars($antivirusIs['expiration_date'] ?? '') ?>">
                                    <label for="expiration_date">Expiration Date</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Additional Information -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Others Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-group row">
                            <div class="col-md-12">
                                <div class="form-floating">
                                    <textarea id="others" name="others" class="form-control" placeholder="Others"><?= htmlspecialchars($antivirusIs['others'] ?? '') ?></textarea>
                                    <label for="others">Others</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        $('#installed_pc').select2({
            theme: "bootstrap-5",
            width: $(this).data('width') ? $(this).data('width') : $(this).hasClass('w-100') ? '100%' : 'style',
            placeholder: $(this).data('placeholder'),
            closeOnSelect: true, // Ensure it closes after selecting one option
        });
    });
</script>
</body>
</html>