<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/encrypt.php'; // For password encryption
require '../functions/decrypt.php'; // For password encryption
date_default_timezone_set('Asia/Kuala_Lumpur');

// Encryption key (must match the key used in encrypt.php)
$encryptionKey = 'your_secret_key'; // Replace with your actual encryption key

// Check if debtor_code and item_type_sw_id are passed via URL
if (!isset($_GET['debtor_code']) || !isset($_GET['item_type_sw_id'])) {
    echo "<p>No debtor code or other software ID provided.</p>";
    exit;
}

$debtorCode = $_GET['debtor_code'];
$otherSwId = $_GET['item_type_sw_id'];

// Fetch the other software details based on debtor_code and item_type_sw_id
$stmt = $pdo->prepare('SELECT * FROM item_type_sw WHERE debtor_code = :debtor_code AND item_type_sw_id = :item_type_sw_id LIMIT 1');
$stmt->execute([':debtor_code' => $debtorCode, ':item_type_sw_id' => $otherSwId]);
$otherSw = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$otherSw) {
    echo "<p>No other software found with the provided ID.</p>";
    exit;
}

// Decrypt sensitive fields for display and comparison
$otherSw['password'] = decryptPassword($otherSw['password'], $encryptionKey);

// Fetch all installed PCs for the given debtor_code
$stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE debtor_code = :debtor_code");
$stmt->execute([':debtor_code' => $debtorCode]);
$computerNames = $stmt->fetchAll(PDO::FETCH_COLUMN);

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // Validate and sanitize input data
        $active = isset($_POST['active']) ? 1 : 0;
        $installed_pc = htmlspecialchars($_POST['installed_pc']);
        $license = htmlspecialchars($_POST['license']);
        $login = htmlspecialchars($_POST['login']);
        $password = htmlspecialchars($_POST['password']);
        $software_provider = htmlspecialchars($_POST['software_provider']);
        $provider_telephone_no = htmlspecialchars($_POST['provider_telephone_no']);
        $others = htmlspecialchars($_POST['others']);

        // Encrypt sensitive fields before storing in the database
        $encryptedPassword = encryptPassword($password, $encryptionKey);

        // Store the old data for logging
        $oldData = $otherSw;

        // Check if any changes were made
        $hasChanges = false;
        if ($active != $oldData['active']) $hasChanges = true;
        if ($installed_pc != $oldData['installed_pc']) $hasChanges = true;
        if ($license != $oldData['license']) $hasChanges = true;
        if ($login != $oldData['login']) $hasChanges = true;
        if ($password != $oldData['password']) $hasChanges = true;
        if ($software_provider != $oldData['software_provider']) $hasChanges = true;
        if ($provider_telephone_no != $oldData['provider_telephone_no']) $hasChanges = true;
        if ($others != $oldData['others']) $hasChanges = true;

        if (!$hasChanges) {
            // No changes were made, display alert and redirect back to view_software_table.php
            echo '<script type="text/javascript">';
            echo 'alert("No changes made.");';
            echo 'window.location.href="/crm/public/company/view_software_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
            exit;
        }

        // Update the other software in the database
        $stmt = $pdo->prepare('UPDATE item_type_sw SET active = :active, installed_pc = :installed_pc, license = :license, login = :login, password = :password, software_provider = :software_provider, provider_telephone_no = :provider_telephone_no, others = :others, updated_time = NOW() WHERE debtor_code = :debtor_code AND item_type_sw_id = :item_type_sw_id');
        $success = $stmt->execute([
            ':active' => $active,
            ':installed_pc' => $installed_pc,
            ':license' => $license,
            ':login' => $login,
            ':password' => $encryptedPassword, // Encrypted password
            ':software_provider' => $software_provider,
            ':provider_telephone_no' => $provider_telephone_no,
            ':others' => $others,
            ':debtor_code' => $debtorCode,
            ':item_type_sw_id' => $otherSwId
        ]);

        if ($success) {
            // Fetch the new data after the update
            $stmt = $pdo->prepare('SELECT * FROM item_type_sw WHERE debtor_code = :debtor_code AND item_type_sw_id = :item_type_sw_id LIMIT 1');
            $stmt->execute([':debtor_code' => $debtorCode, ':item_type_sw_id' => $otherSwId]);
            $newData = $stmt->fetch(PDO::FETCH_ASSOC);

            // Decrypt sensitive fields for logging
            $newData['password'] = decryptPassword($newData['password'], $encryptionKey);

            // Build the log message with only the fields that have changed, excluding 'updated_time'
            $logMessage = "Data change in Other Software (Debtor Code: " . $debtorCode . "):\n";
            foreach ($oldData as $key => $value) {
                if ($key !== 'updated_time' && $newData[$key] !== $value) {
                    $logMessage .= "$key: $value -> " . $newData[$key] . "\n";
                }
            }

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // If update was successful, show success message and redirect
            echo '<script type="text/javascript">';
            echo 'alert("Update successful!");';
            echo 'window.location.href="/crm/public/company/view_software_table.php?debtor_code=' . urlencode($debtorCode) . '";';
            echo '</script>';
        } else {
            throw new Exception("Failed to update the other software details.");
        }
    } catch (Exception $e) {
        echo '<script type="text/javascript">';
        echo 'alert("' . $e->getMessage() . '");';
        echo '</script>';
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Other Software Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Select2 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
    <link href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css" rel="stylesheet" />
</head>
<body>
<div class="container mt-5">
    <div class="card shadow-lg">
        <div class="card-header bg-primary text-white">
            <h1 class="mb-0">Edit Other Software Details</h1>
        </div>
        <div class="card-body">
            <form method="POST">
                <input type="hidden" name="debtor_code" value="<?= htmlspecialchars($debtorCode) ?>">
                <input type="hidden" name="item_type_sw_id" value="<?= htmlspecialchars($otherSwId) ?>">

                <!-- Active Status -->
                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="mb-0">Active Status</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="active" value="1" id="active" <?= $otherSw['active'] ? 'checked' : '' ?>>
                            Active 
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">PC Information</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="installed_pc">Installed PC</label>
                                    <select class="form-select" id="installed_pc" name="installed_pc" data-placeholder="Choose anything">
                                        <?php foreach ($computerNames as $option): ?>
                                            <option value="<?= htmlspecialchars($option) ?>" <?= $option == $otherSw['installed_pc'] ? 'selected' : '' ?>><?= htmlspecialchars($option) ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">License Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="license" id="license" class="form-control" value="<?= htmlspecialchars($otherSw['license'] ?? '') ?>" placeholder="License">
                                    <label for="license">License</label>
                                </div>
                                <div class="form-floating mb-3">
                                    <input type="text" name="provider_telephone_no" id="provider_telephone_no" class="form-control" value="<?= htmlspecialchars($otherSw['provider_telephone_no'] ?? '') ?>" placeholder="Provider Telephone No">
                                    <label for="provider_telephone_no">Provider Telephone No</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="software_provider" id="software_provider" class="form-control" value="<?= htmlspecialchars($otherSw['software_provider'] ?? '') ?>" placeholder="Software Provider">
                                    <label for="software_provider">Software Provider</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Login Details</h5>
                    </div>
                    <div class="card-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="login" id="login" class="form-control" value="<?= htmlspecialchars($otherSw['login'] ?? '') ?>" placeholder="Login">
                                    <label for="login">Login</label>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-floating mb-3">
                                    <input type="text" name="password" id="password" class="form-control" value="<?= htmlspecialchars($otherSw['password'] ?? '') ?>" placeholder="Password">
                                    <label for="password">Password</label>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card mb-3">
                    <div class="card-header">
                        <h5 class="card-title">Others</h5>
                    </div>
                    <div class="card-body">
                        <div class="form-floating mb-3">
                            <textarea id="others" name="others" class="form-control" placeholder="Others"><?= htmlspecialchars($otherSw['others'] ?? '') ?></textarea>
                            <label for="others">Others</label>
                        </div>
                    </div>
                </div>

                <!-- Save Button -->
                <button type="submit" class="btn btn-primary">Save</button>
            </form>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS and dependencies -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<script>
    $(document).ready(function() {
        $('#installed_pc').select2({
            theme: "bootstrap-5",
            width: $(this).data('width') ? $(this).data('width') : $(this).hasClass('w-100') ? '100%' : 'style',
            placeholder: $(this).data('placeholder'),
            closeOnSelect: true, // Ensure only one option can be selected
        });
    });
</script>
</body>
</html>

