<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if debtor_code and company_name are passed as query parameters
$debtorCode = $_GET['debtor_code'] ?? '';
$companyName = $_GET['company_name'] ?? '';

if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action']) && $_POST['action'] == 'add_customer') {
    $customer_prefix = $_POST['customer_prefix'];
    $customer_username = $_POST['customer_username'];
    $customer_mobile = $_POST['customer_mobile'];
    $customer_email = $_POST['customer_email'];
    $customer_title = $_POST['customer_title'];
    $customer_dept = $_POST['customer_dept'];
    $company_name = $_POST['company_name'];
    $main_customer = isset($_POST['main_customer']) ? 1 : 0; // Check if main_customer checkbox is checked

    // Check if debtor_code is set and not empty
    if (!isset($_POST['debtor_code']) || empty($_POST['debtor_code'])) {
        echo "<div class='alert alert-danger'>Please select a company from the dropdown.</div>";
    } else {
        $debtor_code = $_POST['debtor_code'];

        // Insert into customer_info (without combining prefix and username)
        $stmt = $pdo->prepare("INSERT INTO customer_info (customer_username, customer_mobile, customer_email, customer_title, customer_dept, company_name, debtor_code, main_customer, prefix) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
        $stmt->execute([$customer_username, $customer_mobile, $customer_email, $customer_title, $customer_dept, $company_name, $debtor_code, $main_customer, $customer_prefix]);

        // Log the activity
        $logMessage = "Customer added for company_name: $company_name";

        // Insert the log into activity_logs
        $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                   VALUES (:username, :timestamp, :role, :activity)";
        $stmtLog = $pdo->prepare($sqlLog);
        $stmtLog->execute([
            ':username' => $_SESSION['username'],
            ':timestamp' => date('Y-m-d H:i:s'),
            ':role' => $_SESSION['role'],
            ':activity' => $logMessage
        ]);

        echo "<script>alert('Customer added successfully!');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add Customer</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .dropdown-menu {
            display: none;
            position: absolute;
            z-index: 1000;
            background-color: white;
            border: 1px solid #ccc;
            max-height: 200px;
            overflow-y: auto;
            width: 100%;
            box-shadow: 0 8px 16px rgba(0, 0, 0, 0.1);
        }
        .dropdown-menu.show {
            display: block;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h2 class="mb-0">Add Customer</h2>
            </div>
            <div class="card-body">
                <form method="POST" action="">
                    <input type="hidden" name="action" value="add_customer">

                    <!-- Company Details -->
                    <div class="card mb-3 shadow-sm">
                        <div class="card-header">
                            <h5 class="card-title">Company Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-9">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="company_search" oninput="searchCompanies()" placeholder="Company Name" required value="<?= htmlspecialchars($companyName); ?>">
                                        <label for="company_search">Company Name</label>
                                        <div id="company_results" class="dropdown-menu"></div>
                                    </div>
                                    <input type="hidden" id="company_name" name="company_name" value="<?= htmlspecialchars($companyName); ?>">
                                </div>
                                <div class="col-md-3">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="debtor_code_display" disabled placeholder="Debtor Code" value="<?= htmlspecialchars($debtorCode); ?>">
                                        <label for="debtor_code_display">Debtor Code</label>
                                    </div>
                                    <input type="hidden" id="debtor_code" name="debtor_code" value="<?= htmlspecialchars($debtorCode); ?>">
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Main Customer Checkbox -->
                    <div class="card mb-3 shadow-sm">
                        <div class="card-header">
                            <h5 class="card-title">Main Customer</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-check form-switch">
                                <input type="checkbox" class="form-check-input" id="main_customer" name="main_customer">
                                <label class="form-check-label" for="main_customer">Main Customer</label>
                            </div>
                        </div>
                    </div>

                    <!-- Customer Name and Prefix -->
                    <div class="card mb-3 shadow-sm">
                        <div class="card-header">
                            <h5 class="card-title">Customer Name and Prefix</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-2">
                                    <div class="form-floating mb-3">
                                        <select class="form-select" id="customer_prefix" name="customer_prefix">
                                            <option value="Mr.">Mr.</option>
                                            <option value="Mrs.">Mrs.</option>
                                            <option value="Ms.">Ms.</option>
                                        </select>
                                        <label for="customer_prefix">Prefix</label>
                                    </div>
                                </div>
                                <div class="col-md-10">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="customer_username" name="customer_username" placeholder="Customer Name" required>
                                        <label for="customer_username">Customer Name</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Additional Fields -->
                    <div class="card mb-3 shadow-sm">
                        <div class="card-header">
                            <h5 class="card-title">Additional Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="customer_mobile" name="customer_mobile" placeholder="Mobile">
                                        <label for="customer_mobile">Mobile</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="email" class="form-control" id="customer_email" name="customer_email" placeholder="Email">
                                        <label for="customer_email">Email</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="customer_title" name="customer_title" placeholder="Title">
                                        <label for="customer_title">Title</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="customer_dept" name="customer_dept" placeholder="Department">
                                        <label for="customer_dept">Department</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Submit Button -->
                    <div class="text-center">
                        <button type="submit" class="btn btn-primary" id="submitBtn">Add Customer</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script>
    function searchCompanies() {
        var query = document.getElementById('company_search').value;
        if (query.length > 2) {
            var xhr = new XMLHttpRequest();
            xhr.onreadystatechange = function() {
                if (xhr.readyState == 4 && xhr.status == 200) {
                    document.getElementById('company_results').innerHTML = xhr.responseText;
                    document.getElementById('company_results').classList.add('show');
                }
            };
            xhr.open('GET', '/crm/public/functions/search_company_function.php?q=' + encodeURIComponent(query), true);
            xhr.send();
        } else {
            document.getElementById('company_results').innerHTML = '';
            document.getElementById('company_results').classList.remove('show');
        }
    }

    function selectCompany(companyName, debtorCode) {
        document.getElementById('company_search').value = companyName;
        document.getElementById('debtor_code_display').value = debtorCode;
        document.getElementById('debtor_code').value = debtorCode; // Set the hidden field value
        document.getElementById('company_name').value = companyName; // Set the hidden field value
        document.getElementById('company_results').innerHTML = '';
        document.getElementById('company_results').classList.remove('show');
        companySelected = true; // Mark that a company has been selected
    }

    // Track whether a company has been selected
    let companySelected = false;

    // Clear fields if the user modifies the company name after a selection
    document.getElementById('company_search').addEventListener('input', function() {
        if (companySelected) {
            // Clear the company name, debtor code, and hidden fields
            document.getElementById('company_search').value = '';
            document.getElementById('debtor_code_display').value = '';
            document.getElementById('debtor_code').value = '';
            document.getElementById('company_name').value = '';
            document.getElementById('company_results').innerHTML = '';
            document.getElementById('company_results').classList.remove('show');
            companySelected = false; // Reset the selection flag
        }
    });

    // Pre-fill the form fields if debtor_code and company_name are present
    <?php if (!empty($debtorCode) && !empty($companyName)): ?>
        document.getElementById('company_search').value = '<?= htmlspecialchars($companyName); ?>';
        document.getElementById('debtor_code_display').value = '<?= htmlspecialchars($debtorCode); ?>';
        document.getElementById('debtor_code').value = '<?= htmlspecialchars($debtorCode); ?>';
        document.getElementById('company_name').value = '<?= htmlspecialchars($companyName); ?>';
        companySelected = true; // Mark that a company has been pre-selected
    <?php endif; ?>
</script>

    <!-- Bootstrap 5.x JS and dependencies -->
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>

