<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
require '../functions/decrypt.php'; // For password encryption

// Get the parameters from the URL
$debtor_code = $_GET['debtor_code'] ?? '';
$customer_info_id = $_GET['customer_info_id'] ?? '';
$encryption_key = "your_secret_key"; // Replace with your actual encryption key

// Handle delete action
if (isset($_POST['delete_customer'])) {
    // Prepare SQL query to delete the customer
    $delete_sql = "DELETE FROM customer_info WHERE customer_info_id = :customer_info_id AND debtor_code = :debtor_code";
    $delete_stmt = $pdo->prepare($delete_sql);
    $delete_stmt->execute(['customer_info_id' => $customer_info_id, 'debtor_code' => $debtor_code]);

    // Display a success message and redirect
    echo "<script>
        alert('Customer deleted successfully!');
        window.location.href = 'search_customer.php';
    </script>";
    exit();
}

if ($debtor_code && $customer_info_id) {
    // Prepare SQL query to fetch customer details based on debtor_code and customer_info_id
    $sql = "SELECT customer_username, customer_mobile, customer_email, customer_title, customer_dept, debtor_code, company_name 
            FROM customer_info 
            WHERE debtor_code = :debtor_code AND customer_info_id = :customer_info_id";
    
    $stmt = $pdo->prepare($sql);
    $stmt->execute(['debtor_code' => $debtor_code, 'customer_info_id' => $customer_info_id]);
    $customer = $stmt->fetch(PDO::FETCH_ASSOC);

    // Fetch PC details based on customer_username
    $pcDetails = [];
    $acDetails = [];
    $swDetails = [];
    $hwDetails = [];
    $nasDetails = [];
    $hostingDetails = [];
    if ($customer) {
        $stmt = $pdo->prepare("SELECT computer_name FROM item_type_pc WHERE customer_username = :customer_username");
        $stmt->execute([':customer_username' => $customer['customer_username']]);
        $pcDetails = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Fetch AC details and check if the installed PC is assigned to the user
        $stmt = $pdo->prepare("
            SELECT ac.item_type_ac_group_name, ac.installed_pc 
            FROM item_type_ac ac
            LEFT JOIN item_type_pc pc ON ac.installed_pc = pc.computer_name AND pc.customer_username = :customer_username
        ");
        $stmt->execute([':customer_username' => $customer['customer_username']]);
        $acDetails = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Filter AC details to only include those where installed_pc matches a computer_name in pcDetails
        $filteredAcDetails = [];
        $pcNames = array_column($pcDetails, 'computer_name');
        foreach ($acDetails as $ac) {
            if (in_array($ac['installed_pc'], $pcNames)) {
                $filteredAcDetails[] = $ac;
            }
        }

        // Fetch SW details
        $stmt = $pdo->prepare("
            SELECT sw.item_type_sw_group_name, sw.active, sw.installed_pc, sw.enterprise_site_id, sw.login, sw.password, sw.software_name, sw.software_version, sw.master_account_id, sw.software_provider
            FROM item_type_sw sw
            WHERE sw.installed_pc IN (SELECT computer_name FROM item_type_pc WHERE customer_username = :customer_username)
        ");
        $stmt->execute([':customer_username' => $customer['customer_username']]);
        $swDetails = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Separate SW details into categories
        $swCategories = [
            'Antivirus Endpoint Master',
            'Antivirus Endpoint Client',
            'Office 365',
            'Antivirus Internet Security',
            'Other Software',
            'Microsoft (No Renewal)'
        ];
        $separatedSwDetails = [];
        foreach ($swCategories as $category) {
            $separatedSwDetails[$category] = array_filter($swDetails, function($sw) use ($category) {
                return $sw['item_type_sw_group_name'] === $category;
            });
        }

        // Fetch HW details
        $stmt = $pdo->prepare("
            SELECT hw.item_type_hw_group_name, hw.active, hw.installed_pc, hw.brand, hw.model, hw.serial_number, hw.software, hw.ddns, hw.user_login, hw.user_password
            FROM item_type_hw hw
            WHERE hw.installed_pc IN (SELECT computer_name FROM item_type_pc WHERE customer_username = :customer_username)
        ");
        $stmt->execute([':customer_username' => $customer['customer_username']]);
        $hwDetails = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Separate HW details into categories
        $hwCategories = [
            'UPS',
            'Printer',
            'CCTV',
            'Others'
        ];
        $separatedHwDetails = [];
        foreach ($hwCategories as $category) {
            $separatedHwDetails[$category] = array_filter($hwDetails, function($hw) use ($category) {
                return $hw['item_type_hw_group_name'] === $category;
            });
        }

        // Fetch NAS details for Active Backup Physical Server
        $stmt = $pdo->prepare("
            SELECT nas.pb_installed_pc, nas.pb_service_name
            FROM item_type_nas nas
            WHERE nas.pb_installed_pc IN (SELECT computer_name FROM item_type_pc WHERE customer_username = :customer_username)
        ");
        $stmt->execute([':customer_username' => $customer['customer_username']]);
        $pbNasDetails = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Fetch NAS details for Active Backup File Server
        $stmt = $pdo->prepare("
            SELECT nas.fs_installed_pc, nas.fs_service_name
            FROM item_type_nas nas
            WHERE nas.fs_installed_pc IN (SELECT computer_name FROM item_type_pc WHERE customer_username = :customer_username)
        ");
        $stmt->execute([':customer_username' => $customer['customer_username']]);
        $fsNasDetails = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Fetch Hosting details for Email
        $stmt = $pdo->prepare("
            SELECT hosting.email_account, hosting.customer_username, hosting.email_account, hosting.installed_pc
            FROM item_type_hosting hosting
            WHERE hosting.item_type_hosting_group_name = 'Email'
            AND hosting.installed_pc IN (SELECT computer_name FROM item_type_pc WHERE customer_username = :customer_username)
        ");
        $stmt->execute([':customer_username' => $customer['customer_username']]);
        $hostingDetails = $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
} else {
    echo "<p>Invalid parameters. Please check the URL.</p>";
    exit();
}

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Customer Details</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <!-- Custom CSS -->
    <style>
        .card {
            border: 1px solid #ddd; /* Simple border */
            margin-bottom: 20px; /* Spacing between cards */
        }
        .card-header {
            background-color: #f8f9fa; /* Light gray background */
            border-bottom: 1px solid #ddd; /* Simple border */
            padding: 10px 15px; /* Padding for header */
        }
        .card-body {
            padding: 15px; /* Padding for body */
        }
        .table {
            margin-bottom: 0; /* Remove extra margin */
        }
        .table th {
            background-color: #f8f9fa; /* Light gray background for headers */
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <!-- Customer Details -->
        <?php if ($customer): ?>
        <div class="card">
            <div class="card-header d-flex justify-content-between align-items-center">
                <h3 class="mb-0">Customer Details</h3>
                <!-- Edit and Delete Buttons -->
                <div>
                    <a href="edit_customer.php?customer_info_id=<?= $customer_info_id ?>&debtor_code=<?= $debtor_code ?>" class="btn btn-warning">
                        <i class="fas fa-pen"></i> <!-- Font Awesome pen icon -->
                    </a>
                    <form method="POST" style="display: inline-block;" onsubmit="return confirm('Are you sure you want to delete this customer?');">
                        <button type="submit" name="delete_customer" class="btn btn-danger">
                            <i class="fas fa-trash"></i> <!-- Font Awesome trash icon -->
                        </button>
                    </form>
                </div>
            </div>
            <div class="card-body">
                <table class="table table-bordered">
                    <tr>
                        <th>Customer Username</th>
                        <td><?= htmlspecialchars($customer['customer_username']) ?></td>
                    </tr>
                    <tr>
                        <th>Customer Mobile</th>
                        <td><?= htmlspecialchars($customer['customer_mobile']) ?></td>
                    </tr>
                    <tr>
                        <th>Customer Email</th>
                        <td><?= htmlspecialchars($customer['customer_email']) ?></td>
                    </tr>
                    <tr>
                        <th>Customer Title</th>
                        <td><?= htmlspecialchars($customer['customer_title']) ?></td>
                    </tr>
                    <tr>
                        <th>Customer Department</th>
                        <td><?= htmlspecialchars($customer['customer_dept']) ?></td>
                    </tr>
                    <tr>
                        <th>Debtor Code</th>
                        <td><?= htmlspecialchars($customer['debtor_code']) ?></td>
                    </tr>
                    <tr>
                        <th>Company Name</th>
                        <td><?= htmlspecialchars($customer['company_name']) ?></td>
                    </tr>
                </table>
            </div>
        </div>

        <!-- PC Details -->
        <?php if (!empty($pcDetails)): ?>
        <div class="card">
            <div class="card-header">
                <h3 class="mb-0">PC Details</h3>
            </div>
            <div class="card-body">
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>Computer Name</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($pcDetails as $pc): ?>
                        <tr>
                            <td><?= htmlspecialchars($pc['computer_name']) ?></td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
        <?php endif; ?>

        <!-- AC Details -->
        <?php if (!empty($filteredAcDetails)): ?>
        <div class="card">
            <div class="card-header">
                <h3 class="mb-0">AC Details</h3>
            </div>
            <div class="card-body">
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>AC Group Name</th>
                            <th>Installed PC</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($filteredAcDetails as $ac): ?>
                        <tr>
                            <td><?= htmlspecialchars($ac['item_type_ac_group_name']) ?></td>
                            <td><?= htmlspecialchars($ac['installed_pc']) ?></td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
        <?php endif; ?>

        <!-- Software Details -->
        <?php if (!empty($separatedSwDetails)): ?>
        <?php foreach ($separatedSwDetails as $category => $swDetails): ?>
        <?php if (!empty($swDetails)): ?>
        <div class="card">
            <div class="card-header">
                <h3 class="card-title"><?= htmlspecialchars($category) ?></h3>
            </div>
            <div class="card-body">
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>Active</th>
                            <th>Installed PC</th>
                            <?php if (in_array($category, ['Antivirus Endpoint Master', 'Antivirus Endpoint Client'])): ?>
                                <th>Enterprise Site ID</th>
                            <?php endif; ?>
                            <?php if (in_array($category, ['Office 365'])): ?>
                                <th>Master Account ID</th>
                            <?php endif; ?>
                            <th>Login</th>
                            <th>Password</th>
                            <?php if (in_array($category, ['Antivirus Endpoint Master', 'Antivirus Endpoint Client', 'Microsoft (No Renewal)'])): ?>
                                <th>Software Name</th>
                            <?php endif; ?>
                            <?php if (in_array($category, ['Antivirus Endpoint Master', 'Antivirus Endpoint Client'])): ?>
                                <th>Software Version</th>
                            <?php endif; ?>
                            <?php if (in_array($category, ['Other Software'])): ?>
                                <th>Software Provider</th>
                            <?php endif; ?>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($swDetails as $sw): ?>
                        <tr>
                            <td><?= htmlspecialchars($sw['active']) ?></td>
                            <td><?= htmlspecialchars($sw['installed_pc']) ?></td>
                            <?php if (in_array($category, ['Antivirus Endpoint Master', 'Antivirus Endpoint Client'])): ?>
                                <td><?= htmlspecialchars($sw['enterprise_site_id']) ?></td>
                            <?php endif; ?>
                            <?php if (in_array($category, ['Office 365'])): ?>
                                <td><?= htmlspecialchars($sw['master_account_id']) ?></td>
                            <?php endif; ?>
                            <td><?= htmlspecialchars($sw['login']) ?></td>
                            <td><?= htmlspecialchars(decryptPassword($sw['password'], $encryption_key)) ?></td>
                            <?php if (in_array($category, ['Antivirus Endpoint Master', 'Antivirus Endpoint Client', 'Microsoft (No Renewal)'])): ?>
                                <td><?= htmlspecialchars($sw['software_name']) ?></td>
                            <?php endif; ?>
                            <?php if (in_array($category, ['Antivirus Endpoint Master', 'Antivirus Endpoint Client'])): ?>
                                <td><?= htmlspecialchars($sw['software_version']) ?></td>
                            <?php endif; ?>
                            <?php if (in_array($category, ['Other Software'])): ?>
                                <td><?= htmlspecialchars($sw['software_provider']) ?></td>
                            <?php endif; ?>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
        <?php endif; ?>
        <?php endforeach; ?>
        <?php endif; ?>

        <!-- Hardware Details -->
        <?php if (!empty($separatedHwDetails)): ?>
        <?php foreach ($separatedHwDetails as $category => $hwDetails): ?>
        <?php if (!empty($hwDetails)): ?>
        <div class="card">
            <div class="card-header">
                <h3 class="card-title"><?= htmlspecialchars($category) ?></h3>
            </div>
            <div class="card-body">
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>Active</th>
                            <?php if (in_array($category, ['UPS', 'Printer', 'Others'])): ?>
                                <th>Installed PC</th>
                                <th>Brand</th>
                                <th>Model</th>
                                <th>Serial Number</th>
                            <?php endif; ?>
                            <?php if (in_array($category, ['CCTV'])): ?>
                                <th>Model</th>
                                <th>Software</th>
                                <th>DDNS</th>
                                <th>User Login</th>
                                <th>User Password</th>
                            <?php endif; ?>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($hwDetails as $hw): ?>
                        <tr>
                            <td><?= htmlspecialchars($hw['active']) ?></td>
                            <?php if (in_array($category, ['UPS', 'Printer', 'Others'])): ?>
                                <td><?= htmlspecialchars($hw['installed_pc']) ?></td>
                                <td><?= htmlspecialchars($hw['brand']) ?></td>
                                <td><?= htmlspecialchars($hw['model']) ?></td>
                                <td><?= htmlspecialchars($hw['serial_number']) ?></td>
                            <?php endif; ?>
                            <?php if (in_array($category, ['CCTV'])): ?>
                                <td><?= htmlspecialchars($hw['model']) ?></td>
                                <td><?= htmlspecialchars($hw['software']) ?></td>
                                <td><?= htmlspecialchars($hw['ddns']) ?></td>
                                <td><?= htmlspecialchars($hw['user_login']) ?></td>
                                <td><?= htmlspecialchars(decryptPassword($hw['user_password'], $encryption_key)) ?></td>
                            <?php endif; ?>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
        <?php endif; ?>
        <?php endforeach; ?>
        <?php endif; ?>

        <!-- NAS Details -->
        <?php if (!empty($pbNasDetails) || !empty($fsNasDetails)): ?>
        <div class="card">
            <div class="card-header">
                <h3 class="mb-0">NAS Details</h3>
            </div>
            <div class="card-body">
                <?php if (!empty($pbNasDetails)): ?>
                <h3>Active Backup Physical Server</h3>
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>Service Name</th>
                            <th>Installed PC</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($pbNasDetails as $nas): ?>
                        <tr>
                            <td><?= htmlspecialchars($nas['pb_service_name']) ?></td>
                            <td><?= htmlspecialchars($nas['pb_installed_pc']) ?></td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
                <?php endif; ?>

                <?php if (!empty($fsNasDetails)): ?>
                <h3>Active Backup File Server</h3>
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>Service Name</th>
                            <th>Installed PC</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($fsNasDetails as $nas): ?>
                        <tr>
                            <td><?= htmlspecialchars($nas['fs_service_name']) ?></td>
                            <td><?= htmlspecialchars($nas['fs_installed_pc']) ?></td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
                <?php endif; ?>
            </div>
        </div>
        <?php endif; ?>

        <!-- Hosting Details -->
        <?php if (!empty($hostingDetails)): ?>
        <div class="card">
            <div class="card-header">
                <h3 class="mb-0">Hosting Details</h3>
            </div>
            <div class="card-body">
                <table class="table table-bordered">
                    <thead>
                        <tr>
                            <th>Email Account</th>
                            <th>Customer Username</th>
                            <th>Installed PC</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($hostingDetails as $hosting): ?>
                        <tr>
                            <td><?= htmlspecialchars($hosting['email_account']) ?></td>
                            <td><?= htmlspecialchars($hosting['customer_username']) ?></td>
                            <td><?= htmlspecialchars($hosting['installed_pc']) ?></td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
        </div>
        <?php endif; ?>

        <?php else: ?>
        <p class="alert alert-warning">No customer found with the provided debtor code and customer_info_id.</p>
        <?php endif; ?>

        <a href="/crm/public/customer/search_customer.php" class="btn btn-primary mb-3">Back</a>
    </div>

    <!-- Bootstrap 5.x JS and dependencies -->
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>