<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set(timezoneId: 'Asia/Kuala_Lumpur');

// Check if customer_info_id is passed as a query parameter
if (!isset($_GET['customer_info_id']) || empty($_GET['customer_info_id'])) {
    die("<div class='alert alert-danger'>Customer ID is required.</div>");
}
$customerId = $_GET['customer_info_id'];

// Fetch customer details from the database
$stmt = $pdo->prepare("SELECT * FROM customer_info WHERE customer_info_id = ?");
$stmt->execute([$customerId]);
$customer = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$customer) {
    die("<div class='alert alert-danger'>Customer not found.</div>");
}

// Handle form submission for updating customer details
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action']) && $_POST['action'] == 'update_customer') {
    // Retrieve form data
    $customer_prefix = $_POST['customer_prefix'];
    $customer_username = $_POST['customer_username'];
    $customer_mobile = $_POST['customer_mobile'];
    $customer_email = $_POST['customer_email'];
    $customer_title = $_POST['customer_title'];
    $customer_dept = $_POST['customer_dept'];
    $company_name = $_POST['company_name'];
    $debtor_code = $_POST['debtor_code'];
    $main_customer = isset($_POST['main_customer']) ? 1 : 0; // Check if main_customer checkbox is checked

    // Validate company_name and debtor_code
    if (empty($company_name) || empty($debtor_code)) {
        echo "<div class='alert alert-danger'>Company name and debtor code are required.</div>";
    } else {
        // Compare old and new data
        $changes = [];
        if ($customer['prefix'] != $customer_prefix) {
            $changes[] = "Prefix: {$customer['prefix']} → $customer_prefix";
        }
        if ($customer['customer_username'] != $customer_username) {
            $changes[] = "Username: {$customer['customer_username']} → $customer_username";
        }
        if ($customer['customer_mobile'] != $customer_mobile) {
            $changes[] = "Mobile: {$customer['customer_mobile']} → $customer_mobile";
        }
        if ($customer['customer_email'] != $customer_email) {
            $changes[] = "Email: {$customer['customer_email']} → $customer_email";
        }
        if ($customer['customer_title'] != $customer_title) {
            $changes[] = "Title: {$customer['customer_title']} → $customer_title";
        }
        if ($customer['customer_dept'] != $customer_dept) {
            $changes[] = "Department: {$customer['customer_dept']} → $customer_dept";
        }
        if ($customer['company_name'] != $company_name) {
            $changes[] = "Company Name: {$customer['company_name']} → $company_name";
        }
        if ($customer['debtor_code'] != $debtor_code) {
            $changes[] = "Debtor Code: {$customer['debtor_code']} → $debtor_code";
        }
        if ($customer['main_customer'] != $main_customer) {
            $changes[] = "Main Customer: {$customer['main_customer']} → $main_customer";
        }

        // If there are changes, update the database and log the activity
        if (!empty($changes)) {
            // Update customer_info
            $stmt = $pdo->prepare("UPDATE customer_info SET customer_username = ?, customer_mobile = ?, customer_email = ?, customer_title = ?, customer_dept = ?, company_name = ?, debtor_code = ?, main_customer = ?, prefix = ? WHERE customer_info_id = ?");
            $stmt->execute([$customer_username, $customer_mobile, $customer_email, $customer_title, $customer_dept, $company_name, $debtor_code, $main_customer, $customer_prefix, $customerId]);

            // Construct the log message
            $logMessage = "Customer updated for $company_name (Username: $customer_username).\nChanges: " . implode(", ", $changes);

            // Insert the log into activity_logs
            $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
                       VALUES (:username, :timestamp, :role, :activity)";
            $stmtLog = $pdo->prepare($sqlLog);
            $stmtLog->execute([
                ':username' => $_SESSION['username'],
                ':timestamp' => date('Y-m-d H:i:s'),
                ':role' => $_SESSION['role'],
                ':activity' => $logMessage
            ]);

            // Redirect with success message
            echo "<script>alert('Customer updated successfully!'); window.location.href = 'customer_details.php?debtor_code=$debtor_code&customer_info_id=$customerId';</script>";
        } else {
            // No changes detected, show alert and redirect back to customer details page
            echo "<script>alert('No data changed.'); window.location.href = 'customer_details.php?debtor_code=$debtor_code&customer_info_id=$customerId';</script>";
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Customer</title>
    <!-- Bootstrap 5.x CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .dropdown-menu {
            display: none;
            position: absolute;
            z-index: 1000;
            background-color: white;
            border: 1px solid #ccc;
            max-height: 200px;
            overflow-y: auto;
            width: 100%;
            box-shadow: 0 8px 16px rgba(0, 0, 0, 0.1);
        }
        .dropdown-menu.show {
            display: block;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h2 class='mb-0'>Edit Customer</h2>
            </div>
            <div class="card-body">
                <form method="POST" action="">
                    <input type="hidden" name="action" value="update_customer">

                    <!-- Company Details -->
                    <div class="card mb-3 shadow-sm">
                        <div class="card-header">
                            <h5 class="card-title">Company Details</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-9">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="company_search" oninput="searchCompanies()" placeholder="Company Name" required value="<?= htmlspecialchars($customer['company_name']); ?>" disabled>
                                        <label for="company_search">Company Name</label>
                                        <div id="company_results" class="dropdown-menu"></div>
                                    </div>
                                    <input type="hidden" id="company_name" name="company_name" value="<?= htmlspecialchars($customer['company_name']); ?>">
                                </div>
                                <div class="col-md-3">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="debtor_code_display" disabled placeholder="Debtor Code" value="<?= htmlspecialchars($customer['debtor_code']); ?>">
                                        <label for="debtor_code_display">Debtor Code</label>
                                    </div>
                                    <input type="hidden" id="debtor_code" name="debtor_code" value="<?= htmlspecialchars($customer['debtor_code']); ?>">
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Main Customer Checkbox -->
                    <div class="card mb-3 shadow-sm">
                        <div class="card-header">
                            <h5 class="card-title">Main Customer</h5>
                        </div>
                        <div class="card-body">
                            <div class="form-check form-switch">
                                <input type="checkbox" class="form-check-input" id="main_customer" name="main_customer" <?= $customer['main_customer'] ? 'checked' : ''; ?>>
                                <label class="form-check-label" for="main_customer">Main Customer</label>
                            </div>
                        </div>
                    </div>

                    <!-- Customer Name and Prefix -->
                    <div class="card mb-3 shadow-sm">
                        <div class="card-header">
                            <h5 class="card-title">Customer Name and Prefix</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-2">
                                    <div class="form-floating mb-3">
                                        <select class="form-select" id="customer_prefix" name="customer_prefix">
                                            <option value="Mr." <?= ($customer['prefix'] ?? '') == 'Mr.' ? 'selected' : ''; ?>>Mr.</option>
                                            <option value="Mrs." <?= ($customer['prefix'] ?? '') == 'Mrs.' ? 'selected' : ''; ?>>Mrs.</option>
                                            <option value="Ms." <?= ($customer['prefix'] ?? '') == 'Ms.' ? 'selected' : ''; ?>>Ms.</option>
                                        </select>
                                        <label for="customer_prefix">Prefix</label>
                                    </div>
                                </div>
                                <div class="col-md-10">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="customer_username" name="customer_username" placeholder="Customer Name" required value="<?= htmlspecialchars($customer['customer_username']); ?>">
                                        <label for="customer_username">Customer Name</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Additional Fields -->
                    <div class="card mb-3 shadow-sm">
                        <div class="card-header">
                            <h5 class="card-title">Additional Information</h5>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="customer_mobile" name="customer_mobile" placeholder="Mobile" value="<?= htmlspecialchars($customer['customer_mobile']); ?>">
                                        <label for="customer_mobile">Mobile</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="email" class="form-control" id="customer_email" name="customer_email" placeholder="Email" value="<?= htmlspecialchars($customer['customer_email']); ?>">
                                        <label for="customer_email">Email</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="customer_title" name="customer_title" placeholder="Title" value="<?= htmlspecialchars($customer['customer_title']); ?>">
                                        <label for="customer_title">Title</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating mb-3">
                                        <input type="text" class="form-control" id="customer_dept" name="customer_dept" placeholder="Department" value="<?= htmlspecialchars($customer['customer_dept']); ?>">
                                        <label for="customer_dept">Department</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Submit Button -->
                    <div class="text-center">
                        <button type="submit" class="btn btn-primary" id="submitBtn">Update Customer</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.x JS and dependencies -->
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>