<?php
require 'config/auth.php'; // Ensure user is authenticated
require '../layout/header.php';
require '../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Initialize variables
$item_code_id = null;
$item_code = null;
$item_name = null;
$configurations = [];

// Check if item_code_id is passed via URL
if (isset($_GET['item_code_id'])) {
    $item_code_id = filter_input(INPUT_GET, 'item_code_id', FILTER_SANITIZE_NUMBER_INT);
    $sql = "SELECT item_code, item_name FROM item_code WHERE item_code_id = :item_code_id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':item_code_id', $item_code_id);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);
    if ($item) {
        $item_code = $item['item_code'];
        $item_name = $item['item_name'];
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $item_code_id = filter_input(INPUT_POST, 'item_code_id', FILTER_SANITIZE_NUMBER_INT);
    $title = filter_input(INPUT_POST, 'title', FILTER_SANITIZE_STRING);
    $configurations = $_POST['configurations'];

    // Define the base directory for saving photos based on the item_code and title
    $baseDir = '../../images/configuration_note/' . $item_code . '/' . $title . '/';
    if (!is_dir($baseDir)) {
        mkdir($baseDir, 0777, true);
    }

    foreach ($configurations as $index => $configuration) {
        $configuration_name = filter_var($configuration['configuration_name'], FILTER_SANITIZE_STRING);
        $configuration_description = filter_var($configuration['configuration_description'], FILTER_SANITIZE_STRING);

        // Handle file upload if a file is uploaded
        if (!empty($_FILES['configurations']['name'][$index]['configuration_photo'])) {
            $configuration_photo = $_FILES['configurations']['name'][$index]['configuration_photo'];
            $configuration_photo_tmp = $_FILES['configurations']['tmp_name'][$index]['configuration_photo'];

            // Generate garbled characters for the file name (for example, a random string)
            $random_string = bin2hex(random_bytes(10)); // Generates a 20-character random string
            $file_extension = pathinfo($configuration_photo, PATHINFO_EXTENSION); // Get the file extension
            $new_file_name = $random_string . '.' . $file_extension;

            // Set the final path for the image file
            $configuration_photo_path = $baseDir . $new_file_name;

            // Move the uploaded file to the desired folder
            if (move_uploaded_file($configuration_photo_tmp, $configuration_photo_path)) {
                // Insert query including item_code and item_name
                $sql = "INSERT INTO configuration_steps (item_code_id, item_code, item_name, title, configuration_name, configuration_description, configuration_photo) 
                        VALUES (:item_code_id, :item_code, :item_name, :title, :configuration_name, :configuration_description, :configuration_photo)";
                $stmt = $pdo->prepare($sql);
                $stmt->bindParam(':item_code_id', $item_code_id);
                $stmt->bindParam(':item_code', $item_code);
                $stmt->bindParam(':item_name', $item_name);
                $stmt->bindParam(':title', $title);
                $stmt->bindParam(':configuration_name', $configuration_name);
                $stmt->bindParam(':configuration_description', $configuration_description);
                $stmt->bindParam(':configuration_photo', $configuration_photo_path);

                if ($stmt->execute()) {
                    echo "<script>alert('Data saved successfully!'); window.location.href='item_function.php';</script>";
                } else {
                    echo "<script>alert('Failed to save data. Please try again.');</script>";
                }            
            } else {
                echo "<script>alert('Failed to upload photo. Please try again.');</script>";
            }
        } else {
            // Insert query without the configuration_photo field
            $sql = "INSERT INTO configuration_steps (item_code_id, item_code, item_name, title, configuration_name, configuration_description) 
                    VALUES (:item_code_id, :item_code, :item_name, :title, :configuration_name, :configuration_description)";
            $stmt = $pdo->prepare($sql);
            $stmt->bindParam(':item_code_id', $item_code_id);
            $stmt->bindParam(':item_code', $item_code);
            $stmt->bindParam(':item_name', $item_name);
            $stmt->bindParam(':title', $title);
            $stmt->bindParam(':configuration_name', $configuration_name);
            $stmt->bindParam(':configuration_description', $configuration_description);

            if ($stmt->execute()) {
                echo "<script>alert('Data saved successfully!'); window.location.href='item_function.php';</script>";
            } else {
                echo "<script>alert('Failed to save data. Please try again.');</script>";
            }            
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Configuration Step</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <h2 class="mb-4">Configuration Step</h2>
    <form method="POST" action="" enctype="multipart/form-data">
        <input type="hidden" name="item_code_id" value="<?= $item_code_id ?>">

        <!-- Card for Item Code, Item Name, and Title -->
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="card-title">Item Details</h5>
            </div>
            <div class="card-body">
                <div class="row">
                    <div class="col-md-4">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="item_code" name="item_code" value="<?= htmlspecialchars($item_code) ?>" disabled>
                            <label for="item_code">Item Code</label>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="item_name" name="item_name" value="<?= htmlspecialchars($item_name) ?>" disabled>
                            <label for="item_name">Item Name</label>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="title" name="title" required>
                            <label for="title">Title</label>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Card for Configuration Steps -->
        <div id="configurations-container">
            <div class="card mb-3">
                <div class="card-header">
                    <h5 class="card-title">Configuration Step 1</h5>
                </div>
                <div class="card-body">
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="configuration_name_1" name="configurations[0][configuration_name]" placeholder="Configuration Name" required>
                                <label for="configuration_name_1">Configuration Name</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="configuration_description_1" name="configurations[0][configuration_description]" placeholder="Configuration Description" required></textarea>
                                <label for="configuration_description_1">Configuration Description</label>
                            </div>
                        </div>
                        <div class="col-md-12">
                            <div class="mb-3">
                                <label for="configuration_photo_1" class="form-label">Configuration Photo</label>
                                <input type="file" class="form-control" id="configuration_photo_1" name="configurations[0][configuration_photo]">
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <button type="button" class="btn btn-secondary" id="add-configuration">Add New Configuration</button>
        <button type="submit" class="btn btn-primary">Save</button>
    </form>
</div>

<!-- Bootstrap 5.3 JS Bundle CDN (includes Popper.js) -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
<script>
    document.addEventListener('DOMContentLoaded', function() {
        let configurationCounter = 2;
        const addConfigurationButton = document.getElementById('add-configuration');
        const configurationsContainer = document.getElementById('configurations-container');

        addConfigurationButton.addEventListener('click', function() {
            const card = document.createElement('div');
            card.className = 'card mb-3';
            card.innerHTML = `
                <div class="card-header">
                    <h5 class="card-title">Configuration Step ${configurationCounter}</h5>
                </div>
                <div class="card-body">
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="configuration_name_${configurationCounter}" name="configurations[${configurationCounter - 1}][configuration_name]" placeholder="Configuration Name" required>
                                <label for="configuration_name_${configurationCounter}">Configuration Name</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="configuration_description_${configurationCounter}" name="configurations[${configurationCounter - 1}][configuration_description]" placeholder="Configuration Description" required></textarea>
                                <label for="configuration_description_${configurationCounter}">Configuration Description</label>
                            </div>
                        </div>
                        <div class="col-md-12">
                            <div class="mb-3">
                                <label for="configuration_photo_${configurationCounter}" class="form-label">Configuration Photo</label>
                                <input type="file" class="form-control" id="configuration_photo_${configurationCounter}" name="configurations[${configurationCounter - 1}][configuration_photo]">
                            </div>
                        </div>
                    </div>
                </div>
            `;

            configurationsContainer.appendChild(card);
            configurationCounter++;
        });
    });
</script>


</body>
</html>