<?php
require 'config/auth.php'; // Ensure user is authenticated
require '../layout/header.php';
require '../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Initialize variables
$item_code_id = null;
$title = null;
$item_code = null;
$item_name = null;
$configurations = [];

// Check if item_code_id and title are passed via URL
if (isset($_GET['item_code_id']) && isset($_GET['title'])) {
    $item_code_id = filter_input(INPUT_GET, 'item_code_id', FILTER_SANITIZE_NUMBER_INT);
    $title = filter_input(INPUT_GET, 'title', FILTER_SANITIZE_STRING);

    // Fetch item code and item name for the selected item code ID
    $sql = "SELECT item_code, item_name FROM item_code WHERE item_code_id = :item_code_id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':item_code_id', $item_code_id);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);
    if ($item) {
        $item_code = $item['item_code'];
        $item_name = $item['item_name'];
    }

    // Fetch existing configuration steps for the selected item code and title
    $sql = "SELECT id, configuration_name, configuration_description, configuration_photo FROM configuration_steps WHERE item_code_id = :item_code_id AND title = :title";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':item_code_id', $item_code_id);
    $stmt->bindParam(':title', $title);
    $stmt->execute();
    $configurations = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Check if any configurations were found
    if (empty($configurations)) {
        echo "<script>alert('No configuration steps found for the given item code and title.'); window.location.href='item_function.php';</script>";
        exit();
    }
} else {
    echo "<script>alert('Item code ID and title are required.'); window.location.href='item_function.php';</script>";
    exit();
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $item_code_id = filter_input(INPUT_POST, 'item_code_id', FILTER_SANITIZE_NUMBER_INT);
    $title = filter_input(INPUT_POST, 'title', FILTER_SANITIZE_STRING);
    $configurations = $_POST['configurations'];
    $deleted_ids = isset($_POST['deleted_ids']) ? $_POST['deleted_ids'] : [];

    // Fetch existing configurations from the database for comparison
    $sql = "SELECT id, configuration_name, configuration_description, configuration_photo FROM configuration_steps WHERE item_code_id = :item_code_id AND title = :title";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':item_code_id', $item_code_id);
    $stmt->bindParam(':title', $title);
    $stmt->execute();
    $existing_configurations = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Check if any changes were made
    $has_changes = false;

    // Compare existing data with submitted data
    foreach ($existing_configurations as $existing) {
        $id = $existing['id'];
        if (isset($configurations[$id])) {
            if ($existing['configuration_name'] !== $configurations[$id]['configuration_name'] ||
                $existing['configuration_description'] !== $configurations[$id]['configuration_description']) {
                $has_changes = true;
                break;
            }
        }
    }

    // Check if new configurations were added
    if (isset($_POST['new_configurations']) && !empty($_POST['new_configurations'])) {
        $has_changes = true;
    }

    // Check if any configurations were deleted
    if (!empty($deleted_ids)) {
        $has_changes = true;
    }

    // If no changes were made, display an alert and exit
    if (!$has_changes) {
        echo "<script>alert('No data changed.'); window.location.href='search_configuration_steps.php';</script>";
        exit();
    }

    // Delete configurations marked for deletion
    foreach ($deleted_ids as $id) {
        $sql = "DELETE FROM configuration_steps WHERE id = :id AND item_code_id = :item_code_id AND title = :title";
        $stmt = $pdo->prepare($sql);
        $stmt->bindParam(':id', $id);
        $stmt->bindParam(':item_code_id', $item_code_id);
        $stmt->bindParam(':title', $title);
        $stmt->execute();
    }

    // Update existing configurations and insert new configurations
    foreach ($configurations as $id => $configuration) {
        $configuration_name = filter_var($configuration['configuration_name'], FILTER_SANITIZE_STRING);
        $configuration_description = filter_var($configuration['configuration_description'], FILTER_SANITIZE_STRING);

        // Handle file upload if a file is uploaded
        if (!empty($_FILES['configurations']['name'][$id]['configuration_photo'])) {
            $configuration_photo = $_FILES['configurations']['name'][$id]['configuration_photo'];
            $configuration_photo_tmp = $_FILES['configurations']['tmp_name'][$id]['configuration_photo'];

            // Generate garbled characters for the file name (for example, a random string)
            $random_string = bin2hex(random_bytes(10)); // Generates a 20-character random string
            $file_extension = pathinfo($configuration_photo, PATHINFO_EXTENSION); // Get the file extension
            $new_file_name = $random_string . '.' . $file_extension;

            // Set the final path for the image file
            $configuration_photo_path = '../../images/configuration_note/' . $new_file_name;

            // Move the uploaded file to the desired folder
            if (move_uploaded_file($configuration_photo_tmp, $configuration_photo_path)) {
                // Update query including configuration_name and configuration_description
                $sql = "UPDATE configuration_steps SET configuration_name = :configuration_name, configuration_description = :configuration_description, configuration_photo = :configuration_photo WHERE id = :id AND item_code_id = :item_code_id AND title = :title";
                $stmt = $pdo->prepare($sql);
                $stmt->bindParam(':configuration_name', $configuration_name);
                $stmt->bindParam(':configuration_description', $configuration_description);
                $stmt->bindParam(':configuration_photo', $configuration_photo_path);
                $stmt->bindParam(':id', $id);
                $stmt->bindParam(':item_code_id', $item_code_id);
                $stmt->bindParam(':title', $title);

                if ($stmt->execute()) {
                    echo "<script>alert('Data updated successfully!'); window.location.href='item_function.php';</script>";
                } else {
                    echo "<script>alert('Failed to update data. Please try again.');</script>";
                }            
            } else {
                echo "<script>alert('Failed to upload photo. Please try again.');</script>";
            }
        } else {
            // Update query without the configuration_photo field
            $sql = "UPDATE configuration_steps SET configuration_name = :configuration_name, configuration_description = :configuration_description WHERE id = :id AND item_code_id = :item_code_id AND title = :title";
            $stmt = $pdo->prepare($sql);
            $stmt->bindParam(':configuration_name', $configuration_name);
            $stmt->bindParam(':configuration_description', $configuration_description);
            $stmt->bindParam(':id', $id);
            $stmt->bindParam(':item_code_id', $item_code_id);
            $stmt->bindParam(':title', $title);

            if ($stmt->execute()) {
                echo "<script>alert('Data updated successfully!'); window.location.href='item_function.php';</script>";
            } else {
                echo "<script>alert('Failed to update data. Please try again.');</script>";
            }            
        }
    }

    // Insert new configurations
    if (isset($_POST['new_configurations'])) {
        $new_configurations = $_POST['new_configurations'];
        foreach ($new_configurations as $index => $new_configuration) {
            $new_configuration_name = filter_var($new_configuration['configuration_name'], FILTER_SANITIZE_STRING);
            $new_configuration_description = filter_var($new_configuration['configuration_description'], FILTER_SANITIZE_STRING);

            // Handle file upload if a file is uploaded
            if (!empty($_FILES['new_configurations']['name'][$index]['configuration_photo'])) {
                $new_configuration_photo = $_FILES['new_configurations']['name'][$index]['configuration_photo'];
                $new_configuration_photo_tmp = $_FILES['new_configurations']['tmp_name'][$index]['configuration_photo'];

                // Generate garbled characters for the file name (for example, a random string)
                $random_string = bin2hex(random_bytes(10)); // Generates a 20-character random string
                $file_extension = pathinfo($new_configuration_photo, PATHINFO_EXTENSION); // Get the file extension
                $new_file_name = $random_string . '.' . $file_extension;

                // Set the final path for the image file
                $new_configuration_photo_path = '../../images/configuration_note/' . $new_file_name;

                // Move the uploaded file to the desired folder
                if (move_uploaded_file($new_configuration_photo_tmp, $new_configuration_photo_path)) {
                    // Insert query including configuration_name and configuration_description
                    $sql = "INSERT INTO configuration_steps (item_code_id, title, configuration_name, configuration_description, configuration_photo) VALUES (:item_code_id, :title, :configuration_name, :configuration_description, :configuration_photo)";
                    $stmt = $pdo->prepare($sql);
                    $stmt->bindParam(':item_code_id', $item_code_id);
                    $stmt->bindParam(':title', $title);
                    $stmt->bindParam(':configuration_name', $new_configuration_name);
                    $stmt->bindParam(':configuration_description', $new_configuration_description);
                    $stmt->bindParam(':configuration_photo', $new_configuration_photo_path);

                    if ($stmt->execute()) {
                        echo "<script>alert('Data inserted successfully!'); window.location.href='item_function.php';</script>";
                    } else {
                        echo "<script>alert('Failed to insert data. Please try again.');</script>";
                    }            
                } else {
                    echo "<script>alert('Failed to upload photo. Please try again.');</script>";
                }
            } else {
                // Insert query without the configuration_photo field
                $sql = "INSERT INTO configuration_steps (item_code_id, title, configuration_name, configuration_description) VALUES (:item_code_id, :title, :configuration_name, :configuration_description)";
                $stmt = $pdo->prepare($sql);
                $stmt->bindParam(':item_code_id', $item_code_id);
                $stmt->bindParam(':title', $title);
                $stmt->bindParam(':configuration_name', $new_configuration_name);
                $stmt->bindParam(':configuration_description', $new_configuration_description);

                if ($stmt->execute()) {
                    echo "<script>alert('Data inserted successfully!'); window.location.href='item_function.php';</script>";
                } else {
                    echo "<script>alert('Failed to insert data. Please try again.');</script>";
                }            
            }
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Configuration Steps</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <h2 class="mb-4">Edit Configuration Steps for Item Code ID: <?= $item_code_id ?> and Title: <?= htmlspecialchars($title) ?></h2>
    <form method="POST" action="" enctype="multipart/form-data">
        <input type="hidden" name="item_code_id" value="<?= $item_code_id ?>">
        <input type="hidden" name="title" value="<?= htmlspecialchars($title) ?>">

        <!-- Card for Item Code, Item Name, and Title -->
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="card-title">Item Details</h5>
            </div>
            <div class="card-body">
                <div class="row">
                    <div class="col-md-4">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="item_code" name="item_code" value="<?= htmlspecialchars($item_code) ?>" disabled>
                            <label for="item_code">Item Code</label>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="item_name" name="item_name" value="<?= htmlspecialchars($item_name) ?>" disabled>
                            <label for="item_name">Item Name</label>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="title" name="title" value="<?= htmlspecialchars($title) ?>" disabled>
                            <label for="title">Title</label>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Card for Configuration Steps -->
        <div id="configurations-container">
            <?php foreach ($configurations as $index => $configuration): ?>
                <div class="card mb-3 configuration-group" data-id="<?= $configuration['id'] ?>">
                    <div class="card-body">
                        <input type="hidden" name="configurations[<?= $configuration['id'] ?>][id]" value="<?= $configuration['id'] ?>">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="configuration_name_<?= $index + 1 ?>" name="configurations[<?= $configuration['id'] ?>][configuration_name]" value="<?= htmlspecialchars($configuration['configuration_name']) ?>" required>
                            <label for="configuration_name_<?= $index + 1 ?>">Configuration Name</label>
                        </div>
                        <div class="form-floating mb-3">
                            <textarea class="form-control" id="configuration_description_<?= $index + 1 ?>" name="configurations[<?= $configuration['id'] ?>][configuration_description]" required><?= htmlspecialchars($configuration['configuration_description']) ?></textarea>
                            <label for="configuration_description_<?= $index + 1 ?>">Configuration Description</label>
                        </div>
                        <div class="mb-3">
                            <label for="configuration_photo_<?= $index + 1 ?>" class="form-label">Configuration Photo</label>
                            <input type="file" class="form-control" id="configuration_photo_<?= $index + 1 ?>" name="configurations[<?= $configuration['id'] ?>][configuration_photo]">
                            
                            <?php if (!empty($configuration['configuration_photo'])): ?>
                                <p>Current Photo:</p>
                                <img src="<?= htmlspecialchars($configuration['configuration_photo']) ?>" alt="<?= basename($configuration['configuration_photo']) ?>" style="max-width: 300px; max-height: 300px;">
                                <p><?= basename($configuration['configuration_photo']) ?></p>
                            <?php endif; ?>
                        </div>

                        <button type="button" class="btn btn-danger delete-configuration">Delete</button>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>

        <button type="button" class="btn btn-secondary" id="add-configuration">Add New Configuration</button>
        <button type="submit" class="btn btn-primary">Update Configuration Steps</button>
    </form>
</div>

<!-- Bootstrap 5.3 JS Bundle CDN (includes Popper.js) -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
<script>
    document.addEventListener('DOMContentLoaded', function() {
        let configurationCounter = <?= count($configurations) + 1 ?>;
        const addConfigurationButton = document.getElementById('add-configuration');
        const configurationsContainer = document.getElementById('configurations-container');

        addConfigurationButton.addEventListener('click', function() {
            const card = document.createElement('div');
            card.className = 'card mb-3 configuration-group';

            card.innerHTML = `
                <div class="card-body">
                    <div class="form-floating mb-3">
                        <input type="text" class="form-control" id="new_configuration_name_${configurationCounter}" name="new_configurations[${configurationCounter - 1}][configuration_name]" required>
                        <label for="new_configuration_name_${configurationCounter}">Configuration Name</label>
                    </div>
                    <div class="form-floating mb-3">
                        <textarea class="form-control" id="new_configuration_description_${configurationCounter}" name="new_configurations[${configurationCounter - 1}][configuration_description]" required></textarea>
                        <label for="new_configuration_description_${configurationCounter}">Configuration Description</label>
                    </div>
                    <div class="mb-3">
                        <label for="new_configuration_photo_${configurationCounter}" class="form-label">Configuration Photo</label>
                        <input type="file" class="form-control" id="new_configuration_photo_${configurationCounter}" name="new_configurations[${configurationCounter - 1}][configuration_photo]">
                    </div>
                    <button type="button" class="btn btn-danger delete-configuration">Delete</button>
                </div>
            `;

            configurationsContainer.appendChild(card);
            configurationCounter++;
        });

        configurationsContainer.addEventListener('click', function(event) {
            if (event.target.classList.contains('delete-configuration')) {
                const card = event.target.closest('.configuration-group');
                const id = card.getAttribute('data-id');
                if (id) {
                    const deletedIdsInput = document.createElement('input');
                    deletedIdsInput.type = 'hidden';
                    deletedIdsInput.name = 'deleted_ids[]';
                    deletedIdsInput.value = id;
                    card.appendChild(deletedIdsInput);
                }
                card.style.display = 'none'; // Hide the card instead of removing it
            }
        });
    });
</script>


</body>
</html>