<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Initialize variables
$item_code_id = null;
$item_code = null;
$item_name = null;
$functions = [];

// Check if item_code_id is passed via URL
if (isset($_GET['item_code_id'])) {
    $item_code_id = filter_input(INPUT_GET, 'item_code_id', FILTER_SANITIZE_NUMBER_INT);
    $sql = "SELECT item_code, item_name FROM item_code WHERE item_code_id = :item_code_id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':item_code_id', $item_code_id);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);
    if ($item) {
        $item_code = $item['item_code'];
        $item_name = $item['item_name'];
    }

    // Fetch existing function notes
    $sql = "SELECT * FROM function_notes WHERE item_code_id = :item_code_id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':item_code_id', $item_code_id);
    $stmt->execute();
    $functions = $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $item_code_id = filter_input(INPUT_POST, 'item_code_id', FILTER_SANITIZE_NUMBER_INT);
    $functions = $_POST['functions'];

    // Define the base directory for saving photos based on the item_code
    $baseDir = '../../images/function_note/' . $item_code . '/';
    if (!is_dir($baseDir)) {
        mkdir($baseDir, 0777, true);
    }

    foreach ($functions as $index => $function) {
        $function_name = filter_var($function['function_name'], FILTER_SANITIZE_STRING);
        $function_description = filter_var($function['function_description'], FILTER_SANITIZE_STRING);

        // Handle file upload
        $function_photo = isset($_FILES['functions']['name'][$index]['function_photo']) ? $_FILES['functions']['name'][$index]['function_photo'] : null;
        $function_photo_tmp = isset($_FILES['functions']['tmp_name'][$index]['function_photo']) ? $_FILES['functions']['tmp_name'][$index]['function_photo'] : null;

        $function_photo_path = null;

        if ($function_photo && $function_photo_tmp) {
            // Generate garbled characters for the file name (for example, a random string)
            $random_string = bin2hex(random_bytes(10)); // Generates a 20-character random string
            $file_extension = pathinfo($function_photo, PATHINFO_EXTENSION); // Get the file extension
            $new_file_name = $random_string . '.' . $file_extension;

            // Set the final path for the image file
            $function_photo_path = $baseDir . $new_file_name;

            // Delete the old file if it exists
            if (!empty($function['function_photo']) && file_exists($function['function_photo'])) {
                unlink($function['function_photo']);
            }

            // Move the uploaded file to the desired folder
            if (!move_uploaded_file($function_photo_tmp, $function_photo_path)) {
                echo "<script>alert('Failed to upload photo. Please try again.');</script>";
                continue; // Skip this function and move to the next one
            }
        } else {
            // If no new file is uploaded, keep the old file path
            $function_photo_path = $function['function_photo'];
        }

        // Update query including item_code and item_name
        $sql = "UPDATE function_notes 
                SET function_name = :function_name, function_description = :function_description, function_photo = :function_photo 
                WHERE item_code_id = :item_code_id AND id = :id";
        $stmt = $pdo->prepare($sql);
        $stmt->bindParam(':item_code_id', $item_code_id);
        $stmt->bindParam(':function_name', $function_name);
        $stmt->bindParam(':function_description', $function_description);
        $stmt->bindParam(':function_photo', $function_photo_path);
        $stmt->bindParam(':id', $function['id']);

        // Execute and check for success
        if ($stmt->execute()) {
            echo "<script>alert('Data updated successfully!'); window.location.href='view_stock_item.php';</script>";
        } else {
            echo "<script>alert('Failed to update data. Please try again.');</script>";
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Function Note</title>
    <!-- Bootstrap 5.3 CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-5">
        <!-- Wrapping the entire form in a card with shadow -->
        <div class="card shadow-lg">
            <!-- Card Header -->
            <div class="card-header bg-primary text-white">
                <h2 class="mb-0">Edit Function Note</h2>
            </div>

            <!-- Card Body -->
            <div class="card-body">
                <form method="POST" action="" enctype="multipart/form-data">
                    <input type="hidden" name="item_code_id" value="<?= $item_code_id ?>">

                    <!-- Item Code and Item Name Wrapped in a Card -->
                    <div class="card mb-4">
                        <div class="card-body">
                            <div class="row">
                                <!-- Item Code Column -->
                                <div class="col-md-6">
                                    <div class="form-group mb-3">
                                        <label for="item_code">Item Code</label>
                                        <input type="text" class="form-control" id="item_code" name="item_code" value="<?= htmlspecialchars($item_code) ?>" disabled>
                                    </div>
                                </div>

                                <!-- Item Name Column -->
                                <div class="col-md-6">
                                    <div class="form-group mb-3">
                                        <label for="item_name">Item Name</label>
                                        <input type="text" class="form-control" id="item_name" name="item_name" value="<?= htmlspecialchars($item_name) ?>" disabled>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Functions Container -->
                    <div id="functions-container">
                        <?php foreach ($functions as $index => $function): ?>
                            <div class="card mb-3">
                                <div class="card-body">
                                    <input type="hidden" name="functions[<?= $index ?>][id]" value="<?= $function['id'] ?>">
                                    <div class="form-group mb-3">
                                        <label for="function_name_<?= $index ?>">Function Name <?= $index + 1 ?></label>
                                        <input type="text" class="form-control" id="function_name_<?= $index ?>" name="functions[<?= $index ?>][function_name]" value="<?= htmlspecialchars($function['function_name']) ?>" required>
                                    </div>
                                    <div class="form-group mb-3">
                                        <label for="function_description_<?= $index ?>">Function Description <?= $index + 1 ?></label>
                                        <textarea class="form-control" id="function_description_<?= $index ?>" name="functions[<?= $index ?>][function_description]" required><?= htmlspecialchars($function['function_description']) ?></textarea>
                                    </div>
                                    <div class="form-group mb-3">
                                        <label for="function_photo_<?= $index ?>">Function Photo <?= $index + 1 ?></label>
                                        <input type="file" class="form-control-file" id="function_photo_<?= $index ?>" name="functions[<?= $index ?>][function_photo]" onchange="previewImage(this, 'preview_<?= $index ?>')">
                                        <?php if (!empty($function['function_photo'])): ?>
                                            <img id="preview_<?= $index ?>" src="<?= $function['function_photo'] ?>" alt="Function Photo" style="max-width: 200px; margin-top: 10px;">
                                            <p>Current Photo: <?= basename($function['function_photo']) ?></p>
                                        <?php else: ?>
                                            <img id="preview_<?= $index ?>" src="#" alt="Function Photo" style="max-width: 200px; margin-top: 10px; display: none;">
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>

                    <!-- Buttons -->
                    <div class="mt-4">
                        <button type="button" class="btn btn-secondary" id="add-function">Add New Function</button>
                        <button type="submit" class="btn btn-primary">Save</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS and dependencies -->
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>

    <script>
        document.addEventListener('DOMContentLoaded', function() {
            let functionCounter = <?= count($functions) + 1 ?>;
            const addFunctionButton = document.getElementById('add-function');
            const functionsContainer = document.getElementById('functions-container');

            addFunctionButton.addEventListener('click', function() {
                const card = document.createElement('div');
                card.className = 'card mb-3';

                card.innerHTML = `
                    <div class="card-body">
                        <div class="form-group mb-3">
                            <label for="function_name_${functionCounter}">Function Name ${functionCounter}</label>
                            <input type="text" class="form-control" id="function_name_${functionCounter}" name="functions[${functionCounter - 1}][function_name]" required>
                        </div>
                        <div class="form-group mb-3">
                            <label for="function_description_${functionCounter}">Function Description ${functionCounter}</label>
                            <textarea class="form-control" id="function_description_${functionCounter}" name="functions[${functionCounter - 1}][function_description]" required></textarea>
                        </div>
                        <div class="form-group mb-3">
                            <label for="function_photo_${functionCounter}">Function Photo ${functionCounter}</label>
                            <input type="file" class="form-control-file" id="function_photo_${functionCounter}" name="functions[${functionCounter - 1}][function_photo]" onchange="previewImage(this, 'preview_${functionCounter}')">
                            <img id="preview_${functionCounter}" src="#" alt="Function Photo" style="max-width: 200px; margin-top: 10px; display: none;">
                        </div>
                    </div>
                `;

                functionsContainer.appendChild(card);
                functionCounter++;
            });
        });

        function previewImage(input, previewId) {
            const preview = document.getElementById(previewId);
            if (input.files && input.files[0]) {
                const reader = new FileReader();
                reader.onload = function(e) {
                    preview.src = e.target.result;
                    preview.style.display = 'block';
                }
                reader.readAsDataURL(input.files[0]);
            } else {
                preview.src = '#';
                preview.style.display = 'none';
            }
        }
    </script>
</body>
</html>