<?php
require 'config/auth.php'; // Ensure user is authenticated
require '../layout/header.php';
require '../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Initialize variables
$item_code_id = null;
$title = null;
$item_code = null;
$item_name = null;
$solve_problems = [];

// Check if item_code_id and title are passed via URL
if (isset($_GET['item_code_id']) && isset($_GET['title'])) {
    $item_code_id = filter_input(INPUT_GET, 'item_code_id', FILTER_SANITIZE_NUMBER_INT);
    $title = filter_input(INPUT_GET, 'title', FILTER_SANITIZE_STRING);

    // Fetch item code and item name for the selected item code ID
    $sql = "SELECT item_code, item_name FROM item_code WHERE item_code_id = :item_code_id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':item_code_id', $item_code_id);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);
    if ($item) {
        $item_code = $item['item_code'];
        $item_name = $item['item_name'];
    }

    // Fetch existing solve problem steps for the selected item code and title
    $sql = "SELECT id, solve_problem_name, solve_problem_description, solve_problem_photo FROM solve_problem_steps WHERE item_code_id = :item_code_id AND title = :title";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':item_code_id', $item_code_id);
    $stmt->bindParam(':title', $title);
    $stmt->execute();
    $solve_problems = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Check if any solve problems were found
    if (empty($solve_problems)) {
        echo "<script>alert('No solve problem steps found for the given item code and title.'); window.location.href='search_solve_problem_steps.php';</script>";
        exit();
    }
} else {
    echo "<script>alert('Item code ID and title are required.'); window.location.href='search_solve_problem_steps.php';</script>";
    exit();
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $item_code_id = filter_input(INPUT_POST, 'item_code_id', FILTER_SANITIZE_NUMBER_INT);
    $title = filter_input(INPUT_POST, 'title', FILTER_SANITIZE_STRING);
    $solve_problems = $_POST['solve_problems'];
    $deleted_ids = isset($_POST['deleted_ids']) ? $_POST['deleted_ids'] : [];

    // Fetch existing solve problems from the database for comparison
    $sql = "SELECT id, solve_problem_name, solve_problem_description, solve_problem_photo FROM solve_problem_steps WHERE item_code_id = :item_code_id AND title = :title";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':item_code_id', $item_code_id);
    $stmt->bindParam(':title', $title);
    $stmt->execute();
    $existing_solve_problems = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Check if any changes were made
    $has_changes = false;

    // Compare existing data with submitted data
    foreach ($existing_solve_problems as $existing) {
        $id = $existing['id'];
        if (isset($solve_problems[$id])) {
            if ($existing['solve_problem_name'] !== $solve_problems[$id]['solve_problem_name'] ||
                $existing['solve_problem_description'] !== $solve_problems[$id]['solve_problem_description']) {
                $has_changes = true;
                break;
            }
        }
    }

    // Check if new solve problems were added
    if (isset($_POST['new_solve_problems']) && !empty($_POST['new_solve_problems'])) {
        $has_changes = true;
    }

    // Check if any solve problems were deleted
    if (!empty($deleted_ids)) {
        $has_changes = true;
    }

    // If no changes were made, display an alert and exit
    if (!$has_changes) {
        echo "<script>alert('No data changed.'); window.location.href='search_solve_problem_steps.php';</script>";
        exit();
    }

    // Delete solve problems marked for deletion
    foreach ($deleted_ids as $id) {
        $sql = "DELETE FROM solve_problem_steps WHERE id = :id AND item_code_id = :item_code_id AND title = :title";
        $stmt = $pdo->prepare($sql);
        $stmt->bindParam(':id', $id);
        $stmt->bindParam(':item_code_id', $item_code_id);
        $stmt->bindParam(':title', $title);
        $stmt->execute();
    }

    // Update existing solve problems and insert new solve problems
    foreach ($solve_problems as $id => $solve_problem) {
        $solve_problem_name = filter_var($solve_problem['solve_problem_name'], FILTER_SANITIZE_STRING);
        $solve_problem_description = filter_var($solve_problem['solve_problem_description'], FILTER_SANITIZE_STRING);

        // Handle file upload if a file is uploaded
        if (!empty($_FILES['solve_problems']['name'][$id]['solve_problem_photo'])) {
            $solve_problem_photo = $_FILES['solve_problems']['name'][$id]['solve_problem_photo'];
            $solve_problem_photo_tmp = $_FILES['solve_problems']['tmp_name'][$id]['solve_problem_photo'];

            // Generate garbled characters for the file name (for example, a random string)
            $random_string = bin2hex(random_bytes(10)); // Generates a 20-character random string
            $file_extension = pathinfo($solve_problem_photo, PATHINFO_EXTENSION); // Get the file extension
            $new_file_name = $random_string . '.' . $file_extension;

            // Set the final path for the image file
            $solve_problem_photo_path = '../../images/solve_problem_note/' . $new_file_name;

            // Move the uploaded file to the desired folder
            if (move_uploaded_file($solve_problem_photo_tmp, $solve_problem_photo_path)) {
                // Update query including solve_problem_name and solve_problem_description
                $sql = "UPDATE solve_problem_steps SET solve_problem_name = :solve_problem_name, solve_problem_description = :solve_problem_description, solve_problem_photo = :solve_problem_photo WHERE id = :id AND item_code_id = :item_code_id AND title = :title";
                $stmt = $pdo->prepare($sql);
                $stmt->bindParam(':solve_problem_name', $solve_problem_name);
                $stmt->bindParam(':solve_problem_description', $solve_problem_description);
                $stmt->bindParam(':solve_problem_photo', $solve_problem_photo_path);
                $stmt->bindParam(':id', $id);
                $stmt->bindParam(':item_code_id', $item_code_id);
                $stmt->bindParam(':title', $title);

                if ($stmt->execute()) {
                    echo "<script>alert('Data updated successfully!'); window.location.href='search_solve_problem_steps.php';</script>";
                } else {
                    echo "<script>alert('Failed to update data. Please try again.');</script>";
                }            
            } else {
                echo "<script>alert('Failed to upload photo. Please try again.');</script>";
            }
        } else {
            // Update query without the solve_problem_photo field
            $sql = "UPDATE solve_problem_steps SET solve_problem_name = :solve_problem_name, solve_problem_description = :solve_problem_description WHERE id = :id AND item_code_id = :item_code_id AND title = :title";
            $stmt = $pdo->prepare($sql);
            $stmt->bindParam(':solve_problem_name', $solve_problem_name);
            $stmt->bindParam(':solve_problem_description', $solve_problem_description);
            $stmt->bindParam(':id', $id);
            $stmt->bindParam(':item_code_id', $item_code_id);
            $stmt->bindParam(':title', $title);

            if ($stmt->execute()) {
                echo "<script>alert('Data updated successfully!'); window.location.href='search_solve_problem_steps.php';</script>";
            } else {
                echo "<script>alert('Failed to update data. Please try again.');</script>";
            }            
        }
    }

    // Insert new solve problems
    if (isset($_POST['new_solve_problems'])) {
        $new_solve_problems = $_POST['new_solve_problems'];
        foreach ($new_solve_problems as $index => $new_solve_problem) {
            $new_solve_problem_name = filter_var($new_solve_problem['solve_problem_name'], FILTER_SANITIZE_STRING);
            $new_solve_problem_description = filter_var($new_solve_problem['solve_problem_description'], FILTER_SANITIZE_STRING);

            // Handle file upload if a file is uploaded
            if (!empty($_FILES['new_solve_problems']['name'][$index]['solve_problem_photo'])) {
                $new_solve_problem_photo = $_FILES['new_solve_problems']['name'][$index]['solve_problem_photo'];
                $new_solve_problem_photo_tmp = $_FILES['new_solve_problems']['tmp_name'][$index]['solve_problem_photo'];

                // Generate garbled characters for the file name (for example, a random string)
                $random_string = bin2hex(random_bytes(10)); // Generates a 20-character random string
                $file_extension = pathinfo($new_solve_problem_photo, PATHINFO_EXTENSION); // Get the file extension
                $new_file_name = $random_string . '.' . $file_extension;

                // Set the final path for the image file
                $new_solve_problem_photo_path = '../../images/solve_problem_note/' . $new_file_name;

                // Move the uploaded file to the desired folder
                if (move_uploaded_file($new_solve_problem_photo_tmp, $new_solve_problem_photo_path)) {
                    // Insert query including solve_problem_name and solve_problem_description
                    $sql = "INSERT INTO solve_problem_steps (item_code_id, title, solve_problem_name, solve_problem_description, solve_problem_photo) VALUES (:item_code_id, :title, :solve_problem_name, :solve_problem_description, :solve_problem_photo)";
                    $stmt = $pdo->prepare($sql);
                    $stmt->bindParam(':item_code_id', $item_code_id);
                    $stmt->bindParam(':title', $title);
                    $stmt->bindParam(':solve_problem_name', $new_solve_problem_name);
                    $stmt->bindParam(':solve_problem_description', $new_solve_problem_description);
                    $stmt->bindParam(':solve_problem_photo', $new_solve_problem_photo_path);

                    if ($stmt->execute()) {
                        echo "<script>alert('Data inserted successfully!'); window.location.href='item_function.php';</script>";
                    } else {
                        echo "<script>alert('Failed to insert data. Please try again.');</script>";
                    }            
                } else {
                    echo "<script>alert('Failed to upload photo. Please try again.');</script>";
                }
            } else {
                // Insert query without the solve_problem_photo field
                $sql = "INSERT INTO solve_problem_steps (item_code_id, title, solve_problem_name, solve_problem_description) VALUES (:item_code_id, :title, :solve_problem_name, :solve_problem_description)";
                $stmt = $pdo->prepare($sql);
                $stmt->bindParam(':item_code_id', $item_code_id);
                $stmt->bindParam(':title', $title);
                $stmt->bindParam(':solve_problem_name', $new_solve_problem_name);
                $stmt->bindParam(':solve_problem_description', $new_solve_problem_description);

                if ($stmt->execute()) {
                    echo "<script>alert('Data inserted successfully!'); window.location.href='item_function.php';</script>";
                } else {
                    echo "<script>alert('Failed to insert data. Please try again.');</script>";
                }            
            }
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Solve Problem Steps</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <h2 class="mb-4">Edit Solve Problem Steps for Item Code ID: <?= $item_code_id ?> and Title: <?= htmlspecialchars($title) ?></h2>
    <form method="POST" action="" enctype="multipart/form-data">
        <input type="hidden" name="item_code_id" value="<?= $item_code_id ?>">
        <input type="hidden" name="title" value="<?= htmlspecialchars($title) ?>">

        <!-- Card for Item Code, Item Name, and Title -->
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="card-title">Item Details</h5>
            </div>
            <div class="card-body">
                <div class="row">
                    <div class="col-md-4">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="item_code" name="item_code" value="<?= htmlspecialchars($item_code) ?>" disabled>
                            <label for="item_code">Item Code</label>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="item_name" name="item_name" value="<?= htmlspecialchars($item_name) ?>" disabled>
                            <label for="item_name">Item Name</label>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="title" name="title" value="<?= htmlspecialchars($title) ?>" disabled>
                            <label for="title">Title</label>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Card for Solve Problem Steps -->
        <div id="solve_problems-container">
            <?php foreach ($solve_problems as $index => $solve_problem): ?>
                <div class="card mb-3 solve_problem-group" data-id="<?= $solve_problem['id'] ?>">
                    <div class="card-body">
                        <input type="hidden" name="solve_problems[<?= $solve_problem['id'] ?>][id]" value="<?= $solve_problem['id'] ?>">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="solve_problem_name_<?= $index + 1 ?>" name="solve_problems[<?= $solve_problem['id'] ?>][solve_problem_name]" value="<?= htmlspecialchars($solve_problem['solve_problem_name']) ?>" required>
                            <label for="solve_problem_name_<?= $index + 1 ?>">Solve Problem Name</label>
                        </div>
                        <div class="form-floating mb-3">
                            <textarea class="form-control" id="solve_problem_description_<?= $index + 1 ?>" name="solve_problems[<?= $solve_problem['id'] ?>][solve_problem_description]" required><?= htmlspecialchars($solve_problem['solve_problem_description']) ?></textarea>
                            <label for="solve_problem_description_<?= $index + 1 ?>">Solve Problem Description</label>
                        </div>
                        <div class="mb-3">
                            <label for="solve_problem_photo_<?= $index + 1 ?>" class="form-label">Solve Problem Photo</label>
                            <input type="file" class="form-control" id="solve_problem_photo_<?= $index + 1 ?>" name="solve_problems[<?= $solve_problem['id'] ?>][solve_problem_photo]">
                            <?php if (!empty($solve_problem['solve_problem_photo'])): ?>
                                <p>Current Photo:</p>
                                <img src="<?= htmlspecialchars($solve_problem['solve_problem_photo']) ?>" alt="<?= basename($solve_problem['solve_problem_photo']) ?>" style="max-width: 300px; max-height: 300px;">
                                <p><?= basename($solve_problem['solve_problem_photo']) ?></p>
                            <?php endif; ?>
                        </div>
                        <button type="button" class="btn btn-danger delete-solve_problem">Delete</button>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>

        <button type="button" class="btn btn-secondary" id="add-solve_problem">Add New Solve Problem</button>
        <button type="submit" class="btn btn-primary">Update Solve Problem Steps</button>
    </form>
</div>

<!-- Bootstrap 5.3 JS Bundle CDN (includes Popper.js) -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
<script>
    document.addEventListener('DOMContentLoaded', function() {
        let solveProblemCounter = <?= count($solve_problems) + 1 ?>;
        const addSolveProblemButton = document.getElementById('add-solve_problem');
        const solveProblemsContainer = document.getElementById('solve_problems-container');

        addSolveProblemButton.addEventListener('click', function() {
            const card = document.createElement('div');
            card.className = 'card mb-3 solve_problem-group';

            card.innerHTML = `
                <div class="card-body">
                    <div class="form-floating mb-3">
                        <input type="text" class="form-control" id="new_solve_problem_name_${solveProblemCounter}" name="new_solve_problems[${solveProblemCounter - 1}][solve_problem_name]" required>
                        <label for="new_solve_problem_name_${solveProblemCounter}">Solve Problem Name</label>
                    </div>
                    <div class="form-floating mb-3">
                        <textarea class="form-control" id="new_solve_problem_description_${solveProblemCounter}" name="new_solve_problems[${solveProblemCounter - 1}][solve_problem_description]" required></textarea>
                        <label for="new_solve_problem_description_${solveProblemCounter}">Solve Problem Description</label>
                    </div>
                    <div class="mb-3">
                        <label for="new_solve_problem_photo_${solveProblemCounter}" class="form-label">Solve Problem Photo</label>
                        <input type="file" class="form-control" id="new_solve_problem_photo_${solveProblemCounter}" name="new_solve_problems[${solveProblemCounter - 1}][solve_problem_photo]">
                    </div>
                    <button type="button" class="btn btn-danger delete-solve_problem">Delete</button>
                </div>
            `;

            solveProblemsContainer.appendChild(card);
            solveProblemCounter++;
        });

        solveProblemsContainer.addEventListener('click', function(event) {
            if (event.target.classList.contains('delete-solve_problem')) {
                const card = event.target.closest('.solve_problem-group');
                const id = card.getAttribute('data-id');
                if (id) {
                    const deletedIdsInput = document.createElement('input');
                    deletedIdsInput.type = 'hidden';
                    deletedIdsInput.name = 'deleted_ids[]';
                    deletedIdsInput.value = id;
                    card.appendChild(deletedIdsInput);
                }
                card.style.display = 'none'; // Hide the card instead of removing it
            }
        });
    });
</script>


</body>
</html>