<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Fetch data from the database
$sql = "SELECT item_code_id, item_code, active, item_name, item_group FROM item_code";
$stmt = $pdo->query($sql);
$data = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Fetch solve problem step titles for each item code
$item_code_ids = array_column($data, 'item_code_id');

if (!empty($item_code_ids)) {
    $placeholders = implode(',', array_fill(0, count($item_code_ids), '?'));
    $sql = "SELECT DISTINCT item_code_id, title FROM solve_problem_steps WHERE item_code_id IN ($placeholders)";
    $stmt = $pdo->prepare($sql);
    $stmt->execute($item_code_ids);
    $solve_problem_steps = $stmt->fetchAll(PDO::FETCH_ASSOC);
} else {
    $solve_problem_steps = []; // No item codes found, so no steps to fetch
}

// Create a mapping of item_code_id to solve problem step titles
$solve_problem_steps_map = [];
foreach ($solve_problem_steps as $step) {
    if (!isset($solve_problem_steps_map[$step['item_code_id']])) {
        $solve_problem_steps_map[$step['item_code_id']] = [];
    }
    $solve_problem_steps_map[$step['item_code_id']][] = $step['title'];
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Search Solve Problem Steps</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .button-group {
            gap: 10px; /* Adjust the gap size as needed */
        }
        .hidden {
            display: none;
        }
    </style>
</head>
<body>
<div class="container mt-5">
    <h2 class="mb-4">Search Solve Problem Steps</h2>
    <input type="text" id="searchBar" class="form-control mb-3" placeholder="Search by Item Code or Item Name">
    <?php if (empty($data)): ?>
        <p class="text-muted">No item codes found in the database.</p>
    <?php else: ?>
        <table class="table table-bordered hidden" id="itemTable">
            <thead>
                <tr>
                    <th>Item Code</th>
                    <th>Active</th>
                    <th>Item Name</th>
                    <th>Item Group</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($data as $row): ?>
                    <tr>
                        <td><?= htmlspecialchars($row['item_code']) ?></td>
                        <td><?= $row['active'] ? 'Active' : 'Inactive' ?></td>
                        <td><?= htmlspecialchars($row['item_name']) ?></td>
                        <td><?= htmlspecialchars($row['item_group']) ?></td>
                        <td>
                            <div class="d-flex button-group">
                                <?php if (isset($solve_problem_steps_map[$row['item_code_id']])): ?>
                                    <?php foreach ($solve_problem_steps_map[$row['item_code_id']] as $title): ?>
                                        <a href="edit_solve_problem_steps.php?item_code_id=<?= $row['item_code_id'] ?>&title=<?= urlencode($title) ?>" class="btn btn-danger">Edit(Title: <?= htmlspecialchars($title) ?>)</a>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <span class="text-muted">No solve problem steps found</span>
                                <?php endif; ?>
                            </div>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    <?php endif; ?>
</div>

<!-- jQuery CDN -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<!-- Bootstrap 5.3 JS Bundle CDN (includes Popper.js) -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script>
$(document).ready(function() {
    $('#searchBar').on('keyup', function() {
        var value = $(this).val().toLowerCase();
        $('#itemTable tbody tr').filter(function() {
            $(this).toggle($(this).text().toLowerCase().indexOf(value) > -1)
        });
        if (value.length > 0) {
            $('#itemTable').removeClass('hidden');
        } else {
            $('#itemTable').addClass('hidden');
        }
    });
});
</script>


</body>
</html>