<?php
require 'config/auth.php'; // Ensure user is authenticated
require '../layout/header.php';
require '../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Initialize variables
$item_code_id = null;
$item_code = null;
$item_name = null;
$solve_problems = [];

// Check if item_code_id is passed via URL
if (isset($_GET['item_code_id'])) {
    $item_code_id = filter_input(INPUT_GET, 'item_code_id', FILTER_SANITIZE_NUMBER_INT);
    $sql = "SELECT item_code, item_name FROM item_code WHERE item_code_id = :item_code_id";
    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':item_code_id', $item_code_id);
    $stmt->execute();
    $item = $stmt->fetch(PDO::FETCH_ASSOC);
    if ($item) {
        $item_code = $item['item_code'];
        $item_name = $item['item_name'];
    }
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $item_code_id = filter_input(INPUT_POST, 'item_code_id', FILTER_SANITIZE_NUMBER_INT);
    $title = filter_input(INPUT_POST, 'title', FILTER_SANITIZE_STRING);
    $solve_problems = $_POST['solve_problems'];

    // Define the base directory for saving photos based on the item_code and title
    $baseDir = '../../images/solve_problem_note/' . $item_code . '/' . $title . '/';
    if (!is_dir($baseDir)) {
        mkdir($baseDir, 0777, true);
    }

    foreach ($solve_problems as $index => $solve_problem) {
        $solve_problem_name = filter_var($solve_problem['solve_problem_name'], FILTER_SANITIZE_STRING);
        $solve_problem_description = filter_var($solve_problem['solve_problem_description'], FILTER_SANITIZE_STRING);

        // Handle file upload if a file is uploaded
        if (!empty($_FILES['solve_problems']['name'][$index]['solve_problem_photo'])) {
            $solve_problem_photo = $_FILES['solve_problems']['name'][$index]['solve_problem_photo'];
            $solve_problem_photo_tmp = $_FILES['solve_problems']['tmp_name'][$index]['solve_problem_photo'];

            // Generate garbled characters for the file name (for example, a random string)
            $random_string = bin2hex(random_bytes(10)); // Generates a 20-character random string
            $file_extension = pathinfo($solve_problem_photo, PATHINFO_EXTENSION); // Get the file extension
            $new_file_name = $random_string . '.' . $file_extension;

            // Set the final path for the image file
            $solve_problem_photo_path = $baseDir . $new_file_name;

            // Move the uploaded file to the desired folder
            if (move_uploaded_file($solve_problem_photo_tmp, $solve_problem_photo_path)) {
                // Insert query including item_code and item_name
                $sql = "INSERT INTO solve_problem_steps (item_code_id, item_code, item_name, title, solve_problem_name, solve_problem_description, solve_problem_photo) 
                        VALUES (:item_code_id, :item_code, :item_name, :title, :solve_problem_name, :solve_problem_description, :solve_problem_photo)";
                $stmt = $pdo->prepare($sql);
                $stmt->bindParam(':item_code_id', $item_code_id);
                $stmt->bindParam(':item_code', $item_code);
                $stmt->bindParam(':item_name', $item_name);
                $stmt->bindParam(':title', $title);
                $stmt->bindParam(':solve_problem_name', $solve_problem_name);
                $stmt->bindParam(':solve_problem_description', $solve_problem_description);
                $stmt->bindParam(':solve_problem_photo', $solve_problem_photo_path);

                // Execute and check for success
                if ($stmt->execute()) {
                    echo "<script>alert('Data saved successfully!'); window.location.href='item_function.php';</script>";
                } else {
                    echo "<script>alert('Failed to save data. Please try again.');</script>";
                }
            } else {
                echo "<script>alert('Failed to upload photo. Please try again.');</script>";
            }
        } else {
            // Insert query without the solve_problem_photo field
            $sql = "INSERT INTO solve_problem_steps (item_code_id, item_code, item_name, title, solve_problem_name, solve_problem_description) 
                    VALUES (:item_code_id, :item_code, :item_name, :title, :solve_problem_name, :solve_problem_description)";
            $stmt = $pdo->prepare($sql);
            $stmt->bindParam(':item_code_id', $item_code_id);
            $stmt->bindParam(':item_code', $item_code);
            $stmt->bindParam(':item_name', $item_name);
            $stmt->bindParam(':title', $title);
            $stmt->bindParam(':solve_problem_name', $solve_problem_name);
            $stmt->bindParam(':solve_problem_description', $solve_problem_description);

            // Execute and check for success
            if ($stmt->execute()) {
                echo "<script>alert('Data saved successfully!'); window.location.href='item_function.php';</script>";
            } else {
                echo "<script>alert('Failed to save data. Please try again.');</script>";
            }
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Solve Problem Step</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container mt-5">
    <h2 class="mb-4">Solve Problem Step</h2>
    <form method="POST" action="" enctype="multipart/form-data">
        <input type="hidden" name="item_code_id" value="<?= $item_code_id ?>">

        <!-- Card for Item Code, Item Name, and Title -->
        <div class="card mb-4">
            <div class="card-header">
                <h5 class="card-title">Item Details</h5>
            </div>
            <div class="card-body">
                <div class="row">
                    <div class="col-md-4">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="item_code" name="item_code" value="<?= htmlspecialchars($item_code) ?>" disabled>
                            <label for="item_code">Item Code</label>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="item_name" name="item_name" value="<?= htmlspecialchars($item_name) ?>" disabled>
                            <label for="item_name">Item Name</label>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="form-floating mb-3">
                            <input type="text" class="form-control" id="title" name="title" required>
                            <label for="title">Title</label>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Card for Solve Problem Steps -->
        <div id="solve_problems-container">
            <div class="card mb-3">
                <div class="card-header">
                    <h5 class="card-title">Solve Problem Step 1</h5>
                </div>
                <div class="card-body">
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="solve_problem_name_1" name="solve_problems[0][solve_problem_name]" placeholder="Solve Problem Name" required>
                                <label for="solve_problem_name_1">Solve Problem Name</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="solve_problem_description_1" name="solve_problems[0][solve_problem_description]" placeholder="Solve Problem Description" required></textarea>
                                <label for="solve_problem_description_1">Solve Problem Description</label>
                            </div>
                        </div>
                        <div class="col-md-12">
                            <div class="mb-3">
                                <label for="solve_problem_photo_1" class="form-label">Solve Problem Photo</label>
                                <input type="file" class="form-control" id="solve_problem_photo_1" name="solve_problems[0][solve_problem_photo]">
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <button type="button" class="btn btn-secondary" id="add-solve_problem">Add New Solve Problem</button>
        <button type="submit" class="btn btn-primary">Save</button>
    </form>
</div>

<!-- Bootstrap 5.3 JS Bundle CDN (includes Popper.js) -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
<script>
    document.addEventListener('DOMContentLoaded', function() {
        let solveProblemCounter = 2;
        const addSolveProblemButton = document.getElementById('add-solve_problem');
        const solveProblemsContainer = document.getElementById('solve_problems-container');

        addSolveProblemButton.addEventListener('click', function() {
            const card = document.createElement('div');
            card.className = 'card mb-3';
            card.innerHTML = `
                <div class="card-header">
                    <h5 class="card-title">Solve Problem Step ${solveProblemCounter}</h5>
                </div>
                <div class="card-body">
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <input type="text" class="form-control" id="solve_problem_name_${solveProblemCounter}" name="solve_problems[${solveProblemCounter - 1}][solve_problem_name]" placeholder="Solve Problem Name" required>
                                <label for="solve_problem_name_${solveProblemCounter}">Solve Problem Name</label>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-floating mb-3">
                                <textarea class="form-control" id="solve_problem_description_${solveProblemCounter}" name="solve_problems[${solveProblemCounter - 1}][solve_problem_description]" placeholder="Solve Problem Description" required></textarea>
                                <label for="solve_problem_description_${solveProblemCounter}">Solve Problem Description</label>
                            </div>
                        </div>
                        <div class="col-md-12">
                            <div class="mb-3">
                                <label for="solve_problem_photo_${solveProblemCounter}" class="form-label">Solve Problem Photo</label>
                                <input type="file" class="form-control" id="solve_problem_photo_${solveProblemCounter}" name="solve_problems[${solveProblemCounter - 1}][solve_problem_photo]">
                            </div>
                        </div>
                    </div>
                </div>
            `;

            solveProblemsContainer.appendChild(card);
            solveProblemCounter++;
        });
    });
</script>


</body>
</html>