<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database

// Set default item_code_id if not set
$item_code_id = filter_input(INPUT_GET, 'item_code_id', FILTER_SANITIZE_NUMBER_INT);
if (!$item_code_id) {
    $item_code_id = 1; // Default value (change as appropriate)
}

// Fetch item_name and item_code from the item_code table
$sql_item = "SELECT item_name, item_code FROM item_code WHERE item_code_id = :item_code_id";
$stmt_item = $pdo->prepare($sql_item);
$stmt_item->bindParam(':item_code_id', $item_code_id);
$stmt_item->execute();
$item = $stmt_item->fetch(PDO::FETCH_ASSOC);

$item_name = $item ? htmlspecialchars($item['item_name']) : 'Unknown Item';
$item_code = $item ? htmlspecialchars($item['item_code']) : 'Unknown Code';

// Fetch function notes related to the item_code_id
$sql_functions = "SELECT function_name, function_description, function_photo FROM function_notes WHERE item_code_id = :item_code_id";
$stmt_functions = $pdo->prepare($sql_functions);
$stmt_functions->bindParam(':item_code_id', $item_code_id);
$stmt_functions->execute();
$functions = $stmt_functions->fetchAll(PDO::FETCH_ASSOC);
?>

<!-- Add Bootstrap 5.3 CSS CDN -->
<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-9ndCyUaIbzAi2FUVXJi0CjmCapSmO7SnpJef0486qhLnuZ2cdeRhO02iuK6FUUVM" crossorigin="anonymous">

<div class="container mt-5">
    <h2 class="mb-4">Function Notes for <?= $item_name ?> (<?= $item_code ?>)</h2>
    <div class="mb-3">
        <a href="view_function.php?item_code_id=<?= $item_code_id ?>" class="btn btn-primary">Function Note</a>
        <a href="/crm/public/item_function/view_configuration_steps.php?item_code_id=<?= $item_code_id ?>" class="btn btn-secondary">Configuration Step</a>
        <a href="/crm/public/item_function/view_solve_problem_steps.php?item_code_id=<?= $item_code_id ?>" class="btn btn-success">Solve Problem Step</a>
    </div>

    <div class="card"> <!-- This is the box -->
        <?php if (!empty($functions)): ?>
            <div class="list-group">
                <?php foreach ($functions as $index => $function): ?>
                    <div class="list-group-item">
                        <h5>Function Name: <?= htmlspecialchars($function['function_name']) ?></h5>
                        <p><strong>Description:</strong> <?= htmlspecialchars($function['function_description']) ?></p>
                        <?php if (!empty($function['function_photo'])): ?>
                            <p><strong>Photo:</strong></p>
                            <div class="photo-container">
                                <img src="<?= htmlspecialchars($function['function_photo']) ?>" alt="Function Photo" class="img-fluid">
                            </div>
                        <?php endif; ?>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php else: ?>
            <p>No function notes found for this item.</p>
        <?php endif; ?>
    </div>
</div>

<!-- Add Bootstrap 5.3 JS CDN -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js" integrity="sha384-geWF76RCwLtnZ8qwWowPQNguL3RmwHVBC9FhGdlKrxdiJJigb/j/68SIy3Te4Bkz" crossorigin="anonymous"></script>

