<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database

// Set default item_code_id if not set
$item_code_id = filter_input(INPUT_GET, 'item_code_id', FILTER_SANITIZE_NUMBER_INT);
if (!$item_code_id) {
    $item_code_id = 1; // Default value (change as appropriate)
}

// Fetch item_name and item_code from the item_code table
$sql_item = "SELECT item_name, item_code FROM item_code WHERE item_code_id = :item_code_id";
$stmt_item = $pdo->prepare($sql_item);
$stmt_item->bindParam(':item_code_id', $item_code_id);
$stmt_item->execute();
$item = $stmt_item->fetch(PDO::FETCH_ASSOC);

$item_name = $item ? htmlspecialchars($item['item_name']) : 'Unknown Item';
$item_code = $item ? htmlspecialchars($item['item_code']) : 'Unknown Code';

// Fetch unique titles related to the item_code_id
$sql_titles = "SELECT DISTINCT title FROM solve_problem_steps WHERE item_code_id = :item_code_id";
$stmt_titles = $pdo->prepare($sql_titles);
$stmt_titles->bindParam(':item_code_id', $item_code_id);
$stmt_titles->execute();
$titles = $stmt_titles->fetchAll(PDO::FETCH_COLUMN);

// Initialize variables
$selected_title = null;
$solve_problems = [];

// Check if a title is selected
if (isset($_GET['title'])) {
    $selected_title = filter_input(INPUT_GET, 'title', FILTER_SANITIZE_STRING);

    // Fetch solve problem steps for the selected title
    $sql_solve_problems = "SELECT solve_problem_name, solve_problem_description, solve_problem_photo 
                           FROM solve_problem_steps 
                           WHERE item_code_id = :item_code_id AND title = :title";
    $stmt_solve_problems = $pdo->prepare($sql_solve_problems);
    $stmt_solve_problems->bindParam(':item_code_id', $item_code_id);
    $stmt_solve_problems->bindParam(':title', $selected_title);
    $stmt_solve_problems->execute();
    $solve_problems = $stmt_solve_problems->fetchAll(PDO::FETCH_ASSOC);
}
?>

<!-- Add Bootstrap 5.3 CSS CDN -->
<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-9ndCyUaIbzAi2FUVXJi0CjmCapSmO7SnpJef0486qhLnuZ2cdeRhO02iuK6FUUVM" crossorigin="anonymous">

<div class="container mt-5">
    <h2 class="mb-4">Solve Problem Steps for <?= $item_name ?> (<?= $item_code ?>)</h2>
    <div class="mb-3">
        <a href="view_function.php?item_code_id=<?= $item_code_id ?>" class="btn btn-primary">Function Note</a>
        <a href="view_configuration_steps.php?item_code_id=<?= $item_code_id ?>" class="btn btn-secondary">Configuration Step</a>
        <a href="view_solve_problem_steps.php?item_code_id=<?= $item_code_id ?>" class="btn btn-success">Solve Problem Step</a>
    </div>

    <form method="GET" action="">
        <input type="hidden" name="item_code_id" value="<?= $item_code_id ?>">
        <div class="form-group">
            <label for="title">Select Title</label>
            <select class="form-control" id="title" name="title" onchange="this.form.submit()">
                <option value="">-- Select Title --</option>
                <?php foreach ($titles as $title): ?>
                    <option value="<?= htmlspecialchars($title) ?>" <?= $selected_title == $title ? 'selected' : '' ?>>
                        <?= htmlspecialchars($title) ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </div>
    </form>

    <?php if ($selected_title && !empty($solve_problems)): ?>
        <div class="list-group">
            <?php foreach ($solve_problems as $index => $solve_problem): ?>
                <div class="list-group-item">
                    <h5>Solve Problem Name: <?= htmlspecialchars($solve_problem['solve_problem_name']) ?></h5>
                    <p><strong>Description:</strong> <?= htmlspecialchars($solve_problem['solve_problem_description']) ?></p>
                    <?php if (!empty($solve_problem['solve_problem_photo'])): ?>
                        <p><strong>Photo:</strong></p>
                        <img src="<?= htmlspecialchars($solve_problem['solve_problem_photo']) ?>" alt="Solve Problem Photo" style="max-width: 800px; max-height: 800px;">
                    <?php endif; ?>
                </div>
            <?php endforeach; ?>
        </div>
    <?php elseif ($selected_title): ?>
        <p>No solve problem steps found for this title.</p>
    <?php endif; ?>

</div>

<!-- Add Bootstrap 5.3 JS CDN -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js" integrity="sha384-geWF76RCwLtnZ8qwWowPQNguL3RmwHVBC9FhGdlKrxdiJJigb/j/68SIy3Te4Bkz" crossorigin="anonymous"></script>

