<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database

// Fetch all usernames from the admins table
try {
    $stmt = $pdo->query("SELECT username FROM admins ORDER BY username ASC");
    $usernames = $stmt->fetchAll(PDO::FETCH_COLUMN);
} catch (PDOException $e) {
    echo "<div class='alert alert-danger'>Error fetching usernames: " . $e->getMessage() . "</div>";
    $usernames = []; // Fallback to an empty array
}

// Initialize filter variables
$startDate = $_GET['start_date'] ?? '';
$endDate = $_GET['end_date'] ?? '';
$filterUsername = $_GET['username'] ?? '';

// Build the base query
$query = "SELECT * FROM activity_logs WHERE 1=1";
$params = [];

// Add date range filter if provided
if (!empty($startDate)) {
    $query .= " AND DATE(timestamp) >= :start_date";
    $params[':start_date'] = $startDate;
}
if (!empty($endDate)) {
    $query .= " AND DATE(timestamp) <= :end_date";
    $params[':end_date'] = $endDate;
}

// Add username filter if provided
if (!empty($filterUsername)) {
    $query .= " AND username = :username";
    $params[':username'] = $filterUsername;
}

// Order by timestamp
$query .= " ORDER BY timestamp DESC";

try {
    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $logs = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    echo "<div class='alert alert-danger'>Error fetching logs: " . $e->getMessage() . "</div>";
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Activity Logs</title>
    <!-- Bootstrap 5.3 CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-5">
        <div class="row">
            <div class="col-12">
                <h2 class="mb-4">Activity Logs</h2>
            </div>
        </div>

        <!-- Filter Form -->
        <div class="row mb-4">
            <div class="col-12">
                <form method="GET" action="" class="row g-3">
                    <!-- Start Date -->
                    <div class="col-md-3">
                        <label for="start_date" class="form-label">Start Date</label>
                        <input type="date" class="form-control" id="start_date" name="start_date" value="<?php echo htmlspecialchars($startDate); ?>">
                    </div>
                    <!-- End Date -->
                    <div class="col-md-3">
                        <label for="end_date" class="form-label">End Date</label>
                        <input type="date" class="form-control" id="end_date" name="end_date" value="<?php echo htmlspecialchars($endDate); ?>">
                    </div>
                    <!-- Username Dropdown -->
                    <div class="col-md-3">
                        <label for="username" class="form-label">Username</label>
                        <select class="form-select" id="username" name="username">
                            <option value="">All Users</option>
                            <?php foreach ($usernames as $username): ?>
                                <option value="<?php echo htmlspecialchars($username); ?>" <?php echo ($filterUsername === $username) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($username); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <!-- Filter and Clear Buttons -->
                    <div class="col-md-3 d-flex align-items-end">
                        <button type="submit" class="btn btn-primary">Filter</button>
                        <a href="?" class="btn btn-secondary ms-2">Clear</a>
                    </div>
                </form>
            </div>
        </div>

        <!-- Logs Table -->
        <div class="row">
            <div class="col-12">
                <?php if (!empty($logs)): ?>
                    <table class="table table-striped table-hover">
                        <thead class="table-dark">
                            <tr>
                                <th>Timestamp</th>
                                <th>Username</th>
                                <th>Role</th>
                                <th>Activity</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($logs as $log): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($log['timestamp']); ?></td>
                                    <td><?php echo htmlspecialchars($log['username']); ?></td>
                                    <td><?php echo htmlspecialchars($log['role']); ?></td>
                                    <td><?php echo nl2br(htmlspecialchars($log['activity'])); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                <?php else: ?>
                    <div class="alert alert-info">No activity logs found.</div>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS and dependencies (Popper.js) -->
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.6/dist/umd/popper.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
</body>
</html>

