<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');


// Fetch user groups
$query = $pdo->query("SELECT user_group FROM user_groups");
$user_groups = $query->fetchAll(PDO::FETCH_ASSOC);

// Fetch the menu item to edit
if (isset($_GET['menu_item'])) {
    $menu_item = $_GET['menu_item'];

    // Fetch existing permissions for the menu item
    $stmt = $pdo->prepare("SELECT user_group, can_access FROM menu_permissions WHERE menu_item = :menu_item");
    $stmt->bindParam(':menu_item', $menu_item);
    $stmt->execute();
    $existing_permissions = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Create an associative array for easy lookup
    $permissions_map = [];
    foreach ($existing_permissions as $perm) {
        $permissions_map[$perm['user_group']] = $perm['can_access'];
    }
} else {
    // Redirect if no menu item is specified
    header("Location: menu_management.php");
    exit;
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $menu_item = $_POST['menu_item'];

    // Delete existing permissions for the menu item
    $stmt = $pdo->prepare("DELETE FROM menu_permissions WHERE menu_item = :menu_item");
    $stmt->bindParam(':menu_item', $menu_item);
    $stmt->execute();

    // Insert updated permissions
    $stmt = $pdo->prepare("INSERT INTO menu_permissions (user_group, menu_item, can_access) VALUES (:user_group, :menu_item, :can_access)");

    foreach ($_POST['user_groups'] as $user_group => $can_access) {
        $stmt->bindParam(':user_group', $user_group);
        $stmt->bindParam(':menu_item', $menu_item);
        $stmt->bindParam(':can_access', $can_access);

        if ($stmt->execute()) {
            $message = "Permissions updated successfully!";
        } else {
            $message = "Failed to update permission. Please try again.";
            break; // Stop processing if any insert fails
        }
    }

    // Redirect to clear form fields
    echo "<script>
            alert('$message');
            window.location.href = 'menu_management.php';
          </script>";
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Menu Management</title>
    <!-- Add Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-9ndCyUaIbzAi2FUVXJi0CjmCapSmO7SnpJef0486qhLnuZ2cdeRhO02iuK6FUUVM" crossorigin="anonymous">
</head>
<body>
<div class="container">
    <!-- Card for User Groups -->
    <div class="card mb-3">
        <div class="card-header">
            <h5 class="card-title">Edit Menu Permissions for "<?= htmlspecialchars($menu_item); ?>"</h5>
        </div>
        <div class="card-body">
            <form method="POST" action="">
                <input type="hidden" name="menu_item" value="<?= htmlspecialchars($menu_item); ?>">
                <div class="form-group">
                    <label>User Groups</label>
                    <div class="form-check">
                        <?php foreach ($user_groups as $group): ?>
                            <input type="checkbox" class="form-check-input" id="<?= htmlspecialchars($group['user_group']); ?>" name="user_groups[<?= htmlspecialchars($group['user_group']); ?>]" value="1" <?= isset($permissions_map[$group['user_group']]) && $permissions_map[$group['user_group']] ? 'checked' : ''; ?>>
                            <label class="form-check-label" for="<?= htmlspecialchars($group['user_group']); ?>">
                                <?= htmlspecialchars($group['user_group']); ?>
                            </label><br>
                        <?php endforeach; ?>
                    </div>
                </div>
                <button type="submit" class="btn btn-primary">Save Changes</button>
                <a href="menu_management.php" class="btn btn-secondary">Cancel</a>
            </form>
        </div>
    </div>
</div>

<!-- Add Bootstrap 5.3 JS CDN -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js" integrity="sha384-geWF76RCwLtnZ8qwWowPQNguL3RmwHVBC9FhGdlKrxdiJJigb/j/68SIy3Te4Bkz" crossorigin="anonymous"></script>
</body>
</html>