<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');
// Fetch user groups
$query = $pdo->query("SELECT user_group FROM user_groups");
$user_groups = $query->fetchAll(PDO::FETCH_ASSOC);

// Get the URL from the query string
$original_url = isset($_GET['url']) ? urldecode($_GET['url']) : null;

if (!$original_url) {
    die("URL not provided.");
}

// Fetch the existing permissions for the given URL
$stmt = $pdo->prepare("SELECT id, user_group, can_access FROM permissions WHERE url = :url");
$stmt->bindParam(':url', $original_url);
$stmt->execute();
$existing_permissions = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $new_url = $_POST['url'];
    $can_access = isset($_POST['can_access']) ? 1 : 0;

    // Update the URL for all existing permissions
    $update_url_stmt = $pdo->prepare("UPDATE permissions SET url = :new_url WHERE url = :original_url");
    $update_url_stmt->bindParam(':new_url', $new_url);
    $update_url_stmt->bindParam(':original_url', $original_url);
    $update_url_stmt->execute();

    // Update the can_access for all existing permissions
    $update_access_stmt = $pdo->prepare("UPDATE permissions SET can_access = :can_access WHERE url = :new_url");
    $update_access_stmt->bindParam(':can_access', $can_access);
    $update_access_stmt->bindParam(':new_url', $new_url);
    $update_access_stmt->execute();

    // Update the user groups
    $update_user_group_stmt = $pdo->prepare("UPDATE permissions SET user_group = :user_group WHERE url = :new_url AND user_group = :original_user_group");
    $delete_user_group_stmt = $pdo->prepare("DELETE FROM permissions WHERE url = :new_url AND user_group = :original_user_group");
    $insert_user_group_stmt = $pdo->prepare("INSERT INTO permissions (user_group, url, can_access) VALUES (:user_group, :url, :can_access)");

    // Track which user groups were selected in the form
    $selected_user_groups = isset($_POST['user_groups']) ? $_POST['user_groups'] : [];

    // Process existing permissions
    foreach ($existing_permissions as $perm) {
        $original_user_group = $perm['user_group'];

        if (in_array($original_user_group, $selected_user_groups)) {
            // Update the user group if it was selected
            $update_user_group_stmt->bindParam(':user_group', $original_user_group);
            $update_user_group_stmt->bindParam(':new_url', $new_url);
            $update_user_group_stmt->bindParam(':original_user_group', $original_user_group);
            $update_user_group_stmt->execute();
        } else {
            // Delete the user group if it was not selected
            $delete_user_group_stmt->bindParam(':new_url', $new_url);
            $delete_user_group_stmt->bindParam(':original_user_group', $original_user_group);
            $delete_user_group_stmt->execute();
        }
    }

    // Insert new user groups that were selected but not in the existing permissions
    foreach ($selected_user_groups as $user_group) {
        if (!in_array($user_group, array_column($existing_permissions, 'user_group'))) {
            $insert_user_group_stmt->bindParam(':user_group', $user_group);
            $insert_user_group_stmt->bindParam(':url', $new_url);
            $insert_user_group_stmt->bindParam(':can_access', $can_access);
            $insert_user_group_stmt->execute();
        }
    }

    // Redirect to clear form fields
    echo "<script>
            alert('Permissions updated successfully!');
            window.location.href = 'permission_settings.php';
          </script>";
    exit;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Permissions</title>
    <!-- Add Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-9ndCyUaIbzAi2FUVXJi0CjmCapSmO7SnpJef0486qhLnuZ2cdeRhO02iuK6FUUVM" crossorigin="anonymous">
</head>
<body>
<div class="container">
    <!-- Card for URL and User Groups -->
    <div class="card mb-3">
        <div class="card-header">
            <h5 class="card-title">Edit Permissions for URL: <?= htmlspecialchars($original_url); ?></h5>
        </div>
        <div class="card-body">
            <form method="POST" action="">
                <div class="form-floating mb-3">
                    <input type="text" name="url" id="url" class="form-control" value="<?= htmlspecialchars($original_url); ?>" required>
                    <label for="url">URL</label>
                </div>
                <div class="form-group">
                    <label>User Groups</label>
                    <div class="form-check">
                        <?php foreach ($user_groups as $group): ?>
                            <input type="checkbox" class="form-check-input" id="<?= htmlspecialchars($group['user_group']); ?>" name="user_groups[]" value="<?= htmlspecialchars($group['user_group']); ?>"
                                <?php foreach ($existing_permissions as $perm): ?>
                                    <?php if ($perm['user_group'] == $group['user_group']): ?>
                                        checked
                                    <?php endif; ?>
                                <?php endforeach; ?>
                            >
                            <label class="form-check-label" for="<?= htmlspecialchars($group['user_group']); ?>">
                                <?= htmlspecialchars($group['user_group']); ?>
                            </label><br>
                        <?php endforeach; ?>
                    </div>
                </div>
                <div class="form-group form-check">
                    <input type="checkbox" class="form-check-input" id="can_access" name="can_access" value="1"
                        <?php foreach ($existing_permissions as $perm): ?>
                            <?php if ($perm['can_access']): ?>
                                checked
                            <?php endif; ?>
                        <?php endforeach; ?>
                    >
                    <label class="form-check-label" for="can_access">Can Access</label>
                    <br>
                </div>
                <br>
                <button type="submit" class="btn btn-primary">Update Permission</button>
            </form>
        </div>
    </div>
</div>

<!-- Add Bootstrap 5.3 JS CDN -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js" integrity="sha384-geWF76RCwLtnZ8qwWowPQNguL3RmwHVBC9FhGdlKrxdiJJigb/j/68SIy3Te4Bkz" crossorigin="anonymous"></script>
</body>
</html>