<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Fetch user groups
$query = $pdo->query("SELECT user_group FROM user_groups");
$user_groups = $query->fetchAll(PDO::FETCH_ASSOC);

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['delete_menu_item'])) {
        // Handle delete request
        $menu_item_to_delete = $_POST['delete_menu_item'];
        $stmt = $pdo->prepare("DELETE FROM menu_permissions WHERE menu_item = :menu_item");
        $stmt->bindParam(':menu_item', $menu_item_to_delete);
        if ($stmt->execute()) {
            $message = "Menu item deleted successfully!";
        } else {
            $message = "Failed to delete menu item. Please try again.";
        }
    } else {
        // Handle save permission request
        $menu_item = $_POST['menu_item'];
        $can_access = 1;

        // Insert data into permissions table for each user group
        $stmt = $pdo->prepare("INSERT INTO menu_permissions (user_group, menu_item, can_access) VALUES (:user_group, :menu_item, :can_access) ON DUPLICATE KEY UPDATE can_access = VALUES(can_access)");

        foreach ($_POST['user_groups'] as $user_group) {
            $stmt->bindParam(':user_group', $user_group);
            $stmt->bindParam(':menu_item', $menu_item);
            $stmt->bindParam(':can_access', $can_access);

            if ($stmt->execute()) {
                $message = "Permissions saved successfully!";
            } else {
                $message = "Failed to save permission. Please try again.";
                break; // Stop processing if any insert fails
            }
        }
    }

    // Redirect to clear form fields
    echo "<script>
            alert('$message');
            window.location.href = window.location.href;
          </script>";
    exit;
}

// Fetch permissions for display
$query = $pdo->query("SELECT menu_item, user_group, can_access FROM menu_permissions");
$permissions = $query->fetchAll(PDO::FETCH_ASSOC);

// Group permissions by menu item and filter user groups with can_access = 1
$grouped_permissions = [];
foreach ($permissions as $perm) {
    $menu_item = $perm['menu_item'];
    if (!isset($grouped_permissions[$menu_item])) {
        $grouped_permissions[$menu_item] = [
            'user_groups' => [],
            'can_access' => $perm['can_access']
        ];
    }
    if ($perm['can_access'] == 1) {
        $grouped_permissions[$menu_item]['user_groups'][] = $perm['user_group'];
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Menu Management</title>
    <!-- Add Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-9ndCyUaIbzAi2FUVXJi0CjmCapSmO7SnpJef0486qhLnuZ2cdeRhO02iuK6FUUVM" crossorigin="anonymous">
    <!-- Add Bootstrap Icons CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
</head>
<body>
<div class="container">
    <!-- Card for Menu Item and User Groups -->
    <div class="card mb-3">
        <div class="card-header">
            <h5 class="card-title">Set Menu Permissions</h5>
        </div>
        <div class="card-body">
            <form method="POST" action="">
                <div class="form-floating mb-3">
                    <input type="text" name="menu_item" id="menu_item" class="form-control" placeholder="Enter Menu Item" required>
                    <label for="menu_item">Menu Item</label>
                </div>
                <div class="form-group">
                    <label>User Groups</label>
                    <div class="form-check">
                        <?php foreach ($user_groups as $group): ?>
                            <input type="checkbox" class="form-check-input" id="<?= htmlspecialchars($group['user_group']); ?>" name="user_groups[]" value="<?= htmlspecialchars($group['user_group']); ?>">
                            <label class="form-check-label" for="<?= htmlspecialchars($group['user_group']); ?>">
                                <?= htmlspecialchars($group['user_group']); ?>
                            </label><br>
                        <?php endforeach; ?>
                    </div>
                </div>
                <button type="submit" class="btn btn-primary">Save Permission</button>
            </form>
        </div>
    </div>

    <!-- Display Permissions Table -->
    <h3 class="mt-5">Existing Menu Permissions</h3>
    <table class="table table-striped">
        <thead>
            <tr>
                <th>Menu Item</th>
                <th>User Group</th>
                <th>Action</th>
            </tr>
        </thead>
        <tbody>
            <?php if ($grouped_permissions): ?>
                <?php foreach ($grouped_permissions as $menu_item => $data): ?>
                    <tr>
                        <td><?= htmlspecialchars($menu_item); ?></td>
                        <td><?= htmlspecialchars(implode(', ', $data['user_groups'])); ?></td>
                        <td>
                            <!-- Edit Button with Pen Icon -->
                            <a href="edit_menu_management.php?menu_item=<?= urlencode($menu_item); ?>" class="btn btn-primary btn-sm">
                                <i class="bi bi-pencil"></i> <!-- Bootstrap Pen Icon -->
                            </a>
                            <!-- Delete Button with Bin Icon -->
                            <form method="POST" action="" style="display:inline;">
                                <input type="hidden" name="delete_menu_item" value="<?= htmlspecialchars($menu_item); ?>">
                                <button type="submit" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this menu item?')">
                                    <i class="bi bi-trash"></i> <!-- Bootstrap Bin/Trash Icon -->
                                </button>
                            </form>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="4" class="text-center">No permissions available</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>
</div>

<!-- Add Bootstrap 5.3 JS CDN -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js" integrity="sha384-geWF76RCwLtnZ8qwWowPQNguL3RmwHVBC9FhGdlKrxdiJJigb/j/68SIy3Te4Bkz" crossorigin="anonymous"></script>
</body>
</html>