<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Pagination variables
$items_per_page = 50;
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$offset = ($page - 1) * $items_per_page;

// Fetch total number of permissions
$total_query = $pdo->query("SELECT COUNT(*) FROM permissions");
$total_permissions = $total_query->fetchColumn();
$total_pages = ceil($total_permissions / $items_per_page);

// Fetch permissions for display with pagination (URL contains specific keyword)
$query = $pdo->prepare("SELECT url, user_group, can_access FROM permissions LIMIT :limit OFFSET :offset");
$query->bindParam(':limit', $items_per_page, PDO::PARAM_INT);
$query->bindParam(':offset', $offset, PDO::PARAM_INT);
$query->execute();
$permissions = $query->fetchAll(PDO::FETCH_ASSOC);

// Fetch user groups
$query = $pdo->query("SELECT user_group FROM user_groups");
$user_groups = $query->fetchAll(PDO::FETCH_ASSOC);

// Group permissions by URL
$grouped_permissions = [];
foreach ($permissions as $perm) {
    $url = $perm['url'];
    if (!isset($grouped_permissions[$url])) {
        $grouped_permissions[$url] = [
            'user_groups' => [],
            'can_access' => $perm['can_access']
        ];
    }
    $grouped_permissions[$url]['user_groups'][] = $perm['user_group'];
}

// Handle form submission for adding new permissions
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $url = $_POST['url'];
    $can_access = 1;

    // Insert data into permissions table for each user group
    $stmt = $pdo->prepare("INSERT INTO permissions (user_group, url, can_access) VALUES (:user_group, :url, :can_access)");

    foreach ($_POST['user_groups'] as $user_group) {
        $stmt->bindParam(':user_group', $user_group);
        $stmt->bindParam(':url', $url);
        $stmt->bindParam(':can_access', $can_access);

        if ($stmt->execute()) {
            $message = "Permissions saved successfully!";
        } else {
            $message = "Failed to save permission. Please try again.";
            break; // Stop processing if any insert fails
        }
    }

    // Redirect to clear form fields
    echo "<script>
            alert('$message');
            window.location.href = window.location.href;
          </script>";
    exit;
}

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Save Permissions</title>
    <!-- Add Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-9ndCyUaIbzAi2FUVXJi0CjmCapSmO7SnpJef0486qhLnuZ2cdeRhO02iuK6FUUVM" crossorigin="anonymous">
    <!-- Add Bootstrap Icons CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.0/font/bootstrap-icons.css" rel="stylesheet">
</head>
<body>
<div class="container">
    <!-- Card for URL and User Groups -->
    <div class="card mb-3">
        <div class="card-header">
            <h5 class="card-title">Set Permissions</h5>
        </div>
        <div class="card-body">
            <div class="row">
                <div class="col-md-12">
                    <form method="POST" action="">
                        <div class="form-floating mb-3">
                            <input type="text" name="url" id="url" class="form-control" placeholder="Enter URL or keyword" required>
                            <label for="url">URL</label>
                        </div>
                        <div class="form-group">
                            <label>User Groups</label>
                            <div class="form-check">
                                <?php foreach ($user_groups as $group): ?>
                                    <input type="checkbox" class="form-check-input" id="<?= htmlspecialchars($group['user_group']); ?>" name="user_groups[]" value="<?= htmlspecialchars($group['user_group']); ?>">
                                    <label class="form-check-label" for="<?= htmlspecialchars($group['user_group']); ?>">
                                        <?= htmlspecialchars($group['user_group']); ?>
                                    </label><br>
                                <?php endforeach; ?>
                            </div>
                        </div>
                        <button type="submit" class="btn btn-primary">Save Permission</button>
                    </form>
                </div>
            </div>
        </div>
    </div>

    <!-- Display Permissions Table -->
    <h3 class="mt-5">Existing Permissions</h3>
    <table class="table table-striped">
        <thead>
            <tr>
                <th>URL</th>
                <th>User Group</th>
                <th>Action</th>
            </tr>
        </thead>
        <tbody>
            <?php if ($grouped_permissions): ?>
                <?php foreach ($grouped_permissions as $url => $data): ?>
                    <tr>
                        <td><?= htmlspecialchars($url); ?></td>
                        <td><?= htmlspecialchars(implode(', ', $data['user_groups'])); ?></td>
                        <td>
                            <a href="edit_permission_settings.php?url=<?= urlencode($url); ?>" class="btn btn-primary btn-sm">
                                <i class="bi bi-pencil"></i> <!-- Bootstrap Pen Icon -->
                            </a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            <?php else: ?>
                <tr>
                    <td colspan="4" class="text-center">No permissions available</td>
                </tr>
            <?php endif; ?>
        </tbody>
    </table>
</div>

<!-- Add Bootstrap 5.3 JS CDN -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js" integrity="sha384-geWF76RCwLtnZ8qwWowPQNguL3RmwHVBC9FhGdlKrxdiJJigb/j/68SIy3Te4Bkz" crossorigin="anonymous"></script>
</body>
</html>