<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Function to check if item_code exists
function itemCodeExists($pdo, $itemCode) {
    $stmt = $pdo->prepare("SELECT COUNT(*) FROM item_code WHERE item_code = :item_code");
    $stmt->execute([':item_code' => $itemCode]);
    return $stmt->fetchColumn() > 0;
}

// Function to log activity
function logActivity($pdo, $activity) {
    $sqlLog = "INSERT INTO activity_logs (username, timestamp, role, activity)
               VALUES (:username, :timestamp, :role, :activity)";
    $stmtLog = $pdo->prepare($sqlLog);
    $stmtLog->execute([
        ':username' => $_SESSION['username'],
        ':timestamp' => date('Y-m-d H:i:s'),
        ':role' => $_SESSION['role'],
        ':activity' => $activity
    ]);
}

// Handle form submission to save data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_FILES['csv_file']) && $_FILES['csv_file']['error'] == 0) {
        // CSV file upload handling
        $file = $_FILES['csv_file']['tmp_name'];
        if (($handle = fopen($file, "r")) !== FALSE) {
            // Skip the header row
            fgetcsv($handle, 1000, ",");
            
            $successCount = 0;
            $skipCount = 0;
            $errorCount = 0;

            while (($data = fgetcsv($handle, 1000, ",")) !== FALSE) {
                $itemCode = $data[0] ?? null;
                $itemName = $data[1] ?? null;
                $itemGroup = $data[2] ?? null;
                $uom = $data[3] ?? null;
                $active = 1; // Always set active to 1

                if (itemCodeExists($pdo, $itemCode)) {
                    $skipCount++;
                    continue;
                }

                try {
                    $stmt = $pdo->prepare("INSERT INTO item_code (
                        item_code, active, item_name, item_group, uom
                    ) VALUES (
                        :item_code, :active, :item_name, :item_group, :uom
                    )");
                    $stmt->execute([
                        ':item_code' => $itemCode,
                        ':active' => $active,
                        ':item_name' => $itemName,
                        ':item_group' => $itemGroup,
                        ':uom' => $uom
                    ]);
                    $successCount++;
                } catch (PDOException $e) {
                    error_log('Database insert error: ' . $e->getMessage());
                    $errorCount++;
                }
            }
            fclose($handle);

            // Log the activity for CSV upload
            $logMessage = "CSV upload completed. Successfully added $successCount items. Skipped $skipCount existing items. Failed to add $errorCount items.";
            logActivity($pdo, $logMessage);

            echo "<script>alert('$logMessage'); window.location.href = '/crm/public/stock_item/view_stock_item.php';</script>";
        } else {
            echo "<script>alert('Failed to open CSV file. Please try again.');</script>";
        }
    } else {
        // Single item addition
        $active = 1; // Always set active to 1
        $itemCode = $_POST['item_code'] ?? null;
        $itemName = $_POST['item_name'] ?? null;
        $description = $_POST['description'] ?? null;
        $itemGroup = $_POST['item_group'] ?? null;
        $uom = $_POST['uom'] ?? null;
        $others = $_POST['others'] ?? null;

        if (itemCodeExists($pdo, $itemCode)) {
            echo "<script>alert('Item code already exists. Please use a different item code.'); window.history.back();</script>";
            exit;
        }

        try {
            $stmt = $pdo->prepare("INSERT INTO item_code (
                item_code, active, item_name, description, item_group, uom, others
            ) VALUES (
                :item_code, :active, :item_name, :description, :item_group, :uom, :others
            )");
            $stmt->execute([
                ':item_code' => $itemCode,
                ':active' => $active,
                ':item_name' => $itemName,
                ':description' => $description,
                ':item_group' => $itemGroup,
                ':uom' => $uom,
                ':others' => $others
            ]);

            // Log the activity for single item addition
            $logMessage = "Stock Item added: Item Code - $itemCode, Item Name - $itemName";
            logActivity($pdo, $logMessage);

            echo "<script>alert('Data saved successfully!'); window.location.href = 'view_stock_item.php';</script>";
        } catch (PDOException $e) {
            error_log('Database insert error: ' . $e->getMessage());
            echo "<script>alert('Failed to save data. Please try again.');</script>";
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <title>Add Stock Item</title>
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h2 class="mb-0">Add Stock Item</h2>
            </div>
            <div class="card-body">
                <ul class="nav nav-tabs" id="myTab" role="tablist">
                    <li class="nav-item" role="presentation">
                        <a class="nav-link active" id="single-tab" data-bs-toggle="tab" href="#single" role="tab" aria-controls="single" aria-selected="true">Add Single Item</a>
                    </li>
                    <li class="nav-item" role="presentation">
                        <a class="nav-link" id="csv-tab" data-bs-toggle="tab" href="#csv" role="tab" aria-controls="csv" aria-selected="false">CSV Batch Upload</a>
                    </li>
                </ul>
                <div class="tab-content" id="myTabContent">
                    <!-- Single Item Tab -->
                    <div class="tab-pane fade show active" id="single" role="tabpanel" aria-labelledby="single-tab">
                        <form method="POST" class="mt-3">
                            <!-- Stock Item Details Card -->
                            <div class="card mb-3">
                                <div class="card-header">
                                    <h5 class="card-title">Stock Item Details</h5>
                                </div>
                                <div class="card-body">
                                    <div class="row">
                                        <div class="col-md-6">
                                            <div class="form-floating mb-3">
                                                <input type="text" class="form-control" name="item_code" id="item_code" placeholder="Item Code" required>
                                                <label for="item_code">Item Code</label>
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="form-floating mb-3">
                                                <input type="text" class="form-control" name="item_name" id="item_name" placeholder="Item Name" required>
                                                <label for="item_name">Item Name</label>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="row">
                                        <div class="col-md-6">
                                            <div class="form-floating mb-3">
                                                <input type="text" class="form-control" name="uom" id="uom" placeholder="UOM">
                                                <label for="uom">UOM</label>
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="form-floating mb-3">
                                                <select class="form-select" name="item_group" id="item_group" required>
                                                    <option value="" disabled selected>Please select an item group</option>
                                                    <option value="Goods">Goods</option>
                                                    <option value="Licences">Licences</option>
                                                    <option value="Subscriptions">Subscriptions</option>
                                                </select>
                                                <label for="item_group">Item Group</label>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="row">
                                        <div class="col-md-12">
                                            <div class="form-floating mb-3">
                                                <textarea class="form-control" name="description" id="description" placeholder="Description"></textarea>
                                                <label for="description">Description</label>
                                            </div>
                                        </div>
                                        <div class="col-md-12">
                                            <div class="form-floating mb-3">
                                                <textarea class="form-control" name="others" id="others" placeholder="Others"></textarea>
                                                <label for="others">Others</label>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <!-- Submit Button -->
                            <button type="submit" class="btn btn-primary">Save</button>
                        </form>
                    </div>

                    <!-- CSV Batch Upload Tab -->
                    <div class="tab-pane fade" id="csv" role="tabpanel" aria-labelledby="csv-tab">
                        <form method="POST" enctype="multipart/form-data" class="mt-3">
                            <!-- CSV Upload Card -->
                            <div class="card mb-3">
                                <div class="card-header">
                                    <h5 class="card-title">CSV Batch Upload</h5>
                                </div>
                                <div class="card-body">
                                    <div class="form-floating mb-3">
                                        <input type="file" class="form-control" id="csv_file" name="csv_file" accept=".csv" required>
                                        <label for="csv_file">Upload CSV File</label>
                                    </div>
                                    <button type="submit" class="btn btn-primary">Upload and Process</button>
                                </div>
                            </div>
                            <!-- CSV Format Instructions -->
                            <div class="card mb-3">
                                <div class="card-header">
                                    <h5 class="card-title">CSV Format</h5>
                                </div>
                                <div class="card-body">
                                    <p>Your CSV file should have the following columns in this order:</p>
                                    <ol>
                                        <li>Item Code</li>
                                        <li>Item Name</li>
                                        <li>Item Group</li>
                                        <li>UOM</li>
                                    </ol>
                                    <p>The first row should be a header row and will be skipped during import.</p>
                                    <p><strong>Note:</strong> Items with existing item codes will be skipped during the import process.</p>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS CDN with Popper.js -->
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
</body>
</html>