<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php'; // Include the header
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Get the item_code_id from the URL
$itemCodeId = $_GET['item_code_id'] ?? null;

// Fetch the existing item data from the database
$itemData = [];
if ($itemCodeId) {
    $stmt = $pdo->prepare("SELECT * FROM item_code WHERE item_code_id = :item_code_id");
    $stmt->execute([':item_code_id' => $itemCodeId]);
    $itemData = $stmt->fetch(PDO::FETCH_ASSOC);
}

// Handle form submission to update data
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Debugging: Print out the POST data
    error_log(print_r($_POST, true));

    $active = isset($_POST['active']) ? 1 : 0; // Check if the checkbox is checked
    $itemCode = $_POST['item_code_hidden'] ?? null; // Use the hidden field value
    $itemName = $_POST['item_name'] ?? null;
    $description = $_POST['description'] ?? null;
    $itemGroup = $_POST['item_group'] ?? null;
    $uom = $_POST['uom'] ?? null;
    $others = $_POST['others'] ?? null;

    try {
        $stmt = $pdo->prepare("UPDATE item_code SET
            item_code = :item_code,
            active = :active,
            item_name = :item_name,
            description = :description,
            item_group = :item_group,
            uom = :uom,
            others = :others
            WHERE item_code_id = :item_code_id");
        // Execute the update query
        $stmt->execute([
            ':item_code' => $itemCode,
            ':active' => $active,
            ':item_name' => $itemName,
            ':description' => $description,
            ':item_group' => $itemGroup,
            ':uom' => $uom,
            ':others' => $others,
            ':item_code_id' => $itemCodeId
        ]);
        // Success alert and redirect
        echo "<script>alert('Data updated successfully!'); window.location.href = 'view_stock_item.php';</script>";
    } catch (PDOException $e) {
        error_log('Database update error: ' . $e->getMessage());
        echo "<script>alert('Failed to update data. Please try again.');</script>";
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <title>Edit Stock Item</title>
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h2 class="mb-0">Edit Stock Item</h2>
            </div>
            <div class="card-body">
                <form method="POST">
                    <!-- Active Checkbox -->
                    <div class="row mb-3">
                        <div class="col-md-12 d-flex align-items-center">
                            <div class="form-check">
                                <input type="checkbox" class="form-check-input" name="active" id="active" value="1" <?= isset($itemData['active']) && $itemData['active'] == 1 ? 'checked' : '' ?>>
                                <label for="active" class="form-check-label">Active</label>
                            </div>
                        </div>
                    </div>

                    <!-- Stock Item Details Card -->
                    <div class="card mb-3">
                        <div class="card-header">
                            <h5 class="card-title">Stock Item Details</h5>
                        </div>
                        <div class="card-body">
                            <!-- Item Code -->
                            <div class="row mb-3">
                                <div class="col-md-12">
                                    <div class="form-floating">
                                        <input type="text" class="form-control" name="item_code" id="item_code" value="<?= htmlspecialchars($itemData['item_code'] ?? '') ?>" disabled>
                                        <label for="item_code">Item Code</label>
                                    </div>
                                    <input type="hidden" name="item_code_hidden" id="item_code_hidden">
                                </div>
                            </div>

                            <!-- Item Name and UOM -->
                            <div class="row mb-3">
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" class="form-control" name="item_name" id="item_name" value="<?= htmlspecialchars($itemData['item_name'] ?? '') ?>">
                                        <label for="item_name">Item Name</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <input type="text" class="form-control" name="uom" id="uom" value="<?= htmlspecialchars($itemData['uom'] ?? '') ?>">
                                        <label for="uom">UOM</label>
                                    </div>
                                </div>
                            </div>

                            <!-- Description and Item Group -->
                            <div class="row mb-3">
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <textarea class="form-control" name="description" id="description"><?= htmlspecialchars($itemData['description'] ?? '') ?></textarea>
                                        <label for="description">Description</label>
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-floating">
                                        <select class="form-select" name="item_group" id="item_group">
                                            <option value="" disabled>Please select an item group</option>
                                            <option value="Goods" <?= isset($itemData['item_group']) && $itemData['item_group'] == 'Goods' ? 'selected' : '' ?>>Goods</option>
                                            <option value="Licences" <?= isset($itemData['item_group']) && $itemData['item_group'] == 'Licences' ? 'selected' : '' ?>>Licences</option>
                                            <option value="Subscriptions" <?= isset($itemData['item_group']) && $itemData['item_group'] == 'Subscriptions' ? 'selected' : '' ?>>Subscriptions</option>
                                        </select>
                                        <label for="item_group">Item Group</label>
                                    </div>
                                </div>
                            </div>

                            <!-- Others Field -->
                            <div class="row mb-3">
                                <div class="col-md-12">
                                    <div class="form-floating">
                                        <input type="text" class="form-control" name="others" id="others" value="<?= htmlspecialchars($itemData['others'] ?? '') ?>">
                                        <label for="others">Others</label>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Submit Button -->
                    <button type="submit" class="btn btn-primary">Update</button>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS CDN with Popper.js -->
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.min.js"></script>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
        document.getElementById('item_code_hidden').value = document.getElementById('item_code').value;
    });
    </script>
</body>
</html>