<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

$success = false; // Variable to track if the operation was successful
$error = ''; // Variable to hold any error messages

// Fetch item_code and item_name values where item_group = 'subscription'
$stmt = $pdo->prepare("SELECT item_code, item_name FROM item_code WHERE item_group = 'Subscriptions'");
$stmt->execute();
$items = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $startDate = $_POST['start_date'] ?? '';
    $endDate = $_POST['end_date'] ?? '';
    $others = $_POST['others'] ?? '';
    $debtorCode = $_POST['debtor_code'] ?? '';
    $itemCode = $_POST['item_code'] ?? '';
    $duration = $_POST['duration'] ?? '';

    try {
        // Prepare and execute insertion into the subscriptions table
        $stmt = $pdo->prepare('INSERT INTO subscriptions (
            start_date,
            end_date,
            others,
            debtor_code,
            item_code,
            duration
        ) VALUES (
            :start_date,
            :end_date,
            :others,
            :debtor_code,
            :item_code,
            :duration
        )');
        
        $stmt->execute([
            ':start_date' => $startDate,
            ':end_date' => $endDate,
            ':others' => $others,
            ':debtor_code' => $debtorCode,
            ':item_code' => $itemCode,
            ':duration' => $duration
        ]);

        // Success alert and redirect
        echo "<script>alert('Data saved successfully!'); window.location.href = '/crm/public/subscription/add_subscription.php';</script>";
    } catch (PDOException $e) {
        error_log('Database insert error: ' . $e->getMessage());
        echo "<script>alert('Failed to save data. Please try again.');</script>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add Subscription</title>
    <!-- Bootstrap 5.x CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
<div class="container">
    <div class="row justify-content-center">
        <div class="col-md-12">
            <div class="card mt-5">
                <div class="card-header bg-primary text-white">
                    <h3 class="mb-0">Add Subscription Service</h3>
                </div>
                <div class="card-body">
                    <!-- Form starts here -->
                    <form action="" method="POST">
                        <!-- Company Information Card -->
                        <div class="card mb-3">
                            <div class="card-header">
                                <h5 class="mb-0">Company Information</h5>
                            </div>
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <div class="form-floating">
                                            <input type="text" class="form-control" id="company_search" name="company_search" placeholder="Search Company" required>
                                            <label for="company_search">Search Company</label>
                                        </div>
                                    </div>
                                    <div class="col-md-6 mb-3">
                                        <div class="form-floating">
                                            <input type="text" class="form-control" id="debtor_code" name="debtor_code" placeholder="Debtor Code" readonly required>
                                            <label for="debtor_code">Debtor Code</label>
                                        </div>
                                    </div>
                                </div>
                                <div id="company_results" class="mb-3"></div>
                            </div>
                        </div>

                        <!-- Subscription Details Card -->
                        <div class="card mb-3">
                            <div class="card-header">
                                <h5 class="mb-0">Subscription Details</h5>
                            </div>
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <div class="form-floating">
                                            <select class="form-select" id="item_code" name="item_code" required>
                                                <option value="" selected>Select Item Code</option>
                                                <?php foreach ($items as $item): ?>
                                                    <option value="<?= htmlspecialchars($item['item_code']) ?>"><?= htmlspecialchars($item['item_code']) ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                            <label for="item_code">Item Code</label>
                                        </div>
                                    </div>
                                    <div class="col-md-6 mb-3">
                                        <div class="form-floating">
                                            <input type="text" class="form-control" id="item_name" name="item_name" placeholder="Item Name" readonly required>
                                            <label for="item_name">Item Name</label>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <div class="form-floating">
                                            <select class="form-select" id="duration" name="duration" required>
                                                <option value="" selected>Select Duration</option>
                                                <option value="1">1 Month</option>
                                                <option value="3">3 Months</option>
                                                <option value="6">6 Months</option>
                                                <option value="12">1 Year</option>
                                                <option value="18">18 Months</option>
                                            </select>
                                            <label for="duration">Subscription Duration</label>
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6 mb-3">
                                        <div class="form-floating">
                                            <input type="date" class="form-control" id="start_date" name="start_date" placeholder="Start Date" required>
                                            <label for="start_date">Start Date</label>
                                        </div>
                                    </div>
                                    <div class="col-md-6 mb-3">
                                        <div class="form-floating">
                                            <input type="date" class="form-control" id="end_date" name="end_date" placeholder="End Date" readonly required>
                                            <label for="end_date">End Date</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <!-- Additional Information Card -->
                        <div class="card mb-3">
                            <div class="card-header">
                                <h5 class="mb-0">Additional Information</h5>
                            </div>
                            <div class="card-body">
                                <div class="row">
                                    <div class="col-md-12 mb-3">
                                        <div class="form-floating">
                                            <textarea class="form-control" id="others" name="others" placeholder="Others" rows="3" required></textarea>
                                            <label for="others">Others</label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <!-- Submit Button -->
                        <button type="submit" class="btn btn-primary">Add Subscription</button>
                    </form>
                    <!-- Form ends here -->
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Bootstrap 5.x JS CDN -->
<script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.min.js"></script>
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script>
    document.getElementById('item_code').addEventListener('change', function() {
        const selectedItemCode = this.value;
        const selectedItem = <?= json_encode($items) ?>.find(item => item.item_code === selectedItemCode);
        if (selectedItem) {
            document.getElementById('item_name').value = selectedItem.item_name;
        } else {
            document.getElementById('item_name').value = '';
        }
    });

    document.getElementById('company_search').addEventListener('input', function() {
        const query = this.value;
        if (query.length > 2) {
            fetchCompanies(query);
        } else {
            document.getElementById('company_results').innerHTML = '';
        }
    });

    function fetchCompanies(query) {
        fetch('/crm/public/functions/search_company_function.php?q=' + encodeURIComponent(query))
            .then(response => response.text())
            .then(data => {
                document.getElementById('company_results').innerHTML = data;
            });
    }

    function selectCompany(companyName, debtorCode) {
        document.getElementById('company_search').value = companyName;
        document.getElementById('debtor_code').value = debtorCode;
        document.getElementById('company_results').innerHTML = '';
    }

    // Add event listeners for start date and duration selection
    document.getElementById('start_date').addEventListener('change', calculateEndDate);
    document.getElementById('duration').addEventListener('change', calculateEndDate);

    function calculateEndDate() {
        const startDate = document.getElementById('start_date').value;
        const duration = document.getElementById('duration').value;
        
        if (startDate && duration) {
            const start = new Date(startDate);
            const end = new Date(start);
            end.setMonth(end.getMonth() + parseInt(duration));
            // Subtract one day to get correct end date
            end.setDate(end.getDate() - 1);
            
            // Format the date as YYYY-MM-DD
            const endDateStr = end.toISOString().split('T')[0];
            document.getElementById('end_date').value = endDateStr;
        }
    }
</script>

</body>
</html>