<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Get the subscription_id from the query parameter
if (isset($_GET['id'])) {
    $subscription_id = $_GET['id'];
} else {
    echo "<script>alert('No subscription selected.'); window.location.href = 'view_subscription.php';</script>";
    exit();
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $quotation_number = $_POST['quotation_number'];
    $quotation_date = $_POST['quotation_date'];

    // Handle file upload
    $target_dir = "uploads/quotation/";
    if (!file_exists($target_dir)) {
        mkdir($target_dir, 0777, true);
    }
    $target_file = $target_dir . basename($_FILES["pdf_file"]["name"]);
    $uploadOk = 1;
    $fileType = strtolower(pathinfo($target_file, PATHINFO_EXTENSION));

    // Check if file is a PDF
    if ($fileType != "pdf") {
        echo "<script>alert('Only PDF files are allowed.');</script>";
        $uploadOk = 0;
    }

    // Check if file was uploaded successfully
    if ($uploadOk == 1) {
        if (move_uploaded_file($_FILES["pdf_file"]["tmp_name"], $target_file)) {
            // Insert the quotation details into the renewals table
            $insert_sql = "INSERT INTO renewals (subscription_id, quotation_number, quotation_date, pdf_file)
                           VALUES (:subscription_id, :quotation_number, :quotation_date, :pdf_file)";
            $stmt = $pdo->prepare($insert_sql);
            $stmt->bindParam(':subscription_id', $subscription_id, PDO::PARAM_INT);
            $stmt->bindParam(':quotation_number', $quotation_number);
            $stmt->bindParam(':quotation_date', $quotation_date);
            $stmt->bindParam(':pdf_file', $target_file);
            $stmt->execute();

            echo "<script>alert('Quotation created successfully!'); window.location.href = 'view_subscription.php';</script>";
            exit();
        } else {
            echo "<script>alert('Failed to upload PDF file.');</script>";
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add Quotation</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h2 class="mb-0">Add Quotation</h2>
            </div>
            <div class="card-body">
                <form action="create_quotation.php?id=<?= $subscription_id; ?>" method="POST" enctype="multipart/form-data">
                    <div class="mb-3">
                        <label for="quotation_number" class="form-label">Quotation Number</label>
                        <input type="text" id="quotation_number" name="quotation_number" class="form-control" required>
                    </div>
                    <div class="mb-3">
                        <label for="quotation_date" class="form-label">Quotation Date</label>
                        <input type="date" id="quotation_date" name="quotation_date" class="form-control" required>
                    </div>
                    <div class="mb-3">
                        <label for="pdf_file" class="form-label">Upload PDF</label>
                        <input type="file" id="pdf_file" name="pdf_file" class="form-control" accept="application/pdf" required>
                    </div>
                    <button type="submit" class="btn btn-primary">Add Quotation</button>
                </form>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Add Enter key functionality
        document.addEventListener('DOMContentLoaded', function() {
            document.querySelector('form').addEventListener('keypress', function(e) {
                if (e.key === 'Enter') {
                    e.preventDefault();
                    document.querySelector('button[type="submit"]').click();
                }
            });
        });
    </script>
</body>
</html>