<?php
require 'config/auth.php'; // Ensure user is authenticated
require '../layout/header.php';
require '../database/db.php'; // Connect to the database

$success = false;
$error = '';
$id = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $customer_id = $_POST['customer_id'] ?? '';
    $start_date = $_POST['start_date'] ?? '';
    $end_date = $_POST['end_date'] ?? '';
    $invoice_number = $_POST['invoice_number'] ?? '';

    try {
        $stmt = $pdo->prepare('UPDATE subscriptions SET customer_id = :customer_id, start_date = :start_date, end_date = :end_date, invoice_number = :invoice_number WHERE id = :id');
        $stmt->bindParam(':customer_id', $customer_id);
        $stmt->bindParam(':start_date', $start_date);
        $stmt->bindParam(':end_date', $end_date);
        $stmt->bindParam(':invoice_number', $invoice_number);
        $stmt->bindParam(':id', $id);
        $stmt->execute();
        $success = true;
    } catch (PDOException $e) {
        $error = 'Database error: ' . $e->getMessage();
    }
}

if ($id) {
    $stmt = $pdo->prepare('SELECT * FROM subscriptions WHERE id = :id');
    $stmt->execute([':id' => $id]);
    $subscription = $stmt->fetch(PDO::FETCH_ASSOC);
    if (!$subscription) {
        echo "<p>No subscription found.</p>";
        exit();
    }
} else {
    echo "<p>Invalid request.</p>";
    exit();
}

// Fetch customers for dropdown
$customerStmt = $pdo->query('SELECT id, company_name FROM company_info');
$customers = $customerStmt->fetchAll(PDO::FETCH_ASSOC);
?>

<div class="content">
    <h1>Edit Subscription</h1>

    <?php if ($success): ?>
        <p style="color: green;">Subscription updated successfully!</p>
    <?php elseif ($error): ?>
        <p style="color: red;"><?php echo $error; ?></p>
    <?php endif; ?>

    <form method="post" action="">
        <div>
            <label for="service_name">Service Name:</label>
            <input type="text" id="service_name" name="service_name" value="<?php echo htmlspecialchars($subscription['service_name']); ?>" readonly>
        </div>
        <div>
            <label for="customer_id">Customer:</label>
            <select id="customer_id" name="customer_id" required>
                <?php foreach ($customers as $customer): ?>
                    <option value="<?php echo $customer['id']; ?>" <?php echo ($customer['id'] == $subscription['customer_id']) ? 'selected' : ''; ?>>
                        <?php echo htmlspecialchars($customer['company_name']); ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </div>
        <div>
            <label for="start_date">Start Date:</label>
            <input type="date" id="start_date" name="start_date" value="<?php echo htmlspecialchars($subscription['start_date']); ?>" required>
        </div>
        <div>
            <label for="end_date">End Date:</label>
            <input type="date" id="end_date" name="end_date" value="<?php echo htmlspecialchars($subscription['end_date']); ?>" required>
        </div>
        <div>
            <label for="invoice_number">Invoice Number:</label>
            <input type="text" id="invoice_number" name="invoice_number" value="<?php echo htmlspecialchars($subscription['invoice_number']); ?>" required>
        </div>
        <button type="submit">Update Subscription</button>
    </form>
</div>

