<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Modified SQL to include invoice_number, invoice_date, purchase_order, purchase_invoice, or_number, or_date check from renewals table and join with item_code table
$sql = "SELECT s.subscription_id, r.invoice_number, r.invoice_date, c.company_name, r.purchase_order, r.purchase_invoice, r.or_number, r.or_date
        FROM subscriptions s
        LEFT JOIN company_info c ON s.debtor_code = c.debtor_code
        LEFT JOIN renewals r ON s.subscription_id = r.subscription_id
        WHERE r.invoice_number IS NOT NULL AND r.invoice_number != ''
        AND ((r.or_number IS NULL OR r.or_number = '') OR (r.purchase_invoice IS NULL OR r.purchase_invoice = ''))
        GROUP BY s.subscription_id
        ORDER BY s.end_date DESC";

$stmt = $pdo->prepare($sql);
$stmt->execute();
$subscriptions = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Pagination settings
$items_per_page = 5;
$total_items = count($subscriptions);
$total_pages = ceil($total_items / $items_per_page);

// Get the current page from the URL, default to 1
$current_page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$current_page = max(1, min($current_page, $total_pages));

// Calculate the offset
$offset = ($current_page - 1) * $items_per_page;

// Get the current page's data
$subscriptions_page = array_slice($subscriptions, $offset, $items_per_page);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Pending Payment Listing</title>
    <style>
        .hidden {
            display: none;
        }
        .both-empty {
            background-color: #d4edda;  /* Light green for both empty */
        }
        .or-empty {
            background-color: #fff3cd;  /* Light yellow for or_number empty */
        }
        .pi-empty {
            background-color: #f8d7da;  /* Light pink for purchase_invoice empty */
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <h2 class="mb-4">Pending Payment Listing</h2>
        <div class="mb-3">
            <span class="badge bg-success">Both Empty</span>
            <span class="badge bg-warning text-dark">OR Number Empty</span>
            <span class="badge bg-danger">Purchase Invoice Empty</span>
        </div>
        <table class="table table-bordered">
            <thead class="thead-dark">
                <tr>
                    <th>Company Name</th>
                    <th>Invoice Number</th>
                    <th>Invoice Date</th>
                    <th>Action</th>
                </tr>
            </thead>
            <tbody>
                <?php if (!empty($subscriptions_page)): ?>
                    <?php foreach ($subscriptions_page as $row): ?>
                        <?php
                        $or_empty = empty($row['or_number']);
                        $pi_empty = empty($row['purchase_invoice']);
                        
                        // Determine row class based on or_number and purchase_invoice status
                        if ($or_empty && $pi_empty) {
                            $row_class = 'both-empty';
                        } elseif ($or_empty) {
                            $row_class = 'or-empty';
                        } elseif ($pi_empty) {
                            $row_class = 'pi-empty';
                        } else {
                            $row_class = '';
                        }
                        ?>
                        <tr class="<?= $row_class ?>">
                            <td><?= htmlspecialchars($row['company_name']); ?></td>
                            <td><?= htmlspecialchars($row['invoice_number']); ?></td>
                            <td><?= htmlspecialchars($row['invoice_date']); ?></td>
                            <td>
                                <a href="sub_preview.php?id=<?= $row['subscription_id']; ?>" 
                                   class="btn btn-info btn-sm">View</a>
                                <a href="sub_payment.php?id=<?= $row['subscription_id']; ?>" 
                                   class="btn btn-warning btn-sm ml-1">Payment</a>
                                <a href="sub_purchase.php?id=<?= $row['subscription_id']; ?>" 
                                   class="btn btn-success btn-sm ml-1">Purchase</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="4" class="text-center">No pending payment listings found</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>

        <!-- Pagination links -->
        <?php if ($total_pages > 1): ?>
        <nav aria-label="Page navigation">
            <ul class="pagination justify-content-center">
                <?php for ($i = 1; $i <= $total_pages; $i++): ?>
                    <li class="page-item <?= $i == $current_page ? 'active' : ''; ?>">
                        <a class="page-link" href="?page=<?= $i; ?>"><?= $i; ?></a>
                    </li>
                <?php endfor; ?>
            </ul>
        </nav>
        <?php endif; ?>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>