<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Fetch data from the database
$sql = "SELECT company_name, debtor_code FROM company_info";
$stmt = $pdo->query($sql);
$data = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Search Subscriptions</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome CDN for icons -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
        .button-group {
            gap: 10px;
        }
        .hidden {
            display: none;
        }
        .search-container {
            position: relative;
            margin-top: 20px;
        }
        .search-input {
            padding-right: 40px;
        }
        .search-icon {
            position: absolute;
            top: calc(50% + 12px); /* Adjust for label height */
            right: 15px;
            transform: translateY(-50%);
            cursor: pointer;
            color: #6c757d;
            height: 16px; /* Fixed icon height */
            line-height: 1; /* Ensure vertical alignment */
            display: flex; /* Use flex for centering */
            align-items: center;
        }
        .search-conditions {
            border: 1px solid #ccc;
            padding: 20px;
            border-radius: 5px;
            background-color: #f8f9fa;
        }
        .search-conditions .form-group {
            margin-bottom: 15px;
        }
        .search-conditions .form-group label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
            color: #495057;
        }
        .end-date-group {
            display: flex;
            gap: 15px;
            margin-bottom: 15px;
        }
        .end-date-group .form-group {
            flex: 1;
            margin-bottom: 0;
        }
        .main-search-group {
            background-color: #fff;
            padding: 15px;
            border: 1px solid #dee2e6;
            border-radius: 5px;
            margin-top: 20px;
            box-shadow: 0 1px 3px rgba(0,0,0,0.1);
        }
        .main-search-group label {
            font-weight: bold;
            color: #495057;
            margin-bottom: 8px;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h2 class="mb-0">Search Subscriptions</h2>
            </div>
            <div class="card-body">
                <form id="searchForm" class="mb-3">
                    <div class="search-conditions">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="quotationNumber">Quotation Number</label>
                                    <input type="text" id="quotationNumber" name="quotationNumber" class="form-control" placeholder="Quotation Number">
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="invoiceNumber">Invoice Number</label>
                                    <input type="text" id="invoiceNumber" name="invoiceNumber" class="form-control" placeholder="Invoice Number">
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="purchaseOrderNumber">Purchase Order Number</label>
                                    <input type="text" id="purchaseOrderNumber" name="purchaseOrderNumber" class="form-control" placeholder="Purchase Order Number">
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="purchaseInvoiceNumber">Purchase Invoice Number</label>
                                    <input type="text" id="purchaseInvoiceNumber" name="purchaseInvoiceNumber" class="form-control" placeholder="Purchase Invoice Number">
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="form-group">
                                    <label for="orNumber">OR Number</label>
                                    <input type="text" id="orNumber" name="orNumber" class="form-control" placeholder="OR Number">
                                </div>
                            </div>
                            <div class="col-md-6">
                                <label>End Date</label>
                                <div class="end-date-group">
                                    <div class="form-group">
                                        <select id="endDateYear" name="endDateYear" class="form-control">
                                            <option value="">Year</option>
                                            <?php for ($year = date('Y'); $year >= 2000; $year--): ?>
                                                <option value="<?= $year ?>"><?= $year ?></option>
                                            <?php endfor; ?>
                                        </select>
                                    </div>
                                    <div class="form-group">
                                        <select id="endDateMonth" name="endDateMonth" class="form-control">
                                            <option value="">Month</option>
                                            <?php for ($month = 1; $month <= 12; $month++): ?>
                                                <option value="<?= $month ?>"><?= date('F', mktime(0, 0, 0, $month, 1)) ?></option>
                                            <?php endfor; ?>
                                        </select>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="main-search-group">
                        <div class="search-container">
                            <label for="companyName">Company Name</label>
                            <input type="text" id="companyName" name="companyName" class="form-control search-input" placeholder="Search by Company Name">
                            <i class="fas fa-search search-icon" id="searchIcon"></i>
                        </div>
                    </div>
                </form>

                <table class="table table-bordered hidden" id="subscriptionTable">
                    <thead>
                        <tr>
                            <th>Company Name</th>
                            <th>End Date</th>
                            <th>Item Code</th>
                            <th>Action</th>
                        </tr>
                    </thead>
                    <tbody>
                        <!-- Table rows will be populated dynamically -->
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <!-- jQuery and Bootstrap JS CDN -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
    <script>
    $(document).ready(function() {
        $('#searchIcon').on('click', function() {
            var formData = $('#searchForm').serialize();

            $.ajax({
                url: 'search_subscriptions.php',
                type: 'POST',
                data: formData,
                success: function(response) {
                    $('#subscriptionTable tbody').html(response);
                    $('#subscriptionTable').removeClass('hidden');
                }
            });
        });

        $('#companyName').on('keyup', function() {
            var value = $(this).val().toLowerCase();
            $('#subscriptionTable tbody tr').filter(function() {
                $(this).toggle($(this).text().toLowerCase().indexOf(value) > -1)
            });
            if (value.length > 0) {
                $('#subscriptionTable').removeClass('hidden');
            } else {
                $('#subscriptionTable').addClass('hidden');
            }
        });
    });
    </script>
</body>
</html>