<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Get the subscription_id from the query parameter
if (isset($_GET['id'])) {
    $subscription_id = $_GET['id'];
} else {
    echo "<script>alert('No subscription selected.'); window.location.href = 'payment_purchase.php';</script>";
    exit();
}

// Fetch subscription details
$sql = "SELECT s.subscription_id, s.duration, s.end_date, 
               i.item_name, c.company_name, r.purchase_order, r.purchase_invoice, r.or_number, r.or_date
        FROM subscriptions s
        LEFT JOIN company_info c ON s.debtor_code = c.debtor_code
        LEFT JOIN renewals r ON s.subscription_id = r.subscription_id
        LEFT JOIN item_code i ON s.item_code = i.item_code
        WHERE s.subscription_id = :subscription_id";

$stmt = $pdo->prepare($sql);
$stmt->bindParam(':subscription_id', $subscription_id, PDO::PARAM_INT);
$stmt->execute();
$subscription = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$subscription) {
    echo "<script>alert('Subscription not found.'); window.location.href = 'payment_purchase.php';</script>";
    exit();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Subscription Preview</title>
</head>
<body>
    <div class="container mt-5">
        <h2>Subscription Preview</h2>
        <table class="table table-bordered">
            <tbody>
                <tr>
                    <th>Company Name</th>
                    <td><?= htmlspecialchars($subscription['company_name']); ?></td>
                </tr>
                <tr>
                    <th>Duration</th>
                    <td><?= htmlspecialchars($subscription['duration']) . ' Month'; ?></td>
                </tr>
                <tr>
                    <th>End Date</th>
                    <td><?= htmlspecialchars($subscription['end_date']); ?></td>
                </tr>
                <tr>
                    <th>Item Name</th>
                    <td><?= htmlspecialchars($subscription['item_name']); ?></td>
                </tr>
                <tr>
                    <th>Purchase Order</th>
                    <td><?= htmlspecialchars($subscription['purchase_order']); ?></td>
                </tr>
                <tr>
                    <th>Purchase Invoice</th>
                    <td><?= htmlspecialchars($subscription['purchase_invoice']); ?></td>
                </tr>
                <tr>
                    <th>OR Number</th>
                    <td><?= htmlspecialchars($subscription['or_number']); ?></td>
                </tr>
                <tr>
                    <th>OR Date</th>
                    <td><?= htmlspecialchars($subscription['or_date']); ?></td>
                </tr>
            </tbody>
        </table>
        <a href="payment_purchase.php" class="btn btn-secondary">Back</a>
    </div>
</body>
</html>