<?php
require '../config/auth.php'; // Ensure user is authenticated
require '../../layout/header.php';
require '../../database/db.php'; // Connect to the database
date_default_timezone_set('Asia/Kuala_Lumpur');

// Check if the subscription_id is passed in the URL
if (isset($_GET['id'])) {
    $subscription_id = $_GET['id'];

    // Fetch subscription details by subscription_id
    $sql = "SELECT s.subscription_id, s.debtor_code, s.item_code, s.start_date, s.end_date, s.amount,
                   i.item_name
            FROM subscriptions s
            LEFT JOIN item_code i ON s.item_code = i.item_code
            WHERE s.subscription_id = :subscription_id";

    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':subscription_id', $subscription_id, PDO::PARAM_INT);
    $stmt->execute();
    $subscription = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$subscription) {
        echo "<script>alert('No subscription found for this subscription ID.'); window.location.href='search_subscription.php';</script>";
        exit;
    }

    // Fetch renewal details
    $renewal_sql = "SELECT renewal_id, subscription_id, invoice_number, invoice_date, start_date, end_date, 
                           amount, created_at, quotation_number, quotation_date, pdf_file, purchase_order, 
                           purchase_invoice, or_number, or_date, pi_date
                    FROM renewals
                    WHERE subscription_id = :subscription_id
                    ORDER BY created_at DESC";

    $renewal_stmt = $pdo->prepare($renewal_sql);
    $renewal_stmt->bindParam(':subscription_id', $subscription_id, PDO::PARAM_INT);
    $renewal_stmt->execute();
    $renewals = $renewal_stmt->fetchAll(PDO::FETCH_ASSOC);

    // Add this for debugging
    echo "<!-- Debug: " . print_r($renewals, true) . " -->";
} else {
    echo "<script>alert('Invalid request.'); window.location.href='search_subscription.php';</script>";
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>View Subscription Details</title>
    <!-- Bootstrap 5.3 CSS CDN -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        .renewal-card {
            border: 1px solid #ddd;
            border-radius: 8px;
            padding: 15px;
            margin-bottom: 20px;
        }
        .renewal-card h4 {
            margin-top: 0;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="card shadow-lg">
            <div class="card-header bg-primary text-white">
                <h2 class="mb-0">Subscription Details</h2>
            </div>
            <div class="card-body">
                <form>
                    <div class="row mb-3">
                        <label for="subscription_id" class="col-sm-2 col-form-label">Subscription ID</label>
                        <div class="col-sm-10">
                            <input type="text" class="form-control" id="subscription_id" value="<?= htmlspecialchars($subscription['subscription_id']); ?>" readonly>
                        </div>
                    </div>
                    <div class="row mb-3">
                        <label for="debtor_code" class="col-sm-2 col-form-label">Debtor Code</label>
                        <div class="col-sm-10">
                            <input type="text" class="form-control" id="debtor_code" value="<?= htmlspecialchars($subscription['debtor_code']); ?>" readonly>
                        </div>
                    </div>
                    <div class="row mb-3">
                        <label for="item_code" class="col-sm-2 col-form-label">Item Code</label>
                        <div class="col-sm-10">
                            <input type="text" class="form-control" id="item_code" value="<?= htmlspecialchars($subscription['item_code']); ?>" readonly>
                        </div>
                    </div>
                    <div class="row mb-3">
                        <label for="item_name" class="col-sm-2 col-form-label">Item Name</label>
                        <div class="col-sm-10">
                            <input type="text" class="form-control" id="item_name" value="<?= htmlspecialchars($subscription['item_name']); ?>" readonly>
                        </div>
                    </div>
                    <div class="row mb-3">
                        <label for="start_date" class="col-sm-2 col-form-label">Start Date</label>
                        <div class="col-sm-10">
                            <input type="text" class="form-control" id="start_date" value="<?= htmlspecialchars($subscription['start_date']); ?>" readonly>
                        </div>
                    </div>
                    <div class="row mb-3">
                        <label for="end_date" class="col-sm-2 col-form-label">End Date</label>
                        <div class="col-sm-10">
                            <input type="text" class="form-control" id="end_date" value="<?= htmlspecialchars($subscription['end_date']); ?>" readonly>
                        </div>
                    </div>
                    <div class="row mb-3">
                        <label for="amount" class="col-sm-2 col-form-label">Amount</label>
                        <div class="col-sm-10">
                            <input type="text" class="form-control" id="amount" value="<?= htmlspecialchars($subscription['amount']); ?>" readonly>
                        </div>
                    </div>
                </form>

                <h3 class="mt-5 mb-4">Renewal History</h3>
                <?php if (empty($renewals)): ?>
                    <p>No renewal history found for this subscription. (Subscription ID: <?= htmlspecialchars($subscription_id) ?>)</p>
                <?php else: ?>
                    <?php foreach ($renewals as $renewal): ?>
                        <div class="renewal-card">
                            <h4>Renewal ID: <?= htmlspecialchars($renewal['renewal_id']); ?></h4>
                            <div class="row">
                                <div class="col-md-6">
                                    <p><strong>Invoice Number:</strong> <?= htmlspecialchars($renewal['invoice_number']); ?></p>
                                    <p><strong>Invoice Date:</strong> <?= htmlspecialchars($renewal['invoice_date']); ?></p>
                                    <p><strong>Start Date:</strong> <?= htmlspecialchars($renewal['start_date']); ?></p>
                                    <p><strong>End Date:</strong> <?= htmlspecialchars($renewal['end_date']); ?></p>
                                    <p><strong>Amount:</strong> <?= htmlspecialchars($renewal['amount']); ?></p>
                                    <p><strong>Quotation Number:</strong> <?= htmlspecialchars($renewal['quotation_number']); ?></p>
                                    <p><strong>Quotation Date:</strong> <?= htmlspecialchars($renewal['quotation_date']); ?></p>
                                    <p><strong>PDF File:</strong> 
                                        <?php if (!empty($renewal['pdf_file'])): ?>
                                            <a href="<?= htmlspecialchars($renewal['pdf_file']); ?>" target="_blank">View PDF</a>
                                        <?php else: ?>
                                            No PDF file available
                                        <?php endif; ?>
                                    </p>
                                </div>
                                <div class="col-md-6">
                                    <p><strong>Purchase Order:</strong> <?= htmlspecialchars($renewal['purchase_order']); ?></p>
                                    <p><strong>Purchase Invoice:</strong> <?= htmlspecialchars($renewal['purchase_invoice']); ?></p>
                                    <p><strong>OR Number:</strong> <?= htmlspecialchars($renewal['or_number']); ?></p>
                                    <p><strong>OR Date:</strong> <?= htmlspecialchars($renewal['or_date']); ?></p>
                                    <p><strong>PI Date:</strong> <?= htmlspecialchars($renewal['pi_date']); ?></p>
                                    <p><strong>Created At:</strong> <?= htmlspecialchars($renewal['created_at']); ?></p>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                <?php endif; ?>
            </div>
            <div class="card-footer text-center">
                <a href="search_subscription.php" class="btn btn-primary">Back to Search</a>
            </div>
        </div>
    </div>

    <!-- Bootstrap 5.3 JS CDN -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha1/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>